public class AWTEventMulticaster extends Object implements ComponentListener, ContainerListener, FocusListener, KeyListener, MouseListener, MouseMotionListener, WindowListener, WindowFocusListener, ActionListener, ItemListener, InputMethodListener, AdjustmentListener, TextListener, MouseWheelListener
public myComponent extends Component {
ActionListener actionListener = null;
public synchronized void addActionListener(ActionListener l) {
actionListener = AWTEventMulticaster.add(actionListener, l);
}
public synchronized void removeActionListener(ActionListener l) {
actionListener = AWTEventMulticaster.remove(actionListener, l);
}
public void processEvent(AWTEvent e) {
// when event occurs which causes "action" semantic
ActionListener listener = actionListener;
if (listener != null) {
listener.actionPerformed(new ActionEvent());
}
}
}
| Modifier and Type | Field and Description |
|---|---|
protected EventListener |
a |
protected EventListener |
b |
| Modifier | Constructor and Description |
|---|---|
protected |
AWTEventMulticaster(EventListener a,
EventListener b)
Creates an event multicaster instance which chains listener-a
with listener-b.
|
| Modifier and Type | Method and Description |
|---|---|
void |
actionPerformed(ActionEvent e)
Handles the actionPerformed event by invoking the
actionPerformed methods on listener-a and listener-b.
|
static ActionListener |
add(ActionListener a,
ActionListener b)
Adds action-listener-a with action-listener-b and
returns the resulting multicast listener.
|
static AdjustmentListener |
add(AdjustmentListener a,
AdjustmentListener b)
Adds adjustment-listener-a with adjustment-listener-b and
returns the resulting multicast listener.
|
static ComponentListener |
add(ComponentListener a,
ComponentListener b)
Adds component-listener-a with component-listener-b and
returns the resulting multicast listener.
|
static ContainerListener |
add(ContainerListener a,
ContainerListener b)
Adds container-listener-a with container-listener-b and
returns the resulting multicast listener.
|
static FocusListener |
add(FocusListener a,
FocusListener b)
Adds focus-listener-a with focus-listener-b and
returns the resulting multicast listener.
|
static InputMethodListener |
add(InputMethodListener a,
InputMethodListener b)
Adds input-method-listener-a with input-method-listener-b and
returns the resulting multicast listener.
|
static ItemListener |
add(ItemListener a,
ItemListener b)
Adds item-listener-a with item-listener-b and
returns the resulting multicast listener.
|
static KeyListener |
add(KeyListener a,
KeyListener b)
Adds key-listener-a with key-listener-b and
returns the resulting multicast listener.
|
static MouseListener |
add(MouseListener a,
MouseListener b)
Adds mouse-listener-a with mouse-listener-b and
returns the resulting multicast listener.
|
static MouseMotionListener |
add(MouseMotionListener a,
MouseMotionListener b)
Adds mouse-motion-listener-a with mouse-motion-listener-b and
returns the resulting multicast listener.
|
static MouseWheelListener |
add(MouseWheelListener a,
MouseWheelListener b)
Adds mouse-wheel-listener-a with mouse-wheel-listener-b and
returns the resulting multicast listener.
|
static TextListener |
add(TextListener a,
TextListener b) |
static WindowFocusListener |
add(WindowFocusListener a,
WindowFocusListener b)
Adds window-focus-listener-a with window-focus-listener-b
and returns the resulting multicast listener.
|
static WindowListener |
add(WindowListener a,
WindowListener b)
Adds window-listener-a with window-listener-b and
returns the resulting multicast listener.
|
protected static EventListener |
addInternal(EventListener a,
EventListener b)
Returns the resulting multicast listener from adding listener-a
and listener-b together.
|
void |
adjustmentValueChanged(AdjustmentEvent e)
Handles the adjustmentValueChanged event by invoking the
adjustmentValueChanged methods on listener-a and listener-b.
|
void |
caretPositionChanged(InputMethodEvent e)
Handles the caretPositionChanged event by invoking the
caretPositionChanged methods on listener-a and listener-b.
|
void |
componentAdded(ContainerEvent e)
Handles the componentAdded container event by invoking the
componentAdded methods on listener-a and listener-b.
|
void |
componentHidden(ComponentEvent e)
Handles the componentHidden event by invoking the
componentHidden methods on listener-a and listener-b.
|
void |
componentMoved(ComponentEvent e)
Handles the componentMoved event by invoking the
componentMoved methods on listener-a and listener-b.
|
void |
componentRemoved(ContainerEvent e)
Handles the componentRemoved container event by invoking the
componentRemoved methods on listener-a and listener-b.
|
void |
componentResized(ComponentEvent e)
Handles the componentResized event by invoking the
componentResized methods on listener-a and listener-b.
|
void |
componentShown(ComponentEvent e)
Handles the componentShown event by invoking the
componentShown methods on listener-a and listener-b.
|
void |
focusGained(FocusEvent e)
Handles the focusGained event by invoking the
focusGained methods on listener-a and listener-b.
|
void |
focusLost(FocusEvent e)
Handles the focusLost event by invoking the
focusLost methods on listener-a and listener-b.
|
static EventListener[] |
getListeners(EventListener l,
Class listenerType)
Returns an array of all the objects chained as
FooListeners by the specified
java.util.EventListener. |
void |
inputMethodTextChanged(InputMethodEvent e)
Handles the inputMethodTextChanged event by invoking the
inputMethodTextChanged methods on listener-a and listener-b.
|
void |
itemStateChanged(ItemEvent e)
Handles the itemStateChanged event by invoking the
itemStateChanged methods on listener-a and listener-b.
|
void |
keyPressed(KeyEvent e)
Handles the keyPressed event by invoking the
keyPressed methods on listener-a and listener-b.
|
void |
keyReleased(KeyEvent e)
Handles the keyReleased event by invoking the
keyReleased methods on listener-a and listener-b.
|
void |
keyTyped(KeyEvent e)
Handles the keyTyped event by invoking the
keyTyped methods on listener-a and listener-b.
|
void |
mouseClicked(MouseEvent e)
Handles the mouseClicked event by invoking the
mouseClicked methods on listener-a and listener-b.
|
void |
mouseDragged(MouseEvent e)
Handles the mouseDragged event by invoking the
mouseDragged methods on listener-a and listener-b.
|
void |
mouseEntered(MouseEvent e)
Handles the mouseEntered event by invoking the
mouseEntered methods on listener-a and listener-b.
|
void |
mouseExited(MouseEvent e)
Handles the mouseExited event by invoking the
mouseExited methods on listener-a and listener-b.
|
void |
mouseMoved(MouseEvent e)
Handles the mouseMoved event by invoking the
mouseMoved methods on listener-a and listener-b.
|
void |
mousePressed(MouseEvent e)
Handles the mousePressed event by invoking the
mousePressed methods on listener-a and listener-b.
|
void |
mouseReleased(MouseEvent e)
Handles the mouseReleased event by invoking the
mouseReleased methods on listener-a and listener-b.
|
void |
mouseWheelMoved(MouseWheelEvent e)
Handles the mouseWheelMoved event by invoking the
mouseWheelMoved methods on listener-a and listener-b.
|
static ActionListener |
remove(ActionListener l,
ActionListener oldl)
Removes the old action-listener from action-listener-l and
returns the resulting multicast listener.
|
static AdjustmentListener |
remove(AdjustmentListener l,
AdjustmentListener oldl)
Removes the old adjustment-listener from adjustment-listener-l and
returns the resulting multicast listener.
|
static ComponentListener |
remove(ComponentListener l,
ComponentListener oldl)
Removes the old component-listener from component-listener-l and
returns the resulting multicast listener.
|
static ContainerListener |
remove(ContainerListener l,
ContainerListener oldl)
Removes the old container-listener from container-listener-l and
returns the resulting multicast listener.
|
protected EventListener |
remove(EventListener oldl)
Removes a listener from this multicaster and returns the
resulting multicast listener.
|
static FocusListener |
remove(FocusListener l,
FocusListener oldl)
Removes the old focus-listener from focus-listener-l and
returns the resulting multicast listener.
|
static InputMethodListener |
remove(InputMethodListener l,
InputMethodListener oldl)
Removes the old input-method-listener from input-method-listener-l and
returns the resulting multicast listener.
|
static ItemListener |
remove(ItemListener l,
ItemListener oldl)
Removes the old item-listener from item-listener-l and
returns the resulting multicast listener.
|
static KeyListener |
remove(KeyListener l,
KeyListener oldl)
Removes the old key-listener from key-listener-l and
returns the resulting multicast listener.
|
static MouseListener |
remove(MouseListener l,
MouseListener oldl)
Removes the old mouse-listener from mouse-listener-l and
returns the resulting multicast listener.
|
static MouseMotionListener |
remove(MouseMotionListener l,
MouseMotionListener oldl)
Removes the old mouse-motion-listener from mouse-motion-listener-l
and returns the resulting multicast listener.
|
static MouseWheelListener |
remove(MouseWheelListener l,
MouseWheelListener oldl)
Removes the old mouse-wheel-listener from mouse-wheel-listener-l
and returns the resulting multicast listener.
|
static TextListener |
remove(TextListener l,
TextListener oldl) |
static WindowFocusListener |
remove(WindowFocusListener l,
WindowFocusListener oldl)
Removes the old window-focus-listener from window-focus-listener-l
and returns the resulting multicast listener.
|
static WindowListener |
remove(WindowListener l,
WindowListener oldl)
Removes the old window-listener from window-listener-l and
returns the resulting multicast listener.
|
protected static EventListener |
removeInternal(EventListener l,
EventListener oldl)
Returns the resulting multicast listener after removing the
old listener from listener-l.
|
protected static void |
save(ObjectOutputStream s,
String k,
EventListener l) |
protected void |
saveInternal(ObjectOutputStream s,
String k) |
void |
textValueChanged(TextEvent e)
Invoked when the value of the text has changed.
|
void |
windowActivated(WindowEvent e)
Handles the windowActivated event by invoking the
windowActivated methods on listener-a and listener-b.
|
void |
windowClosed(WindowEvent e)
Handles the windowClosed event by invoking the
windowClosed methods on listener-a and listener-b.
|
void |
windowClosing(WindowEvent e)
Handles the windowClosing event by invoking the
windowClosing methods on listener-a and listener-b.
|
void |
windowDeactivated(WindowEvent e)
Handles the windowDeactivated event by invoking the
windowDeactivated methods on listener-a and listener-b.
|
void |
windowDeiconified(WindowEvent e)
Handles the windowDeiconfied event by invoking the
windowDeiconified methods on listener-a and listener-b.
|
void |
windowGainedFocus(WindowEvent e)
Handles the windowGainedFocus event by invoking the windowGainedFocus
methods on listener-a and listener-b.
|
void |
windowIconified(WindowEvent e)
Handles the windowIconified event by invoking the
windowIconified methods on listener-a and listener-b.
|
void |
windowLostFocus(WindowEvent e)
Handles the windowLostFocus event by invoking the windowLostFocus
methods on listener-a and listener-b.
|
void |
windowOpened(WindowEvent e)
Handles the windowOpened event by invoking the
windowOpened methods on listener-a and listener-b.
|
protected final EventListener a
protected final EventListener b
protected AWTEventMulticaster(EventListener a, EventListener b)
a and b
should not be null, though implementations may vary in
choosing whether or not to throw NullPointerException
in that case.a - listener-ab - listener-bprotected EventListener remove(EventListener oldl)
oldl - the listener to be removedpublic void componentResized(ComponentEvent e)
componentResized in interface ComponentListenere - the component eventpublic void componentMoved(ComponentEvent e)
componentMoved in interface ComponentListenere - the component eventpublic void componentShown(ComponentEvent e)
componentShown in interface ComponentListenere - the component eventpublic void componentHidden(ComponentEvent e)
componentHidden in interface ComponentListenere - the component eventpublic void componentAdded(ContainerEvent e)
componentAdded in interface ContainerListenere - the component eventpublic void componentRemoved(ContainerEvent e)
componentRemoved in interface ContainerListenere - the component eventpublic void focusGained(FocusEvent e)
focusGained in interface FocusListenere - the focus eventpublic void focusLost(FocusEvent e)
focusLost in interface FocusListenere - the focus eventpublic void keyTyped(KeyEvent e)
keyTyped in interface KeyListenere - the key eventpublic void keyPressed(KeyEvent e)
keyPressed in interface KeyListenere - the key eventpublic void keyReleased(KeyEvent e)
keyReleased in interface KeyListenere - the key eventpublic void mouseClicked(MouseEvent e)
mouseClicked in interface MouseListenere - the mouse eventpublic void mousePressed(MouseEvent e)
mousePressed in interface MouseListenere - the mouse eventpublic void mouseReleased(MouseEvent e)
mouseReleased in interface MouseListenere - the mouse eventpublic void mouseEntered(MouseEvent e)
mouseEntered in interface MouseListenere - the mouse eventpublic void mouseExited(MouseEvent e)
mouseExited in interface MouseListenere - the mouse eventpublic void mouseDragged(MouseEvent e)
mouseDragged in interface MouseMotionListenere - the mouse eventpublic void mouseMoved(MouseEvent e)
mouseMoved in interface MouseMotionListenere - the mouse eventpublic void windowOpened(WindowEvent e)
windowOpened in interface WindowListenere - the window eventpublic void windowClosing(WindowEvent e)
windowClosing in interface WindowListenere - the window eventpublic void windowClosed(WindowEvent e)
windowClosed in interface WindowListenere - the window eventpublic void windowIconified(WindowEvent e)
windowIconified in interface WindowListenere - the window eventFrame.setIconImage(java.awt.Image)public void windowDeiconified(WindowEvent e)
windowDeiconified in interface WindowListenere - the window eventpublic void windowActivated(WindowEvent e)
windowActivated in interface WindowListenere - the window eventpublic void windowDeactivated(WindowEvent e)
windowDeactivated in interface WindowListenere - the window eventpublic void windowGainedFocus(WindowEvent e)
windowGainedFocus in interface WindowFocusListenere - the window eventpublic void windowLostFocus(WindowEvent e)
windowLostFocus in interface WindowFocusListenere - the window eventpublic void actionPerformed(ActionEvent e)
actionPerformed in interface ActionListenere - the action eventpublic void itemStateChanged(ItemEvent e)
itemStateChanged in interface ItemListenere - the item eventpublic void adjustmentValueChanged(AdjustmentEvent e)
adjustmentValueChanged in interface AdjustmentListenere - the adjustment eventpublic void textValueChanged(TextEvent e)
TextListenertextValueChanged in interface TextListenerpublic void inputMethodTextChanged(InputMethodEvent e)
inputMethodTextChanged in interface InputMethodListenere - the item eventpublic void caretPositionChanged(InputMethodEvent e)
caretPositionChanged in interface InputMethodListenere - the item eventpublic void mouseWheelMoved(MouseWheelEvent e)
mouseWheelMoved in interface MouseWheelListenere - the mouse eventMouseWheelEventpublic static ComponentListener add(ComponentListener a, ComponentListener b)
a - component-listener-ab - component-listener-bpublic static ContainerListener add(ContainerListener a, ContainerListener b)
a - container-listener-ab - container-listener-bpublic static FocusListener add(FocusListener a, FocusListener b)
a - focus-listener-ab - focus-listener-bpublic static KeyListener add(KeyListener a, KeyListener b)
a - key-listener-ab - key-listener-bpublic static MouseListener add(MouseListener a, MouseListener b)
a - mouse-listener-ab - mouse-listener-bpublic static MouseMotionListener add(MouseMotionListener a, MouseMotionListener b)
a - mouse-motion-listener-ab - mouse-motion-listener-bpublic static WindowListener add(WindowListener a, WindowListener b)
a - window-listener-ab - window-listener-bpublic static WindowFocusListener add(WindowFocusListener a, WindowFocusListener b)
a - window-focus-listener-ab - window-focus-listener-bpublic static ActionListener add(ActionListener a, ActionListener b)
a - action-listener-ab - action-listener-bpublic static ItemListener add(ItemListener a, ItemListener b)
a - item-listener-ab - item-listener-bpublic static AdjustmentListener add(AdjustmentListener a, AdjustmentListener b)
a - adjustment-listener-ab - adjustment-listener-bpublic static TextListener add(TextListener a, TextListener b)
public static InputMethodListener add(InputMethodListener a, InputMethodListener b)
a - input-method-listener-ab - input-method-listener-bpublic static MouseWheelListener add(MouseWheelListener a, MouseWheelListener b)
a - mouse-wheel-listener-ab - mouse-wheel-listener-bpublic static ComponentListener remove(ComponentListener l, ComponentListener oldl)
l - component-listener-loldl - the component-listener being removedpublic static ContainerListener remove(ContainerListener l, ContainerListener oldl)
l - container-listener-loldl - the container-listener being removedpublic static FocusListener remove(FocusListener l, FocusListener oldl)
l - focus-listener-loldl - the focus-listener being removedpublic static KeyListener remove(KeyListener l, KeyListener oldl)
l - key-listener-loldl - the key-listener being removedpublic static MouseListener remove(MouseListener l, MouseListener oldl)
l - mouse-listener-loldl - the mouse-listener being removedpublic static MouseMotionListener remove(MouseMotionListener l, MouseMotionListener oldl)
l - mouse-motion-listener-loldl - the mouse-motion-listener being removedpublic static WindowListener remove(WindowListener l, WindowListener oldl)
l - window-listener-loldl - the window-listener being removedpublic static WindowFocusListener remove(WindowFocusListener l, WindowFocusListener oldl)
l - window-focus-listener-loldl - the window-focus-listener being removedpublic static ActionListener remove(ActionListener l, ActionListener oldl)
l - action-listener-loldl - the action-listener being removedpublic static ItemListener remove(ItemListener l, ItemListener oldl)
l - item-listener-loldl - the item-listener being removedpublic static AdjustmentListener remove(AdjustmentListener l, AdjustmentListener oldl)
l - adjustment-listener-loldl - the adjustment-listener being removedpublic static TextListener remove(TextListener l, TextListener oldl)
public static InputMethodListener remove(InputMethodListener l, InputMethodListener oldl)
l - input-method-listener-loldl - the input-method-listener being removedpublic static MouseWheelListener remove(MouseWheelListener l, MouseWheelListener oldl)
l - mouse-wheel-listener-loldl - the mouse-wheel-listener being removedprotected static EventListener addInternal(EventListener a, EventListener b)
a - event listener-ab - event listener-bprotected static EventListener removeInternal(EventListener l, EventListener oldl)
l - the listener being removed fromoldl - the listener being removedprotected void saveInternal(ObjectOutputStream s, String k) throws IOException
IOExceptionprotected static void save(ObjectOutputStream s, String k, EventListener l) throws IOException
IOExceptionpublic static EventListener[] getListeners(EventListener l, Class listenerType)
FooListeners by the specified
java.util.EventListener.
FooListeners are chained by the
AWTEventMulticaster using the
addFooListener method.
If a null listener is specified, this method returns an
empty array. If the specified listener is not an instance of
AWTEventMulticaster, this method returns an array which
contains only the specified listener. If no such listeners are chanined,
this method returns an empty array.l - the specified java.util.EventListenerlistenerType - the type of listeners requested; this parameter
should specify an interface that descends from
java.util.EventListenerFooListeners by the specified multicast
listener, or an empty array if no such listeners have been
chained by the specified multicast listenerClassCastException - if listenerType
doesn't specify a class or interface that implements
java.util.EventListenerCopyright © 2013 CableLabs. All rights reserved.