public class BorderLayout extends Object implements LayoutManager2, Serializable
NORTH, SOUTH, EAST,
WEST, and CENTER. When adding a
component to a container with a border layout, use one of these
five constants, for example:
Note: The following code examples include classes that do not appear in this specification. Their inclusion is purely to serve as a demonstration.
Panel p = new Panel();
p.setLayout(new BorderLayout());
p.add(new Button("Okay"), BorderLayout.SOUTH);
As a convenience, BorderLayout interprets the
absence of a string specification the same as the constant
CENTER:
Panel p2 = new Panel();
p2.setLayout(new BorderLayout());
p2.add(new TextArea()); // Same as p.add(new TextArea(), BorderLayout.CENTER);
The components are laid out according to their
preferred sizes and the constraints of the container's size.
The NORTH and SOUTH components may
be stretched horizontally; the EAST and
WEST components may be stretched vertically;
the CENTER component may stretch both horizontally
and vertically to fill any space left over.
Here is an example of five buttons in an applet laid out using
the BorderLayout layout manager:
The code for this applet is as follows:
import java.awt.*;
import java.applet.Applet;
public class buttonDir extends Applet {
public void init() {
setLayout(new BorderLayout());
add(new Button("North"), BorderLayout.NORTH);
add(new Button("South"), BorderLayout.SOUTH);
add(new Button("East"), BorderLayout.EAST);
add(new Button("West"), BorderLayout.WEST);
add(new Button("Center"), BorderLayout.CENTER);
}
}
,
Serialized Form| Modifier and Type | Field and Description |
|---|---|
static String |
CENTER
The center layout constraint (middle of container).
|
static String |
EAST
The east layout constraint (right side of container).
|
static String |
NORTH
The north layout constraint (top of container).
|
static String |
SOUTH
The south layout constraint (bottom of container).
|
static String |
WEST
The west layout constraint (left side of container).
|
| Constructor and Description |
|---|
BorderLayout()
Constructs a new border layout with
no gaps between components.
|
BorderLayout(int hgap,
int vgap)
Constructs a border layout with the specified gaps
between components.
|
| Modifier and Type | Method and Description |
|---|---|
void |
addLayoutComponent(Component comp,
Object constraints)
Adds the specified component to the layout, using the specified
constraint object.
|
void |
addLayoutComponent(String name,
Component comp)
Deprecated.
replaced by
addLayoutComponent(Component, Object). |
int |
getHgap()
Returns the horizontal gap between components.
|
float |
getLayoutAlignmentX(Container parent)
Returns the alignment along the x axis.
|
float |
getLayoutAlignmentY(Container parent)
Returns the alignment along the y axis.
|
int |
getVgap()
Returns the vertical gap between components.
|
void |
invalidateLayout(Container target)
Invalidates the layout, indicating that if the layout manager
has cached information it should be discarded.
|
void |
layoutContainer(Container target)
Lays out the container argument using this border layout.
|
Dimension |
maximumLayoutSize(Container target)
Returns the maximum dimensions for this layout given the components
in the specified target container.
|
Dimension |
minimumLayoutSize(Container target)
Determines the minimum size of the
target container
using this layout manager. |
Dimension |
preferredLayoutSize(Container target)
Determines the preferred size of the
target
container using this layout manager, based on the components
in the container. |
void |
removeLayoutComponent(Component comp)
Removes the specified component from this border layout.
|
void |
setHgap(int hgap)
Sets the horizontal gap between components.
|
void |
setVgap(int vgap)
Sets the vertical gap between components.
|
String |
toString()
Returns a string representation of the state of this border layout.
|
public static final String NORTH
public static final String SOUTH
public static final String EAST
public static final String WEST
public static final String CENTER
public BorderLayout()
public BorderLayout(int hgap,
int vgap)
hgap
and the vertical gap is specified by vgap.hgap - the horizontal gap.vgap - the vertical gap.public int getHgap()
public void setHgap(int hgap)
hgap - the horizontal gap between componentspublic int getVgap()
public void setVgap(int vgap)
vgap - the vertical gap between componentspublic void addLayoutComponent(Component comp, Object constraints)
NORTH,
SOUTH, EAST,
WEST, or CENTER.
Most applications do not call this method directly. This method
is called when a component is added to a container using the
Container.add method with the same argument types.
addLayoutComponent in interface LayoutManager2comp - the component to be added.constraints - an object that specifies how and where
the component is added to the layout.IllegalArgumentException - if the constraint object is not
a string, or if it not one of the five specified
constants.Container.add(java.awt.Component, java.lang.Object)public void addLayoutComponent(String name, Component comp)
addLayoutComponent(Component, Object).LayoutManagercomp to the layout,
associating it
with the string specified by name.addLayoutComponent in interface LayoutManagername - the string to be associated with the componentcomp - the component to be addedpublic void removeLayoutComponent(Component comp)
remove or
removeAll methods. Most applications do not call this
method directly.removeLayoutComponent in interface LayoutManagercomp - the component to be removed.Container.remove(java.awt.Component),
Container.removeAll()public Dimension minimumLayoutSize(Container target)
target container
using this layout manager.
This method is called when a container calls its
getMinimumSize method. Most applications do not call
this method directly.
minimumLayoutSize in interface LayoutManagertarget - the container in which to do the layout.Container,
preferredLayoutSize(java.awt.Container),
Container.getMinimumSize()public Dimension preferredLayoutSize(Container target)
target
container using this layout manager, based on the components
in the container.
Most applications do not call this method directly. This method
is called when a container calls its getPreferredSize
method.
preferredLayoutSize in interface LayoutManagertarget - the container in which to do the layout.Container,
minimumLayoutSize(java.awt.Container),
Container.getPreferredSize()public Dimension maximumLayoutSize(Container target)
maximumLayoutSize in interface LayoutManager2target - the component which needs to be laid outContainer,
minimumLayoutSize(java.awt.Container),
preferredLayoutSize(java.awt.Container)public float getLayoutAlignmentX(Container parent)
getLayoutAlignmentX in interface LayoutManager2public float getLayoutAlignmentY(Container parent)
getLayoutAlignmentY in interface LayoutManager2public void invalidateLayout(Container target)
invalidateLayout in interface LayoutManager2public void layoutContainer(Container target)
This method actually reshapes the components in the specified
container in order to satisfy the constraints of this
BorderLayout object. The NORTH
and SOUTH components, if any, are placed at
the top and bottom of the container, respectively. The
WEST and EAST components are
then placed on the left and right, respectively. Finally,
the CENTER object is placed in any remaining
space in the middle.
Most applications do not call this method directly. This method
is called when a container calls its doLayout method.
layoutContainer in interface LayoutManagertarget - the container in which to do the layout.Container,
Container.doLayout()Copyright © 2013 CableLabs. All rights reserved.