public class ContainerOrderFocusTraversalPolicy extends FocusTraversalPolicy implements Serializable
Container.getComponents(). Portions of the hierarchy that are
not visible and displayable will not be searched.
By default, ContainerOrderFocusTraversalPolicy implicitly transfers focus
down-cycle. That is, during normal forward focus traversal, the Component
traversed after a focus cycle root will be the focus-cycle-root's default
Component to focus. This behavior can be disabled using the
setImplicitDownCycleTraversal method.
By default, methods of this class with return a Component only if it is
visible, displayable, enabled, and focusable. Subclasses can modify this
behavior by overriding the accept method.
Container.getComponents(),
Serialized Form| Constructor and Description |
|---|
ContainerOrderFocusTraversalPolicy() |
| Modifier and Type | Method and Description |
|---|---|
protected boolean |
accept(Component aComponent)
Determines whether a Component is an acceptable choice as the new
focus owner.
|
Component |
getComponentAfter(Container focusCycleRoot,
Component aComponent)
Returns the Component that should receive the focus after aComponent.
|
Component |
getComponentBefore(Container focusCycleRoot,
Component aComponent)
Returns the Component that should receive the focus before aComponent.
|
Component |
getDefaultComponent(Container focusCycleRoot)
Returns the default Component to focus.
|
Component |
getFirstComponent(Container focusCycleRoot)
Returns the first Component in the traversal cycle.
|
boolean |
getImplicitDownCycleTraversal()
Returns whether this ContainerOrderFocusTraversalPolicy transfers focus
down-cycle implicitly.
|
Component |
getLastComponent(Container focusCycleRoot)
Returns the last Component in the traversal cycle.
|
void |
setImplicitDownCycleTraversal(boolean implicitDownCycleTraversal)
Sets whether this ContainerOrderFocusTraversalPolicy transfers focus
down-cycle implicitly.
|
getInitialComponentpublic Component getComponentAfter(Container focusCycleRoot, Component aComponent)
By default, ContainerOrderFocusTraversalPolicy implicitly transfers
focus down-cycle. That is, during normal forward focus traversal, the
Component traversed after a focus cycle root will be the focus-cycle-
root's default Component to focus. This behavior can be disabled using
the setImplicitDownCycleTraversal method.
getComponentAfter in class FocusTraversalPolicyfocusCycleRoot - a focus cycle root of aComponentaComponent - a (possibly indirect) child of focusCycleRoot, or
focusCycleRoot itselfIllegalArgumentException - if focusCycleRoot is not a focus cycle
root of aComponent, or if either focusCycleRoot or aComponent is
nullpublic Component getComponentBefore(Container focusCycleRoot, Component aComponent)
getComponentBefore in class FocusTraversalPolicyfocusCycleRoot - a focus cycle root of aComponentaComponent - a (possibly indirect) child of focusCycleRoot, or
focusCycleRoot itselfIllegalArgumentException - if focusCycleRoot is not a focus cycle
root of aComponent, or if either focusCycleRoot or aComponent is
nullpublic Component getFirstComponent(Container focusCycleRoot)
getFirstComponent in class FocusTraversalPolicyfocusCycleRoot - the focus cycle root whose first Component is to
be returnedIllegalArgumentException - if focusCycleRoot is nullpublic Component getLastComponent(Container focusCycleRoot)
getLastComponent in class FocusTraversalPolicyfocusCycleRoot - the focus cycle root whose last Component is to be
returnedIllegalArgumentException - if focusCycleRoot is nullpublic Component getDefaultComponent(Container focusCycleRoot)
getFirstComponent.getDefaultComponent in class FocusTraversalPolicyfocusCycleRoot - the focus cycle root whose default Component is to
be returnedIllegalArgumentException - if focusCycleRoot is nullgetFirstComponent(java.awt.Container)public void setImplicitDownCycleTraversal(boolean implicitDownCycleTraversal)
true, during normal forward focus
traversal, the Component traversed after a focus cycle root will be the
focus-cycle-root's default Component to focus. If false,
the next Component in the focus traversal cycle rooted at the specified
focus cycle root will be traversed instead. The default value for this
property is true.implicitDownCycleTraversal - whether this
ContainerOrderFocusTraversalPolicy transfers focus down-cycle
implicitlygetImplicitDownCycleTraversal(),
getFirstComponent(java.awt.Container)public boolean getImplicitDownCycleTraversal()
true, during normal forward focus
traversal, the Component traversed after a focus cycle root will be the
focus-cycle-root's default Component to focus. If false,
the next Component in the focus traversal cycle rooted at the specified
focus cycle root will be traversed instead.setImplicitDownCycleTraversal(boolean),
getFirstComponent(java.awt.Container)protected boolean accept(Component aComponent)
aComponent - the Component whose fitness as a focus owner is to
be testedtrue if aComponent is visible, displayable,
enabled, and focusable; false otherwiseCopyright © 2012. All Rights Reserved.