public class FlowLayout extends Object implements LayoutManager, Serializable
For example, the following picture shows an applet using the flow layout manager (its default layout manager) to position three buttons:
Here is the code for this applet:
Note: The following code example includes classes that do not appear in this specification. Their inclusion is purely to serve as a demonstration.
import java.awt.*;
import java.applet.Applet;
public class myButtons extends Applet {
Button button1, button2, button3;
public void init() {
button1 = new Button("Ok");
button2 = new Button("Open");
button3 = new Button("Close");
add(button1);
add(button2);
add(button3);
}
}
A flow layout lets each component assume its natural (preferred) size.
| Modifier and Type | Field and Description |
|---|---|
static int |
CENTER
This value indicates that each row of components
should be centered.
|
static int |
LEFT
This value indicates that each row of components
should be left-justified.
|
static int |
RIGHT
This value indicates that each row of components
should be right-justified.
|
| Constructor and Description |
|---|
FlowLayout()
Constructs a new
FlowLayout with a centered alignment and a
default 5-unit horizontal and vertical gap. |
FlowLayout(int align)
Constructs a new
FlowLayout with the specified
alignment and a default 5-unit horizontal and vertical gap. |
FlowLayout(int align,
int hgap,
int vgap)
Creates a new flow layout manager with the indicated alignment
and the indicated horizontal and vertical gaps.
|
| Modifier and Type | Method and Description |
|---|---|
void |
addLayoutComponent(String name,
Component comp)
Adds the specified component to the layout.
|
int |
getAlignment()
Gets the alignment for this layout.
|
int |
getHgap()
Gets the horizontal gap between components.
|
int |
getVgap()
Gets the vertical gap between components.
|
void |
layoutContainer(Container target)
Lays out the container.
|
Dimension |
minimumLayoutSize(Container target)
Returns the minimum dimensions needed to layout the visible
components contained in the specified target container.
|
Dimension |
preferredLayoutSize(Container target)
Returns the preferred dimensions for this layout given the
visible components in the specified target container.
|
void |
removeLayoutComponent(Component comp)
Removes the specified component from the layout.
|
void |
setAlignment(int align)
Sets the alignment for this layout.
|
void |
setHgap(int hgap)
Sets the horizontal gap between components.
|
void |
setVgap(int vgap)
Sets the vertical gap between components.
|
String |
toString()
Returns a string representation of this
FlowLayout
object and its values. |
public static final int LEFT
public static final int CENTER
public static final int RIGHT
public FlowLayout()
FlowLayout with a centered alignment and a
default 5-unit horizontal and vertical gap.public FlowLayout(int align)
FlowLayout with the specified
alignment and a default 5-unit horizontal and vertical gap.
The value of the alignment argument must be one of
FlowLayout.LEFT, FlowLayout.RIGHT,
or FlowLayout.CENTER.align - the alignment valuepublic FlowLayout(int align,
int hgap,
int vgap)
The value of the alignment argument must be one of
FlowLayout.LEFT, FlowLayout.RIGHT,
or FlowLayout.CENTER.
align - the alignment valuehgap - the horizontal gap between componentsvgap - the vertical gap between componentspublic int getAlignment()
FlowLayout.LEFT,
FlowLayout.RIGHT, FlowLayout.CENTER,setAlignment(int)public void setAlignment(int align)
FlowLayout.LEFT
FlowLayout.RIGHT
FlowLayout.CENTER
align - one of the alignment values shown abovegetAlignment()public int getHgap()
setHgap(int)public void setHgap(int hgap)
hgap - the horizontal gap between componentsgetHgap()public int getVgap()
setVgap(int)public void setVgap(int vgap)
vgap - the vertical gap between componentsgetVgap()public void addLayoutComponent(String name, Component comp)
addLayoutComponent in interface LayoutManagername - the name of the componentcomp - the component to be addedpublic void removeLayoutComponent(Component comp)
removeLayoutComponent in interface LayoutManagercomp - the component to removeContainer.removeAll()public Dimension preferredLayoutSize(Container target)
preferredLayoutSize in interface LayoutManagertarget - the component which needs to be laid outContainer,
minimumLayoutSize(java.awt.Container),
Container.getPreferredSize()public Dimension minimumLayoutSize(Container target)
minimumLayoutSize in interface LayoutManagertarget - the component which needs to be laid outpreferredLayoutSize(java.awt.Container),
Container,
Container.doLayout()public void layoutContainer(Container target)
FlowLayout object.layoutContainer in interface LayoutManagertarget - the specified component being laid outContainer,
Container.doLayout()Copyright © 2013 CableLabs. All rights reserved.