public abstract class GraphicsEnvironment extends Object
GraphicsEnvironment class describes the collection
of GraphicsDevice objects and Font objects
available to a Java(tm) application on a particular platform.
The resources in this GraphicsEnvironment might be local
or on a remote machine. GraphicsDevice objects can be
screens, printers or image buffers and are the destination of
Graphics2D drawing methods. Each GraphicsDevice
has a number of GraphicsConfiguration objects associated with
it. These objects specify the different configurations in which the
GraphicsDevice can be used.GraphicsDevice,
GraphicsConfiguration| Modifier | Constructor and Description |
|---|---|
protected |
GraphicsEnvironment()
This is an abstract class and cannot be instantiated directly.
|
| Modifier and Type | Method and Description |
|---|---|
abstract Graphics2D |
createGraphics(BufferedImage img)
Returns a
Graphics2D object for rendering into the
specified BufferedImage. |
abstract String[] |
getAvailableFontFamilyNames()
Returns an array containing the names of all font families available
in this
GraphicsEnvironment. |
abstract String[] |
getAvailableFontFamilyNames(Locale l)
Returns an array containing the localized names of all font families
available in this
GraphicsEnvironment. |
abstract GraphicsDevice |
getDefaultScreenDevice()
Returns the default screen
GraphicsDevice. |
static GraphicsEnvironment |
getLocalGraphicsEnvironment()
Returns the local
GraphicsEnvironment. |
abstract GraphicsDevice[] |
getScreenDevices()
Returns an array of all of the screen
GraphicsDevice
objects. |
static boolean |
isHeadless()
Tests whether or not a display
and some form of input device
can be
supported in this environment.
|
protected GraphicsEnvironment()
public static GraphicsEnvironment getLocalGraphicsEnvironment()
GraphicsEnvironment.GraphicsEnvironmentpublic static boolean isHeadless()
true if this environment cannot support
a display and input device; false
otherwiseHeadlessExceptionpublic abstract GraphicsDevice[] getScreenDevices() throws HeadlessException
GraphicsDevice
objects.GraphicsDevice
objects that represent screen devicesHeadlessException - if isHeadless() returns trueisHeadless()public abstract GraphicsDevice getDefaultScreenDevice() throws HeadlessException
GraphicsDevice.GraphicsDevice that represents the
default screen deviceHeadlessException - if isHeadless() returns trueisHeadless()public abstract Graphics2D createGraphics(BufferedImage img)
Graphics2D object for rendering into the
specified BufferedImage.img - the specified BufferedImageGraphics2D to be used for rendering into
the specified BufferedImagepublic abstract String[] getAvailableFontFamilyNames()
GraphicsEnvironment.
Typical usage would be to allow a user to select a particular family
name and allow the application to choose related variants of the
same family when the user specifies style attributes such
as Bold or Italic.
This method provides for the application some control over which
Font instance is used to render text, but allows the
Font object more flexibility in choosing its own best
match among multiple fonts in the same font family.
String containing names of font
familiesFont,
Font.getFamily()public abstract String[] getAvailableFontFamilyNames(Locale l)
GraphicsEnvironment.
Typical usage would be to allow a user to select a particular family
name and allow the application to choose related variants of the
same family when the user specifies style attributes such
as Bold or Italic.
This method provides for the application some control over which
Font instance used to render text, but allows the
Font object more flexibility in choosing its own best
match among multiple fonts in the same font family.
If l is null, this method returns an
array containing all font family names available in this
GraphicsEnvironment.
l - a Locale object that represents a
particular geographical, political, or cultural regionString objects containing names of
font families specific to the specified LocaleFont,
Font.getFamily()Copyright © 2013 CableLabs. All rights reserved.