public class Point extends Object implements Serializable, Cloneable
| Modifier and Type | Field and Description |
|---|---|
int |
x
The x coordinate.
|
int |
y
The y coordinate.
|
| Constructor and Description |
|---|
Point()
Constructs and initializes a point at the origin
(0, 0) of the coordinate space.
|
Point(int x,
int y)
Constructs and initializes a point at the specified
(x, y) location in the coordinate space.
|
Point(Point p)
Constructs and initializes a point with the same location as
the specified
Point object. |
| Modifier and Type | Method and Description |
|---|---|
Object |
clone()
Creates a new object of the same class and with the
same contents as this object.
|
boolean |
equals(Object obj)
Determines whether or not two points are equal.
|
Point |
getLocation()
Returns the location of this point.
|
int |
hashCode()
Returns the hashcode for this
Point. |
void |
move(int x,
int y)
Moves this point to the specified location in the
(x, y) coordinate plane.
|
void |
setLocation(int x,
int y)
Changes the point to have the specified location.
|
void |
setLocation(Point p)
Sets the location of the point to the specified location.
|
String |
toString()
Returns a string representation of this point and its location
in the (x, y) coordinate space.
|
void |
translate(int dx,
int dy)
Translates this point, at location (x, y),
by
dx along the x axis and dy
along the y axis so that it now represents the point
(x + dx,
y + dy). |
public int x
getLocation(),
move(int, int)public int y
getLocation(),
move(int, int)public Point()
public Point(Point p)
Point object.p - a pointpublic Point(int x,
int y)
x - the x coordinatey - the y coordinatepublic Point getLocation()
getLocation method of Component.Component.getLocation(),
setLocation(java.awt.Point),
setLocation(int, int)public void setLocation(Point p)
setLocation method of Component.p - a point, the new location for this pointComponent.setLocation(java.awt.Point),
getLocation()public void setLocation(int x,
int y)
This method is included for completeness, to parallel the
setLocation method of Component.
Its behavior is identical with move(int, int).
x - the x coordinate of the new locationy - the y coordinate of the new locationComponent.setLocation(int, int),
getLocation(),
move(int, int)public void move(int x,
int y)
setLocation(int, int).x - the x coordinate of the new locationy - the y coordinate of the new locationComponent.setLocation(int, int)public void translate(int dx,
int dy)
dx along the x axis and dy
along the y axis so that it now represents the point
(x + dx,
y + dy).dx - the distance to move this point
along the x axisdy - the distance to move this point
along the y axispublic boolean equals(Object obj)
Point are equal if the values of their
x and y member fields, representing
their position in the coordinate space, are the same.equals in class Objectobj - an object to be compared with this Pointtrue if the object to be compared is
an instance of Point and has
the same values; false otherwise.Object.hashCode(),
Hashtablepublic String toString()
null.public Object clone()
clone in class ObjectOutOfMemoryError - if there is not enough memory.Cloneablepublic int hashCode()
Point.hashCode in class ObjectPoint.Object.equals(java.lang.Object),
HashtableCopyright © 2013 CableLabs. All rights reserved.