public interface Stroke
Stroke interface allows a
Graphics2D object to obtain a Shape that is the
decorated outline, or stylistic representation of the outline,
of the specified Shape.
The objects of the classes implementing Stroke
must be read-only because Graphics2D does not
clone these objects either when they are set as an attribute
with the setStroke method or when the
Graphics2D object is itself cloned.
If a Stroke object is modified after it is set in
the Graphics2D context then the behavior
of subsequent rendering would be undefined.
BasicStroke,
Graphics2D.setStroke(java.awt.Stroke)Copyright © 2012. All Rights Reserved.