public class Window extends Container
WindowEvent,
addWindowListener(java.awt.event.WindowListener),
BorderLayout,
Serialized FormBOTTOM_ALIGNMENT, CENTER_ALIGNMENT, LEFT_ALIGNMENT, RIGHT_ALIGNMENT, TOP_ALIGNMENTABORT, ALLBITS, ERROR, FRAMEBITS, HEIGHT, PROPERTIES, SOMEBITS, WIDTH| Modifier and Type | Method and Description |
|---|---|
void |
addWindowFocusListener(WindowFocusListener l)
Adds the specified window focus listener to receive window events
from this window.
|
void |
addWindowListener(WindowListener l)
Adds the specified window listener to receive window events from
this window.
|
void |
dispose()
Releases all of the native screen resources used by this
Window, its subcomponents, and all of its owned
children. |
boolean |
getFocusableWindowState()
Returns whether this Window can become the focused Window if it meets
the other requirements outlined in
isFocusableWindow. |
Container |
getFocusCycleRootAncestor()
Always returns
null because Windows have no ancestors; they
represent the top of the Component hierarchy. |
Component |
getFocusOwner()
Returns the child Component of this Window that has focus if this Window
is focused; returns null otherwise.
|
Set |
getFocusTraversalKeys(int id)
Gets a focus traversal key for this Window.
|
GraphicsConfiguration |
getGraphicsConfiguration()
This method returns the GraphicsConfiguration used by this Window.
|
InputContext |
getInputContext()
Gets the input context for this window.
|
Locale |
getLocale()
Gets the
Locale object that is associated
with this window, if the locale has been set. |
Component |
getMostRecentFocusOwner()
Returns the child Component of this Window that will receive the focus
when this Window is focused.
|
Toolkit |
getToolkit()
Returns the toolkit of this frame.
|
String |
getWarningString()
Gets the warning string that is displayed with this window.
|
WindowFocusListener[] |
getWindowFocusListeners()
Returns an array of all the window focus listeners
registered on this window.
|
WindowListener[] |
getWindowListeners()
Returns an array of all the window listeners
registered on this window.
|
boolean |
isActive()
Returns whether this Window is active.
|
boolean |
isFocusableWindow()
Returns whether this Window can become the focused Window, that is,
whether this Window or any of its subcomponents can become the focus
owner.
|
boolean |
isFocusCycleRoot()
Always returns
true because all Windows must be roots of a
focus traversal cycle. |
boolean |
isFocused()
Returns whether this Window is focused.
|
boolean |
isShowing()
Checks if this Window is showing on screen.
|
void |
pack()
Causes this Window to be sized to fit the preferred size
and layouts of its subcomponents.
|
protected void |
processEvent(AWTEvent e)
Processes events on this window.
|
protected void |
processWindowEvent(WindowEvent e)
Processes window events occurring on this window by
dispatching them to any registered WindowListener objects.
|
protected void |
processWindowFocusEvent(WindowEvent e)
Processes window focus event occuring on this window by
dispatching them to any registered WindowFocusListener objects.
|
void |
removeWindowFocusListener(WindowFocusListener l)
Removes the specified window focus listener so that it no longer
receives window events from this window.
|
void |
removeWindowListener(WindowListener l)
Removes the specified window listener so that it no longer
receives window events from this window.
|
void |
setCursor(Cursor cursor)
Set the cursor image to a specified cursor.
|
void |
setFocusableWindowState(boolean focusableWindowState)
Sets whether this Window can become the focused Window if it meets
the other requirements outlined in
isFocusableWindow. |
void |
setFocusCycleRoot(boolean focusCycleRoot)
Does nothing because Windows must always be roots of a focus traversal
cycle.
|
void |
show()
Makes the Window visible.
|
void |
toBack()
If this Window is visible, sends this Window to the back and may cause
it to lose focus or activation if it is the focused or active Window.
|
void |
toFront()
If this Window is visible, brings this Window to the front and may make
it the focused Window.
|
add, add, add, add, add, addContainerListener, addImpl, areFocusTraversalKeysSet, doLayout, findComponentAt, findComponentAt, getAlignmentX, getAlignmentY, getComponent, getComponentAt, getComponentAt, getComponentCount, getComponents, getContainerListeners, getFocusTraversalPolicy, getInsets, getLayout, getMaximumSize, getMinimumSize, getPreferredSize, invalidate, isAncestorOf, isFocusCycleRoot, isFocusTraversalPolicySet, list, list, paint, paintComponents, paramString, print, printComponents, processContainerEvent, remove, remove, removeAll, removeContainerListener, setFocusTraversalKeys, setFocusTraversalPolicy, setFont, setLayout, transferFocusBackward, transferFocusDownCycle, update, validate, validateTreeaddComponentListener, addFocusListener, addInputMethodListener, addKeyListener, addMouseListener, addMouseMotionListener, addMouseWheelListener, addNotify, addPropertyChangeListener, checkImage, checkImage, coalesceEvents, contains, contains, createImage, createImage, createVolatileImage, createVolatileImage, disableEvents, dispatchEvent, enableEvents, enableInputMethods, firePropertyChange, getBackground, getBounds, getBounds, getColorModel, getComponentListeners, getCursor, getFocusListeners, getFocusTraversalKeysEnabled, getFont, getFontMetrics, getForeground, getGraphics, getHeight, getIgnoreRepaint, getInputMethodListeners, getInputMethodRequests, getKeyListeners, getLocation, getLocation, getLocationOnScreen, getMouseListeners, getMouseMotionListeners, getMouseWheelListeners, getName, getParent, getPropertyChangeListeners, getSize, getSize, getTreeLock, getWidth, getX, getY, hasFocus, imageUpdate, isBackgroundSet, isCursorSet, isDisplayable, isDoubleBuffered, isEnabled, isFocusable, isFocusOwner, isFocusTraversable, isFontSet, isForegroundSet, isLightweight, isOpaque, isValid, isVisible, list, list, list, paintAll, prepareImage, prepareImage, printAll, processComponentEvent, processFocusEvent, processInputMethodEvent, processKeyEvent, processMouseEvent, processMouseMotionEvent, processMouseWheelEvent, removeComponentListener, removeFocusListener, removeInputMethodListener, removeKeyListener, removeMouseListener, removeMouseMotionListener, removeMouseWheelListener, removeNotify, removePropertyChangeListener, repaint, repaint, repaint, repaint, requestFocus, requestFocus, requestFocusInWindow, requestFocusInWindow, setBackground, setBounds, setBounds, setEnabled, setFocusable, setFocusTraversalKeysEnabled, setForeground, setIgnoreRepaint, setLocale, setLocation, setLocation, setName, setSize, setSize, setVisible, toString, transferFocus, transferFocusUpCyclepublic void pack()
Component.isDisplayable()public void show()
public void dispose()
Window, its subcomponents, and all of its owned
children. That is, the resources for these Components
will be destroyed, any memory they consume will be returned to the
OS, and they will be marked as undisplayable.
The Window and its subcomponents can be made displayable
again by rebuilding the native resources with a subsequent call to
pack or show. The states of the recreated
Window and its subcomponents will be identical to the
states of these objects at the point where the Window
was disposed (not accounting for additional modifications between
those actions).
Note: When the last displayable window within the Java virtual machine (VM) is disposed of, the VM may terminate. See AWT Threading Issues for more information.
Component.isDisplayable(),
pack(),
show()public void toFront()
Places this Window at the top of the stacking order and shows it in front of any other Windows in this VM. No action will take place if this Window is not visible. Some platforms do not allow Windows which own other Windows to appear on top of those owned Windows. Some platforms may not permit this VM to place its Windows above windows of native applications, or Windows of other VMs. This permission may depend on whether a Window in this VM is already focused. Every attempt will be made to move this Window as high as possible in the stacking order; however, developers should not assume that this method will move this Window above all other windows in every situation.
Because of variations in native windowing systems, no guarantees about changes to the focused and active Windows can be made. Developers must never assume that this Window is the focused or active Window until this Window receives a WINDOW_GAINED_FOCUS or WINDOW_ACTIVATED event. On platforms where the top-most window is the focused window, this method will probably focus this Window, if it is not already focused. On platforms where the stacking order does not typically affect the focused window, this method will probably leave the focused and active Windows unchanged.
If this method causes this Window to be focused, and this Window is a Frame it will also become activated. If this Window is focused, but it is not a Frame then the first Frame that is an owner of this Window will be activated.
toBack()public void toBack()
Places this Window at the bottom of the stacking order and shows it behind any other Windows in this VM. No action will take place is this Window is not visible. Some platforms do not allow Windows which are owned by other Windows to appear below their owners. Every attempt will be made to move this Window as low as possible in the stacking order; however, developers should not assume that this method will move this Window below all other windows in every situation.
Because of variations in native windowing systems, no guarantees about changes to the focused and active Windows can be made. Developers must never assume that this Window is no longer the focused or active Window until this Window receives a WINDOW_LOST_FOCUS or WINDOW_DEACTIVATED event. On platforms where the top-most window is the focused window, this method will probably cause this Window to lose focus. In that case, the next highest, focusable Window in this VM will receive focus. On platforms where the stacking order does not typically affect the focused window, this method will probably leave the focused and active Windows unchanged.
toFront()public Toolkit getToolkit()
getToolkit in class ComponentToolkit,
Toolkit.getDefaultToolkit(),
Component.getToolkit()public final String getWarningString()
checkTopLevelWindow method returns
false when this window is passed to it as an
argument.
If the window is secure, then getWarningString
returns null. If the window is insecure, this
method checks for the system property
awt.appletWarning
and returns the string value of that property.
SecurityManager.checkTopLevelWindow(java.lang.Object)public Locale getLocale()
Locale object that is associated
with this window, if the locale has been set.
If no locale has been set, then the default locale
is returned.public InputContext getInputContext()
getInputContext in class Componentnull if no context can be determinedComponent.getInputContext()public void setCursor(Cursor cursor)
setCursor in class Componentcursor - One of the constants defined
by the Cursor class. If this parameter is null
then the cursor for this window will be set to the type
Cursor.DEFAULT_CURSOR.Component.getCursor(),
Cursorpublic void addWindowListener(WindowListener l)
l - the window listenerremoveWindowListener(java.awt.event.WindowListener)public void addWindowFocusListener(WindowFocusListener l)
l - the window focus listenerremoveWindowFocusListener(java.awt.event.WindowFocusListener),
getWindowFocusListeners()public void removeWindowListener(WindowListener l)
l - the window listeneraddWindowListener(java.awt.event.WindowListener)public void removeWindowFocusListener(WindowFocusListener l)
l - the window focus listeneraddWindowFocusListener(java.awt.event.WindowFocusListener),
getWindowFocusListeners()public WindowListener[] getWindowListeners()
WindowListeners
or an empty array if no window
listeners are currently registeredaddWindowListener(java.awt.event.WindowListener),
removeWindowListener(java.awt.event.WindowListener)public WindowFocusListener[] getWindowFocusListeners()
WindowFocusListeners
or an empty array if no window focus
listeners are currently registeredaddWindowFocusListener(java.awt.event.WindowFocusListener),
removeWindowFocusListener(java.awt.event.WindowFocusListener)protected void processEvent(AWTEvent e)
WindowEvent, it invokes the
processWindowEvent method, else it invokes its
superclass's processEvent.
Note that if the event parameter is null
the behavior is unspecified and may result in an
exception.
processEvent in class Containere - the eventComponent.processComponentEvent(java.awt.event.ComponentEvent),
Component.processFocusEvent(java.awt.event.FocusEvent),
Component.processKeyEvent(java.awt.event.KeyEvent),
Component.processMouseEvent(java.awt.event.MouseEvent),
Component.processMouseMotionEvent(java.awt.event.MouseEvent),
Component.processInputMethodEvent(java.awt.event.InputMethodEvent),
Component.processMouseWheelEvent(java.awt.event.MouseWheelEvent)protected void processWindowEvent(WindowEvent e)
addWindowListener
enableEvents
Note that if the event parameter is null
the behavior is unspecified and may result in an
exception.
e - the window eventComponent.enableEvents(long)protected void processWindowFocusEvent(WindowEvent e)
addWindowFocusListener
enableEvents
Note that if the event parameter is null
the behavior is unspecified and may result in an
exception.
e - the window focus eventComponent.enableEvents(long)public Component getFocusOwner()
getMostRecentFocusOwner(),
isFocused()public Component getMostRecentFocusOwner()
getFocusOwner(). If
this Window is not focused, then the child Component that most recently
requested focus will be returned. If no child Component has ever
requested focus, and this is a focusable Window, then this Window's
initial focusable Component is returned. If no child Component has ever
requested focus, and this is a non-focusable Window, null is returned.getFocusOwner(),
isFocused(),
isFocusableWindow()public boolean isActive()
isFocused()public boolean isFocused()
If the focused Window is a Frame it is also the active Window. Otherwise, the active Window is the first Frame that is an owner of the focused Window.
public Set getFocusTraversalKeys(int id)
setFocusTraversalKeys for a full description of each key.)
If the traversal key has not been explicitly set for this Window, then this Window's parent's traversal key is returned. If the traversal key has not been explicitly set for any of this Window's ancestors, then the current KeyboardFocusManager's default traversal key is returned.
getFocusTraversalKeys in class Containerid - one of KeyboardFocusManager.FORWARD_TRAVERSAL_KEYS,
KeyboardFocusManager.BACKWARD_TRAVERSAL_KEYS,
KeyboardFocusManager.UP_CYCLE_TRAVERSAL_KEYS, or
KeyboardFocusManager.DOWN_CYCLE_TRAVERSAL_KEYSIllegalArgumentException - if id is not one of
KeyboardFocusManager.FORWARD_TRAVERSAL_KEYS,
KeyboardFocusManager.BACKWARD_TRAVERSAL_KEYS,
KeyboardFocusManager.UP_CYCLE_TRAVERSAL_KEYS, or
KeyboardFocusManager.DOWN_CYCLE_TRAVERSAL_KEYSContainer.setFocusTraversalKeys(int, java.util.Set),
KeyboardFocusManager.FORWARD_TRAVERSAL_KEYS,
KeyboardFocusManager.BACKWARD_TRAVERSAL_KEYS,
KeyboardFocusManager.UP_CYCLE_TRAVERSAL_KEYS,
KeyboardFocusManager.DOWN_CYCLE_TRAVERSAL_KEYSpublic final void setFocusCycleRoot(boolean focusCycleRoot)
setFocusCycleRoot in class ContainerfocusCycleRoot - this value is ignoredisFocusCycleRoot(),
Container.setFocusTraversalPolicy(java.awt.FocusTraversalPolicy),
Container.getFocusTraversalPolicy()public final boolean isFocusCycleRoot()
true because all Windows must be roots of a
focus traversal cycle.isFocusCycleRoot in class ContainertruesetFocusCycleRoot(boolean),
Container.setFocusTraversalPolicy(java.awt.FocusTraversalPolicy),
Container.getFocusTraversalPolicy()public final Container getFocusCycleRootAncestor()
null because Windows have no ancestors; they
represent the top of the Component hierarchy.getFocusCycleRootAncestor in class ComponentnullContainer.isFocusCycleRoot()public final boolean isFocusableWindow()
true. For a Window which is not a Frame to be focusable, its focusable Window state must be set to
true, its nearest owning Frame must be
showing on the screen, and it must contain at least one Component in
its focus traversal cycle. If any of these conditions is not met, then
neither this Window nor any of its subcomponents can become the focus
owner.true if this Window can be the focused Window;
false otherwisegetFocusableWindowState(),
setFocusableWindowState(boolean),
isShowing(),
Component.isFocusable()public boolean getFocusableWindowState()
isFocusableWindow. If
this method returns false, then
isFocusableWindow will return false as well.
If this method returns true, then
isFocusableWindow may return true or
false depending upon the other requirements which must be
met in order for a Window to be focusable.
By default, all Windows have a focusable Window state of
true.
isFocusableWindow(),
setFocusableWindowState(boolean),
isShowing(),
Component.setFocusable(boolean)public void setFocusableWindowState(boolean focusableWindowState)
isFocusableWindow. If
this Window's focusable Window state is set to false, then
isFocusableWindow will return false. If this
Window's focusable Window state is set to true, then
isFocusableWindow may return true or
false depending upon the other requirements which must be
met in order for a Window to be focusable.
Setting a Window's focusability state to false is the
standard mechanism for an application to identify to the AWT a Window
which will be used as a floating palette or toolbar, and thus should be
a non-focusable Window.
focusableWindowState - whether this Window can be the focused
WindowisFocusableWindow(),
getFocusableWindowState(),
isShowing(),
Component.setFocusable(boolean)public boolean isShowing()
isShowing in class Componenttrue if the component is showing,
false otherwiseComponent.setVisible(boolean)public GraphicsConfiguration getGraphicsConfiguration()
getGraphicsConfiguration in class ComponentGraphicsConfiguration used by this
Component or nullCopyright © 2013 CableLabs. All rights reserved.