| Package | Description |
|---|---|
| java.awt |
Contains all of the classes for creating user
interfaces and for painting graphics and images.
|
| javax.tv.graphics |
Provides a mechanism by which Xlets may discover their root container and
describes a mechanism for alpha blending.
|
| org.dvb.ui |
Provides extended graphics functionality.
|
| org.havi.ui |
Provides user interfaces to HAVI components.
|
| org.havi.ui.event |
Provides ability to receive HAVI UI events.
|
| Modifier and Type | Class and Description |
|---|---|
class |
SystemColor
A class to encapsulate symbolic colors representing the color of
native GUI objects on a system.
|
| Modifier and Type | Field and Description |
|---|---|
static Color |
Color.black
An object of type
Color representing
the color black. |
static Color |
Color.BLACK
An object of type
Color representing
the color black. |
static Color |
Color.blue
An object of type
Color representing
the color blue. |
static Color |
Color.BLUE
An object of type
Color representing
the color blue. |
static Color |
Color.cyan
An object of type
Color representing
the color cyan. |
static Color |
Color.CYAN
An object of type
Color representing
the color cyan. |
static Color |
Color.DARK_GRAY
An object of type
Color representing
the color dark gray. |
static Color |
Color.darkGray
An object of type
Color representing
the color dark gray. |
static Color |
Color.gray
An object of type
Color representing
the color gray. |
static Color |
Color.GRAY
An object of type
Color representing
the color gray. |
static Color |
Color.green
An object of type
Color representing
the color green. |
static Color |
Color.GREEN
An object of type
Color representing
the color green. |
static Color |
Color.LIGHT_GRAY
An object of type
Color representing
the color light gray. |
static Color |
Color.lightGray
An object of type
Color representing
the color light gray. |
static Color |
Color.magenta
An object of type
Color representing
the color magenta. |
static Color |
Color.MAGENTA
An object of type
Color representing
the color magenta. |
static Color |
Color.orange
An object of type
Color representing
the color orange. |
static Color |
Color.ORANGE
An object of type
Color representing
the color orange. |
static Color |
Color.pink
An object of type
Color representing
the color pink. |
static Color |
Color.PINK
An object of type
Color representing
the color pink. |
static Color |
Color.red
An object of type
Color representing
the color red. |
static Color |
Color.RED
An object of type
Color representing
the color red. |
static Color |
Color.white
An object of type
Color representing
the color white. |
static Color |
Color.WHITE
An object of type
Color representing
the color white. |
static Color |
Color.yellow
An object of type
Color representing
the color yellow. |
static Color |
Color.YELLOW
An object of type
Color representing
the color yellow. |
| Modifier and Type | Method and Description |
|---|---|
Color |
Color.brighter()
Creates a new
Color that is a brighter version of this
Color. |
Color |
Color.darker()
Creates a new
Color that is a darker version of this
Color. |
static Color |
Color.decode(String nm)
Converts a
String to an integer and returns the
specified opaque Color. |
Color |
Component.getBackground()
Gets the background color of this component.
|
abstract Color |
Graphics.getColor()
Gets this graphics context's current color.
|
static Color |
Color.getColor(String nm)
Finds a color in the system properties.
|
static Color |
Color.getColor(String nm,
Color v)
Finds a color in the system properties.
|
static Color |
Color.getColor(String nm,
int v)
Finds a color in the system properties.
|
Color |
Component.getForeground()
Gets the foreground color of this component.
|
static Color |
Color.getHSBColor(float h,
float s,
float b)
Creates a
Color object based on the specified values
for the HSB color model. |
| Modifier and Type | Method and Description |
|---|---|
abstract boolean |
Graphics.drawImage(Image img,
int x,
int y,
Color bgcolor,
ImageObserver observer)
Draws as much of the specified image as is currently available.
|
abstract boolean |
Graphics.drawImage(Image img,
int x,
int y,
int width,
int height,
Color bgcolor,
ImageObserver observer)
Draws as much of the specified image as has already been scaled
to fit inside the specified rectangle.
|
abstract boolean |
Graphics.drawImage(Image img,
int dx1,
int dy1,
int dx2,
int dy2,
int sx1,
int sy1,
int sx2,
int sy2,
Color bgcolor,
ImageObserver observer)
Draws as much of the specified area of the specified image as is
currently available, scaling it on the fly to fit inside the
specified area of the destination drawable surface.
|
static Color |
Color.getColor(String nm,
Color v)
Finds a color in the system properties.
|
void |
Component.setBackground(Color c)
Sets the background color of this component.
|
abstract void |
Graphics.setColor(Color c)
Sets this graphics context's current color to the specified
color.
|
void |
Component.setForeground(Color c)
Sets the foreground color of this component.
|
abstract void |
Graphics.setXORMode(Color c1)
Sets the paint mode of this graphics context to alternate between
this graphics context's current color and the new specified color.
|
| Modifier and Type | Class and Description |
|---|---|
class |
AlphaColor
A class that allows a very simple, interoperable form of
compositing.
|
| Modifier and Type | Method and Description |
|---|---|
Color |
AlphaColor.brighter()
Creates a brighter version of this color.
|
Color |
AlphaColor.darker()
Creates a darker version of this color.
|
| Constructor and Description |
|---|
AlphaColor(Color c)
Constructs a new
AlphaColor using the specified
java.awt.Color. |
| Modifier and Type | Class and Description |
|---|---|
class |
DVBColor
A Color class which adds the notion of alpha.
|
| Modifier and Type | Method and Description |
|---|---|
Color |
DVBColor.brighter()
Creates a brighter version of this color.
|
Color |
DVBColor.darker()
Creates a darker version of this color.
|
abstract Color |
DVBGraphics.getColor()
Gets this graphics context's current color.
|
| Modifier and Type | Method and Description |
|---|---|
DVBColor |
DVBGraphics.getBestColorMatch(Color c)
Returns the best match for the specified Color as a DVBColor, in a
device-dependent manner, as constrained by the MHP graphics reference model.
|
abstract void |
DVBGraphics.setColor(Color c)
Sets this graphics context's current color to the specified
color.
|
| Constructor and Description |
|---|
DVBColor(Color c)
Constructs a new DVBColor using the specified color.
|
| Modifier and Type | Method and Description |
|---|---|
Color |
HBackgroundConfiguration.getColor()
Obtain the current color of this background.
|
Color |
HGraphicsConfiguration.getPunchThroughToBackgroundColor(Color color,
int percentage)
This method returns a Color that may be used in standard
graphics drawing operations, which has the effect of
"punching though" all Components that are behind the
Component in which the drawing operation is performed.
|
Color |
HGraphicsConfiguration.getPunchThroughToBackgroundColor(Color color,
int percentage,
HVideoDevice v)
This method returns a Color that may be used in standard
graphics drawing operations, which has the effect of modifying
the existing color of a pixel to make it partially (or wholly)
transparent to the background.
|
Color |
HGraphicsConfiguration.getPunchThroughToBackgroundColor(int percentage)
This method returns a Color that may be used in standard
graphics drawing operations, which has the effect of modifying
the existing color of a pixel to make it partially (or wholly)
transparent to the background.
|
Color |
HGraphicsConfiguration.getPunchThroughToBackgroundColor(int percentage,
HVideoDevice hvd)
This method returns a Color that may be used in standard
graphics drawing operations, which has the effect of
"punching though" the
HGraphicsDevice in which the
drawing operation is performed. |
| Modifier and Type | Method and Description |
|---|---|
void |
HGraphicsConfiguration.dispose(Color c)
This method is used by an application when a color returned
from those versions of the method
getPunchThroughToBackgroundColor with a Color as a parameter is
no longer required.
|
Color |
HGraphicsConfiguration.getPunchThroughToBackgroundColor(Color color,
int percentage)
This method returns a Color that may be used in standard
graphics drawing operations, which has the effect of
"punching though" all Components that are behind the
Component in which the drawing operation is performed.
|
Color |
HGraphicsConfiguration.getPunchThroughToBackgroundColor(Color color,
int percentage,
HVideoDevice v)
This method returns a Color that may be used in standard
graphics drawing operations, which has the effect of modifying
the existing color of a pixel to make it partially (or wholly)
transparent to the background.
|
void |
HStillImageBackgroundConfiguration.setColor(Color color)
Set the current color of this background.
|
void |
HBackgroundConfiguration.setColor(Color color)
Set the current color of this background.
|
| Constructor and Description |
|---|
HMultilineEntry(String text,
int maxChars,
Font font,
Color color)
Creates an
HMultilineEntry
object. |
HMultilineEntry(String text,
int x,
int y,
int width,
int height,
int maxChars,
Font font,
Color color)
Creates an
HMultilineEntry
object. |
HSinglelineEntry(String text,
int maxChars,
Font font,
Color color)
Creates an
HSinglelineEntry
object. |
HSinglelineEntry(String text,
int x,
int y,
int width,
int height,
int maxChars,
Font font,
Color color)
Creates an
HSinglelineEntry
object. |
HStaticText(String textNormal,
Font font,
Color foreground,
Color background,
HTextLayoutManager tlm)
Creates an
HStaticText
object. |
HStaticText(String textNormal,
int x,
int y,
int width,
int height,
Font font,
Color foreground,
Color background,
HTextLayoutManager tlm)
Creates an
HStaticText
object. |
HText(String text,
Font font,
Color foreground,
Color background,
HTextLayoutManager tlm)
Creates an
HText object. |
HText(String text,
int x,
int y,
int width,
int height,
Font font,
Color foreground,
Color background,
HTextLayoutManager tlm)
Creates an
HText object. |
HText(String textNormal,
String textFocus,
Font font,
Color foreground,
Color background,
HTextLayoutManager tlm)
Creates an
HText object. |
HText(String textNormal,
String textFocus,
int x,
int y,
int width,
int height,
Font font,
Color foreground,
Color background,
HTextLayoutManager tlm)
Creates an
HText object. |
HTextButton(String text,
Font font,
Color foreground,
Color background,
HTextLayoutManager tlm)
Creates an
HTextButton
object. |
HTextButton(String text,
int x,
int y,
int width,
int height,
Font font,
Color foreground,
Color background,
HTextLayoutManager tlm)
Creates an
HTextButton
object. |
| Modifier and Type | Method and Description |
|---|---|
Color |
HEventRepresentation.getColor()
This returns the color representation (generally used for
colored soft keys) of the current event code.
|
| Modifier and Type | Method and Description |
|---|---|
protected void |
HEventRepresentation.setColor(Color aColor)
Sets the Color representation for this
HEventRepresentation. |
Copyright © 2012 CableLabs. All Rights Reserved.