| Package | Description |
|---|---|
| java.awt |
Contains all of the classes for creating user
interfaces and for painting graphics and images.
|
| java.awt.event |
Provides interfaces and classes for dealing with different
types of events fired by AWT components.
|
| java.awt.im |
Provides classes and interfaces for the input method framework.
|
| javax.media |
Provides media players, means of controlling playback and being notified of playback state changes.
|
| org.havi.ui |
Provides user interfaces to HAVI components.
|
| org.havi.ui.event |
Provides ability to receive HAVI UI events.
|
| org.ocap.ui.event |
Extensions to HAVi User Interface Event classes, including OCAP
specific remote control events and multiscreen management events.
|
| Modifier and Type | Class and Description |
|---|---|
class |
Container
A generic Abstract Window Toolkit(AWT) container object is a component
that can contain other AWT components.
|
class |
Frame
A
Frame is a top-level window with a title and a border. |
class |
Window
A
Window object is a top-level window with no borders and no
menubar. |
| Modifier and Type | Method and Description |
|---|---|
Component |
Container.add(Component comp)
Appends the specified component to the end of this container.
|
Component |
Container.add(Component comp,
int index)
Adds the specified component to this container at the given
position.
|
Component |
Container.add(String name,
Component comp)
Adds the specified component to this container.
|
Component |
Container.findComponentAt(int x,
int y)
Locates the visible child component that contains the specified
position.
|
Component |
Container.findComponentAt(Point p)
Locates the visible child component that contains the specified
point.
|
Component |
Container.getComponent(int n)
Gets the nth component in this container.
|
abstract Component |
FocusTraversalPolicy.getComponentAfter(Container focusCycleRoot,
Component aComponent)
Returns the Component that should receive the focus after aComponent.
|
Component |
ContainerOrderFocusTraversalPolicy.getComponentAfter(Container focusCycleRoot,
Component aComponent)
Returns the Component that should receive the focus after aComponent.
|
Component |
Container.getComponentAt(int x,
int y)
Locates the component that contains the x,y position.
|
Component |
Component.getComponentAt(int x,
int y)
Determines if this component or one of its immediate
subcomponents contains the (x, y) location,
and if so, returns the containing component.
|
Component |
Container.getComponentAt(Point p)
Gets the component that contains the specified point.
|
Component |
Component.getComponentAt(Point p)
Returns the component or subcomponent that contains the
specified point.
|
abstract Component |
FocusTraversalPolicy.getComponentBefore(Container focusCycleRoot,
Component aComponent)
Returns the Component that should receive the focus before aComponent.
|
Component |
ContainerOrderFocusTraversalPolicy.getComponentBefore(Container focusCycleRoot,
Component aComponent)
Returns the Component that should receive the focus before aComponent.
|
Component[] |
Container.getComponents()
Gets all the components in this container.
|
abstract Component |
FocusTraversalPolicy.getDefaultComponent(Container focusCycleRoot)
Returns the default Component to focus.
|
Component |
ContainerOrderFocusTraversalPolicy.getDefaultComponent(Container focusCycleRoot)
Returns the default Component to focus.
|
abstract Component |
FocusTraversalPolicy.getFirstComponent(Container focusCycleRoot)
Returns the first Component in the traversal cycle.
|
Component |
ContainerOrderFocusTraversalPolicy.getFirstComponent(Container focusCycleRoot)
Returns the first Component in the traversal cycle.
|
Component |
Window.getFocusOwner()
Returns the child Component of this Window that has focus if this Window
is focused; returns null otherwise.
|
Component |
KeyboardFocusManager.getFocusOwner()
Returns the focus owner, if the focus owner is in the same context as
the calling thread.
|
Component |
FocusTraversalPolicy.getInitialComponent(Window window)
Returns the Component that should receive the focus when a Window is
made visible for the first time.
|
abstract Component |
FocusTraversalPolicy.getLastComponent(Container focusCycleRoot)
Returns the last Component in the traversal cycle.
|
Component |
ContainerOrderFocusTraversalPolicy.getLastComponent(Container focusCycleRoot)
Returns the last Component in the traversal cycle.
|
Component |
Window.getMostRecentFocusOwner()
Returns the child Component of this Window that will receive the focus
when this Window is focused.
|
Component |
KeyboardFocusManager.getPermanentFocusOwner()
Returns the permanent focus owner, if the permanent focus owner is in
the same context as the calling thread.
|
| Modifier and Type | Method and Description |
|---|---|
protected boolean |
DefaultFocusTraversalPolicy.accept(Component aComponent)
Determines whether a Component is an acceptable choice as the new
focus owner.
|
protected boolean |
ContainerOrderFocusTraversalPolicy.accept(Component aComponent)
Determines whether a Component is an acceptable choice as the new
focus owner.
|
Component |
Container.add(Component comp)
Appends the specified component to the end of this container.
|
Component |
Container.add(Component comp,
int index)
Adds the specified component to this container at the given
position.
|
void |
Container.add(Component comp,
Object constraints)
Adds the specified component to the end of this container.
|
void |
Container.add(Component comp,
Object constraints,
int index)
Adds the specified component to this container with the specified
constraints at the specified index.
|
Component |
Container.add(String name,
Component comp)
Adds the specified component to this container.
|
protected void |
Container.addImpl(Component comp,
Object constraints,
int index)
Adds the specified component to this container at the specified
index.
|
void |
LayoutManager2.addLayoutComponent(Component comp,
Object constraints)
Adds the specified component to the layout, using the specified
constraint object.
|
void |
GridBagLayout.addLayoutComponent(Component comp,
Object constraints)
Adds the specified component to the layout, using the specified
constraints object. |
void |
CardLayout.addLayoutComponent(Component comp,
Object constraints)
Adds the specified component to this card layout's internal
table of names.
|
void |
BorderLayout.addLayoutComponent(Component comp,
Object constraints)
Adds the specified component to the layout, using the specified
constraint object.
|
void |
LayoutManager.addLayoutComponent(String name,
Component comp)
If the layout manager uses a per-component string,
adds the component
comp to the layout,
associating it
with the string specified by name. |
void |
GridLayout.addLayoutComponent(String name,
Component comp)
Adds the specified component with the specified name to the layout.
|
void |
GridBagLayout.addLayoutComponent(String name,
Component comp)
Adds the specified component with the specified name to the layout.
|
void |
FlowLayout.addLayoutComponent(String name,
Component comp)
Adds the specified component to the layout.
|
void |
CardLayout.addLayoutComponent(String name,
Component comp)
Deprecated.
replaced by
addLayoutComponent(Component, Object). |
void |
BorderLayout.addLayoutComponent(String name,
Component comp)
Deprecated.
replaced by
addLayoutComponent(Component, Object). |
abstract void |
KeyboardFocusManager.focusNextComponent(Component aComponent)
Focuses the Component after aComponent, typically based on a
FocusTraversalPolicy.
|
abstract void |
KeyboardFocusManager.focusPreviousComponent(Component aComponent)
Focuses the Component before aComponent, typically based on a
FocusTraversalPolicy.
|
abstract Component |
FocusTraversalPolicy.getComponentAfter(Container focusCycleRoot,
Component aComponent)
Returns the Component that should receive the focus after aComponent.
|
Component |
ContainerOrderFocusTraversalPolicy.getComponentAfter(Container focusCycleRoot,
Component aComponent)
Returns the Component that should receive the focus after aComponent.
|
abstract Component |
FocusTraversalPolicy.getComponentBefore(Container focusCycleRoot,
Component aComponent)
Returns the Component that should receive the focus before aComponent.
|
Component |
ContainerOrderFocusTraversalPolicy.getComponentBefore(Container focusCycleRoot,
Component aComponent)
Returns the Component that should receive the focus before aComponent.
|
GridBagConstraints |
GridBagLayout.getConstraints(Component comp)
Gets the constraints for the specified component.
|
boolean |
Container.isAncestorOf(Component c)
Checks if the component is contained in the component hierarchy of
this container.
|
protected GridBagConstraints |
GridBagLayout.lookupConstraints(Component comp)
Retrieves the constraints for the specified component.
|
abstract void |
KeyboardFocusManager.processKeyEvent(Component focusedComponent,
KeyEvent e)
This method initiates a focus traversal operation if and only if the
KeyEvent represents a focus traversal key for the specified
focusedComponent.
|
void |
KeyboardFocusManager.redispatchEvent(Component target,
AWTEvent e)
Redispatches an AWTEvent in such a way that the AWT event dispatcher
will not recursively request that the KeyboardFocusManager, or any
installed KeyEventDispatchers, dispatch the event again.
|
void |
Container.remove(Component comp)
Removes the specified component from this container.
|
void |
LayoutManager.removeLayoutComponent(Component comp)
Removes the specified component from the layout.
|
void |
GridLayout.removeLayoutComponent(Component comp)
Removes the specified component from the layout.
|
void |
GridBagLayout.removeLayoutComponent(Component comp)
Removes the specified component from this layout.
|
void |
FlowLayout.removeLayoutComponent(Component comp)
Removes the specified component from the layout.
|
void |
CardLayout.removeLayoutComponent(Component comp)
Removes the specified component from the layout.
|
void |
BorderLayout.removeLayoutComponent(Component comp)
Removes the specified component from this border layout.
|
void |
GridBagLayout.setConstraints(Component comp,
GridBagConstraints constraints)
Sets the constraints for the specified component in this layout.
|
abstract void |
KeyboardFocusManager.upFocusCycle(Component aComponent)
Moves the focus up one focus traversal cycle.
|
| Constructor and Description |
|---|
MediaTracker(Component comp)
Creates a media tracker to track images for a given component.
|
| Modifier and Type | Method and Description |
|---|---|
Component |
ContainerEvent.getChild()
Returns the component that was affected by the event.
|
Component |
ComponentEvent.getComponent()
Returns the originator of the event.
|
Component |
FocusEvent.getOppositeComponent()
Returns the other Component involved in this focus change.
|
| Constructor and Description |
|---|
ComponentEvent(Component source,
int id)
Constructs a
ComponentEvent object. |
ContainerEvent(Component source,
int id,
Component child)
Constructs a
ContainerEvent object. |
FocusEvent(Component source,
int id)
Constructs a
FocusEvent object and identifies it
as a permanent change in focus. |
FocusEvent(Component source,
int id,
boolean temporary)
Constructs a
FocusEvent object and identifies
whether or not the change is temporary. |
FocusEvent(Component source,
int id,
boolean temporary,
Component opposite)
Constructs a
FocusEvent object with the
specified temporary state and opposite Component. |
InputMethodEvent(Component source,
int id,
AttributedCharacterIterator text,
int committedCharacterCount,
TextHitInfo caret,
TextHitInfo visiblePosition)
Constructs an
InputMethodEvent with the specified
source component, type, text, caret, and visiblePosition. |
InputMethodEvent(Component source,
int id,
long when,
AttributedCharacterIterator text,
int committedCharacterCount,
TextHitInfo caret,
TextHitInfo visiblePosition)
Constructs an
InputMethodEvent with the specified
source component, type, time, text, caret, and visiblePosition. |
InputMethodEvent(Component source,
int id,
TextHitInfo caret,
TextHitInfo visiblePosition)
Constructs an
InputMethodEvent with the
specified source component, type, caret, and visiblePosition. |
KeyEvent(Component source,
int id,
long when,
int modifiers,
int keyCode,
char keyChar)
Constructs a
KeyEvent object. |
MouseEvent(Component source,
int id,
long when,
int modifiers,
int x,
int y,
int clickCount,
boolean popupTrigger)
Constructs a
MouseEvent object with the
specified source component,
type, modifiers, coordinates, and click count. |
MouseEvent(Component source,
int id,
long when,
int modifiers,
int x,
int y,
int clickCount,
boolean popupTrigger,
int button)
Constructs a
MouseEvent object with the
specified source component,
type, modifiers, coordinates, and click count. |
MouseWheelEvent(Component source,
int id,
long when,
int modifiers,
int x,
int y,
int clickCount,
boolean popupTrigger,
int scrollType,
int scrollAmount,
int wheelRotation)
Constructs a
MouseWheelEvent object with the
specified source component, type, modifiers, coordinates,
scroll type, scroll amount, and wheel rotation. |
PaintEvent(Component source,
int id,
Rectangle updateRect)
Constructs a
PaintEvent object with the specified
source component and type. |
| Modifier and Type | Method and Description |
|---|---|
void |
InputContext.removeNotify(Component client)
Notifies the input context that a client component has been
removed from its containment hierarchy, or that input method
support has been disabled for the component.
|
| Modifier and Type | Method and Description |
|---|---|
Component |
Control.getControlComponent()
Get the
Component associated with this
Control object. |
Component |
CachingControl.getControlComponent()
Get a
Component that provides additional download control. |
Component |
Player.getControlPanelComponent()
Obtain the
Component that provides the default user
interface for controlling this Player. |
Component |
CachingControl.getProgressBarComponent()
Get a
Component for displaying the download progress. |
Component |
Player.getVisualComponent()
Obtain the display
Component for this Player. |
| Modifier and Type | Class and Description |
|---|---|
class |
HAnimation
The
HAnimation class is a user
interface component used to display animated graphical content (as
HStaticAnimation) which
additionally enables a user to navigate to it, i.e. |
class |
HComponent
The
HComponent class extends the
java.awt.Component class by implementing the HMatteLayer interface. |
class |
HContainer
The
HContainer class extends the
java.awt.Container class by implementing the HMatteLayer interface and providing
additional Z-ordering capabilities, which are required since
components in the HAVi user-interface are explicitly allowed to
overlap each other. |
class |
HGraphicButton
The
HGraphicButton is a user interface
component representing a push-button with static read-only graphical
content. |
class |
HIcon
The
HIcon is a user interface
component used to display static graphical content (as HStaticIcon) which also enables a user to
navigate to it, i.e. |
class |
HListGroup
The
HListGroup is a user interface
component representing a list of selectable items (HListElements) which contain
graphical and / or textual content. |
class |
HMultilineEntry
The
HMultilineEntry is a user interface
component used to receive multiple lines of alphanumeric entry from
the user. |
class |
HRange
The
HRange is a user interface
component used to display a value within a fixed range (as
org.havi.ui.HStaticRange HStaticRange}) which also enables a user to
navigate to it, i.e. |
class |
HRangeValue
The
HRangeValue is a user interface
component used to display a value within a fixed range (as
org.havi.ui.HStaticRange HStaticRange}) which enables a user to
navigate to and alter the value of it, i.e. |
class |
HScene
An
HScene is a container representing
the displayable area on-screen within which the application can
display itself and thus interact with the user. |
class |
HSinglelineEntry
The
HSinglelineEntry is a user interface
component used to receive a single line of alphanumeric entry from
the user and can also be used for password input. |
class |
HStaticAnimation
The
HStaticAnimation is a user interface
component used to display animated graphical content but which does
not permit the user to navigate (focus) upon it. |
class |
HStaticIcon
The
HStaticIcon is a user interface
component used to display static graphical content which does
not permit the user to navigate (focus) upon it. |
class |
HStaticRange
The
HStaticRange is a user interface
component used to display a static value which is within a fixed
range, but does not permit the user to navigate (focus) upon it. |
class |
HStaticText
The
HStaticText is a user interface
component used to display static read-only textual content which
does not permit the user to navigate (focus) upon it. |
class |
HText
The
HText is a user interface
component used to display static read-only textual content (as
HStaticText) which additionally
enables a user to navigate to it, i.e. |
class |
HTextButton
The
HTextButton is a user interface
component representing a push-button with static read-only textual
content. |
class |
HToggleButton
The
HToggleButton is a user interface
component representing a "check box", or with the support
of the HToggleGroup class,
"radio buttons". |
class |
HVideoComponent
HVideoComponent is an opaque
class encapsulating the presentation of a video source
within an application, i.e. |
class |
HVisible
The
HVisible class is the base class
for all non-interactive components. |
| Modifier and Type | Method and Description |
|---|---|
Component |
HScene.addAfter(Component component,
Component front)
|
Component |
HContainer.addAfter(Component component,
Component front)
|
Component |
HComponentOrdering.addAfter(Component component,
Component front)
Adds a
java.awt.Component to this HComponentOrdering directly behind a previously
added java.awt.Component. |
Component |
HScene.addBefore(Component component,
Component behind)
Adds a
java.awt.Component to this HScene directly in front of a
previously added java.awt.Component. |
Component |
HContainer.addBefore(Component component,
Component behind)
Adds a
java.awt.Component to this HContainer directly in front of a
previously added java.awt.Component. |
Component |
HComponentOrdering.addBefore(Component component,
Component behind)
Adds a
java.awt.Component to this HComponentOrdering directly in front of a
previously added java.awt.Component. |
Component |
HScene.getFocusOwner()
|
| Modifier and Type | Method and Description |
|---|---|
Component |
HScene.addAfter(Component component,
Component front)
|
Component |
HContainer.addAfter(Component component,
Component front)
|
Component |
HComponentOrdering.addAfter(Component component,
Component front)
Adds a
java.awt.Component to this HComponentOrdering directly behind a previously
added java.awt.Component. |
Component |
HScene.addBefore(Component component,
Component behind)
Adds a
java.awt.Component to this HScene directly in front of a
previously added java.awt.Component. |
Component |
HContainer.addBefore(Component component,
Component behind)
Adds a
java.awt.Component to this HContainer directly in front of a
previously added java.awt.Component. |
Component |
HComponentOrdering.addBefore(Component component,
Component behind)
Adds a
java.awt.Component to this HComponentOrdering directly in front of a
previously added java.awt.Component. |
HScreenRectangle |
HGraphicsConfiguration.getComponentHScreenRectangle(Component component)
Returns the on-screen location of a given visible
java.awt.Component as an
HScreenRectangle
for this HGraphicsDevice. |
boolean |
HScene.pop(Component component)
Moves the specified
java.awt.Component one
component nearer in the Z-order, i.e. |
boolean |
HContainer.pop(Component component)
Moves the specified
java.awt.Component one
component nearer in the Z-order, i.e. |
boolean |
HComponentOrdering.pop(Component component)
Moves the specified
java.awt.Component one
component nearer in the Z-order, i.e. |
boolean |
HScene.popInFrontOf(Component move,
Component behind)
Puts the specified
java.awt.Component in front of
another java.awt.Component in the Z-order of this
HScene. |
boolean |
HContainer.popInFrontOf(Component move,
Component behind)
Puts the specified
java.awt.Component in front of
another java.awt.Component in the Z-order of this
HContainer. |
boolean |
HComponentOrdering.popInFrontOf(Component move,
Component behind)
Puts the specified
java.awt.Component in front of
another java.awt.Component in the Z-order of this
HComponentOrdering. |
boolean |
HScene.popToFront(Component component)
Brings the specified
java.awt.Component to the
"front" of the Z-order in this HScene. |
boolean |
HContainer.popToFront(Component component)
Brings the specified
java.awt.Component to the
"front" of the Z-order in this HContainer. |
boolean |
HComponentOrdering.popToFront(Component component)
Brings the specified
java.awt.Component to the
"front" of the Z-order in this HComponentOrdering. |
boolean |
HScene.push(Component component)
Moves the specified
java.awt.Component one
component further away in the Z-order, i.e. |
boolean |
HContainer.push(Component component)
Moves the specified
java.awt.Component one
component further away in the Z-order, i.e. |
boolean |
HComponentOrdering.push(Component component)
Moves the specified
java.awt.Component one
component further away in the Z-order, i.e. |
boolean |
HScene.pushBehind(Component move,
Component front)
Puts the specified
java.awt.Component behind
another java.awt.Component in the Z-order of this
HScene. |
boolean |
HContainer.pushBehind(Component move,
Component front)
Puts the specified
java.awt.Component behind
another java.awt.Component in the Z-order of this
HContainer. |
boolean |
HComponentOrdering.pushBehind(Component move,
Component front)
Puts the specified
java.awt.Component behind
another java.awt.Component in the Z-order of this
HComponentOrdering. |
boolean |
HScene.pushToBack(Component component)
Place the specified
java.awt.Component at the
"back" of the Z-order in this HScene. |
boolean |
HContainer.pushToBack(Component component)
Place the specified
java.awt.Component at the
"back" of the Z-order in this HContainer. |
boolean |
HComponentOrdering.pushToBack(Component component)
Place the specified
java.awt.Component at the
"back" of the Z-order in this HComponentOrdering. |
| Constructor and Description |
|---|
HFocusEvent(Component source,
int id)
Constructs an
HFocusEvent. |
HFocusEvent(Component source,
int id,
int transfer)
Constructs an
HFocusEvent. |
HKeyEvent(Component source,
int id,
long when,
int modifiers,
int keyCode,
char keyChar)
Constructs an
HKeyEvent
object with the specified source component, type, modifiers and
key. |
HRcEvent(Component source,
int id,
long when,
int modifiers,
int keyCode,
char keyChar)
Constructs an
HRcEvent
object with the specified source component, type, modifiers and
key. |
| Constructor and Description |
|---|
OCRcEvent(Component source,
int id,
long when,
int modifiers,
int keyCode,
char keyChar)
Constructs an
OCRcEvent object. |
Copyright © 2012 CableLabs. All Rights Reserved.