| Package | Description |
|---|---|
| java.awt |
Contains all of the classes for creating user
interfaces and for painting graphics and images.
|
| org.dvb.ui |
Provides extended graphics functionality.
|
| org.havi.ui |
| Modifier and Type | Field and Description |
|---|---|
protected Font |
FontMetrics.font
The actual
Font from which the font metrics are
created. |
| Modifier and Type | Method and Description |
|---|---|
static Font |
Font.decode(String str)
Returns the
Font that the str
argument describes. |
abstract Font |
Graphics.getFont()
Gets the current font.
|
Font |
FontMetrics.getFont()
Gets the
Font described by this
FontMetrics object. |
Font |
Component.getFont()
Gets the font of this component.
|
static Font |
Font.getFont(Map attributes)
Returns a
Font appropriate to this attribute set. |
static Font |
Font.getFont(String nm)
Returns a
Font object from the system properties list. |
static Font |
Font.getFont(String nm,
Font font)
Gets the specified
Font from the system properties
list. |
| Modifier and Type | Method and Description |
|---|---|
static Font |
Font.getFont(String nm,
Font font)
Gets the specified
Font from the system properties
list. |
abstract FontMetrics |
Toolkit.getFontMetrics(Font font)
Deprecated.
Deprecated. This returns integer metrics for
the default screen.
|
abstract FontMetrics |
Graphics.getFontMetrics(Font f)
Gets the font metrics for the specified font.
|
FontMetrics |
Component.getFontMetrics(Font font)
Gets the font metrics for the specified font.
|
abstract void |
Graphics.setFont(Font font)
Sets this graphics context's font to the specified font.
|
void |
Container.setFont(Font f)
Sets the font of this container.
|
void |
Component.setFont(Font f)
Sets the font of this component.
|
| Constructor and Description |
|---|
FontMetrics(Font font)
Creates a new
FontMetrics object for finding out
height and width information about the specified Font
and specific character glyphs in that Font. |
| Modifier and Type | Method and Description |
|---|---|
Font |
FontFactory.createFont(String name,
int style,
int size)
Creates a font object from the font source associated with this
FontFactory.
|
| Modifier and Type | Method and Description |
|---|---|
Font[] |
HGraphicsConfiguration.getAllFonts()
List the fonts that are always available on the device, but
does not list fonts that may be (temporarily) available for
download from other sources.
|
| Modifier and Type | Method and Description |
|---|---|
static int[] |
HFontCapabilities.getSupportedCharacterRanges(Font font)
Returns the set of character ranges as defined in ISO
10646-1(E) normative Annex A that this font supports, or a
null array if the capabilities of the font are unknown.
|
static boolean |
HFontCapabilities.isCharAvailable(Font font,
char c)
Returns whether a specific character is available within the
specified font, and can be used as defined in ISO
10646-1(E) specification by the rendering system, e.g.
|
| Constructor and Description |
|---|
HMultilineEntry(String text,
int maxChars,
Font font,
Color color)
Creates an
HMultilineEntry
object. |
HMultilineEntry(String text,
int x,
int y,
int width,
int height,
int maxChars,
Font font,
Color color)
Creates an
HMultilineEntry
object. |
HSinglelineEntry(String text,
int maxChars,
Font font,
Color color)
Creates an
HSinglelineEntry
object. |
HSinglelineEntry(String text,
int x,
int y,
int width,
int height,
int maxChars,
Font font,
Color color)
Creates an
HSinglelineEntry
object. |
HStaticText(String textNormal,
Font font,
Color foreground,
Color background,
HTextLayoutManager tlm)
Creates an
HStaticText
object. |
HStaticText(String textNormal,
int x,
int y,
int width,
int height,
Font font,
Color foreground,
Color background,
HTextLayoutManager tlm)
Creates an
HStaticText
object. |
HText(String text,
Font font,
Color foreground,
Color background,
HTextLayoutManager tlm)
Creates an
HText object. |
HText(String text,
int x,
int y,
int width,
int height,
Font font,
Color foreground,
Color background,
HTextLayoutManager tlm)
Creates an
HText object. |
HText(String textNormal,
String textFocus,
Font font,
Color foreground,
Color background,
HTextLayoutManager tlm)
Creates an
HText object. |
HText(String textNormal,
String textFocus,
int x,
int y,
int width,
int height,
Font font,
Color foreground,
Color background,
HTextLayoutManager tlm)
Creates an
HText object. |
HTextButton(String text,
Font font,
Color foreground,
Color background,
HTextLayoutManager tlm)
Creates an
HTextButton
object. |
HTextButton(String text,
int x,
int y,
int width,
int height,
Font font,
Color foreground,
Color background,
HTextLayoutManager tlm)
Creates an
HTextButton
object. |
Copyright © 2012. All Rights Reserved.