| Package | Description |
|---|---|
| java.awt |
Contains all of the classes for creating user
interfaces and for painting graphics and images.
|
| java.awt.image |
Provides classes for creating and modifying images.
|
| org.dvb.ui |
Provides extended graphics functionality.
|
| org.havi.ui |
Provides user interfaces to HAVI components.
|
| Modifier and Type | Class and Description |
|---|---|
class |
Graphics2D
This
Graphics2D class extends the
Graphics class to provide more sophisticated
control over
graphics operations. |
| Modifier and Type | Method and Description |
|---|---|
abstract Graphics |
Graphics.create()
Creates a new
Graphics object that is
a copy of this Graphics object. |
Graphics |
Graphics.create(int x,
int y,
int width,
int height)
Creates a new
Graphics object based on this
Graphics object, but with a new translation and clip area. |
abstract Graphics |
Image.getGraphics()
Creates a graphics context for drawing to an off-screen image.
|
Graphics |
Component.getGraphics()
Creates a graphics context for this component.
|
| Modifier and Type | Method and Description |
|---|---|
void |
Container.paint(Graphics g)
Paints the container.
|
void |
Component.paint(Graphics g)
Paints this component.
|
void |
Component.paintAll(Graphics g)
Paints this component and all of its subcomponents.
|
void |
Container.paintComponents(Graphics g)
Paints each of the components in this container.
|
void |
Container.print(Graphics g)
Prints the container.
|
void |
Component.print(Graphics g)
Prints this component.
|
void |
Component.printAll(Graphics g)
Prints this component and all of its subcomponents.
|
void |
Container.printComponents(Graphics g)
Prints each of the components in this container.
|
void |
Container.update(Graphics g)
Updates the container.
|
void |
Component.update(Graphics g)
Updates this component.
|
| Modifier and Type | Method and Description |
|---|---|
Graphics |
VolatileImage.getGraphics()
This method returns a
Graphics2D, but is here
for backwards compatibility. |
Graphics |
BufferedImage.getGraphics()
This method returns a
Graphics2D, but is here
for backwards compatibility. |
| Modifier and Type | Class and Description |
|---|---|
class |
DVBGraphics
The
DVBGraphics class is a adapter class to support alpha compositing in an MHP device. |
| Modifier and Type | Method and Description |
|---|---|
Graphics |
DVBBufferedImage.getGraphics()
This method returns a
Graphics, it is here
for backwards compatibility. |
| Modifier and Type | Method and Description |
|---|---|
void |
DVBTextLayoutManager.render(String markedUpString,
Graphics g,
HVisible v,
Insets insets)
Render the string.
|
| Modifier and Type | Method and Description |
|---|---|
void |
HTextLook.fillBackground(Graphics g,
HVisible visible,
int state)
The
HExtendedLook.fillBackground(java.awt.Graphics, org.havi.ui.HVisible, int) method
paints the component with its current background Color
according to the HVisible.setBackgroundMode(int)
method of HVisible. |
void |
HSinglelineEntryLook.fillBackground(Graphics g,
HVisible visible,
int state)
The
HExtendedLook.fillBackground(java.awt.Graphics, org.havi.ui.HVisible, int) method
paints the component with its current background Color
according to the HVisible.setBackgroundMode(int)
method of HVisible. |
void |
HRangeLook.fillBackground(Graphics g,
HVisible visible,
int state)
The
HExtendedLook.fillBackground(java.awt.Graphics, org.havi.ui.HVisible, int) method
paints the component with its current background Color
according to the HVisible.setBackgroundMode(int)
method of HVisible. |
void |
HMultilineEntryLook.fillBackground(Graphics g,
HVisible visible,
int state)
The
HExtendedLook.fillBackground(java.awt.Graphics, org.havi.ui.HVisible, int) method
paints the component with its current background Color
according to the HVisible.setBackgroundMode(int)
method of HVisible. |
void |
HListGroupLook.fillBackground(Graphics g,
HVisible visible,
int state)
The
HExtendedLook.fillBackground(java.awt.Graphics, org.havi.ui.HVisible, int) method
paints the component with its current background Color
according to the HVisible.setBackgroundMode(int)
method of HVisible. |
void |
HGraphicLook.fillBackground(Graphics g,
HVisible visible,
int state)
The
HExtendedLook.fillBackground(java.awt.Graphics, org.havi.ui.HVisible, int) method
paints the component with its current background Color
according to the HVisible.setBackgroundMode(int)
method of HVisible. |
void |
HExtendedLook.fillBackground(Graphics g,
HVisible visible,
int state)
The
HExtendedLook.fillBackground(java.awt.Graphics, org.havi.ui.HVisible, int) method
paints the component with its current background Color
according to the HVisible.setBackgroundMode(int)
method of HVisible. |
void |
HAnimateLook.fillBackground(Graphics g,
HVisible visible,
int state)
The
HExtendedLook.fillBackground(java.awt.Graphics, org.havi.ui.HVisible, int) method
paints the component with its current background Color
according to the HVisible.setBackgroundMode(int)
method of HVisible. |
void |
HVisible.paint(Graphics g)
Draws the current state of the component, by calling the
HLook.showLook(java.awt.Graphics, org.havi.ui.HVisible, int) method of the associated
HLook. |
void |
HScene.paint(Graphics g)
HScene objects override the paint
method (defined in java.awt.Component) to paint
the added "child" components on top of an optional
background color or image. |
void |
HTextLayoutManager.render(String markedUpString,
Graphics g,
HVisible v,
Insets insets)
Render the string.
|
void |
HDefaultTextLayoutManager.render(String markedUpString,
Graphics g,
HVisible v,
Insets insets)
Render the string.
|
void |
HTextLook.renderBorders(Graphics g,
HVisible visible,
int state)
The
HExtendedLook.renderBorders(java.awt.Graphics, org.havi.ui.HVisible, int) method
paints any implementation specific borders according to
the HVisible.setBordersEnabled(boolean) method of
HVisible. |
void |
HSinglelineEntryLook.renderBorders(Graphics g,
HVisible visible,
int state)
The
HExtendedLook.renderBorders(java.awt.Graphics, org.havi.ui.HVisible, int) method
paints any implementation specific borders according to
the HVisible.setBordersEnabled(boolean) method of
HVisible. |
void |
HRangeLook.renderBorders(Graphics g,
HVisible visible,
int state)
The
HExtendedLook.renderBorders(java.awt.Graphics, org.havi.ui.HVisible, int) method
paints any implementation specific borders according to
the HVisible.setBordersEnabled(boolean) method of
HVisible. |
void |
HMultilineEntryLook.renderBorders(Graphics g,
HVisible visible,
int state)
The
HExtendedLook.renderBorders(java.awt.Graphics, org.havi.ui.HVisible, int) method
paints any implementation specific borders according to
the HVisible.setBordersEnabled(boolean) method of
HVisible. |
void |
HListGroupLook.renderBorders(Graphics g,
HVisible visible,
int state)
The
HExtendedLook.renderBorders(java.awt.Graphics, org.havi.ui.HVisible, int) method
paints any implementation specific borders according to
the HVisible.setBordersEnabled(boolean) method of
HVisible. |
void |
HGraphicLook.renderBorders(Graphics g,
HVisible visible,
int state)
The
HExtendedLook.renderBorders(java.awt.Graphics, org.havi.ui.HVisible, int) method
paints any implementation specific borders according to
the HVisible.setBordersEnabled(boolean) method of
HVisible. |
void |
HExtendedLook.renderBorders(Graphics g,
HVisible visible,
int state)
The
HExtendedLook.renderBorders(java.awt.Graphics, org.havi.ui.HVisible, int) method
paints any implementation specific borders according to
the HVisible.setBordersEnabled(boolean) method of
HVisible. |
void |
HAnimateLook.renderBorders(Graphics g,
HVisible visible,
int state)
The
HExtendedLook.renderBorders(java.awt.Graphics, org.havi.ui.HVisible, int) method
paints any implementation specific borders according to
the HVisible.setBordersEnabled(boolean) method of
HVisible. |
void |
HTextLook.renderVisible(Graphics g,
HVisible visible,
int state)
The
HExtendedLook.renderVisible(java.awt.Graphics, org.havi.ui.HVisible, int) method
paints any content or other data associated with the look's HVisible. |
void |
HSinglelineEntryLook.renderVisible(Graphics g,
HVisible visible,
int state)
The
HExtendedLook.renderVisible(java.awt.Graphics, org.havi.ui.HVisible, int) method
paints any content or other data associated with the look's HVisible. |
void |
HRangeLook.renderVisible(Graphics g,
HVisible visible,
int state)
The
HExtendedLook.renderVisible(java.awt.Graphics, org.havi.ui.HVisible, int) method
paints any content or other data associated with the look's HVisible. |
void |
HMultilineEntryLook.renderVisible(Graphics g,
HVisible visible,
int state)
The
HExtendedLook.renderVisible(java.awt.Graphics, org.havi.ui.HVisible, int) method
paints any content or other data associated with the look's HVisible. |
void |
HListGroupLook.renderVisible(Graphics g,
HVisible visible,
int state)
The
HExtendedLook.renderVisible(java.awt.Graphics, org.havi.ui.HVisible, int) method
paints any content or other data associated with the look's HVisible. |
void |
HGraphicLook.renderVisible(Graphics g,
HVisible visible,
int state)
The
HExtendedLook.renderVisible(java.awt.Graphics, org.havi.ui.HVisible, int) method
paints any content or other data associated with the look's HVisible. |
void |
HExtendedLook.renderVisible(Graphics g,
HVisible visible,
int state)
The
HExtendedLook.renderVisible(java.awt.Graphics, org.havi.ui.HVisible, int) method
paints any content or other data associated with the look's HVisible. |
void |
HAnimateLook.renderVisible(Graphics g,
HVisible visible,
int state)
The
HExtendedLook.renderVisible(java.awt.Graphics, org.havi.ui.HVisible, int) method
paints any content or other data associated with the look's HVisible. |
void |
HTextLook.showLook(Graphics g,
HVisible visible,
int state)
|
void |
HSinglelineEntryLook.showLook(Graphics g,
HVisible visible,
int state)
|
void |
HRangeLook.showLook(Graphics g,
HVisible visible,
int state)
|
void |
HMultilineEntryLook.showLook(Graphics g,
HVisible visible,
int state)
|
void |
HLook.showLook(Graphics g,
HVisible visible,
int state)
|
void |
HListGroupLook.showLook(Graphics g,
HVisible visible,
int state)
|
void |
HGraphicLook.showLook(Graphics g,
HVisible visible,
int state)
|
void |
HExtendedLook.showLook(Graphics g,
HVisible visible,
int state)
|
void |
HAnimateLook.showLook(Graphics g,
HVisible visible,
int state)
|
void |
HVisible.update(Graphics g)
The update() method in
HVisible
overrides that in Component and does not clear the background
of the component, it simply modifies the current Color of the
Graphics object to match that of the components background Color,
and calls the paint() method. |
Copyright © 2013 CableLabs. All rights reserved.