| Package | Description |
|---|---|
| java.awt |
Contains all of the classes for creating user
interfaces and for painting graphics and images.
|
| java.awt.image |
Provides classes for creating and modifying images.
|
| org.dvb.ui |
Provides extended graphics functionality.
|
| org.havi.ui |
Provides user interfaces to HAVI components.
|
| org.havi.ui.event |
Provides ability to receive HAVI UI events.
|
| Modifier and Type | Method and Description |
|---|---|
Image |
Toolkit.createImage(byte[] imagedata)
Creates an image which decodes the image stored in the specified
byte array.
|
abstract Image |
Toolkit.createImage(byte[] imagedata,
int imageoffset,
int imagelength)
Creates an image which decodes the image stored in the specified
byte array, and at the specified offset and length.
|
abstract Image |
Toolkit.createImage(ImageProducer producer)
Creates an image with the specified image producer.
|
Image |
Component.createImage(ImageProducer producer)
Creates an image from the specified image producer.
|
Image |
Component.createImage(int width,
int height)
Creates an off-screen drawable image
to be used for double buffering.
|
abstract Image |
Toolkit.createImage(String filename)
Returns an image which gets pixel data from the specified file.
|
abstract Image |
Toolkit.createImage(URL url)
Returns an image which gets pixel data from the specified URL.
|
Image |
Frame.getIconImage()
Gets the image to be displayed in the minimized icon
for this frame.
|
abstract Image |
Toolkit.getImage(String filename)
Returns an image which gets pixel data from the specified file,
whose format can be either GIF, JPEG or PNG.
|
abstract Image |
Toolkit.getImage(URL url)
Returns an image which gets pixel data from the specified URL.
|
Image |
Image.getScaledInstance(int width,
int height,
int hints)
Creates a scaled version of this image.
|
| Modifier and Type | Method and Description |
|---|---|
void |
MediaTracker.addImage(Image image,
int id)
Adds an image to the list of images being tracked by this media
tracker.
|
void |
MediaTracker.addImage(Image image,
int id,
int w,
int h)
Adds a scaled image to the list of images being tracked
by this media tracker.
|
int |
Component.checkImage(Image image,
ImageObserver observer)
Returns the status of the construction of a screen representation
of the specified image.
|
abstract int |
Toolkit.checkImage(Image image,
int width,
int height,
ImageObserver observer)
Indicates the construction status of a specified image that is
being prepared for display.
|
int |
Component.checkImage(Image image,
int width,
int height,
ImageObserver observer)
Returns the status of the construction of a screen representation
of the specified image.
|
abstract boolean |
Graphics.drawImage(Image img,
int x,
int y,
Color bgcolor,
ImageObserver observer)
Draws as much of the specified image as is currently available.
|
abstract boolean |
Graphics.drawImage(Image img,
int x,
int y,
ImageObserver observer)
Draws as much of the specified image as is currently available.
|
abstract boolean |
Graphics.drawImage(Image img,
int x,
int y,
int width,
int height,
Color bgcolor,
ImageObserver observer)
Draws as much of the specified image as has already been scaled
to fit inside the specified rectangle.
|
abstract boolean |
Graphics.drawImage(Image img,
int x,
int y,
int width,
int height,
ImageObserver observer)
Draws as much of the specified image as has already been scaled
to fit inside the specified rectangle.
|
abstract boolean |
Graphics.drawImage(Image img,
int dx1,
int dy1,
int dx2,
int dy2,
int sx1,
int sy1,
int sx2,
int sy2,
Color bgcolor,
ImageObserver observer)
Draws as much of the specified area of the specified image as is
currently available, scaling it on the fly to fit inside the
specified area of the destination drawable surface.
|
abstract boolean |
Graphics.drawImage(Image img,
int dx1,
int dy1,
int dx2,
int dy2,
int sx1,
int sy1,
int sx2,
int sy2,
ImageObserver observer)
Draws as much of the specified area of the specified image as is
currently available, scaling it on the fly to fit inside the
specified area of the destination drawable surface.
|
boolean |
Component.imageUpdate(Image img,
int infoflags,
int x,
int y,
int w,
int h)
Repaints the component when the image has changed.
|
boolean |
Component.prepareImage(Image image,
ImageObserver observer)
Prepares an image for rendering on this component.
|
abstract boolean |
Toolkit.prepareImage(Image image,
int width,
int height,
ImageObserver observer)
Prepares an image for rendering.
|
boolean |
Component.prepareImage(Image image,
int width,
int height,
ImageObserver observer)
Prepares an image for rendering on this component at the
specified width and height.
|
void |
MediaTracker.removeImage(Image image)
Removes the specified image from this media tracker.
|
void |
MediaTracker.removeImage(Image image,
int id)
Removes the specified image from the specified tracking
ID of this media tracker.
|
void |
MediaTracker.removeImage(Image image,
int id,
int width,
int height)
Removes the specified image with the specified
width, height, and ID from this media tracker.
|
void |
Frame.setIconImage(Image image)
Sets the image to be displayed in the minimized icon for this frame.
|
| Modifier and Type | Class and Description |
|---|---|
class |
BufferedImage
The
BufferedImage subclass describes an Image with an accessible buffer of image data. |
class |
VolatileImage
VolatileImage is an image which can lose its
contents at any time due to circumstances beyond the control of the
application (e.g., situations caused by the operating system or by
other applications).
|
| Modifier and Type | Method and Description |
|---|---|
boolean |
ImageObserver.imageUpdate(Image img,
int infoflags,
int x,
int y,
int width,
int height)
This method is called when information about an image which was
previously requested using an asynchronous interface becomes
available.
|
| Constructor and Description |
|---|
PixelGrabber(Image img,
int x,
int y,
int w,
int h,
boolean forceRGB)
Create a PixelGrabber object to grab the (x, y, w, h) rectangular
section of pixels from the specified image.
|
PixelGrabber(Image img,
int x,
int y,
int w,
int h,
int[] pix,
int off,
int scansize)
Create a PixelGrabber object to grab the (x, y, w, h) rectangular
section of pixels from the specified image into the given array.
|
| Modifier and Type | Class and Description |
|---|---|
class |
DVBBufferedImage
The
DVBBufferedImage subclass describes an Image with
an accessible buffer of image data. |
| Modifier and Type | Method and Description |
|---|---|
Image |
DVBBufferedImage.getImage()
Returns a java.awt.Image representing this buffered image.
|
Image |
DVBBufferedImage.getScaledInstance(int width,
int height,
int hints)
Creates a scaled version of this image.
|
| Modifier and Type | Method and Description |
|---|---|
Image[] |
HVisible.getAnimateContent(int state)
Gets the animate content for this component.
|
Image |
HScene.getBackgroundImage()
Retrieve any image used as a background for this
HScene. |
Image |
HGraphicsConfiguration.getCompatibleImage(Image input,
HImageHints ih)
Generate a java.awt.Image which may be a modified copy
of the image passed as
input. |
Image |
HVisible.getGraphicContent(int state)
Gets the graphic content for this component.
|
Image |
HListElement.getIcon()
Retrieve the icon for this HListElement.
|
Image |
HImageMatte.getMatteData()
Returns the data used for this matte.
|
Image[] |
HImageEffectMatte.getMatteData()
Returns the data used for this matte.
|
| Modifier and Type | Method and Description |
|---|---|
Image |
HGraphicsConfiguration.getCompatibleImage(Image input,
HImageHints ih)
Generate a java.awt.Image which may be a modified copy
of the image passed as
input. |
void |
HVisible.setAnimateContent(Image[] imageArray,
int state)
Sets an array of graphical content (primarily used for
animation), per state.
|
void |
HScene.setBackgroundImage(Image image)
Set an image which shall be painted in the background of the
HScene, after the background has
been drawn according to the current mode set with setBackgroundMode,
but before any children are drawn. |
void |
HVisible.setGraphicContent(Image image,
int state)
Sets a single piece of graphical content for this component,
per state.
|
void |
HListElement.setIcon(Image icon)
Set the icon for this HListElement.
|
void |
HImageMatte.setMatteData(Image data)
Sets the data for this matte.
|
void |
HImageEffectMatte.setMatteData(Image[] data)
Sets the data for this matte (an array of images).
|
| Constructor and Description |
|---|
HAnimation(Image[] imagesNormal,
Image[] imagesFocused,
int delay,
int playMode,
int repeatCount)
Creates an HAnimation object.
|
HAnimation(Image[] imagesNormal,
Image[] imagesFocused,
int delay,
int playMode,
int repeatCount)
Creates an HAnimation object.
|
HAnimation(Image[] imagesNormal,
Image[] imagesFocused,
int delay,
int playMode,
int repeatCount,
int x,
int y,
int width,
int height)
Creates an HAnimation object.
|
HAnimation(Image[] imagesNormal,
Image[] imagesFocused,
int delay,
int playMode,
int repeatCount,
int x,
int y,
int width,
int height)
Creates an HAnimation object.
|
HAnimation(Image[] images,
int delay,
int playMode,
int repeatCount)
Creates an HAnimation object.
|
HAnimation(Image[] images,
int delay,
int playMode,
int repeatCount,
int x,
int y,
int width,
int height)
Creates an HAnimation object.
|
HGraphicButton(Image image)
Creates an
HGraphicButton
object. |
HGraphicButton(Image imageNormal,
Image imageFocused,
Image imageActioned)
Creates an
HGraphicButton
object. |
HGraphicButton(Image imageNormal,
Image imageFocused,
Image imageActioned,
int x,
int y,
int width,
int height)
Creates an
HGraphicButton
object. |
HGraphicButton(Image image,
int x,
int y,
int width,
int height)
Creates an
HGraphicButton
object. |
HIcon(Image image)
Creates an
HIcon object. |
HIcon(Image imageNormal,
Image imageFocus,
int x,
int y,
int width,
int height)
Creates an
HIcon object. |
HIcon(Image image,
int x,
int y,
int width,
int height)
Creates an
HIcon object. |
HImageEffectMatte(Image[] data)
Creates an
HImageEffectMatte object. |
HImageMatte(Image data)
Creates an
HImageMatte
object. |
HListElement(Image icon,
String label)
Creates an HListElement object.
|
HStaticAnimation(Image[] imagesNormal,
int delay,
int playMode,
int repeatCount)
Creates an
HStaticAnimation object. |
HStaticAnimation(Image[] imagesNormal,
int delay,
int playMode,
int repeatCount,
int x,
int y,
int width,
int height)
Creates an
HStaticAnimation object. |
HStaticIcon(Image imageNormal)
Creates an
HStaticIcon
object. |
HStaticIcon(Image imageNormal,
int x,
int y,
int width,
int height)
Creates an
HStaticIcon
object. |
HToggleButton(Image image)
Creates an
HToggleButton
object. |
HToggleButton(Image image,
boolean state,
HToggleGroup group)
Creates an
HToggleButton
object. |
HToggleButton(Image imageNormal,
Image imageFocused,
Image imageActioned,
Image imageNormalActioned,
boolean state)
Creates an
HToggleButton
object. |
HToggleButton(Image imageNormal,
Image imageFocused,
Image imageActioned,
Image imageNormalActioned,
boolean state,
HToggleGroup group)
Creates an
HToggleButton
object. |
HToggleButton(Image imageNormal,
Image imageFocused,
Image imageActioned,
Image imageNormalActioned,
int x,
int y,
int width,
int height,
boolean state)
Creates an
HToggleButton
object. |
HToggleButton(Image imageNormal,
Image imageFocused,
Image imageActioned,
Image imageNormalActioned,
int x,
int y,
int width,
int height,
boolean state,
HToggleGroup group)
Creates an
HToggleButton
object. |
HToggleButton(Image image,
int x,
int y,
int width,
int height)
Creates an
HToggleButton
object. |
HToggleButton(Image image,
int x,
int y,
int width,
int height,
boolean state)
Creates an
HToggleButton
object. |
HToggleButton(Image image,
int x,
int y,
int width,
int height,
boolean state,
HToggleGroup group)
Creates an
HToggleButton
object. |
| Modifier and Type | Method and Description |
|---|---|
Image |
HEventRepresentation.getSymbol()
This returns an image-based representation (generally used for
symbolic keys) of the current event code.
|
| Modifier and Type | Method and Description |
|---|---|
protected void |
HEventRepresentation.setSymbol(Image aSymbol)
Sets the symbolic representation for this
HEventRepresentation. |
Copyright © 2012 CableLabs. All Rights Reserved.