| Package | Description |
|---|---|
| java.awt |
Contains all of the classes for creating user
interfaces and for painting graphics and images.
|
| java.awt.event |
Provides interfaces and classes for dealing with different
types of events fired by AWT components.
|
| org.havi.ui |
| Modifier and Type | Method and Description |
|---|---|
Point |
GridBagLayout.getLayoutOrigin()
Determines the origin of the layout area, in the graphics coordinate
space of the target container.
|
Point |
Rectangle.getLocation()
Returns the location of this
Rectangle. |
Point |
Point.getLocation()
Returns the location of this point.
|
Point |
Component.getLocation()
Gets the location of this component in the form of a
point specifying the component's top-left corner.
|
Point |
Component.getLocation(Point rv)
Stores the x,y origin of this component into "return value" rv
and return rv.
|
Point |
Component.getLocationOnScreen()
Gets the location of this component in the form of a point
specifying the component's top-left corner in the screen's
coordinate space.
|
Point |
GridBagLayout.location(int x,
int y)
Determines which cell in the layout grid contains the point
specified by
(x, y). |
| Modifier and Type | Method and Description |
|---|---|
void |
Rectangle.add(Point pt)
Adds the specified
Point to this
Rectangle. |
boolean |
Rectangle.contains(Point p)
Checks whether or not this
Rectangle contains the
specified Point. |
boolean |
Polygon.contains(Point p)
Determines whether the specified
Point is inside this
Polygon. |
boolean |
Component.contains(Point p)
Checks whether this component "contains" the specified point,
where the point's x and y coordinates are defined
to be relative to the coordinate system of this component.
|
Component |
Container.findComponentAt(Point p)
Locates the visible child component that contains the specified
point.
|
Component |
Container.getComponentAt(Point p)
Gets the component that contains the specified point.
|
Component |
Component.getComponentAt(Point p)
Returns the component or subcomponent that contains the
specified point.
|
Point |
Component.getLocation(Point rv)
Stores the x,y origin of this component into "return value" rv
and return rv.
|
void |
Rectangle.setLocation(Point p)
Moves this
Rectangle to the specified location. |
void |
Point.setLocation(Point p)
Sets the location of the point to the specified location.
|
void |
Component.setLocation(Point p)
Moves this component to a new location.
|
| Constructor and Description |
|---|
Point(Point p)
Constructs and initializes a point with the same location as
the specified
Point object. |
Rectangle(Point p)
Constructs a new
Rectangle whose top-left corner is the
specified Point, and whose width and height are both zero. |
Rectangle(Point p,
Dimension d)
|
| Modifier and Type | Method and Description |
|---|---|
Point |
MouseEvent.getPoint()
Returns the x,y position of the event relative to the source component.
|
| Modifier and Type | Method and Description |
|---|---|
Point |
HScreenConfiguration.convertTo(HScreenConfiguration destination,
Point source)
Convert a pixel position from one coordinate system to another
without including any rounding errors from passing through
normalized coordinates.
|
Point |
HImageMatte.getOffset()
Get the offset of the matte relative to its component in
pixels.
|
Point |
HImageEffectMatte.getOffset(int index)
Get the offset of a specified frame of the matte relative to
its component in pixels.
|
| Modifier and Type | Method and Description |
|---|---|
Point |
HScreenConfiguration.convertTo(HScreenConfiguration destination,
Point source)
Convert a pixel position from one coordinate system to another
without including any rounding errors from passing through
normalized coordinates.
|
Integer |
HRangeLook.getValue(HOrientable component,
Point pt)
Returns the value of the component which corresponds to the pointer
position specified by pt.
|
Integer |
HListGroupLook.getValue(HOrientable component,
Point pt)
Returns the value of the component which corresponds to the pointer
position specified by pt.
|
Integer |
HAdjustableLook.getValue(HOrientable component,
Point pt)
Returns the value of the component which corresponds to the pointer
position specified by pt.
|
int |
HRangeLook.hitTest(HOrientable component,
Point pt)
Returns a value which indicates the pointer click position in the
on-screen representation of the orientable component.
|
int |
HListGroupLook.hitTest(HOrientable component,
Point pt)
Returns a value which indicates the pointer click position in the
on-screen representation of the orientable component.
|
int |
HAdjustableLook.hitTest(HOrientable component,
Point pt)
Returns a value which indicates the pointer click position in the
on-screen representation of the orientable component.
|
void |
HImageMatte.setOffset(Point p)
Set the offset of the matte relative to its component in
pixels.
|
void |
HImageEffectMatte.setOffset(Point p,
int index)
Set the offset of a specified frame of the matte relative to
its component in pixels.
|
Copyright © 2012. All Rights Reserved.