| Package | Description |
|---|---|
| java.awt |
Contains all of the classes for creating user
interfaces and for painting graphics and images.
|
| java.awt.event |
Provides interfaces and classes for dealing with different
types of events fired by AWT components.
|
| java.awt.im |
Provides classes and interfaces for the input method framework.
|
| javax.tv.media |
Provides controls and events for the management of real-time media
in a television environment.
|
| org.dvb.media |
Provides DVB specific extensions to the Java Media Framework.
|
| org.havi.ui |
Provides user interfaces to HAVI components.
|
| Modifier and Type | Field and Description |
|---|---|
protected Rectangle |
Polygon.bounds
Bounds of the polygon.
|
| Modifier and Type | Method and Description |
|---|---|
Rectangle |
Shape.getBounds()
Returns an integer
Rectangle that completely encloses the
Shape. |
Rectangle |
Rectangle.getBounds()
Gets the bounding
Rectangle of this Rectangle. |
Rectangle |
Polygon.getBounds()
Gets the bounding box of this
Polygon. |
abstract Rectangle |
GraphicsConfiguration.getBounds()
Returns the bounds of the
GraphicsConfiguration
in the device coordinates. |
Rectangle |
Component.getBounds()
Gets the bounds of this component in the form of a
Rectangle object. |
Rectangle |
Component.getBounds(Rectangle rv)
Stores the bounds of this component into "return value" rv and
return rv.
|
abstract Rectangle |
Graphics.getClipBounds()
Returns the bounding rectangle of the current clipping area.
|
Rectangle |
Graphics.getClipBounds(Rectangle r)
Returns the bounding rectangle of the current clipping area.
|
Rectangle |
Rectangle.intersection(Rectangle r)
Computes the intersection of this
Rectangle with the
specified Rectangle. |
Rectangle |
Rectangle.union(Rectangle r)
Computes the union of this
Rectangle with the
specified Rectangle. |
| Modifier and Type | Method and Description |
|---|---|
void |
Rectangle.add(Rectangle r)
Adds a
Rectangle to this Rectangle. |
protected void |
GridBagLayout.adjustForGravity(GridBagConstraints constraints,
Rectangle r)
Adjusts the x, y, width, and height fields to the correct
values depending on the constraint geometry and pads.
|
protected void |
GridBagLayout.AdjustForGravity(GridBagConstraints constraints,
Rectangle r)
This method is obsolete and supplied for backwards
compatability only; new code should call
adjustForGravity instead. |
boolean |
Rectangle.contains(Rectangle r)
Checks whether or not this
Rectangle entirely contains
the specified Rectangle. |
Rectangle |
Component.getBounds(Rectangle rv)
Stores the bounds of this component into "return value" rv and
return rv.
|
Rectangle |
Graphics.getClipBounds(Rectangle r)
Returns the bounding rectangle of the current clipping area.
|
Rectangle |
Rectangle.intersection(Rectangle r)
Computes the intersection of this
Rectangle with the
specified Rectangle. |
boolean |
Rectangle.intersects(Rectangle r)
Determines whether or not this
Rectangle and the specified
Rectangle intersect. |
void |
Rectangle.setBounds(Rectangle r)
Sets the bounding
Rectangle of this Rectangle
to match the specified Rectangle. |
void |
Component.setBounds(Rectangle r)
Moves and resizes this component to conform to the new
bounding rectangle
r. |
Rectangle |
Rectangle.union(Rectangle r)
Computes the union of this
Rectangle with the
specified Rectangle. |
| Constructor and Description |
|---|
Rectangle(Rectangle r)
Constructs a new
Rectangle, initialized to match
the values of the specified Rectangle. |
| Modifier and Type | Method and Description |
|---|---|
Rectangle |
PaintEvent.getUpdateRect()
Returns the rectangle representing the area which needs to be
repainted in response to this event.
|
| Modifier and Type | Method and Description |
|---|---|
void |
PaintEvent.setUpdateRect(Rectangle updateRect)
Sets the rectangle representing the area which needs to be
repainted in response to this event.
|
| Constructor and Description |
|---|
PaintEvent(Component source,
int id,
Rectangle updateRect)
Constructs a
PaintEvent object with the specified
source component and type. |
| Modifier and Type | Method and Description |
|---|---|
Rectangle |
InputMethodRequests.getTextLocation(TextHitInfo offset)
Gets the location of a specified offset in the current composed text,
or of the selection in committed text.
|
| Modifier and Type | Method and Description |
|---|---|
Rectangle |
AWTVideoSize.getDestination()
Return a copy of the rectangle representing where the video is to be
displayed, in the coordinate system of the screen.
|
Rectangle |
AWTVideoSize.getSource()
Return a copy of the rectangle representing the portion of the source
video to display, in the coordinate system of the screen.
|
| Constructor and Description |
|---|
AWTVideoSize(Rectangle source,
Rectangle dest)
Constructs a new
AWTVideoSize instance. |
| Modifier and Type | Method and Description |
|---|---|
Rectangle |
VideoTransformation.getClipRegion()
Gets the clipping region.
|
Rectangle |
VideoPresentationControl.getClipRegion()
This method returns the area of the decoded video that will be
displayed.
|
Rectangle |
VideoPresentationControl.setClipRegion(Rectangle clipRect)
Set the region of the decoded video that will be displayed.
|
| Modifier and Type | Method and Description |
|---|---|
void |
VideoTransformation.setClipRegion(Rectangle clipRect)
Sets the clipping region.
|
Rectangle |
VideoPresentationControl.setClipRegion(Rectangle clipRect)
Set the region of the decoded video that will be displayed.
|
| Constructor and Description |
|---|
VideoTransformation(Rectangle clipRect,
float horizontalScalingFactor,
float verticalScalingFactor,
HScreenPoint location)
Creates a VideoTransformation object with the supplied
parameters.
|
| Modifier and Type | Method and Description |
|---|---|
Rectangle |
HGraphicsConfiguration.getPixelCoordinatesHScreenRectangle(HScreenRectangle sr,
Container cont)
Returns a java.awt.Rectangle which contains the graphics (AWT)
pixel area for an
HScreenRectangle
relative to the supplied java.awt.Container. |
| Modifier and Type | Method and Description |
|---|---|
HScreenRectangle |
HScene.getPixelCoordinatesHScreenRectangle(Rectangle r)
Returns an HScreenRectangle which corresponds to the graphics
(AWT) pixel area specified by the parameter in this HScene.
|
Copyright © 2013 CableLabs. All rights reserved.