| Package | Description |
|---|---|
| java.awt |
Contains all of the classes for creating user
interfaces and for painting graphics and images.
|
| Modifier and Type | Class and Description |
|---|---|
class |
Polygon
The
Polygon class encapsulates a description of a
closed, two-dimensional region within a coordinate space. |
class |
Rectangle
A
Rectangle specifies an area in a coordinate space that is
enclosed by the Rectangle object's top-left point
(x, y)
in the coordinate space, its width, and its height. |
| Modifier and Type | Method and Description |
|---|---|
abstract Shape |
Graphics.getClip()
Gets the current clipping area.
|
| Modifier and Type | Method and Description |
|---|---|
abstract void |
Graphics.setClip(Shape clip)
Sets the current clipping area to an arbitrary clip shape.
|
Copyright © 2012 CableLabs. All Rights Reserved.