| Package | Description |
|---|---|
| java.awt |
Contains all of the classes for creating user
interfaces and for painting graphics and images.
|
| java.awt.image |
Provides classes for creating and modifying images.
|
| javax.tv.graphics |
Provides a mechanism by which Xlets may discover their root container and
describes a mechanism for alpha blending.
|
| org.dvb.ui |
Provides extended graphics functionality.
|
| Modifier and Type | Class and Description |
|---|---|
class |
Color
The
Color class is used encapsulate colors in the default
sRGB color space or colors in arbitrary color spaces identified by a
ColorSpace. |
class |
SystemColor
A class to encapsulate symbolic colors representing the color of
native GUI objects on a system.
|
| Modifier and Type | Class and Description |
|---|---|
class |
ColorModel
The
ColorModel abstract class encapsulates the
methods for translating a pixel value to color components
(for example, red, green, and blue) and an alpha component. |
class |
DirectColorModel
The
DirectColorModel class is a ColorModel
class that works with pixel values that represent RGB
color and alpha information as separate samples and that pack all
samples for a single pixel into a single int, short, or byte quantity. |
class |
IndexColorModel
The
IndexColorModel class is a ColorModel
class that works with pixel values consisting of a
single sample that is an index into a fixed colormap in the default
sRGB color space. |
| Modifier and Type | Class and Description |
|---|---|
class |
AlphaColor
A class that allows a very simple, interoperable form of
compositing.
|
| Modifier and Type | Class and Description |
|---|---|
class |
DVBColor
A Color class which adds the notion of alpha.
|
Copyright © 2013 CableLabs. All rights reserved.