| Package | Description |
|---|---|
| java.awt |
Contains all of the classes for creating user
interfaces and for painting graphics and images.
|
| java.awt.event |
Provides interfaces and classes for dealing with different
types of events fired by AWT components.
|
| Modifier and Type | Class and Description |
|---|---|
class |
Frame
A
Frame is a top-level window with a title and a border. |
| Modifier and Type | Method and Description |
|---|---|
Window |
KeyboardFocusManager.getActiveWindow()
Returns the active Window, if the active Window is in the same context
as the calling thread.
|
Window |
KeyboardFocusManager.getFocusedWindow()
Returns the focused Window, if the focused Window is in the same context
as the calling thread.
|
abstract Window |
GraphicsDevice.getFullScreenWindow()
Returns the
Window object representing the
full-screen window if the device is in full-screen mode
and the Window is in the same context
as the calling thread. |
| Modifier and Type | Method and Description |
|---|---|
Component |
FocusTraversalPolicy.getInitialComponent(Window window)
Returns the Component that should receive the focus when a Window is
made visible for the first time.
|
abstract void |
GraphicsDevice.setFullScreenWindow(Window w)
Enter full-screen mode, or return to windowed mode.
|
| Modifier and Type | Method and Description |
|---|---|
Window |
WindowEvent.getOppositeWindow()
Returns the other Window involved in this focus or activation change.
|
Window |
WindowEvent.getWindow()
Returns the originator of the event.
|
| Constructor and Description |
|---|
WindowEvent(Window source,
int id)
Constructs a
WindowEvent object. |
WindowEvent(Window source,
int id,
Window opposite)
Constructs a
WindowEvent object with the
specified opposite Window. |
Copyright © 2013 CableLabs. All rights reserved.