public class InvocationEvent extends AWTEvent implements ActiveEvent
run() method on a Runnable
when dispatched by the AWT event dispatcher thread. This class can
be used as a reference implementation of ActiveEvent rather
than declaring a new class and defining dispatch().
Instances of this class are placed on the EventQueue by calls
to invokeLater and invokeAndWait. Client code
can use this fact to write replacement functions for invokeLater
and invokeAndWait without writing special-case code
in any AWTEventListener objects.
Note: The timestamps used by this class report the difference,
measured in milliseconds, between the time of the event and midnight,
January 1, 1970 UTC
(similar to System.currentTimeMillis).
ActiveEvent,
EventQueue.invokeLater(java.lang.Runnable),
EventQueue.invokeAndWait(java.lang.Runnable),
AWTEventListener,
Serialized Form| Modifier and Type | Field and Description |
|---|---|
protected boolean |
catchExceptions
Set to true if dispatch() catches Exception and stores it in the
exception instance variable.
|
static int |
INVOCATION_DEFAULT
The default id for all InvocationEvents.
|
static int |
INVOCATION_FIRST
Marks the first integer id for the range of invocation event ids.
|
static int |
INVOCATION_LAST
Marks the last integer id for the range of invocation event ids.
|
protected Object |
notifier
The (potentially null) Object whose notifyAll() method will be called
immediately after the Runnable.run() method returns.
|
protected Runnable |
runnable
The Runnable whose run() method will be called.
|
ACTION_EVENT_MASK, ADJUSTMENT_EVENT_MASK, COMPONENT_EVENT_MASK, consumed, CONTAINER_EVENT_MASK, FOCUS_EVENT_MASK, id, INPUT_METHOD_EVENT_MASK, INVOCATION_EVENT_MASK, ITEM_EVENT_MASK, KEY_EVENT_MASK, MOUSE_EVENT_MASK, MOUSE_MOTION_EVENT_MASK, MOUSE_WHEEL_EVENT_MASK, PAINT_EVENT_MASK, RESERVED_ID_MAX, TEXT_EVENT_MASK, WINDOW_EVENT_MASK, WINDOW_FOCUS_EVENT_MASKsource| Modifier | Constructor and Description |
|---|---|
protected |
InvocationEvent(Object source,
int id,
Runnable runnable,
Object notifier,
boolean catchExceptions)
Constructs an
InvocationEvent with the specified
source and ID which will execute the runnable's run
method when dispatched. |
|
InvocationEvent(Object source,
Runnable runnable)
Constructs an
InvocationEvent with the specified
source which will execute the runnable's run
method when dispatched. |
|
InvocationEvent(Object source,
Runnable runnable,
Object notifier,
boolean catchExceptions)
Constructs an
InvocationEvent with the specified
source which will execute the runnable's run
method when dispatched. |
| Modifier and Type | Method and Description |
|---|---|
void |
dispatch()
Executes the Runnable's
run() method and notifies the
notifier (if any) when run() returns. |
Exception |
getException()
Returns any Exception caught while executing the Runnable's
run()
method. |
long |
getWhen()
Returns the timestamp of when this event occurred.
|
String |
paramString()
Returns a parameter string identifying this event.
|
consume, getID, isConsumed, toStringgetSourcepublic static final int INVOCATION_FIRST
public static final int INVOCATION_DEFAULT
public static final int INVOCATION_LAST
protected Runnable runnable
protected Object notifier
protected boolean catchExceptions
public InvocationEvent(Object source, Runnable runnable)
InvocationEvent with the specified
source which will execute the runnable's run
method when dispatched.source - the Object that originated the eventrunnable - the Runnable whose run
method will be executedpublic InvocationEvent(Object source, Runnable runnable, Object notifier, boolean catchExceptions)
InvocationEvent with the specified
source which will execute the runnable's run
method when dispatched. If notifier is non-null,
notifyAll() will be called on it
immediately after run returns.source - the Object that originated
the eventrunnable - the Runnable whose
run method will be
executednotifier - the Object whose notifyAll
method will be called after
Runnable.run has returnedcatchExceptions - specifies whether dispatch
should catch Exception when executing
the Runnable's run
method, or should instead propagate those
Exceptions to the EventDispatchThread's
dispatch loopprotected InvocationEvent(Object source, int id, Runnable runnable, Object notifier, boolean catchExceptions)
InvocationEvent with the specified
source and ID which will execute the runnable's run
method when dispatched. If notifier is non-null,
notifyAll will be called on it
immediately after run returns.
Note that passing in an invalid id results in
unspecified behavior.
source - the Object that originated
the eventid - the ID for the eventrunnable - the Runnable whose
run method will be executednotifier - the Object whose notifyAll
method will be called after
Runnable.run has returnedcatchExceptions - specifies whether dispatch
should catch Exception when executing the
Runnable's run
method, or should instead propagate those
Exceptions to the EventDispatchThread's
dispatch looppublic void dispatch()
run() method and notifies the
notifier (if any) when run() returns.dispatch in interface ActiveEventpublic Exception getException()
run()
method.public long getWhen()
public String paramString()
paramString in class AWTEventCopyright © 2013 CableLabs. All rights reserved.