public abstract class MouseAdapter extends Object implements MouseListener
Mouse events let you track when a mouse is pressed, released, clicked, when it enters a component, and when it exits. (To track mouse moves and mouse drags, use the MouseMotionAdapter.)
Extend this class to create a MouseEvent listener
and override the methods for the events of interest. (If you implement the
MouseListener interface, you have to define all of
the methods in it. This abstract class defines null methods for them
all, so you can only have to define methods for events you care about.)
Create a listener object using the extended class and then register it with
a component using the component's addMouseListener
method. When a mouse button is pressed, released, or clicked (pressed and
released), or when the mouse cursor enters or exits the component,
the relevant method in the listener object is invoked
and the MouseEvent is passed to it.
MouseEvent,
MouseListener,
Tutorial: Writing a Mouse Listener,
Reference: The Java Class Libraries (update file)| Constructor and Description |
|---|
MouseAdapter() |
| Modifier and Type | Method and Description |
|---|---|
void |
mouseClicked(MouseEvent e)
Invoked when the mouse has been clicked on a component.
|
void |
mouseEntered(MouseEvent e)
Invoked when the mouse enters a component.
|
void |
mouseExited(MouseEvent e)
Invoked when the mouse exits a component.
|
void |
mousePressed(MouseEvent e)
Invoked when a mouse button has been pressed on a component.
|
void |
mouseReleased(MouseEvent e)
Invoked when a mouse button has been released on a component.
|
public void mouseClicked(MouseEvent e)
mouseClicked in interface MouseListenerpublic void mousePressed(MouseEvent e)
mousePressed in interface MouseListenerpublic void mouseReleased(MouseEvent e)
mouseReleased in interface MouseListenerpublic void mouseEntered(MouseEvent e)
mouseEntered in interface MouseListenerpublic void mouseExited(MouseEvent e)
mouseExited in interface MouseListenerCopyright © 2012 CableLabs. All Rights Reserved.