public class PaintEvent extends ComponentEvent
| Modifier and Type | Field and Description |
|---|---|
static int |
PAINT
The paint event type.
|
static int |
PAINT_FIRST
Marks the first integer id for the range of paint event ids.
|
static int |
PAINT_LAST
Marks the last integer id for the range of paint event ids.
|
static int |
UPDATE
The update event type.
|
COMPONENT_FIRST, COMPONENT_HIDDEN, COMPONENT_LAST, COMPONENT_MOVED, COMPONENT_RESIZED, COMPONENT_SHOWNACTION_EVENT_MASK, ADJUSTMENT_EVENT_MASK, COMPONENT_EVENT_MASK, consumed, CONTAINER_EVENT_MASK, FOCUS_EVENT_MASK, id, INPUT_METHOD_EVENT_MASK, INVOCATION_EVENT_MASK, ITEM_EVENT_MASK, KEY_EVENT_MASK, MOUSE_EVENT_MASK, MOUSE_MOTION_EVENT_MASK, MOUSE_WHEEL_EVENT_MASK, PAINT_EVENT_MASK, RESERVED_ID_MAX, TEXT_EVENT_MASK, WINDOW_EVENT_MASK, WINDOW_FOCUS_EVENT_MASKsource| Constructor and Description |
|---|
PaintEvent(Component source,
int id,
Rectangle updateRect)
Constructs a
PaintEvent object with the specified
source component and type. |
| Modifier and Type | Method and Description |
|---|---|
Rectangle |
getUpdateRect()
Returns the rectangle representing the area which needs to be
repainted in response to this event.
|
String |
paramString()
Returns a parameter string identifying this event.
|
void |
setUpdateRect(Rectangle updateRect)
Sets the rectangle representing the area which needs to be
repainted in response to this event.
|
getComponentconsume, getID, isConsumed, toStringgetSourcepublic static final int PAINT_FIRST
public static final int PAINT_LAST
public static final int PAINT
public static final int UPDATE
public PaintEvent(Component source, int id, Rectangle updateRect)
PaintEvent object with the specified
source component and type.
Note that passing in an invalid id results in
unspecified behavior.
source - the object where the event originatedid - the event typeupdateRect - the rectangle area which needs to be repaintedpublic Rectangle getUpdateRect()
public void setUpdateRect(Rectangle updateRect)
updateRect - the rectangle area which needs to be repaintedpublic String paramString()
ComponentEventparamString in class ComponentEventCopyright © 2012. All Rights Reserved.