public class TextEvent extends AWTEvent
TextListener object which registered to receive such
events using the component's addTextListener method.
The object that implements the TextListener interface gets
this TextEvent when the event occurs. The listener is
spared the details of processing individual mouse movements and key strokes
Instead, it can process a "meaningful" (semantic) event like "text changed".
TextListener,
Tutorial: Writing a Text Listener,
Reference: The Java Class Libraries (update file),
Serialized Form| Modifier and Type | Field and Description |
|---|---|
static int |
TEXT_FIRST
The first number in the range of ids used for text events.
|
static int |
TEXT_LAST
The last number in the range of ids used for text events.
|
static int |
TEXT_VALUE_CHANGED
This event id indicates that object's text changed.
|
ACTION_EVENT_MASK, ADJUSTMENT_EVENT_MASK, COMPONENT_EVENT_MASK, consumed, CONTAINER_EVENT_MASK, FOCUS_EVENT_MASK, id, INPUT_METHOD_EVENT_MASK, INVOCATION_EVENT_MASK, ITEM_EVENT_MASK, KEY_EVENT_MASK, MOUSE_EVENT_MASK, MOUSE_MOTION_EVENT_MASK, MOUSE_WHEEL_EVENT_MASK, PAINT_EVENT_MASK, RESERVED_ID_MAX, TEXT_EVENT_MASK, WINDOW_EVENT_MASK, WINDOW_FOCUS_EVENT_MASKsource| Constructor and Description |
|---|
TextEvent(Object source,
int id)
Constructs a
TextEvent object. |
| Modifier and Type | Method and Description |
|---|---|
String |
paramString()
Returns a parameter string identifying this text event.
|
consume, getID, isConsumed, toStringgetSourcepublic static final int TEXT_FIRST
public static final int TEXT_LAST
public static final int TEXT_VALUE_CHANGED
public TextEvent(Object source, int id)
TextEvent object.
Note that passing in an invalid id results in
unspecified behavior.
source - the object that
originated the eventid - an integer that identifies the event typepublic String paramString()
paramString in class AWTEventCopyright © 2013 CableLabs. All rights reserved.