public class WindowEvent extends ComponentEvent
The event is passed to every WindowListener
or WindowAdapter object which registered to receive such
events using the window's addWindowListener method.
(WindowAdapter objects implement the
WindowListener interface.) Each such listener object
gets this WindowEvent when the event occurs.
WindowAdapter,
WindowListener,
Tutorial: Writing a Window Listener,
Reference: The Java Class Libraries (update file),
Serialized Form| Modifier and Type | Field and Description |
|---|---|
static int |
WINDOW_ACTIVATED
The window-activated event type.
|
static int |
WINDOW_CLOSED
The window closed event.
|
static int |
WINDOW_CLOSING
The "window is closing" event.
|
static int |
WINDOW_DEACTIVATED
The window-deactivated event type.
|
static int |
WINDOW_DEICONIFIED
The window deiconified event type.
|
static int |
WINDOW_FIRST
The first number in the range of ids used for window events.
|
static int |
WINDOW_GAINED_FOCUS
The window-gained-focus event type.
|
static int |
WINDOW_ICONIFIED
The window iconified event.
|
static int |
WINDOW_LAST
The last number in the range of ids used for window events.
|
static int |
WINDOW_LOST_FOCUS
The window-lost-focus event type.
|
static int |
WINDOW_OPENED
The window opened event.
|
COMPONENT_FIRST, COMPONENT_HIDDEN, COMPONENT_LAST, COMPONENT_MOVED, COMPONENT_RESIZED, COMPONENT_SHOWNACTION_EVENT_MASK, ADJUSTMENT_EVENT_MASK, COMPONENT_EVENT_MASK, consumed, CONTAINER_EVENT_MASK, FOCUS_EVENT_MASK, id, INPUT_METHOD_EVENT_MASK, INVOCATION_EVENT_MASK, ITEM_EVENT_MASK, KEY_EVENT_MASK, MOUSE_EVENT_MASK, MOUSE_MOTION_EVENT_MASK, MOUSE_WHEEL_EVENT_MASK, PAINT_EVENT_MASK, RESERVED_ID_MAX, TEXT_EVENT_MASK, WINDOW_EVENT_MASK, WINDOW_FOCUS_EVENT_MASKsource| Constructor and Description |
|---|
WindowEvent(Window source,
int id)
Constructs a
WindowEvent object. |
WindowEvent(Window source,
int id,
Window opposite)
Constructs a
WindowEvent object with the
specified opposite Window. |
| Modifier and Type | Method and Description |
|---|---|
Window |
getOppositeWindow()
Returns the other Window involved in this focus or activation change.
|
Window |
getWindow()
Returns the originator of the event.
|
String |
paramString()
Returns a parameter string identifying this event.
|
getComponentconsume, getID, isConsumed, toStringgetSourcepublic static final int WINDOW_FIRST
public static final int WINDOW_OPENED
public static final int WINDOW_CLOSING
public static final int WINDOW_CLOSED
public static final int WINDOW_ICONIFIED
public static final int WINDOW_DEICONIFIED
public static final int WINDOW_ACTIVATED
public static final int WINDOW_DEACTIVATED
public static final int WINDOW_GAINED_FOCUS
public static final int WINDOW_LOST_FOCUS
public static final int WINDOW_LAST
public WindowEvent(Window source, int id, Window opposite)
WindowEvent object with the
specified opposite Window. The opposite
Window is the other Window
involved in this focus or activation change.
For a WINDOW_ACTIVATED or
WINDOW_GAINED_FOCUS event, this is the
Window that lost activation or focus.
For a WINDOW_DEACTIVATED or
WINDOW_LOST_FOCUS event, this is the
Window that gained activation or focus.
If this focus change occurs with a native application, with a
Java application in a different VM, or with no other
Window, then the opposite Window is null.
Note that passing in an invalid id results in
unspecified behavior.
source - the Window object that
originated the eventid - WINDOW_ACTIVATED,
WINDOW_DEACTIVATED,
WINDOW_GAINED_FOCUS,
or WINDOW_LOST_FOCUS. It is
expected that this constructor will not be used for
other WindowEvent types because the
opposite Window of such events
will always be nullopposite - the other Window involved in the
focus or activation change, or nullpublic WindowEvent(Window source, int id)
WindowEvent object.
Note that passing in an invalid id results in
unspecified behavior.
source - the Window object that originated the eventid - an integer indicating the type of eventpublic Window getWindow()
public Window getOppositeWindow()
public String paramString()
paramString in class ComponentEventCopyright © 2013 CableLabs. All rights reserved.