| Package | Description |
|---|---|
| java.awt |
Contains all of the classes for creating user
interfaces and for painting graphics and images.
|
| java.awt.event |
Provides interfaces and classes for dealing with different
types of events fired by AWT components.
|
| org.havi.ui.event | |
| org.ocap.ui.event |
Extensions to HAVi User Interface Event classes, including OCAP
specific remote control events and multiscreen management events.
|
| Modifier and Type | Method and Description |
|---|---|
void |
AWTEventMulticaster.componentHidden(ComponentEvent e)
Handles the componentHidden event by invoking the
componentHidden methods on listener-a and listener-b.
|
void |
AWTEventMulticaster.componentMoved(ComponentEvent e)
Handles the componentMoved event by invoking the
componentMoved methods on listener-a and listener-b.
|
void |
AWTEventMulticaster.componentResized(ComponentEvent e)
Handles the componentResized event by invoking the
componentResized methods on listener-a and listener-b.
|
void |
AWTEventMulticaster.componentShown(ComponentEvent e)
Handles the componentShown event by invoking the
componentShown methods on listener-a and listener-b.
|
protected void |
Component.processComponentEvent(ComponentEvent e)
Processes component events occurring on this component by
dispatching them to any registered
ComponentListener objects. |
| Modifier and Type | Class and Description |
|---|---|
class |
ContainerEvent
A low-level event which indicates that a container's contents
changed because a component was added or removed.
|
class |
FocusEvent
A low-level event which indicates that a Component has gained or lost the
input focus.
|
class |
InputEvent
The root event class for all component-level input events.
|
class |
KeyEvent
An event which indicates that a keystroke occurred in a component.
|
class |
MouseEvent
An event which indicates that a mouse action occurred in a component.
|
class |
MouseWheelEvent
An event which indicates that the mouse wheel was rotated in a component.
|
class |
PaintEvent
The component-level paint event.
|
class |
WindowEvent
A low-level event that indicates that a window has changed its status.
|
| Modifier and Type | Method and Description |
|---|---|
void |
ComponentListener.componentHidden(ComponentEvent e)
Invoked when the component has been made invisible.
|
void |
ComponentAdapter.componentHidden(ComponentEvent e)
Invoked when the component has been made invisible.
|
void |
ComponentListener.componentMoved(ComponentEvent e)
Invoked when the component's position changes.
|
void |
ComponentAdapter.componentMoved(ComponentEvent e)
Invoked when the component's position changes.
|
void |
ComponentListener.componentResized(ComponentEvent e)
Invoked when the component's size changes.
|
void |
ComponentAdapter.componentResized(ComponentEvent e)
Invoked when the component's size changes.
|
void |
ComponentListener.componentShown(ComponentEvent e)
Invoked when the component has been made visible.
|
void |
ComponentAdapter.componentShown(ComponentEvent e)
Invoked when the component has been made visible.
|
| Modifier and Type | Class and Description |
|---|---|
class |
HFocusEvent
An
HFocusEvent event is used to
interact with a component implementing the HNavigationInputPreferred
interface as follows: |
class |
HKeyEvent
An
HKeyEvent event is used to
interact with a component implementing the HKeyboardInputPreferred interface
as follows: |
class |
HRcEvent
The remote control event class.
|
| Modifier and Type | Class and Description |
|---|---|
class |
OCRcEvent
The OCAP remote control event class.
|
Copyright © 2012. All Rights Reserved.