| Package | Description |
|---|---|
| java.awt.event |
Provides interfaces and classes for dealing with different
types of events fired by AWT components.
|
| org.havi.ui.event | |
| org.ocap.ui.event |
Extensions to HAVi User Interface Event classes, including OCAP
specific remote control events and multiscreen management events.
|
| Modifier and Type | Class and Description |
|---|---|
class |
KeyEvent
An event which indicates that a keystroke occurred in a component.
|
class |
MouseEvent
An event which indicates that a mouse action occurred in a component.
|
class |
MouseWheelEvent
An event which indicates that the mouse wheel was rotated in a component.
|
| Modifier and Type | Class and Description |
|---|---|
class |
HKeyEvent
An
HKeyEvent event is used to
interact with a component implementing the HKeyboardInputPreferred interface
as follows: |
class |
HRcEvent
The remote control event class.
|
| Modifier and Type | Class and Description |
|---|---|
class |
OCRcEvent
The OCAP remote control event class.
|
Copyright © 2012. All Rights Reserved.