| Package | Description |
|---|---|
| java.awt.event |
Provides interfaces and classes for dealing with different
types of events fired by AWT components.
|
| java.awt.font |
Provides classes and interface relating to fonts.
|
| java.awt.im |
Provides classes and interfaces for the input method framework.
|
| Modifier and Type | Method and Description |
|---|---|
TextHitInfo |
InputMethodEvent.getCaret()
Gets the caret.
|
TextHitInfo |
InputMethodEvent.getVisiblePosition()
Gets the position that's most important to be visible.
|
| Constructor and Description |
|---|
InputMethodEvent(Component source,
int id,
AttributedCharacterIterator text,
int committedCharacterCount,
TextHitInfo caret,
TextHitInfo visiblePosition)
Constructs an
InputMethodEvent with the specified
source component, type, text, caret, and visiblePosition. |
InputMethodEvent(Component source,
int id,
long when,
AttributedCharacterIterator text,
int committedCharacterCount,
TextHitInfo caret,
TextHitInfo visiblePosition)
Constructs an
InputMethodEvent with the specified
source component, type, time, text, caret, and visiblePosition. |
InputMethodEvent(Component source,
int id,
TextHitInfo caret,
TextHitInfo visiblePosition)
Constructs an
InputMethodEvent with the
specified source component, type, caret, and visiblePosition. |
| Modifier and Type | Method and Description |
|---|---|
static TextHitInfo |
TextHitInfo.afterOffset(int offset)
Creates a
TextHitInfo at the specified offset,
associated with the character after the offset. |
static TextHitInfo |
TextHitInfo.beforeOffset(int offset)
Creates a
TextHitInfo at the specified offset,
associated with the character before the offset. |
TextHitInfo |
TextHitInfo.getOffsetHit(int delta)
Creates a
TextHitInfo whose character index is offset
by delta from the charIndex of this
TextHitInfo. |
TextHitInfo |
TextHitInfo.getOtherHit()
Creates a
TextHitInfo on the other side of the
insertion point. |
static TextHitInfo |
TextHitInfo.leading(int charIndex)
Creates a
TextHitInfo on the leading edge of the
character at the specified charIndex. |
static TextHitInfo |
TextHitInfo.trailing(int charIndex)
Creates a hit on the trailing edge of the character at
the specified
charIndex. |
| Modifier and Type | Method and Description |
|---|---|
TextHitInfo |
InputMethodRequests.getLocationOffset(int x,
int y)
Gets the offset within the composed text for the specified absolute x
and y coordinates on the screen.
|
| Modifier and Type | Method and Description |
|---|---|
Rectangle |
InputMethodRequests.getTextLocation(TextHitInfo offset)
Gets the location of a specified offset in the current composed text,
or of the selection in committed text.
|
Copyright © 2012. All Rights Reserved.