| Package | Description |
|---|---|
| java.awt.im |
Provides classes and interfaces for the input method framework.
|
| Modifier and Type | Field and Description |
|---|---|
static InputMethodHighlight |
InputMethodHighlight.SELECTED_CONVERTED_TEXT_HIGHLIGHT
Constant for the default highlight for selected converted text.
|
static InputMethodHighlight |
InputMethodHighlight.SELECTED_RAW_TEXT_HIGHLIGHT
Constant for the default highlight for selected raw text.
|
static InputMethodHighlight |
InputMethodHighlight.UNSELECTED_CONVERTED_TEXT_HIGHLIGHT
Constant for the default highlight for unselected converted text.
|
static InputMethodHighlight |
InputMethodHighlight.UNSELECTED_RAW_TEXT_HIGHLIGHT
Constant for the default highlight for unselected raw text.
|
Copyright © 2013 CableLabs. All rights reserved.