public class BufferedImage extends Image
BufferedImage subclass describes an Image with an accessible buffer of image data.
All BufferedImage objects have an upper left corner
coordinate of (0, 0).ColorModel| Modifier and Type | Field and Description |
|---|---|
static int |
TYPE_BYTE_BINARY
Represents an opaque byte-packed 1, 2, or 4 bit image.
|
static int |
TYPE_BYTE_INDEXED
Represents an indexed byte image.
|
static int |
TYPE_CUSTOM
Image type is not recognized so it must be a customized
image.
|
static int |
TYPE_INT_ARGB
Represents an image with 8-bit RGBA color components packed into
integer pixels.
|
static int |
TYPE_INT_ARGB_PRE
Represents an image with 8-bit RGBA color components packed into
integer pixels.
|
static int |
TYPE_INT_BGR
Represents an image with 8-bit RGB color components, corresponding
to a Windows- or Solaris- style BGR color model, with the colors
Blue, Green, and Red packed into integer pixels.
|
static int |
TYPE_INT_RGB
Represents an image with 8-bit RGB color components packed into
integer pixels.
|
static int |
TYPE_USHORT_555_RGB
Represents an image with 5-5-5 RGB color components (5-bits red,
5-bits green, 5-bits blue) with no alpha.
|
static int |
TYPE_USHORT_565_RGB
Represents an image with 5-6-5 RGB color components (5-bits red,
6-bits green, 5-bits blue) with no alpha.
|
SCALE_AREA_AVERAGING, SCALE_DEFAULT, SCALE_FAST, SCALE_REPLICATE, SCALE_SMOOTH, UndefinedProperty| Modifier and Type | Method and Description |
|---|---|
Graphics2D |
createGraphics()
Creates a
Graphics2D, which can be used to draw into
this BufferedImage. |
void |
flush()
Flushes all resources being used to cache optimization information.
|
ColorModel |
getColorModel()
Returns the
ColorModel. |
Graphics |
getGraphics()
This method returns a
Graphics2D, but is here
for backwards compatibility. |
int |
getHeight()
Returns the height of the
BufferedImage. |
int |
getHeight(ImageObserver observer)
Returns the height of the
BufferedImage. |
Object |
getProperty(String name)
Returns a property of the image by name.
|
Object |
getProperty(String name,
ImageObserver observer)
Returns a property of the image by name.
|
String[] |
getPropertyNames()
Returns an array of names recognized by
getProperty(String)
or null, if no property names are recognized. |
int |
getRGB(int x,
int y)
Returns an integer pixel in the default RGB color model
(TYPE_INT_ARGB) and default sRGB colorspace.
|
int[] |
getRGB(int startX,
int startY,
int w,
int h,
int[] rgbArray,
int offset,
int scansize)
Returns an array of integer pixels in the default RGB color model
(TYPE_INT_ARGB) and default sRGB color space,
from a portion of the image data.
|
ImageProducer |
getSource()
Returns the object that produces the pixels for the image.
|
BufferedImage |
getSubimage(int x,
int y,
int w,
int h)
Returns a subimage defined by a specified rectangular region.
|
int |
getType()
Returns the image type.
|
int |
getWidth()
Returns the width of the
BufferedImage. |
int |
getWidth(ImageObserver observer)
Returns the width of the
BufferedImage. |
void |
setRGB(int x,
int y,
int rgb)
Sets a pixel in this
BufferedImage to the specified
RGB value. |
void |
setRGB(int startX,
int startY,
int w,
int h,
int[] rgbArray,
int offset,
int scansize)
Sets an array of integer pixels in the default RGB color model
(TYPE_INT_ARGB) and default sRGB color space,
into a portion of the image data.
|
String |
toString()
Returns a
String representation of this
BufferedImage object and its values. |
getScaledInstancepublic static final int TYPE_CUSTOM
public static final int TYPE_INT_RGB
DirectColorModel without
alpha.public static final int TYPE_INT_ARGB
DirectColorModel
with alpha. The color data in this image is considered not to be
premultiplied with alpha.public static final int TYPE_INT_ARGB_PRE
DirectColorModel
with alpha. The color data in this image is considered to be
premultiplied with alpha.public static final int TYPE_INT_BGR
DirectColorModel.public static final int TYPE_USHORT_565_RGB
DirectColorModel.public static final int TYPE_USHORT_555_RGB
DirectColorModel.public static final int TYPE_BYTE_BINARY
IndexColorModel without alpha.
Images with 8 bits per pixel should use the image type
TYPE_BYTE_INDEXED.
public static final int TYPE_BYTE_INDEXED
public int getType()
BufferedImage.TYPE_INT_RGB,
TYPE_INT_ARGB,
TYPE_INT_ARGB_PRE,
TYPE_INT_BGR,
TYPE_BYTE_BINARY,
TYPE_BYTE_INDEXED,
TYPE_USHORT_565_RGB,
TYPE_USHORT_555_RGB,
TYPE_CUSTOMpublic ColorModel getColorModel()
ColorModel.ColorModel of this
BufferedImage.public int getRGB(int x,
int y)
ColorModel. There are only 8-bits of
precision for each color component in the returned data when using
this method.x, y - the coordinates of the pixel from which to get
the pixel in the default RGB color model and sRGB
color spacesetRGB(int, int, int),
setRGB(int, int, int, int, int[], int, int)public int[] getRGB(int startX,
int startY,
int w,
int h,
int[] rgbArray,
int offset,
int scansize)
ColorModel. There are only 8-bits of precision for
each color component in the returned data when
using this method. With a specified coordinate (x, y) in the
image, the ARGB pixel can be accessed in this way:
pixel = rgbArray[offset + (y-startY)*scansize + (x-startX)];
startX, startY - the starting coordinatesw - width of regionh - height of regionrgbArray - if not null, the rgb pixels are
written hereoffset - offset into the rgbArrayscansize - scanline stride for the rgbArrayIllegalArgumentException - if an unknown
datatype is specifiedsetRGB(int, int, int),
setRGB(int, int, int, int, int[], int, int)public void setRGB(int x,
int y,
int rgb)
BufferedImage to the specified
RGB value. The pixel is assumed to be in the default RGB color
model, TYPE_INT_ARGB, and default sRGB color space. For images
with an IndexColorModel, the index with the nearest
color is chosen.x, y - the coordinates of the pixel to setrgb - the RGB valuegetRGB(int, int),
getRGB(int, int, int, int, int[], int, int)public void setRGB(int startX,
int startY,
int w,
int h,
int[] rgbArray,
int offset,
int scansize)
ColorModel. There are only 8-bits of precision for
each color component in the returned data when
using this method. With a specified coordinate (x, y) in the
this image, the ARGB pixel can be accessed in this way:
pixel = rgbArray[offset + (y-startY)*scansize + (x-startX)];
WARNING: No dithering takes place.startX, startY - the starting coordinatesw - width of the regionh - height of the regionrgbArray - the rgb pixelsoffset - offset into the rgbArrayscansize - scanline stride for the rgbArraygetRGB(int, int),
getRGB(int, int, int, int, int[], int, int)public int getWidth()
BufferedImage.BufferedImagepublic int getHeight()
BufferedImage.BufferedImagepublic int getWidth(ImageObserver observer)
BufferedImage.getWidth in class Imageobserver - ignoredBufferedImageImage.getHeight(java.awt.image.ImageObserver),
ImageObserverpublic int getHeight(ImageObserver observer)
BufferedImage.getHeight in class Imageobserver - ignoredBufferedImageImage.getWidth(java.awt.image.ImageObserver),
ImageObserverpublic ImageProducer getSource()
getSource in class ImageImageProducer that is used to produce the
pixels for this image.ImageProducerpublic Object getProperty(String name, ImageObserver observer)
UndefinedProperty field. If the properties
for this image are not yet known, then this method returns
null and the ImageObserver object is
notified later. The property name "comment" should be used to
store an optional comment that can be presented to the user as a
description of the image, its source, or its author.getProperty in class Imagename - the property nameobserver - the ImageObserver that receives
notification regarding image informationObject that is the property referred to by the
specified name or null if the
properties of this image are not yet known.ImageObserver,
Image.UndefinedPropertypublic Object getProperty(String name)
name - the property nameObject that is the property referred to by
the specified name.public void flush()
public Graphics getGraphics()
Graphics2D, but is here
for backwards compatibility. createGraphics is more
convenient, since it is declared to return a
Graphics2D.getGraphics in class ImageGraphics2D, which can be used to draw into
this image.Graphics,
Component.createImage(int, int)public Graphics2D createGraphics()
Graphics2D, which can be used to draw into
this BufferedImage.Graphics2D, used for drawing into this
image.public BufferedImage getSubimage(int x, int y, int w, int h)
BufferedImage shares the same
data array as the original image.x, y - the coordinates of the upper-left corner of the
specified rectangular regionw - the width of the specified rectangular regionh - the height of the specified rectangular regionBufferedImage that is the subimage of this
BufferedImage.RasterFormatException - if the specified
area is not contained within this BufferedImage.public String toString()
String representation of this
BufferedImage object and its values.public String[] getPropertyNames()
getProperty(String)
or null, if no property names are recognized.String array containing all of the property
names that getProperty(String) recognizes;
or null if no property names are recognized.Copyright © 2012 CableLabs. All Rights Reserved.