public class CropImageFilter extends ImageFilter
FilteredImageSource,
ImageFilterconsumerCOMPLETESCANLINES, IMAGEABORTED, IMAGEERROR, RANDOMPIXELORDER, SINGLEFRAME, SINGLEFRAMEDONE, SINGLEPASS, STATICIMAGEDONE, TOPDOWNLEFTRIGHT| Constructor and Description |
|---|
CropImageFilter(int x,
int y,
int w,
int h)
Constructs a CropImageFilter that extracts the absolute rectangular
region of pixels from its source Image as specified by the x, y,
w, and h parameters.
|
| Modifier and Type | Method and Description |
|---|---|
void |
setDimensions(int w,
int h)
Override the source image's dimensions and pass the dimensions
of the rectangular cropped region to the ImageConsumer.
|
void |
setPixels(int x,
int y,
int w,
int h,
ColorModel model,
byte[] pixels,
int off,
int scansize)
Determine whether the delivered byte pixels intersect the region to
be extracted and passes through only that subset of pixels that
appear in the output region.
|
void |
setPixels(int x,
int y,
int w,
int h,
ColorModel model,
int[] pixels,
int off,
int scansize)
Determine if the delivered int pixels intersect the region to
be extracted and pass through only that subset of pixels that
appear in the output region.
|
void |
setProperties(Hashtable props)
Passes along the properties from the source object after adding a
property indicating the cropped region.
|
clone, getFilterInstance, imageComplete, resendTopDownLeftRight, setColorModel, setHintspublic CropImageFilter(int x,
int y,
int w,
int h)
x - the x location of the top of the rectangle to be extractedy - the y location of the top of the rectangle to be extractedw - the width of the rectangle to be extractedh - the height of the rectangle to be extractedpublic void setProperties(Hashtable props)
Note: This method is intended to be called by the
ImageProducer of the Image whose pixels
are being filtered. Developers using
this class to filter pixels from an image should avoid calling
this method directly since that operation could interfere
with the filtering operation.
setProperties in interface ImageConsumersetProperties in class ImageFilterprops - the list of properties to be associated with this
imagepublic void setDimensions(int w,
int h)
Note: This method is intended to be called by the
ImageProducer of the Image whose
pixels are being filtered. Developers using
this class to filter pixels from an image should avoid calling
this method directly since that operation could interfere
with the filtering operation.
setDimensions in interface ImageConsumersetDimensions in class ImageFilterw - the width of the source imageh - the height of the source imageImageConsumerpublic void setPixels(int x,
int y,
int w,
int h,
ColorModel model,
byte[] pixels,
int off,
int scansize)
Note: This method is intended to be called by the
ImageProducer of the Image whose
pixels are being filtered. Developers using
this class to filter pixels from an image should avoid calling
this method directly since that operation could interfere
with the filtering operation.
setPixels in interface ImageConsumersetPixels in class ImageFilterw - the width of the area of pixelsh - the height of the area of pixelsmodel - the specified ColorModelpixels - the array of pixelsoff - the offset into the pixels arrayscansize - the distance from one row of pixels to the next in
the pixels arrayImageConsumer.setPixels(int, int, int, int, java.awt.image.ColorModel, byte[], int, int)public void setPixels(int x,
int y,
int w,
int h,
ColorModel model,
int[] pixels,
int off,
int scansize)
Note: This method is intended to be called by the
ImageProducer of the Image whose
pixels are being filtered. Developers using
this class to filter pixels from an image should avoid calling
this method directly since that operation could interfere
with the filtering operation.
setPixels in interface ImageConsumersetPixels in class ImageFilterw - the width of the area of pixelsh - the height of the area of pixelsmodel - the specified ColorModelpixels - the array of pixelsoff - the offset into the pixels arrayscansize - the distance from one row of pixels to the next in
the pixels arrayImageConsumer.setPixels(int, int, int, int, java.awt.image.ColorModel, byte[], int, int)Copyright © 2012 CableLabs. All Rights Reserved.