| Package | Description |
|---|---|
| java.awt |
Contains all of the classes for creating user
interfaces and for painting graphics and images.
|
| java.awt.image |
Provides classes for creating and modifying images.
|
| Modifier and Type | Method and Description |
|---|---|
abstract ColorModel |
Toolkit.getColorModel()
Determines the color model of this toolkit's screen.
|
abstract ColorModel |
GraphicsConfiguration.getColorModel()
Returns the
ColorModel associated with this
GraphicsConfiguration. |
ColorModel |
Component.getColorModel()
Gets the instance of
ColorModel used to display
the component on the output device. |
| Modifier and Type | Class and Description |
|---|---|
class |
DirectColorModel
The
DirectColorModel class is a ColorModel
class that works with pixel values that represent RGB
color and alpha information as separate samples and that pack all
samples for a single pixel into a single int, short, or byte quantity. |
class |
IndexColorModel
The
IndexColorModel class is a ColorModel
class that works with pixel values consisting of a
single sample that is an index into a fixed colormap in the default
sRGB color space. |
| Modifier and Type | Field and Description |
|---|---|
protected ColorModel |
RGBImageFilter.newmodel
The
ColorModel with which to
replace origmodel when the user calls
substituteColorModel. |
protected ColorModel |
RGBImageFilter.origmodel
|
| Modifier and Type | Method and Description |
|---|---|
ColorModel |
PixelGrabber.getColorModel()
Get the ColorModel for the pixels stored in the array.
|
ColorModel |
BufferedImage.getColorModel()
Returns the
ColorModel. |
static ColorModel |
ColorModel.getRGBdefault()
Returns a
DirectColorModel that describes the default
format for integer RGB values used in many of the methods in the
AWT image interfaces for the convenience of the programmer. |
| Modifier and Type | Method and Description |
|---|---|
void |
MemoryImageSource.newPixels(byte[] newpix,
ColorModel newmodel,
int offset,
int scansize)
Changes to a new byte array to hold the pixels for this image.
|
void |
MemoryImageSource.newPixels(int[] newpix,
ColorModel newmodel,
int offset,
int scansize)
Changes to a new int array to hold the pixels for this image.
|
void |
RGBImageFilter.setColorModel(ColorModel model)
If the ColorModel is an IndexColorModel, and the subclass has
set the canFilterIndexColorModel flag to true, we substitute
a filtered version of the color model here and wherever
that original ColorModel object appears in the setPixels methods.
|
void |
PixelGrabber.setColorModel(ColorModel model)
The setColorModel method is part of the ImageConsumer API which
this class must implement to retrieve the pixels.
|
void |
ImageFilter.setColorModel(ColorModel model)
Filter the information provided in the setColorModel method
of the ImageConsumer interface.
|
void |
ImageConsumer.setColorModel(ColorModel model)
Sets the ColorModel object used for the majority of
the pixels reported using the setPixels method
calls.
|
void |
ReplicateScaleFilter.setPixels(int x,
int y,
int w,
int h,
ColorModel model,
byte[] pixels,
int off,
int scansize)
Choose which rows and columns of the delivered byte pixels are
needed for the destination scaled image and pass through just
those rows and columns that are needed, replicated as necessary.
|
void |
RGBImageFilter.setPixels(int x,
int y,
int w,
int h,
ColorModel model,
byte[] pixels,
int off,
int scansize)
If the ColorModel object is the same one that has already
been converted, then simply passes the pixels through with the
converted ColorModel.
|
void |
PixelGrabber.setPixels(int srcX,
int srcY,
int srcW,
int srcH,
ColorModel model,
byte[] pixels,
int srcOff,
int srcScan)
The setPixels method is part of the ImageConsumer API which
this class must implement to retrieve the pixels.
|
void |
ImageFilter.setPixels(int x,
int y,
int w,
int h,
ColorModel model,
byte[] pixels,
int off,
int scansize)
Filters the information provided in the setPixels method of the
ImageConsumer interface which takes an array of bytes.
|
void |
ImageConsumer.setPixels(int x,
int y,
int w,
int h,
ColorModel model,
byte[] pixels,
int off,
int scansize)
Delivers the pixels of the image with one or more calls
to this method.
|
void |
CropImageFilter.setPixels(int x,
int y,
int w,
int h,
ColorModel model,
byte[] pixels,
int off,
int scansize)
Determine whether the delivered byte pixels intersect the region to
be extracted and passes through only that subset of pixels that
appear in the output region.
|
void |
AreaAveragingScaleFilter.setPixels(int x,
int y,
int w,
int h,
ColorModel model,
byte[] pixels,
int off,
int scansize)
Combine the components for the delivered byte pixels into the
accumulation arrays and send on any averaged data for rows of
pixels that are complete.
|
void |
ReplicateScaleFilter.setPixels(int x,
int y,
int w,
int h,
ColorModel model,
int[] pixels,
int off,
int scansize)
Choose which rows and columns of the delivered int pixels are
needed for the destination scaled image and pass through just
those rows and columns that are needed, replicated as necessary.
|
void |
RGBImageFilter.setPixels(int x,
int y,
int w,
int h,
ColorModel model,
int[] pixels,
int off,
int scansize)
If the ColorModel object is the same one that has already
been converted, then simply passes the pixels through with the
converted ColorModel, otherwise converts the buffer of integer
pixels to the default RGB ColorModel and passes the converted
buffer to the filterRGBPixels method to be converted one by one.
|
void |
PixelGrabber.setPixels(int srcX,
int srcY,
int srcW,
int srcH,
ColorModel model,
int[] pixels,
int srcOff,
int srcScan)
The setPixels method is part of the ImageConsumer API which
this class must implement to retrieve the pixels.
|
void |
ImageFilter.setPixels(int x,
int y,
int w,
int h,
ColorModel model,
int[] pixels,
int off,
int scansize)
Filters the information provided in the setPixels method of the
ImageConsumer interface which takes an array of integers.
|
void |
ImageConsumer.setPixels(int x,
int y,
int w,
int h,
ColorModel model,
int[] pixels,
int off,
int scansize)
The pixels of the image are delivered using one or more calls
to the setPixels method.
|
void |
CropImageFilter.setPixels(int x,
int y,
int w,
int h,
ColorModel model,
int[] pixels,
int off,
int scansize)
Determine if the delivered int pixels intersect the region to
be extracted and pass through only that subset of pixels that
appear in the output region.
|
void |
AreaAveragingScaleFilter.setPixels(int x,
int y,
int w,
int h,
ColorModel model,
int[] pixels,
int off,
int scansize)
Combine the components for the delivered int pixels into the
accumulation arrays and send on any averaged data for rows of
pixels that are complete.
|
void |
RGBImageFilter.substituteColorModel(ColorModel oldcm,
ColorModel newcm)
Registers two ColorModel objects for substitution.
|
| Constructor and Description |
|---|
MemoryImageSource(int w,
int h,
ColorModel cm,
byte[] pix,
int off,
int scan)
Constructs an ImageProducer object which uses an array of bytes
to produce data for an Image object.
|
MemoryImageSource(int w,
int h,
ColorModel cm,
byte[] pix,
int off,
int scan,
Hashtable props)
Constructs an ImageProducer object which uses an array of bytes
to produce data for an Image object.
|
MemoryImageSource(int w,
int h,
ColorModel cm,
int[] pix,
int off,
int scan)
Constructs an ImageProducer object which uses an array of integers
to produce data for an Image object.
|
MemoryImageSource(int w,
int h,
ColorModel cm,
int[] pix,
int off,
int scan,
Hashtable props)
Constructs an ImageProducer object which uses an array of integers
to produce data for an Image object.
|
Copyright © 2013 CableLabs. All rights reserved.