| Package | Description |
|---|---|
| java.awt |
Contains all of the classes for creating user
interfaces and for painting graphics and images.
|
| java.awt.image |
Provides classes for creating and modifying images.
|
| org.dvb.ui |
Provides extended graphics functionality.
|
| org.havi.ui |
| Modifier and Type | Class and Description |
|---|---|
class |
Component
A component is an object having a graphical representation
that can be displayed on the screen and that can interact with the
user.
|
class |
Container
A generic Abstract Window Toolkit(AWT) container object is a component
that can contain other AWT components.
|
class |
Frame
A
Frame is a top-level window with a title and a border. |
class |
Window
A
Window object is a top-level window with no borders and no
menubar. |
| Modifier and Type | Method and Description |
|---|---|
int |
Component.checkImage(Image image,
ImageObserver observer)
Returns the status of the construction of a screen representation
of the specified image.
|
abstract int |
Toolkit.checkImage(Image image,
int width,
int height,
ImageObserver observer)
Indicates the construction status of a specified image that is
being prepared for display.
|
int |
Component.checkImage(Image image,
int width,
int height,
ImageObserver observer)
Returns the status of the construction of a screen representation
of the specified image.
|
abstract boolean |
Graphics.drawImage(Image img,
int x,
int y,
Color bgcolor,
ImageObserver observer)
Draws as much of the specified image as is currently available.
|
abstract boolean |
Graphics.drawImage(Image img,
int x,
int y,
ImageObserver observer)
Draws as much of the specified image as is currently available.
|
abstract boolean |
Graphics.drawImage(Image img,
int x,
int y,
int width,
int height,
Color bgcolor,
ImageObserver observer)
Draws as much of the specified image as has already been scaled
to fit inside the specified rectangle.
|
abstract boolean |
Graphics.drawImage(Image img,
int x,
int y,
int width,
int height,
ImageObserver observer)
Draws as much of the specified image as has already been scaled
to fit inside the specified rectangle.
|
abstract boolean |
Graphics.drawImage(Image img,
int dx1,
int dy1,
int dx2,
int dy2,
int sx1,
int sy1,
int sx2,
int sy2,
Color bgcolor,
ImageObserver observer)
Draws as much of the specified area of the specified image as is
currently available, scaling it on the fly to fit inside the
specified area of the destination drawable surface.
|
abstract boolean |
Graphics.drawImage(Image img,
int dx1,
int dy1,
int dx2,
int dy2,
int sx1,
int sy1,
int sx2,
int sy2,
ImageObserver observer)
Draws as much of the specified area of the specified image as is
currently available, scaling it on the fly to fit inside the
specified area of the destination drawable surface.
|
abstract int |
Image.getHeight(ImageObserver observer)
Determines the height of the image.
|
abstract Object |
Image.getProperty(String name,
ImageObserver observer)
Gets a property of this image by name.
|
abstract int |
Image.getWidth(ImageObserver observer)
Determines the width of the image.
|
boolean |
Component.prepareImage(Image image,
ImageObserver observer)
Prepares an image for rendering on this component.
|
abstract boolean |
Toolkit.prepareImage(Image image,
int width,
int height,
ImageObserver observer)
Prepares an image for rendering.
|
boolean |
Component.prepareImage(Image image,
int width,
int height,
ImageObserver observer)
Prepares an image for rendering on this component at the
specified width and height.
|
| Modifier and Type | Method and Description |
|---|---|
int |
BufferedImage.getHeight(ImageObserver observer)
Returns the height of the
BufferedImage. |
Object |
BufferedImage.getProperty(String name,
ImageObserver observer)
Returns a property of the image by name.
|
int |
BufferedImage.getWidth(ImageObserver observer)
Returns the width of the
BufferedImage. |
| Modifier and Type | Method and Description |
|---|---|
int |
DVBBufferedImage.getHeight(ImageObserver observer)
Returns the height of the image.
|
Object |
DVBBufferedImage.getProperty(String name,
ImageObserver observer)
Returns a property of the image by name.
|
int |
DVBBufferedImage.getWidth(ImageObserver observer)
Returns the width of the image.
|
| Modifier and Type | Class and Description |
|---|---|
class |
HAnimation
The
HAnimation class is a user
interface component used to display animated graphical content (as
HStaticAnimation) which
additionally enables a user to navigate to it, i.e. |
class |
HComponent
The
HComponent class extends the
java.awt.Component class by implementing the HMatteLayer interface. |
class |
HContainer
The
HContainer class extends the
java.awt.Container class by implementing the HMatteLayer interface and providing
additional Z-ordering capabilities, which are required since
components in the HAVi user-interface are explicitly allowed to
overlap each other. |
class |
HGraphicButton
The
HGraphicButton is a user interface
component representing a push-button with static read-only graphical
content. |
class |
HIcon
The
HIcon is a user interface
component used to display static graphical content (as HStaticIcon) which also enables a user to
navigate to it, i.e. |
class |
HListGroup
The
HListGroup is a user interface
component representing a list of selectable items (HListElements) which contain
graphical and / or textual content. |
class |
HMultilineEntry
The
HMultilineEntry is a user interface
component used to receive multiple lines of alphanumeric entry from
the user. |
class |
HRange
The
HRange is a user interface
component used to display a value within a fixed range (as
org.havi.ui.HStaticRange HStaticRange}) which also enables a user to
navigate to it, i.e. |
class |
HRangeValue
The
HRangeValue is a user interface
component used to display a value within a fixed range (as
org.havi.ui.HStaticRange HStaticRange}) which enables a user to
navigate to and alter the value of it, i.e. |
class |
HScene
An
HScene is a container representing
the displayable area on-screen within which the application can
display itself and thus interact with the user. |
class |
HSinglelineEntry
The
HSinglelineEntry is a user interface
component used to receive a single line of alphanumeric entry from
the user and can also be used for password input. |
class |
HStaticAnimation
The
HStaticAnimation is a user interface
component used to display animated graphical content but which does
not permit the user to navigate (focus) upon it. |
class |
HStaticIcon
The
HStaticIcon is a user interface
component used to display static graphical content which does
not permit the user to navigate (focus) upon it. |
class |
HStaticRange
The
HStaticRange is a user interface
component used to display a static value which is within a fixed
range, but does not permit the user to navigate (focus) upon it. |
class |
HStaticText
The
HStaticText is a user interface
component used to display static read-only textual content which
does not permit the user to navigate (focus) upon it. |
class |
HText
The
HText is a user interface
component used to display static read-only textual content (as
HStaticText) which additionally
enables a user to navigate to it, i.e. |
class |
HTextButton
The
HTextButton is a user interface
component representing a push-button with static read-only textual
content. |
class |
HToggleButton
The
HToggleButton is a user interface
component representing a "check box", or with the support
of the HToggleGroup class,
"radio buttons". |
class |
HVideoComponent
HVideoComponent is an opaque
class encapsulating the presentation of a video source
within an application, i.e. |
class |
HVisible
The
HVisible class is the base class
for all non-interactive components. |
Copyright © 2012 CableLabs. All Rights Reserved.