| Package | Description |
|---|---|
| java.awt |
Contains all of the classes for creating user
interfaces and for painting graphics and images.
|
| java.awt.image |
Provides classes for creating and modifying images.
|
| org.dvb.ui |
Provides extended graphics functionality.
|
| org.havi.ui |
| Class and Description |
|---|
| BufferedImage
The
BufferedImage subclass describes an Image with an accessible buffer of image data. |
| ColorModel
The
ColorModel abstract class encapsulates the
methods for translating a pixel value to color components
(for example, red, green, and blue) and an alpha component. |
| ImageObserver
An asynchronous update interface for receiving notifications about
Image information as the Image is constructed.
|
| ImageProducer
The interface for objects which can produce the image data for Images.
|
| VolatileImage
VolatileImage is an image which can lose its
contents at any time due to circumstances beyond the control of the
application (e.g., situations caused by the operating system or by
other applications).
|
| Class and Description |
|---|
| BufferedImage
The
BufferedImage subclass describes an Image with an accessible buffer of image data. |
| ColorModel
The
ColorModel abstract class encapsulates the
methods for translating a pixel value to color components
(for example, red, green, and blue) and an alpha component. |
| ImageConsumer
The interface for objects expressing interest in image data through
the ImageProducer interfaces.
|
| ImageFilter
This class implements a filter for the set of interface methods that
are used to deliver data from an ImageProducer to an ImageConsumer.
|
| ImageObserver
An asynchronous update interface for receiving notifications about
Image information as the Image is constructed.
|
| ImageProducer
The interface for objects which can produce the image data for Images.
|
| IndexColorModel
The
IndexColorModel class is a ColorModel
class that works with pixel values consisting of a
single sample that is an index into a fixed colormap in the default
sRGB color space. |
| ReplicateScaleFilter
An ImageFilter class for scaling images using the simplest algorithm.
|
| Class and Description |
|---|
| ImageObserver
An asynchronous update interface for receiving notifications about
Image information as the Image is constructed.
|
| ImageProducer
The interface for objects which can produce the image data for Images.
|
| Class and Description |
|---|
| ImageObserver
An asynchronous update interface for receiving notifications about
Image information as the Image is constructed.
|
Copyright © 2012. All Rights Reserved.