| Package | Description |
|---|---|
| java.awt |
Contains all of the classes for creating user
interfaces and for painting graphics and images.
|
| java.awt.event |
Provides interfaces and classes for dealing with different
types of events fired by AWT components.
|
| java.awt.im |
Provides classes and interfaces for the input method framework.
|
| java.awt.image |
Provides classes for creating and modifying images.
|
| javax.media | |
| javax.microedition.xlet |
Provides interfaces used by applications and the application manager
to communicate.
|
| javax.tv.graphics |
Provides a mechanism by which Xlets may discover their root container and
describes a mechanism for alpha blending.
|
| javax.tv.media |
Provides controls and events for the management of real-time media
in a television environment.
|
| org.dvb.media |
Provides DVB specific extensions to the Java Media Framework.
|
| org.dvb.ui |
Provides extended graphics functionality.
|
| org.havi.ui | |
| org.havi.ui.event | |
| org.ocap.hardware |
The org.ocap.hardware package provides representations of several aspects of the hardware.
|
| org.ocap.ui.event |
Extensions to HAVi User Interface Event classes, including OCAP
specific remote control events and multiscreen management events.
|
| Class and Description |
|---|
| AlphaComposite
This
AlphaComposite class implements the basic alpha
compositing rules for combining source and destination pixels to achieve
blending and transparency effects with graphics and images. |
| AWTEvent
The root event class for all AWT events.
|
| AWTException
Signals that an Absract Window Toolkit exception has occurred.
|
| AWTKeyStroke
An
AWTKeyStroke represents a key action on the
keyboard, or equivalent input device. |
| Color
The
Color class is used encapsulate colors in the default
sRGB color space or colors in arbitrary color spaces identified by a
ColorSpace. |
| Component
A component is an object having a graphical representation
that can be displayed on the screen and that can interact with the
user.
|
| Composite
The
Composite interface defines the methods to compose a draw
primitive with the underlying graphics area. |
| Container
A generic Abstract Window Toolkit(AWT) container object is a component
that can contain other AWT components.
|
| ContainerOrderFocusTraversalPolicy
A FocusTraversalPolicy that determines traversal order based on the order
of child Components in a Container.
|
| Cursor
A class to encapsulate the bitmap representation of the mouse cursor.
|
| Dimension
The
Dimension class encapsulates the width and
height of a component (in integer precision) in a single object. |
EventQueue
EventQueue is a platform-independent class
that queues events, both from the underlying peer classes
and from trusted application classes. |
| FocusTraversalPolicy
A FocusTraversalPolicy defines the order in which Components with a
particular focus cycle root are traversed.
|
| Font
The
Font class represents fonts, which are used to
render text in a visible way. |
| FontMetrics
The
FontMetrics class defines a font metrics object, which
encapsulates information about the rendering of a particular font on a
particular screen. |
| Graphics
The
Graphics class is the abstract base class for
all graphics contexts that allow an application to draw onto
components that are realized on various devices, as well as
onto off-screen images. |
| Graphics2D
This
Graphics2D class extends the
Graphics class to provide more sophisticated
control over
graphics operations. |
| GraphicsConfiguration
The
GraphicsConfiguration class describes the
characteristics of a graphics destination such as a printer or monitor. |
| GraphicsDevice
The
GraphicsDevice class describes the graphics devices
that might be available in a particular graphics environment. |
| GraphicsEnvironment
The
GraphicsEnvironment class describes the collection
of GraphicsDevice objects and Font objects
available to a Java(tm) application on a particular platform. |
| GridBagConstraints
The
GridBagConstraints class specifies constraints
for components that are laid out using the
GridBagLayout class. |
| HeadlessException
Thrown when code that is dependent on a keyboard, display, or mouse
is called in an environment that does not support a keyboard, display,
or mouse.
|
| Image
The abstract class
Image is the superclass of all
classes that represent graphical images. |
| ImageCapabilities
Capabilities and properties of images.
|
| Insets
An
Insets object is a representation of the borders
of a container. |
| KeyboardFocusManager
The KeyboardFocusManager is responsible for managing the active and focused
Windows, and the current focus owner.
|
| KeyEventDispatcher
A KeyEventDispatcher cooperates with the current KeyboardFocusManager in the
targeting and dispatching of all KeyEvents.
|
| KeyEventPostProcessor
A KeyEventPostProcessor cooperates with the current KeyboardFocusManager
in the final resolution of all unconsumed KeyEvents.
|
| LayoutManager
Defines the interface for classes that know how to lay out
Containers. |
| LayoutManager2
Defines an interface for classes that know how to layout Containers
based on a layout constraints object.
|
| Point
A point representing a location in (x, y) coordinate space, specified
in integer precision.
|
| Polygon
The
Polygon class encapsulates a description of a
closed, two-dimensional region within a coordinate space. |
| Rectangle
A
Rectangle specifies an area in a coordinate space that is
enclosed by the Rectangle object's top-left point
(x, y)
in the coordinate space, its width, and its height. |
| Shape
The
Shape interface provides definitions for objects
that represent some form of geometric shape. |
| Stroke
The
Stroke interface allows a
Graphics2D object to obtain a Shape that is the
decorated outline, or stylistic representation of the outline,
of the specified Shape. |
| SystemColor
A class to encapsulate symbolic colors representing the color of
native GUI objects on a system.
|
| Toolkit
This class is the abstract superclass of all actual
implementations of the Abstract Window Toolkit.
|
| Transparency
The
Transparency interface defines the common transparency
modes for implementing classes. |
| Window
A
Window object is a top-level window with no borders and no
menubar. |
| Class and Description |
|---|
| ActiveEvent
An interface for events that know how to dispatch themselves.
|
| Adjustable
The interface for objects which have an adjustable numeric value
contained within a bounded range of values.
|
| AWTEvent
The root event class for all AWT events.
|
| Component
A component is an object having a graphical representation
that can be displayed on the screen and that can interact with the
user.
|
| Container
A generic Abstract Window Toolkit(AWT) container object is a component
that can contain other AWT components.
|
| ItemSelectable
The interface for objects which contain a set of items for
which zero or more can be selected.
|
| Point
A point representing a location in (x, y) coordinate space, specified
in integer precision.
|
| Rectangle
A
Rectangle specifies an area in a coordinate space that is
enclosed by the Rectangle object's top-left point
(x, y)
in the coordinate space, its width, and its height. |
| Window
A
Window object is a top-level window with no borders and no
menubar. |
| Class and Description |
|---|
| AWTEvent
The root event class for all AWT events.
|
| Component
A component is an object having a graphical representation
that can be displayed on the screen and that can interact with the
user.
|
| Rectangle
A
Rectangle specifies an area in a coordinate space that is
enclosed by the Rectangle object's top-left point
(x, y)
in the coordinate space, its width, and its height. |
| Class and Description |
|---|
| Graphics
The
Graphics class is the abstract base class for
all graphics contexts that allow an application to draw onto
components that are realized on various devices, as well as
onto off-screen images. |
| Graphics2D
This
Graphics2D class extends the
Graphics class to provide more sophisticated
control over
graphics operations. |
| GraphicsConfiguration
The
GraphicsConfiguration class describes the
characteristics of a graphics destination such as a printer or monitor. |
| Image
The abstract class
Image is the superclass of all
classes that represent graphical images. |
| ImageCapabilities
Capabilities and properties of images.
|
| Transparency
The
Transparency interface defines the common transparency
modes for implementing classes. |
| Class and Description |
|---|
| Component
A component is an object having a graphical representation
that can be displayed on the screen and that can interact with the
user.
|
| Class and Description |
|---|
| Container
A generic Abstract Window Toolkit(AWT) container object is a component
that can contain other AWT components.
|
| Class and Description |
|---|
| Color
The
Color class is used encapsulate colors in the default
sRGB color space or colors in arbitrary color spaces identified by a
ColorSpace. |
| Container
A generic Abstract Window Toolkit(AWT) container object is a component
that can contain other AWT components.
|
| Transparency
The
Transparency interface defines the common transparency
modes for implementing classes. |
| Class and Description |
|---|
| Dimension
The
Dimension class encapsulates the width and
height of a component (in integer precision) in a single object. |
| Rectangle
A
Rectangle specifies an area in a coordinate space that is
enclosed by the Rectangle object's top-left point
(x, y)
in the coordinate space, its width, and its height. |
| Class and Description |
|---|
| Dimension
The
Dimension class encapsulates the width and
height of a component (in integer precision) in a single object. |
| Rectangle
A
Rectangle specifies an area in a coordinate space that is
enclosed by the Rectangle object's top-left point
(x, y)
in the coordinate space, its width, and its height. |
| Class and Description |
|---|
| Color
The
Color class is used encapsulate colors in the default
sRGB color space or colors in arbitrary color spaces identified by a
ColorSpace. |
| Font
The
Font class represents fonts, which are used to
render text in a visible way. |
| Graphics
The
Graphics class is the abstract base class for
all graphics contexts that allow an application to draw onto
components that are realized on various devices, as well as
onto off-screen images. |
| Image
The abstract class
Image is the superclass of all
classes that represent graphical images. |
| Insets
An
Insets object is a representation of the borders
of a container. |
| Transparency
The
Transparency interface defines the common transparency
modes for implementing classes. |
| Class and Description |
|---|
| AWTEvent
The root event class for all AWT events.
|
| Color
The
Color class is used encapsulate colors in the default
sRGB color space or colors in arbitrary color spaces identified by a
ColorSpace. |
| Component
A component is an object having a graphical representation
that can be displayed on the screen and that can interact with the
user.
|
| Container
A generic Abstract Window Toolkit(AWT) container object is a component
that can contain other AWT components.
|
| Dimension
The
Dimension class encapsulates the width and
height of a component (in integer precision) in a single object. |
| Font
The
Font class represents fonts, which are used to
render text in a visible way. |
| Graphics
The
Graphics class is the abstract base class for
all graphics contexts that allow an application to draw onto
components that are realized on various devices, as well as
onto off-screen images. |
| Image
The abstract class
Image is the superclass of all
classes that represent graphical images. |
| Insets
An
Insets object is a representation of the borders
of a container. |
| Point
A point representing a location in (x, y) coordinate space, specified
in integer precision.
|
| Rectangle
A
Rectangle specifies an area in a coordinate space that is
enclosed by the Rectangle object's top-left point
(x, y)
in the coordinate space, its width, and its height. |
| Class and Description |
|---|
| AWTEvent
The root event class for all AWT events.
|
| Color
The
Color class is used encapsulate colors in the default
sRGB color space or colors in arbitrary color spaces identified by a
ColorSpace. |
| Component
A component is an object having a graphical representation
that can be displayed on the screen and that can interact with the
user.
|
| Image
The abstract class
Image is the superclass of all
classes that represent graphical images. |
| Class and Description |
|---|
| Dimension
The
Dimension class encapsulates the width and
height of a component (in integer precision) in a single object. |
| Class and Description |
|---|
| AWTEvent
The root event class for all AWT events.
|
| Component
A component is an object having a graphical representation
that can be displayed on the screen and that can interact with the
user.
|
Copyright © 2012. All Rights Reserved.