public class Beans extends Object
| Constructor and Description |
|---|
Beans() |
| Modifier and Type | Method and Description |
|---|---|
static Object |
instantiate(ClassLoader cls,
String beanName)
Instantiate a JavaBean.
|
static boolean |
isDesignTime()
Test if we are in design-mode.
|
static boolean |
isGuiAvailable()
Determines whether beans can assume a GUI is available.
|
public static Object instantiate(ClassLoader cls, String beanName) throws IOException, ClassNotFoundException
Instantiate a JavaBean.
The bean is created based on a name relative to a class-loader. This name should be a dot-separated name such as "a.b.c".In Beans 1.0 the given name can indicate either a serialized object or a class. Other mechanisms may be added in the future. In beans 1.0 we first try to treat the beanName as a serialized object name then as a class name.
When using the beanName as a serialized object name we convert the given beanName to a resource pathname and add a trailing ".ser" suffix. We then try to load a serialized object from that resource.
For example, given a beanName of "x.y", Beans.instantiate would first try to read a serialized object from the resource "x/y.ser" and if that failed it would try to load the class "x.y" and create an instance of that class.
cls - the class-loader from which we should create
the bean. If this is null, then the system
class-loader is used.beanName - the name of the bean within the class-loader.
For example "sun.beanbox.foobah"ClassNotFoundException - if the class of a serialized
object could not be found.IOException - if an I/O error occurs.public static boolean isDesignTime()
This method always returns false in
this Profile.
public static boolean isGuiAvailable()
VisibilityCopyright © 2013 CableLabs. All rights reserved.