public class VetoableChangeSupport extends Object implements Serializable
| Constructor and Description |
|---|
VetoableChangeSupport(Object sourceBean)
Constructs a
VetoableChangeSupport object. |
| Modifier and Type | Method and Description |
|---|---|
void |
addVetoableChangeListener(VetoableChangeListener listener)
Add a VetoableListener to the listener list.
|
void |
fireVetoableChange(String propertyName,
Object oldValue,
Object newValue)
Report a vetoable property update to any registered listeners.
|
VetoableChangeListener[] |
getVetoableChangeListeners()
Returns the list of VetoableChangeListeners.
|
void |
removeVetoableChangeListener(VetoableChangeListener listener)
Remove a VetoableChangeListener from the listener list.
|
public VetoableChangeSupport(Object sourceBean)
VetoableChangeSupport object.sourceBean - The bean to be given as the source for any events.public void addVetoableChangeListener(VetoableChangeListener listener)
listener - The VetoableChangeListener to be addedpublic void removeVetoableChangeListener(VetoableChangeListener listener)
listener - The VetoableChangeListener to be removedpublic VetoableChangeListener[] getVetoableChangeListeners()
public void fireVetoableChange(String propertyName, Object oldValue, Object newValue) throws PropertyVetoException
No event is fired if old and new are equal and non-null.
propertyName - The programmatic name of the property
that is about to change..oldValue - The old value of the property.newValue - The new value of the property.PropertyVetoException - if the recipient wishes the property
change to be rolled back.Copyright © 2013 CableLabs. All rights reserved.