| Package | Description |
|---|---|
| java.beans |
Contains classes for run-time Java Beans support.
|
| Modifier and Type | Method and Description |
|---|---|
PropertyChangeEvent |
PropertyVetoException.getPropertyChangeEvent()
Gets the vetoed
PropertyChangeEvent. |
| Modifier and Type | Method and Description |
|---|---|
void |
PropertyChangeListener.propertyChange(PropertyChangeEvent evt)
This method gets called when a bound property is changed.
|
void |
VetoableChangeListener.vetoableChange(PropertyChangeEvent evt)
This method gets called when a constrained property is changed.
|
| Constructor and Description |
|---|
PropertyVetoException(String mess,
PropertyChangeEvent evt)
Constructs a
PropertyVetoException with a
detailed message. |
Copyright © 2012 CableLabs. All Rights Reserved.