| Package | Description |
|---|---|
| java.beans |
Contains classes for run-time Java Beans support.
|
| Modifier and Type | Method and Description |
|---|---|
void |
VetoableChangeSupport.fireVetoableChange(String propertyName,
Object oldValue,
Object newValue)
Report a vetoable property update to any registered listeners.
|
void |
VetoableChangeListener.vetoableChange(PropertyChangeEvent evt)
This method gets called when a constrained property is changed.
|
Copyright © 2013 CableLabs. All rights reserved.