| Interface | Description |
|---|---|
| PropertyChangeListener |
A "PropertyChange" event gets fired whenever a bean changes a "bound"
property.
|
| VetoableChangeListener |
A VetoableChange event gets fired whenever a bean changes a "constrained"
property.
|
| Visibility |
Under some circumstances a bean may be run on servers where a GUI
is not available.
|
| Class | Description |
|---|---|
| Beans |
This class provides some general purpose beans control methods.
|
| PropertyChangeEvent |
A "PropertyChange" event gets delivered whenever a bean changes a "bound"
or "constrained" property.
|
| PropertyChangeSupport |
This is a utility class that can be used by beans that support bound
properties.
|
| VetoableChangeSupport |
This is a utility class that can be used by beans that support constrained
properties.
|
| Exception | Description |
|---|---|
| PropertyVetoException |
A PropertyVetoException is thrown when a proposed change to a
property represents an unacceptable value.
|
Copyright © 2013 CableLabs. All rights reserved.