public class FileNotFoundException extends IOException
This exception will be thrown by the FileInputStream, FileOutputStream, and RandomAccessFile (NOTE: RandomAccessFile
is found in J2ME CDC profiles such as J2ME Foundation Profile)
constructors when a file with the specified pathname does not exist.
It will also be thrown by these constructors if the file does exist but
for some reason is inaccessible, for example when an attempt is made to
open a read-only file for writing.
| Constructor and Description |
|---|
FileNotFoundException()
Constructs a
FileNotFoundException with
null as its error detail message. |
FileNotFoundException(String s)
Constructs a
FileNotFoundException with the
specified detail message. |
fillInStackTrace, getCause, getLocalizedMessage, getMessage, getStackTrace, initCause, printStackTrace, printStackTrace, printStackTrace, setStackTrace, toStringpublic FileNotFoundException()
FileNotFoundException with
null as its error detail message.public FileNotFoundException(String s)
FileNotFoundException with the
specified detail message. The string s can be
retrieved later by the
Throwable.getMessage()
method of class java.lang.Throwable.s - the detail message.Copyright © 2013 CableLabs. All rights reserved.