public abstract class FilterReader extends Reader
FilterReader itself
provides default methods that pass all requests to
the contained stream. Subclasses of FilterReader
should override some of these methods and may also provide
additional methods and fields.| Modifier and Type | Field and Description |
|---|---|
protected Reader |
in
The underlying character-input stream.
|
| Modifier | Constructor and Description |
|---|---|
protected |
FilterReader(Reader in)
Create a new filtered reader.
|
| Modifier and Type | Method and Description |
|---|---|
void |
close()
Close the stream.
|
void |
mark(int readAheadLimit)
Mark the present position in the stream.
|
boolean |
markSupported()
Tell whether this stream supports the mark() operation.
|
int |
read()
Read a single character.
|
int |
read(char[] cbuf,
int off,
int len)
Read characters into a portion of an array.
|
boolean |
ready()
Tell whether this stream is ready to be read.
|
void |
reset()
Reset the stream.
|
long |
skip(long n)
Skip characters.
|
protected Reader in
protected FilterReader(Reader in)
in - a Reader object providing the underlying stream.NullPointerException - if in is nullpublic int read()
throws IOException
read in class ReaderIOException - If an I/O error occurspublic int read(char[] cbuf,
int off,
int len)
throws IOException
read in class Readercbuf - Destination bufferoff - Offset at which to start storing characterslen - Maximum number of characters to readIOException - If an I/O error occurspublic long skip(long n)
throws IOException
skip in class Readern - The number of characters to skipIOException - If an I/O error occurspublic boolean ready()
throws IOException
ready in class ReaderIOException - If an I/O error occurspublic boolean markSupported()
markSupported in class Readerpublic void mark(int readAheadLimit)
throws IOException
mark in class ReaderreadAheadLimit - Limit on the number of characters that may be
read while still preserving the mark. After
reading this many characters, attempting to
reset the stream may fail.IOException - If an I/O error occurspublic void reset()
throws IOException
reset in class ReaderIOException - If an I/O error occurspublic void close()
throws IOException
close in class ReaderIOException - If an I/O error occursCopyright © 2013 CableLabs. All rights reserved.