public abstract static class ObjectOutputStream.PutField extends Object
| Constructor and Description |
|---|
ObjectOutputStream.PutField() |
| Modifier and Type | Method and Description |
|---|---|
abstract void |
put(String name,
boolean val)
Put the value of the named boolean field into the persistent field.
|
abstract void |
put(String name,
byte val)
Put the value of the named byte field into the persistent field.
|
abstract void |
put(String name,
char val)
Put the value of the named char field into the persistent field.
|
abstract void |
put(String name,
double val)
Put the value of the named double field into the persistent field.
|
abstract void |
put(String name,
float val)
Put the value of the named float field into the persistent field.
|
abstract void |
put(String name,
int val)
Put the value of the named int field into the persistent field.
|
abstract void |
put(String name,
long val)
Put the value of the named long field into the persistent field.
|
abstract void |
put(String name,
Object val)
Put the value of the named Object field into the persistent field.
|
abstract void |
put(String name,
short val)
Put the value of the named short field into the persistent field.
|
abstract void |
write(ObjectOutput out)
Write the data and fields to the specified ObjectOutput stream.
|
public abstract void put(String name, boolean val)
name - the name of the serializable fieldval - the value to assign to the fieldpublic abstract void put(String name, byte val)
name - the name of the serializable fieldval - the value to assign to the fieldpublic abstract void put(String name, char val)
name - the name of the serializable fieldval - the value to assign to the fieldpublic abstract void put(String name, short val)
name - the name of the serializable fieldval - the value to assign to the fieldpublic abstract void put(String name, int val)
name - the name of the serializable fieldval - the value to assign to the fieldpublic abstract void put(String name, long val)
name - the name of the serializable fieldval - the value to assign to the fieldpublic abstract void put(String name, float val)
name - the name of the serializable fieldval - the value to assign to the fieldpublic abstract void put(String name, double val)
name - the name of the serializable fieldval - the value to assign to the fieldpublic abstract void put(String name, Object val)
name - the name of the serializable fieldval - the value to assign to the fieldpublic abstract void write(ObjectOutput out) throws IOException
out - the stream to write the data and fields toIOException - if I/O errors occur while writing to the
underlying streamCopyright © 2013 CableLabs. All rights reserved.