public class ObjectStreamClass extends Object implements Serializable
The algorithm to compute the SerialVersionUID is described in Object Serialization Specification, Section 4.4, Stream Unique Identifiers.
ObjectStreamField,
Object Serialization Specification, Section 4, Class Descriptors,
Serialized Form| Modifier and Type | Field and Description |
|---|---|
static ObjectStreamField[] |
NO_FIELDS
serialPersistentFields value indicating no serializable fields
|
| Modifier and Type | Method and Description |
|---|---|
Class |
forClass()
Return the class in the local VM that this version is mapped to.
|
ObjectStreamField |
getField(String name)
Get the field of this class by name.
|
ObjectStreamField[] |
getFields()
Return an array of the fields of this serializable class.
|
String |
getName()
The name of the class described by this descriptor.
|
long |
getSerialVersionUID()
Return the serialVersionUID for this class.
|
static ObjectStreamClass |
lookup(Class cl)
Find the descriptor for a class that can be serialized.
|
String |
toString()
Return a string describing this ObjectStreamClass.
|
public static final ObjectStreamField[] NO_FIELDS
public static ObjectStreamClass lookup(Class cl)
cl - class for which to get the descriptorpublic String getName()
String representing the fully qualified name of
the classpublic long getSerialVersionUID()
public Class forClass()
Class instance that this descriptor representspublic ObjectStreamField[] getFields()
public ObjectStreamField getField(String name)
name - the name of the data field to look forCopyright © 2012 CableLabs. All Rights Reserved.