public class ObjectStreamField extends Object implements Comparable
ObjectStreamClass| Constructor and Description |
|---|
ObjectStreamField(String name,
Class type)
Create a Serializable field with the specified type.
|
ObjectStreamField(String name,
Class type,
boolean unshared)
Creates an ObjectStreamField representing a serializable field with the
given name and type.
|
| Modifier and Type | Method and Description |
|---|---|
int |
compareTo(Object obj)
Compare this field with another
ObjectStreamField. |
String |
getName()
Get the name of this field.
|
int |
getOffset()
Offset of field within instance data.
|
Class |
getType()
Get the type of the field.
|
char |
getTypeCode()
Returns character encoding of field type.
|
String |
getTypeString()
Return the JVM type signature.
|
boolean |
isPrimitive()
Return true if this field has a primitive type.
|
protected void |
setOffset(int offset)
Offset within instance data.
|
String |
toString()
Return a string that describes this field.
|
public ObjectStreamField(String name, Class type)
serialField
tag.n - the name of the serializable fieldclazz - the Class object of the serializable fieldpublic ObjectStreamField(String name, Class type, boolean unshared)
name - field nametype - field typeunshared - if false, write/read field values in the same manner
as writeObject/readObject; if true, write/read in the same
manner as writeUnshared/readUnsharedpublic String getName()
String representing the name of the serializable
fieldpublic Class getType()
Class object of the serializable fieldpublic char getTypeCode()
B byte C char D double F float I int J long L class or interface S short Z boolean [ array
public String getTypeString()
public int getOffset()
setOffset(int)protected void setOffset(int offset)
offset - the offset of the fieldgetOffset()public boolean isPrimitive()
public int compareTo(Object obj)
ObjectStreamField.
Return -1 if this is smaller, 0 if equal, 1 if greater.
Types that are primitives are "smaller" than object types.
If equal, the field names are compared.compareTo in interface Comparableobj - the Object to be compared.Copyright © 2013 CableLabs. All rights reserved.