public class StringReader extends Reader
| Constructor and Description |
|---|
StringReader(String s)
Create a new string reader.
|
| Modifier and Type | Method and Description |
|---|---|
void |
close()
Close the stream.
|
void |
mark(int readAheadLimit)
Mark the present position in the stream.
|
boolean |
markSupported()
Tell whether this stream supports the mark() operation, which it does.
|
int |
read()
Read a single character.
|
int |
read(char[] cbuf,
int off,
int len)
Read characters into a portion of an array.
|
boolean |
ready()
Tell whether this stream is ready to be read.
|
void |
reset()
Reset the stream to the most recent mark, or to the beginning of the
string if it has never been marked.
|
long |
skip(long ns)
Skip characters.
|
public StringReader(String s)
s - String providing the character stream.public int read()
throws IOException
read in class ReaderIOException - If an I/O error occurspublic int read(char[] cbuf,
int off,
int len)
throws IOException
read in class Readercbuf - Destination bufferoff - Offset at which to start writing characterslen - Maximum number of characters to readIOException - If an I/O error occurspublic long skip(long ns)
throws IOException
skip in class Readerns - The number of characters to skipIOException - If an I/O error occurspublic boolean ready()
throws IOException
ready in class ReaderIOException - If the stream is closedpublic boolean markSupported()
markSupported in class Readerpublic void mark(int readAheadLimit)
throws IOException
mark in class ReaderreadAheadLimit - Limit on the number of characters that may be
read while still preserving the mark. Because
the stream's input comes from a string, there
is no actual limit, so this argument must not
be negative, but is otherwise ignored.IllegalArgumentException - If readAheadLimit is < 0IOException - If an I/O error occurspublic void reset()
throws IOException
reset in class ReaderIOException - If an I/O error occursCopyright © 2012 CableLabs. All Rights Reserved.