| Package | Description |
|---|---|
| java.io |
Provides for system input and output through data streams,
serialization and the file system.
|
| javax.microedition.io |
Provides a simplified mechanism for applications to use various types of I/O
protocols in resource-constrained environments.
|
| Modifier and Type | Interface and Description |
|---|---|
interface |
ObjectInput
ObjectInput extends the DataInput interface to include the reading of
objects.
|
| Modifier and Type | Class and Description |
|---|---|
class |
DataInputStream
A data input stream lets an application read primitive Java data
types from an underlying input stream in a machine-independent
way.
|
class |
ObjectInputStream
An ObjectInputStream deserializes primitive data and objects previously
written using an ObjectOutputStream.
|
class |
RandomAccessFile
Instances of this class support both reading and writing to a
random access file.
|
| Modifier and Type | Method and Description |
|---|---|
static String |
DataInputStream.readUTF(DataInput in)
Reads from the
stream
in a representation
of a Unicode character string encoded in
Java modified UTF-8 format; this string
of characters is then returned as a String. |
| Modifier and Type | Interface and Description |
|---|---|
interface |
Datagram
This class defines an abstract interface for datagram packets.
|
Copyright © 2013 CableLabs. All rights reserved.