| Package | Description |
|---|---|
| javax.microedition.io |
Provides a simplified mechanism for applications to use various types of I/O
protocols in resource-constrained environments.
|
| Modifier and Type | Method and Description |
|---|---|
DataInputStream |
InputConnection.openDataInputStream()
Open and return a data input stream for a connection.
|
static DataInputStream |
Connector.openDataInputStream(String name)
Create and open a connection input stream.
|
Copyright © 2013 CableLabs. All rights reserved.