| Package | Description |
|---|---|
| java.io |
Provides for system input and output through data streams,
serialization and the file system.
|
| java.lang |
Provides classes that are fundamental to the design of the Java
programming language.
|
| java.util.jar |
Provides classes for reading and writing the JAR (Java ARchive) file
format, which is based on the standard ZIP file format with an
optional manifest file.
|
| java.util.zip |
Provides classes for reading and writing the standard ZIP and GZIP
file formats.
|
| org.dvb.dsmcc |
Provides extended access to files carried in the broadcast
stream.
|
| org.dvb.io.persistent |
Provides extensions to the java.io package for access to files
held in persistent storage.
|
| org.ocap.hn.content |
Provides representation of the content and content containers, and means of identifying content type.
|
| org.ocap.system |
This API is used to access
system modules. |
| Modifier and Type | Method and Description |
|---|---|
static File |
File.createTempFile(String prefix,
String suffix)
Creates an empty file in the default temporary-file directory, using
the given prefix and suffix to generate its name.
|
static File |
File.createTempFile(String prefix,
String suffix,
File directory)
Creates a new empty file in the specified directory, using the
given prefix and suffix strings to generate its name.
|
File |
File.getAbsoluteFile()
Returns the absolute form of this abstract pathname.
|
File |
File.getCanonicalFile()
Returns the canonical form of this abstract pathname.
|
File |
File.getParentFile()
Returns the abstract pathname of this abstract pathname's parent,
or
null if this pathname does not name a parent
directory. |
File[] |
File.listFiles()
Returns an array of abstract pathnames denoting the files in the
directory denoted by this abstract pathname.
|
File[] |
File.listFiles(FileFilter filter)
Returns an array of abstract pathnames denoting the files and
directories in the directory denoted by this abstract pathname that
satisfy the specified filter.
|
File[] |
File.listFiles(FilenameFilter filter)
Returns an array of abstract pathnames denoting the files and
directories in the directory denoted by this abstract pathname that
satisfy the specified filter.
|
static File[] |
File.listRoots()
List the available filesystem roots.
|
| Modifier and Type | Method and Description |
|---|---|
boolean |
FileFilter.accept(File pathname)
Tests whether or not the specified abstract pathname should be
included in a pathname list.
|
boolean |
FilenameFilter.accept(File dir,
String name)
Tests if a specified file should be included in a file list.
|
int |
File.compareTo(File pathname)
Compares two abstract pathnames lexicographically.
|
static File |
File.createTempFile(String prefix,
String suffix,
File directory)
Creates a new empty file in the specified directory, using the
given prefix and suffix strings to generate its name.
|
boolean |
File.renameTo(File dest)
Renames the file denoted by this abstract pathname.
|
| Constructor and Description |
|---|
File(File parent,
String child)
Creates a new
File instance from a parent abstract
pathname and a child pathname string. |
FileInputStream(File file)
Creates a
FileInputStream by
opening a connection to an actual file,
the file named by the File
object file in the file system. |
FileOutputStream(File file)
Creates a file output stream to write to the file represented by
the specified
File object. |
FileOutputStream(File file,
boolean append)
Creates a file output stream to write to the file represented by
the specified
File object. |
FileReader(File file)
Creates a new FileReader, given the File
to read from.
|
FileWriter(File file)
Constructs a FileWriter object given a File object.
|
FileWriter(File file,
boolean append)
Constructs a FileWriter object given a File object.
|
RandomAccessFile(File file,
String mode)
Creates a random access file stream to read from, and optionally to
write to, the file specified by the
File argument. |
| Modifier and Type | Method and Description |
|---|---|
Process |
Runtime.exec(String[] cmdarray,
String[] envp,
File dir)
Executes the specified command and arguments in a separate process with
the specified environment and working directory.
|
Process |
Runtime.exec(String command,
String[] envp,
File dir)
Executes the specified string command in a separate process with the
specified environment and working directory.
|
| Constructor and Description |
|---|
JarFile(File file)
Creates a new
JarFile to read from the specified
File object. |
JarFile(File file,
boolean verify)
Creates a new
JarFile to read from the specified
File object. |
JarFile(File file,
boolean verify,
int mode)
Creates a new
JarFile to read from the specified
File object in the specified mode. |
| Constructor and Description |
|---|
ZipFile(File file)
Opens a ZIP file for reading given the specified File object.
|
ZipFile(File file,
int mode)
Opens a new
ZipFile to read from the specified
File object in the specified mode. |
| Modifier and Type | Class and Description |
|---|---|
class |
DSMCCObject
A DSMCCObject is an object which belongs to a DSMCC ServiceDomain.
|
| Modifier and Type | Method and Description |
|---|---|
static FileAttributes |
FileAttributes.getFileAttributes(File f)
Get the attributes of a file.
|
static void |
FileAttributes.setFileAttributes(FileAttributes p,
File f)
Associate a set of file attributes with a file.
|
| Modifier and Type | Method and Description |
|---|---|
boolean |
ContentContainer.createContentItem(File content,
String name,
ExtendedFileAccessPermissions permissions)
Creates a new ContentItem representing a local file as a child of this
ContentContainer.
|
| Modifier and Type | Method and Description |
|---|---|
abstract void |
RegisteredApiManager.register(String name,
String version,
File scdf,
short storagePriority)
Registers an API with the implementation.
|
Copyright © 2013 CableLabs. All rights reserved.