| Package | Description |
|---|---|
| java.io |
Provides for system input and output through data streams,
serialization and the file system.
|
| java.security |
Provides the classes and interfaces for the security framework.
|
| java.util.jar |
Provides classes for reading and writing the JAR (Java ARchive) file
format, which is based on the standard ZIP file format with an
optional manifest file.
|
| java.util.zip |
Provides classes for reading and writing the standard ZIP and GZIP
file formats.
|
| Modifier and Type | Class and Description |
|---|---|
class |
BufferedInputStream
A
BufferedInputStream adds
functionality to another input stream-namely,
the ability to buffer the input and to
support the mark and reset
methods. |
class |
DataInputStream
A data input stream lets an application read primitive Java data
types from an underlying input stream in a machine-independent
way.
|
class |
PushbackInputStream
A
PushbackInputStream adds
functionality to another input stream, namely
the ability to "push back" or "unread"
one byte. |
| Modifier and Type | Class and Description |
|---|---|
class |
DigestInputStream
A transparent stream that updates the associated message digest using
the bits going through the stream.
|
| Modifier and Type | Class and Description |
|---|---|
class |
JarInputStream
The
JarInputStream class is used to read the contents of
a JAR file from any input stream. |
| Modifier and Type | Class and Description |
|---|---|
class |
CheckedInputStream
An input stream that also maintains a checksum of the data being read.
|
class |
GZIPInputStream
This class implements a stream filter for reading compressed data in
the GZIP format.
|
class |
InflaterInputStream
This class implements a stream filter for uncompressing data in the
"deflate" compression format.
|
class |
ZipInputStream
This class implements an input stream filter for reading files in the
ZIP file format.
|
Copyright © 2013 CableLabs. All rights reserved.