| Package | Description |
|---|---|
| java.io |
Provides for system input and output through data streams,
serialization and the file system.
|
| java.lang |
Provides classes that are fundamental to the design of the Java
programming language.
|
| java.net |
Provides the classes for implementing networking applications.
|
| java.security |
Provides the classes and interfaces for the security framework.
|
| java.security.cert |
Provides classes and interfaces for parsing and managing
certificates, certificate revocation lists (CRLs), and
certification paths.
|
| java.util |
Contains the collections framework, legacy collection classes, event model,
date and time facilities, internationalization, and miscellaneous utility
classes (a string tokenizer, a random-number generator, and a bit array).
|
| java.util.jar |
Provides classes for reading and writing the JAR (Java ARchive) file
format, which is based on the standard ZIP file format with an
optional manifest file.
|
| java.util.zip |
Provides classes for reading and writing the standard ZIP and GZIP
file formats.
|
| javax.microedition.io |
Provides a simplified mechanism for applications to use various types of I/O
protocols in resource-constrained environments.
|
| javax.security.auth.x500 |
This package contains the classes that should be used to store
X500 Principal and X500 Private Crendentials in a
Subject.
|
| javax.security.cert |
Provides classes for public key certificates.
|
| javax.xml.parsers |
The javax.xml.parsers package contains the Java API for XML Processing (JAXP)
subset defined by JSR 280.
|
| javax.xml.stream |
This package provides the Streaming API for XML (StAX, or JSR 173) subset
defined by JSR 280.
|
| org.apache.log4j.xml | |
| org.ocap.application |
|
| org.ocap.hn.ruihsrc | |
| org.ocap.hn.upnp.server |
Provides UPnP server functionality, permitting management of devices and services in the local Host device.
|
| org.xml.sax |
| Modifier and Type | Class and Description |
|---|---|
class |
BufferedInputStream
A
BufferedInputStream adds
functionality to another input stream-namely,
the ability to buffer the input and to
support the mark and reset
methods. |
class |
ByteArrayInputStream
A
ByteArrayInputStream contains
an internal buffer that contains bytes that
may be read from the stream. |
class |
DataInputStream
A data input stream lets an application read primitive Java data
types from an underlying input stream in a machine-independent
way.
|
class |
FileInputStream
A
FileInputStream obtains input bytes
from a file in a file system. |
class |
FilterInputStream
A
FilterInputStream contains
some other input stream, which it uses as
its basic source of data, possibly transforming
the data along the way or providing additional
functionality. |
class |
ObjectInputStream
An ObjectInputStream deserializes primitive data and objects previously
written using an ObjectOutputStream.
|
class |
PipedInputStream
A piped input stream should be connected
to a piped output stream; the piped input
stream then provides whatever data bytes
are written to the piped output stream.
|
class |
PushbackInputStream
A
PushbackInputStream adds
functionality to another input stream, namely
the ability to "push back" or "unread"
one byte. |
class |
SequenceInputStream
A
SequenceInputStream represents
the logical concatenation of other input
streams. |
| Modifier and Type | Field and Description |
|---|---|
protected InputStream |
FilterInputStream.in
The input stream to be filtered.
|
| Constructor and Description |
|---|
BufferedInputStream(InputStream in)
Creates a
BufferedInputStream
and saves its argument, the input stream
in, for later use. |
BufferedInputStream(InputStream in,
int size)
Creates a
BufferedInputStream
with the specified buffer size,
and saves its argument, the input stream
in, for later use. |
DataInputStream(InputStream in)
Creates a DataInputStream that uses the specified
underlying InputStream.
|
FilterInputStream(InputStream in)
Creates a
FilterInputStream
by assigning the argument in
to the field this.in so as
to remember it for later use. |
InputStreamReader(InputStream in)
Create an InputStreamReader that uses the default character encoding.
|
InputStreamReader(InputStream in,
String enc)
Create an InputStreamReader that uses the named character encoding.
|
ObjectInputStream(InputStream in)
Creates an ObjectInputStream that reads from the specified InputStream.
|
PushbackInputStream(InputStream in)
Creates a
PushbackInputStream
and saves its argument, the input stream
in, for later use. |
PushbackInputStream(InputStream in,
int size)
Creates a
PushbackInputStream
with a pushback buffer of the specified size,
and saves its argument, the input stream
in, for later use. |
SequenceInputStream(InputStream s1,
InputStream s2)
Initializes a newly
created
SequenceInputStream
by remembering the two arguments, which
will be read in order, first s1
and then s2, to provide the
bytes to be read from this SequenceInputStream. |
| Modifier and Type | Field and Description |
|---|---|
static InputStream |
System.in
The "standard" input stream.
|
| Modifier and Type | Method and Description |
|---|---|
abstract InputStream |
Process.getErrorStream()
Gets the error stream of the subprocess.
|
abstract InputStream |
Process.getInputStream()
Gets the input stream of the subprocess.
|
InputStream |
ClassLoader.getResourceAsStream(String name)
Returns an input stream for reading the specified resource.
|
InputStream |
Class.getResourceAsStream(String name)
Finds a resource with a given name.
|
static InputStream |
ClassLoader.getSystemResourceAsStream(String name)
Open for reading, a resource of the specified name from the search path
used to load classes.
|
| Modifier and Type | Method and Description |
|---|---|
static void |
System.setIn(InputStream in)
Reassigns the "standard" input stream.
|
| Modifier and Type | Method and Description |
|---|---|
InputStream |
HttpURLConnection.getErrorStream()
Returns the error stream if the connection failed
but the server sent useful data nonetheless.
|
InputStream |
URLConnection.getInputStream()
Returns an input stream that reads from this open connection.
|
protected abstract InputStream |
SocketImpl.getInputStream()
Returns an input stream for this socket.
|
InputStream |
Socket.getInputStream()
Returns an input stream for this socket.
|
InputStream |
URL.openStream()
Opens a connection to this
URL and returns an
InputStream for reading from that connection. |
| Modifier and Type | Method and Description |
|---|---|
static String |
URLConnection.guessContentTypeFromStream(InputStream is)
Tries to determine the type of an input stream based on the
characters at the beginning of the input stream.
|
| Modifier and Type | Class and Description |
|---|---|
class |
DigestInputStream
A transparent stream that updates the associated message digest using
the bits going through the stream.
|
| Modifier and Type | Method and Description |
|---|---|
void |
Certificate.decode(InputStream stream)
Deprecated.
Decodes a certificate from an input stream.
|
abstract void |
KeyStoreSpi.engineLoad(InputStream stream,
char[] password)
Loads the keystore from the given input stream.
|
void |
Provider.load(InputStream inStream)
Reads a property list (key and element pairs) from the input stream.
|
void |
KeyStore.load(InputStream stream,
char[] password)
Loads this KeyStore from the given input stream.
|
| Constructor and Description |
|---|
DigestInputStream(InputStream stream,
MessageDigest digest)
Creates a digest input stream, using the specified input stream
and message digest.
|
| Modifier and Type | Method and Description |
|---|---|
abstract Certificate |
CertificateFactorySpi.engineGenerateCertificate(InputStream inStream)
Generates a certificate object and initializes it with
the data read from the input stream
inStream. |
abstract Collection |
CertificateFactorySpi.engineGenerateCertificates(InputStream inStream)
Returns a (possibly empty) collection view of the certificates read
from the given input stream
inStream. |
CertPath |
CertificateFactorySpi.engineGenerateCertPath(InputStream inStream)
Generates a
CertPath object and initializes it with
the data read from the InputStream inStream. |
CertPath |
CertificateFactorySpi.engineGenerateCertPath(InputStream inStream,
String encoding)
Generates a
CertPath object and initializes it with
the data read from the InputStream inStream. |
abstract CRL |
CertificateFactorySpi.engineGenerateCRL(InputStream inStream)
Generates a certificate revocation list (CRL) object and initializes it
with the data read from the input stream
inStream. |
abstract Collection |
CertificateFactorySpi.engineGenerateCRLs(InputStream inStream)
Returns a (possibly empty) collection view of the CRLs read
from the given input stream
inStream. |
Certificate |
CertificateFactory.generateCertificate(InputStream inStream)
Generates a certificate object and initializes it with
the data read from the input stream
inStream. |
Collection |
CertificateFactory.generateCertificates(InputStream inStream)
Returns a (possibly empty) collection view of the certificates read
from the given input stream
inStream. |
CertPath |
CertificateFactory.generateCertPath(InputStream inStream)
Generates a
CertPath object and initializes it with
the data read from the InputStream inStream. |
CertPath |
CertificateFactory.generateCertPath(InputStream inStream,
String encoding)
Generates a
CertPath object and initializes it with
the data read from the InputStream inStream. |
CRL |
CertificateFactory.generateCRL(InputStream inStream)
Generates a certificate revocation list (CRL) object and initializes it
with the data read from the input stream
inStream. |
Collection |
CertificateFactory.generateCRLs(InputStream inStream)
Returns a (possibly empty) collection view of the CRLs read
from the given input stream
inStream. |
| Modifier and Type | Method and Description |
|---|---|
void |
Properties.load(InputStream inStream)
Reads a property list (key and element pairs) from the input
stream.
|
| Constructor and Description |
|---|
PropertyResourceBundle(InputStream stream)
Creates a property resource bundle.
|
| Modifier and Type | Class and Description |
|---|---|
class |
JarInputStream
The
JarInputStream class is used to read the contents of
a JAR file from any input stream. |
| Modifier and Type | Method and Description |
|---|---|
InputStream |
JarFile.getInputStream(ZipEntry ze)
Returns an input stream for reading the contents of the specified
ZIP file entry.
|
| Modifier and Type | Method and Description |
|---|---|
void |
Manifest.read(InputStream is)
Reads the Manifest from the specified InputStream.
|
| Constructor and Description |
|---|
JarInputStream(InputStream in)
Creates a new
JarInputStream and reads the optional
manifest. |
JarInputStream(InputStream in,
boolean verify)
Creates a new
JarInputStream and reads the optional
manifest. |
Manifest(InputStream is)
Constructs a new Manifest from the specified input stream.
|
| Modifier and Type | Class and Description |
|---|---|
class |
CheckedInputStream
An input stream that also maintains a checksum of the data being read.
|
class |
GZIPInputStream
This class implements a stream filter for reading compressed data in
the GZIP format.
|
class |
InflaterInputStream
This class implements a stream filter for uncompressing data in the
"deflate" compression format.
|
class |
ZipInputStream
This class implements an input stream filter for reading files in the
ZIP file format.
|
| Modifier and Type | Method and Description |
|---|---|
InputStream |
ZipFile.getInputStream(ZipEntry entry)
Returns an input stream for reading the contents of the specified
zip file entry.
|
| Constructor and Description |
|---|
CheckedInputStream(InputStream in,
Checksum cksum)
Creates an input stream using the specified Checksum.
|
GZIPInputStream(InputStream in)
Creates a new input stream with a default buffer size.
|
GZIPInputStream(InputStream in,
int size)
Creates a new input stream with the specified buffer size.
|
InflaterInputStream(InputStream in)
Creates a new input stream with a default decompressor and buffer size.
|
InflaterInputStream(InputStream in,
Inflater inf)
Creates a new input stream with the specified decompressor and a
default buffer size.
|
InflaterInputStream(InputStream in,
Inflater inf,
int size)
Creates a new input stream with the specified decompressor and
buffer size.
|
ZipInputStream(InputStream in)
Creates a new ZIP input stream.
|
| Modifier and Type | Method and Description |
|---|---|
InputStream |
InputConnection.openInputStream()
Open and return an input stream for a connection.
|
static InputStream |
Connector.openInputStream(String name)
Create and open a connection input stream.
|
| Constructor and Description |
|---|
X500Principal(InputStream is)
Creates an
X500Principal from an InputStream
containing the distinguished name in ASN.1 DER encoded form. |
| Modifier and Type | Method and Description |
|---|---|
static X509Certificate |
X509Certificate.getInstance(InputStream inStream)
Instantiates an X509Certificate object, and initializes it with
the data read from the input stream
inStream. |
| Modifier and Type | Method and Description |
|---|---|
Document |
DocumentBuilder.parse(InputStream is)
Parse the content of the given
InputStream as an XML
document and return a new DOM Document object. |
abstract void |
SAXParser.parse(InputStream is,
DefaultHandler dh)
Parse the content of the given
InputStream
instance as XML using the specified
DefaultHandler. |
| Modifier and Type | Method and Description |
|---|---|
abstract XMLStreamReader |
XMLInputFactory.createXMLStreamReader(InputStream stream)
Create a new XMLStreamReader from a java.io.InputStream
|
abstract XMLStreamReader |
XMLInputFactory.createXMLStreamReader(InputStream stream,
String encoding)
Create a new XMLStreamReader from a java.io.InputStream
|
| Modifier and Type | Method and Description |
|---|---|
void |
DOMConfigurator.doConfigure(InputStream inputStream,
LoggerRepository repository)
Configure log4j by reading in a log4j.dtd compliant XML
configuration file.
|
| Modifier and Type | Method and Description |
|---|---|
void |
AppManagerProxy.registerUnboundApp(InputStream xait)
This method registers new unbound application entries.
|
| Modifier and Type | Method and Description |
|---|---|
abstract void |
RemoteUIServerManager.setUIList(InputStream uiList)
Sets a remote user interface list.
|
| Modifier and Type | Method and Description |
|---|---|
UPnPManagedDevice |
UPnPDeviceManager.createDevice(UPnPManagedDevice parent,
InputStream description,
UPnPManagedDeviceIcon[] icons)
Creates a UPnP device in the local host.
|
UPnPManagedService |
UPnPManagedDevice.createService(String serviceType,
InputStream description,
UPnPActionHandler handler)
Creates a UPnP service associated with this device.
|
| Modifier and Type | Method and Description |
|---|---|
InputStream |
InputSource.getByteStream()
Get the byte stream for this input source.
|
| Modifier and Type | Method and Description |
|---|---|
void |
InputSource.setByteStream(InputStream byteStream)
Set the byte stream for this input source.
|
| Constructor and Description |
|---|
InputSource(InputStream byteStream)
Create a new input source with a byte stream.
|
Copyright © 2013 CableLabs. All rights reserved.