| Package | Description |
|---|---|
| java.net |
Provides the classes for implementing networking applications.
|
| org.dvb.dsmcc |
Provides extended access to files carried in the broadcast
stream.
|
| Modifier and Type | Class and Description |
|---|---|
class |
SocketTimeoutException
Signals that a timeout has occurred on a socket read or accept.
|
| Modifier and Type | Method and Description |
|---|---|
void |
ServiceDomain.attach(byte[] NSAPAddress)
This function is used to attach a
ServiceDomain from either
an object carousel or from an interactive network. |
void |
ServiceDomain.attach(Locator l)
This function is used to attach a
ServiceDomain from an object carousel. |
void |
ServiceDomain.attach(Locator aDVBService,
int aCarouselId)
This function is used to attach a ServiceDomain from an object carousel.
|
X509Certificate[][] |
DSMCCObject.getSigners(boolean known_root)
This method shall attempt to validate all certificate chains found
for this file in the network.
|
void |
DSMCCObject.synchronousLoad()
This method is used to load a DSMCCObject.
|
Copyright © 2013 CableLabs. All rights reserved.