| Package | Description |
|---|---|
| java.io |
Provides for system input and output through data streams,
serialization and the file system.
|
| Modifier and Type | Class and Description |
|---|---|
class |
ObjectOutputStream
An ObjectOutputStream writes primitive data types and graphs of Java objects
to an OutputStream.
|
| Modifier and Type | Method and Description |
|---|---|
abstract void |
ObjectOutputStream.PutField.write(ObjectOutput out)
Write the data and fields to the specified ObjectOutput stream.
|
void |
Externalizable.writeExternal(ObjectOutput out)
The object implements the writeExternal method to save its contents
by calling the methods of DataOutput for its primitive values or
calling the writeObject method of ObjectOutput for objects, strings,
and arrays.
|
Copyright © 2013 CableLabs. All rights reserved.