| Package | Description |
|---|---|
| java.io |
Provides for system input and output through data streams,
serialization and the file system.
|
| Modifier and Type | Method and Description |
|---|---|
Object |
ObjectInputStream.readObject()
Read an object from the ObjectInputStream.
|
protected Object |
ObjectInputStream.readObjectOverride()
This method is called by trusted subclasses of ObjectOutputStream
that constructed ObjectOutputStream using the
protected no-arg constructor.
|
Copyright © 2013 CableLabs. All rights reserved.