| Package | Description |
|---|---|
| java.io |
Provides for system input and output through data streams,
serialization and the file system.
|
| java.lang |
Provides classes that are fundamental to the design of the Java
programming language.
|
| java.net |
Provides the classes for implementing networking applications.
|
| java.security |
Provides the classes and interfaces for the security framework.
|
| java.util |
Contains the collections framework, legacy collection classes, event model,
date and time facilities, internationalization, and miscellaneous utility
classes (a string tokenizer, a random-number generator, and a bit array).
|
| java.util.jar |
Provides classes for reading and writing the JAR (Java ARchive) file
format, which is based on the standard ZIP file format with an
optional manifest file.
|
| java.util.zip |
Provides classes for reading and writing the standard ZIP and GZIP
file formats.
|
| javax.microedition.io |
Provides a simplified mechanism for applications to use various types of I/O
protocols in resource-constrained environments.
|
| javax.xml.stream |
This package provides the Streaming API for XML (StAX, or JSR 173) subset
defined by JSR 280.
|
| Modifier and Type | Class and Description |
|---|---|
class |
BufferedOutputStream
The class implements a buffered output stream.
|
class |
ByteArrayOutputStream
This class implements an output stream in which the data is
written into a byte array.
|
class |
DataOutputStream
A data output stream lets an application write primitive Java data
types to an output stream in a portable way.
|
class |
FileOutputStream
A file output stream is an output stream for writing data to a
File or to a FileDescriptor. |
class |
FilterOutputStream
This class is the superclass of all classes that filter output
streams.
|
class |
ObjectOutputStream
An ObjectOutputStream writes primitive data types and graphs of Java objects
to an OutputStream.
|
class |
PipedOutputStream
A piped output stream can be connected to a piped input stream
to create a communications pipe.
|
class |
PrintStream
A
PrintStream adds functionality to another output stream,
namely the ability to print representations of various data values
conveniently. |
| Modifier and Type | Field and Description |
|---|---|
protected OutputStream |
FilterOutputStream.out
The underlying output stream to be filtered.
|
| Modifier and Type | Method and Description |
|---|---|
void |
ByteArrayOutputStream.writeTo(OutputStream out)
Writes the complete contents of this byte array output stream to
the specified output stream argument, as if by calling the output
stream's write method using
out.write(buf, 0, count). |
| Constructor and Description |
|---|
BufferedOutputStream(OutputStream out)
Creates a new buffered output stream to write data to the
specified underlying output stream with a default 512-byte
buffer size.
|
BufferedOutputStream(OutputStream out,
int size)
Creates a new buffered output stream to write data to the
specified underlying output stream with the specified buffer
size.
|
DataOutputStream(OutputStream out)
Creates a new data output stream to write data to the specified
underlying output stream.
|
FilterOutputStream(OutputStream out)
Creates an output stream filter built on top of the specified
underlying output stream.
|
ObjectOutputStream(OutputStream out)
Creates an ObjectOutputStream that writes to the specified OutputStream.
|
OutputStreamWriter(OutputStream out)
Create an OutputStreamWriter that uses the default character encoding.
|
OutputStreamWriter(OutputStream out,
String enc)
Create an OutputStreamWriter that uses the named character encoding.
|
PrintStream(OutputStream out)
Create a new print stream.
|
PrintStream(OutputStream out,
boolean autoFlush)
Create a new print stream.
|
PrintStream(OutputStream out,
boolean autoFlush,
String encoding)
Create a new print stream.
|
PrintWriter(OutputStream out)
Create a new PrintWriter, without automatic line flushing, from an
existing OutputStream.
|
PrintWriter(OutputStream out,
boolean autoFlush)
Create a new PrintWriter from an existing OutputStream.
|
| Modifier and Type | Method and Description |
|---|---|
abstract OutputStream |
Process.getOutputStream()
Gets the output stream of the subprocess.
|
| Modifier and Type | Method and Description |
|---|---|
OutputStream |
URLConnection.getOutputStream()
Returns an output stream that writes to this connection.
|
protected abstract OutputStream |
SocketImpl.getOutputStream()
Returns an output stream for this socket.
|
OutputStream |
Socket.getOutputStream()
Returns an output stream for this socket.
|
| Modifier and Type | Class and Description |
|---|---|
class |
DigestOutputStream
A transparent stream that updates the associated message digest using
the bits going through the stream.
|
| Modifier and Type | Method and Description |
|---|---|
void |
Certificate.encode(OutputStream stream)
Deprecated.
Encodes the certificate to an output stream in a format that can
be decoded by the
decode method. |
abstract void |
KeyStoreSpi.engineStore(OutputStream stream,
char[] password)
Stores this keystore to the given output stream, and protects its
integrity with the given password.
|
void |
KeyStore.store(OutputStream stream,
char[] password)
Stores this keystore to the given output stream, and protects its
integrity with the given password.
|
| Constructor and Description |
|---|
DigestOutputStream(OutputStream stream,
MessageDigest digest)
Creates a digest output stream, using the specified output stream
and message digest.
|
| Modifier and Type | Method and Description |
|---|---|
void |
Properties.save(OutputStream out,
String header)
Deprecated.
This method does not throw an IOException if an I/O error
occurs while saving the property list. As of the Java 2 platform v1.2, the preferred
way to save a properties list is via the
store(OutputStream out,
String header) method. |
void |
Properties.store(OutputStream out,
String header)
Writes this property list (key and element pairs) in this
Properties table to the output stream in a format suitable
for loading into a Properties table using the
load method. |
| Modifier and Type | Class and Description |
|---|---|
class |
JarOutputStream
The
JarOutputStream class is used to write the contents
of a JAR file to any output stream. |
| Modifier and Type | Method and Description |
|---|---|
void |
Manifest.write(OutputStream out)
Writes the Manifest to the specified OutputStream.
|
| Constructor and Description |
|---|
JarOutputStream(OutputStream out)
Creates a new
JarOutputStream with no manifest. |
JarOutputStream(OutputStream out,
Manifest man)
Creates a new
JarOutputStream with the specified
Manifest. |
| Modifier and Type | Class and Description |
|---|---|
class |
CheckedOutputStream
An output stream that also maintains a checksum of the data being
written.
|
class |
DeflaterOutputStream
This class implements an output stream filter for compressing data in
the "deflate" compression format.
|
class |
GZIPOutputStream
This class implements a stream filter for writing compressed data in
the GZIP file format.
|
class |
ZipOutputStream
This class implements an output stream filter for writing files in the
ZIP file format.
|
| Constructor and Description |
|---|
CheckedOutputStream(OutputStream out,
Checksum cksum)
Creates an output stream with the specified Checksum.
|
DeflaterOutputStream(OutputStream out)
Creates a new output stream with a defaul compressor and buffer size.
|
DeflaterOutputStream(OutputStream out,
Deflater def)
Creates a new output stream with the specified compressor and
a default buffer size.
|
DeflaterOutputStream(OutputStream out,
Deflater def,
int size)
Creates a new output stream with the specified compressor and
buffer size.
|
GZIPOutputStream(OutputStream out)
Creates a new output stream with a default buffer size.
|
GZIPOutputStream(OutputStream out,
int size)
Creates a new output stream with the specified buffer size.
|
ZipOutputStream(OutputStream out)
Creates a new ZIP output stream.
|
| Modifier and Type | Method and Description |
|---|---|
OutputStream |
OutputConnection.openOutputStream()
Open and return an output stream for a connection.
|
static OutputStream |
Connector.openOutputStream(String name)
Create and open a connection output stream.
|
| Modifier and Type | Method and Description |
|---|---|
abstract XMLStreamWriter |
XMLOutputFactory.createXMLStreamWriter(OutputStream stream)
Create a new XMLStreamWriter that writes to a stream
|
abstract XMLStreamWriter |
XMLOutputFactory.createXMLStreamWriter(OutputStream stream,
String encoding)
Create a new XMLStreamWriter that writes to a stream
|
Copyright © 2013 CableLabs. All rights reserved.