| Package | Description |
|---|---|
| java.io |
Provides for system input and output through data streams,
serialization and the file system.
|
| Modifier and Type | Method and Description |
|---|---|
void |
PipedWriter.connect(PipedReader snk)
Connects this piped writer to a receiver.
|
| Constructor and Description |
|---|
PipedWriter(PipedReader snk)
Creates a piped writer connected to the specified piped
reader.
|
Copyright © 2012 CableLabs. All Rights Reserved.