| Package | Description |
|---|---|
| java.io |
Provides for system input and output through data streams,
serialization and the file system.
|
| javax.xml.stream |
This package provides the Streaming API for XML (StAX, or JSR 173) subset
defined by JSR 280.
|
| org.apache.log4j.xml | |
| org.xml.sax |
| Modifier and Type | Class and Description |
|---|---|
class |
BufferedReader
Read text from a character-input stream, buffering characters so as to
provide for the efficient reading of characters, arrays, and lines.
|
class |
CharArrayReader
This class implements a character buffer that can be used as a
character-input stream.
|
class |
FileReader
Convenience class for reading character files.
|
class |
FilterReader
Abstract class for reading filtered character streams.
|
class |
InputStreamReader
An InputStreamReader is a bridge from byte streams to character streams: It
reads bytes and translates them into characters according to a specified character encoding.
|
class |
LineNumberReader
A buffered character-input stream that keeps track of line numbers.
|
class |
PipedReader
Piped character-input streams.
|
class |
PushbackReader
A character-stream reader that allows characters to be pushed back into the
stream.
|
class |
StringReader
A character stream whose source is a string.
|
| Modifier and Type | Field and Description |
|---|---|
protected Reader |
FilterReader.in
The underlying character-input stream.
|
| Constructor and Description |
|---|
BufferedReader(Reader in)
Create a buffering character-input stream that uses a default-sized
input buffer.
|
BufferedReader(Reader in,
int sz)
Create a buffering character-input stream that uses an input buffer of
the specified size.
|
FilterReader(Reader in)
Create a new filtered reader.
|
LineNumberReader(Reader in)
Create a new line-numbering reader, using the default input-buffer
size.
|
LineNumberReader(Reader in,
int sz)
Create a new line-numbering reader, reading characters into a buffer of
the given size.
|
PushbackReader(Reader in)
Create a new pushback reader with a one-character pushback buffer.
|
PushbackReader(Reader in,
int size)
Create a new pushback reader with a pushback buffer of the given size.
|
StreamTokenizer(Reader r)
Create a tokenizer that parses the given character stream.
|
| Modifier and Type | Method and Description |
|---|---|
abstract XMLStreamReader |
XMLInputFactory.createXMLStreamReader(Reader reader)
Create a new XMLStreamReader from a reader
|
| Modifier and Type | Method and Description |
|---|---|
void |
DOMConfigurator.doConfigure(Reader reader,
LoggerRepository repository)
Configure log4j by reading in a log4j.dtd compliant XML
configuration file.
|
| Modifier and Type | Method and Description |
|---|---|
Reader |
InputSource.getCharacterStream()
Get the character stream for this input source.
|
| Modifier and Type | Method and Description |
|---|---|
void |
InputSource.setCharacterStream(Reader characterStream)
Set the character stream for this input source.
|
| Constructor and Description |
|---|
InputSource(Reader characterStream)
Create a new input source with a character stream.
|
Copyright © 2013 CableLabs. All rights reserved.