| Package | Description |
|---|---|
| java.io |
Provides for system input and output through data streams,
serialization and the file system.
|
| Modifier and Type | Method and Description |
|---|---|
void |
FileDescriptor.sync()
Force all system buffers to synchronize with the underlying
device.
|
Copyright © 2012. All Rights Reserved.