| Package | Description |
|---|---|
| java.io |
Provides for system input and output through data streams,
serialization and the file system.
|
| java.lang |
Provides classes that are fundamental to the design of the Java
programming language.
|
| java.net |
Provides the classes for implementing networking applications.
|
| Modifier and Type | Method and Description |
|---|---|
String |
ByteArrayOutputStream.toString(String enc)
Converts the buffer's contents into a string, translating bytes into
characters according to the specified character encoding.
|
| Constructor and Description |
|---|
InputStreamReader(InputStream in,
String enc)
Create an InputStreamReader that uses the named character encoding.
|
OutputStreamWriter(OutputStream out,
String enc)
Create an OutputStreamWriter that uses the named character encoding.
|
PrintStream(OutputStream out,
boolean autoFlush,
String encoding)
Create a new print stream.
|
| Modifier and Type | Method and Description |
|---|---|
byte[] |
String.getBytes(String charsetName)
Encodes this String into a sequence of bytes using the
named charset, storing the result into a new byte array.
|
| Constructor and Description |
|---|
String(byte[] bytes,
int offset,
int length,
String charsetName)
Constructs a new String by decoding the specified subarray of
bytes using the specified charset.
|
String(byte[] bytes,
String charsetName)
Constructs a new String by decoding the specified array of
bytes using the specified charset.
|
| Modifier and Type | Method and Description |
|---|---|
static String |
URLDecoder.decode(String s,
String enc)
Decodes a
application/x-www-form-urlencoded string using a specific
encoding scheme. |
static String |
URLEncoder.encode(String s,
String enc)
Translates a string into
application/x-www-form-urlencoded
format using a specific encoding scheme. |
Copyright © 2013 CableLabs. All rights reserved.