| Package | Description |
|---|---|
| java.io |
Provides for system input and output through data streams,
serialization and the file system.
|
| javax.xml.stream |
This package provides the Streaming API for XML (StAX, or JSR 173) subset
defined by JSR 280.
|
| Modifier and Type | Class and Description |
|---|---|
class |
BufferedWriter
Write text to a character-output stream, buffering characters so as to
provide for the efficient writing of single characters, arrays, and strings.
|
class |
CharArrayWriter
This class implements a character buffer that can be used as an Writer.
|
class |
FileWriter
Convenience class for writing character files.
|
class |
FilterWriter
Abstract class for writing filtered character streams.
|
class |
OutputStreamWriter
An OutputStreamWriter is a bridge from character streams to byte streams:
Characters written to it are translated into bytes according to a specified
character encoding.
|
class |
PipedWriter
Piped character-output streams.
|
class |
PrintWriter
Print formatted representations of objects to a text-output stream.
|
class |
StringWriter
A character stream that collects its output in a string buffer, which can
then be used to construct a string.
|
| Modifier and Type | Field and Description |
|---|---|
protected Writer |
PrintWriter.out
The underlying character-output stream of this
PrintWriter. |
protected Writer |
FilterWriter.out
The underlying character-output stream.
|
| Modifier and Type | Method and Description |
|---|---|
void |
CharArrayWriter.writeTo(Writer out)
Writes the contents of the buffer to another character stream.
|
| Constructor and Description |
|---|
BufferedWriter(Writer out)
Create a buffered character-output stream that uses a default-sized
output buffer.
|
BufferedWriter(Writer out,
int sz)
Create a new buffered character-output stream that uses an output
buffer of the given size.
|
FilterWriter(Writer out)
Create a new filtered writer.
|
PrintWriter(Writer out)
Create a new PrintWriter, without automatic line flushing.
|
PrintWriter(Writer out,
boolean autoFlush)
Create a new PrintWriter.
|
| Modifier and Type | Method and Description |
|---|---|
abstract XMLStreamWriter |
XMLOutputFactory.createXMLStreamWriter(Writer stream)
Create a new XMLStreamWriter that writes to a writer
|
Copyright © 2013 CableLabs. All rights reserved.