public final class StackTraceElement extends Object implements Serializable
Throwable.getStackTrace(). Each element represents a single stack frame.
All stack frames except for the one at the top of the stack represent
a method invocation. The frame at the top of the stack represents the
the execution point at which the stack trace was generated. Typically,
this is the point at which the throwable corresponding to the stack trace
was created.| Modifier and Type | Method and Description |
|---|---|
boolean |
equals(Object obj)
Returns true if the specified object is another
StackTraceElement instance representing the same execution
point as this instance.
|
String |
getClassName()
Returns the fully qualified name of the class containing the
execution point represented by this stack trace element.
|
String |
getFileName()
Returns the name of the source file containing the execution point
represented by this stack trace element.
|
int |
getLineNumber()
Returns the line number of the source line containing the execution
point represented by this stack trace element.
|
String |
getMethodName()
Returns the name of the method containing the execution point
represented by this stack trace element.
|
int |
hashCode()
Returns a hash code value for this stack trace element.
|
boolean |
isNativeMethod()
Returns true if the method containing the execution point
represented by this stack trace element is a native method.
|
String |
toString()
Returns a string representation of this stack trace element.
|
public String getFileName()
public int getLineNumber()
public String getClassName()
public String getMethodName()
public boolean isNativeMethod()
public String toString()
toString in class ObjectThrowable.printStackTrace()public boolean equals(Object obj)
equals(a.getFileName(), b.getFileName()) &&
a.getLineNumber() == b.getLineNumber()) &&
equals(a.getClassName(), b.getClassName()) &&
equals(a.getMethodName(), b.getMethodName())
where equals is defined as:
static boolean equals(Object a, Object b) {
return a==b || (a != null && a.equals(b));
}
equals in class Objectobj - the object to be compared with this stack trace element.Object.hashCode(),
Hashtablepublic int hashCode()
hashCode in class ObjectObject.equals(java.lang.Object),
HashtableCopyright © 2013 CableLabs. All rights reserved.