public class ThreadLocal extends Object
For example, in the class below, the private static ThreadLocal instance (serialNum) maintains a "serial number" for each thread that invokes the class's static SerialNum.get() method, which returns the current thread's serial number. (A thread's serial number is assigned the first time it invokes SerialNum.get(), and remains unchanged on subsequent calls.)
public class SerialNum {
// The next serial number to be assigned
private static int nextSerialNum = 0;
private static ThreadLocal serialNum = new ThreadLocal() {
protected synchronized Object initialValue() {
return new Integer(nextSerialNum++);
}
};
public static int get() {
return ((Integer) (serialNum.get())).intValue();
}
}
Each thread holds an implicit reference to its copy of a thread-local variable as long as the thread is alive and the ThreadLocal instance is accessible; after a thread goes away, all of its copies of thread-local instances are subject to garbage collection (unless other references to these copies exist).
| Constructor and Description |
|---|
ThreadLocal() |
| Modifier and Type | Method and Description |
|---|---|
Object |
get()
Returns the value in the current thread's copy of this thread-local
variable.
|
protected Object |
initialValue()
Returns the current thread's initial value for this thread-local
variable.
|
void |
set(Object value)
Sets the current thread's copy of this thread-local variable
to the specified value.
|
protected Object initialValue()
get() method. The initialValue
method will not be invoked in a thread if the thread invokes the set(Object) method prior to the get method.
This implementation simply returns null; if the programmer desires thread-local variables to be initialized to some value other than null, ThreadLocal must be subclassed, and this method overridden. Typically, an anonymous inner class will be used. Typical implementations of initialValue will invoke an appropriate constructor and return the newly constructed object.
public Object get()
public void set(Object value)
initialValue()
method to set the values of thread-locals.value - the value to be stored in the current threads' copy of
this thread-local.Copyright © 2012 CableLabs. All Rights Reserved.