| Package | Description |
|---|---|
| java.lang |
Provides classes that are fundamental to the design of the Java
programming language.
|
| Modifier and Type | Class and Description |
|---|---|
class |
String
The
String class represents character strings. |
class |
StringBuffer
A string buffer implements a mutable sequence of characters.
|
| Modifier and Type | Method and Description |
|---|---|
CharSequence |
StringBuffer.subSequence(int start,
int end)
Returns a new character sequence that is a subsequence of this sequence.
|
CharSequence |
String.subSequence(int beginIndex,
int endIndex)
Returns a new character sequence that is a subsequence of this sequence.
|
CharSequence |
CharSequence.subSequence(int start,
int end)
Returns a new character sequence that is a subsequence of this sequence.
|
Copyright © 2012. All Rights Reserved.