| Package | Description |
|---|---|
| java.awt |
Contains all of the classes for creating user
interfaces and for painting graphics and images.
|
| java.io |
Provides for system input and output through data streams,
serialization and the file system.
|
| java.lang |
Provides classes that are fundamental to the design of the Java
programming language.
|
| java.lang.reflect |
Provides classes and interfaces for obtaining reflective
information about classes and objects.
|
| java.net |
Provides the classes for implementing networking applications.
|
| java.security |
Provides the classes and interfaces for the security framework.
|
| org.apache.log4j | |
| org.apache.log4j.or | |
| org.apache.log4j.spi | |
| org.apache.log4j.xml | |
| org.dvb.lang |
Provides those core platform related features not found
in the java.lang package.
|
| org.dvb.spi |
This package defines a central registry for all DVB Service Provider Interface
(SPI) providers.
|
| Modifier and Type | Method and Description |
|---|---|
static EventListener[] |
AWTEventMulticaster.getListeners(EventListener l,
Class listenerType)
Returns an array of all the objects chained as
FooListeners by the specified
java.util.EventListener. |
| Modifier and Type | Method and Description |
|---|---|
Class |
ObjectStreamClass.forClass()
Return the class in the local VM that this version is mapped to.
|
Class |
ObjectStreamField.getType()
Get the type of the field.
|
protected Class |
ObjectInputStream.resolveClass(ObjectStreamClass desc)
Load the local class equivalent of the specified stream class
description.
|
protected Class |
ObjectInputStream.resolveProxyClass(String[] interfaces)
Returns a proxy class that implements the interfaces named in a
proxy class descriptor; subclasses may implement this method to
read custom data from the stream along with the descriptors for
dynamic proxy classes, allowing them to use an alternate loading
mechanism for the interfaces and the proxy class.
|
| Modifier and Type | Method and Description |
|---|---|
protected void |
ObjectOutputStream.annotateClass(Class cl)
Subclasses may implement this method to allow class data to be stored in
the stream.
|
protected void |
ObjectOutputStream.annotateProxyClass(Class cl)
Subclasses may implement this method to store custom data in the
stream along with descriptors for dynamic proxy classes.
|
static ObjectStreamClass |
ObjectStreamClass.lookup(Class cl)
Find the descriptor for a class that can be serialized.
|
| Constructor and Description |
|---|
ObjectStreamField(String name,
Class type)
Create a Serializable field with the specified type.
|
ObjectStreamField(String name,
Class type,
boolean unshared)
Creates an ObjectStreamField representing a serializable field with the
given name and type.
|
| Modifier and Type | Field and Description |
|---|---|
static Class |
Void.TYPE
The Class object representing the primitive Java type void.
|
static Class |
Short.TYPE
The
Class instance representing the primitive type
short. |
static Class |
Long.TYPE
The
Class instance representing the primitive type
long. |
static Class |
Integer.TYPE
The
Class instance representing the primitive type
int. |
static Class |
Float.TYPE
The
Class instance representing the primitive type
float. |
static Class |
Double.TYPE
The
Class instance representing the primitive type
double. |
static Class |
Character.TYPE
The
Class instance representing the primitive type
char. |
static Class |
Byte.TYPE
The
Class instance representing the primitive type
byte. |
static Class |
Boolean.TYPE
The Class object representing the primitive type boolean.
|
| Modifier and Type | Method and Description |
|---|---|
protected Class |
ClassLoader.defineClass(String name,
byte[] b,
int off,
int len)
Converts an array of bytes into an instance of class Class.
|
protected Class |
ClassLoader.defineClass(String name,
byte[] b,
int off,
int len,
ProtectionDomain protectionDomain)
Converts an array of bytes into an instance of class Class,
with an optional ProtectionDomain.
|
protected Class |
ClassLoader.findClass(String name)
Finds the specified class.
|
protected Class |
ClassLoader.findLoadedClass(String name)
Returns the class with the given name if this loader has been recorded
by the Java virtual machine as an initiating loader of a class with
that name.
|
protected Class |
ClassLoader.findSystemClass(String name)
Finds a class with the specified name, loading it if necessary.
|
static Class |
Class.forName(String className)
Returns the
Class object associated with the class or
interface with the given string name. |
static Class |
Class.forName(String name,
boolean initialize,
ClassLoader loader)
Returns the
Class object associated with the class or
interface with the given string name, using the given class loader. |
Class |
Object.getClass()
Returns the runtime class of an object.
|
protected Class[] |
SecurityManager.getClassContext()
Returns the current execution stack as an array of classes.
|
Class[] |
Class.getClasses()
Returns an array containing
Class objects representing all
the public classes and interfaces that are members of the class
represented by this Class object. |
Class |
Class.getComponentType()
Returns the
Class representing the component type of an
array. |
Class[] |
Class.getDeclaredClasses()
Returns an array of
Class objects reflecting all the
classes and interfaces declared as members of the class represented by
this Class object. |
Class |
Class.getDeclaringClass()
If the class or interface represented by this
Class object
is a member of another class, returns the Class object
representing the class in which it was declared. |
Class[] |
Class.getInterfaces()
Determines the interfaces implemented by the class or interface
represented by this object.
|
Class |
Class.getSuperclass()
Returns the
Class representing the superclass of the entity
(class, interface, primitive type or void) represented by this
Class. |
Class |
ClassLoader.loadClass(String name)
Loads the class with the specified name.
|
protected Class |
ClassLoader.loadClass(String name,
boolean resolve)
Loads the class with the specified name.
|
| Modifier and Type | Method and Description |
|---|---|
void |
SecurityManager.checkMemberAccess(Class clazz,
int which)
Throws a
SecurityException if the
calling thread is not allowed to access members. |
static boolean |
Compiler.compileClass(Class clazz)
Compiles the specified class.
|
Constructor |
Class.getConstructor(Class[] parameterTypes)
Returns a
Constructor object that reflects the specified
public constructor of the class represented by this Class
object. |
Constructor |
Class.getDeclaredConstructor(Class[] parameterTypes)
Returns a
Constructor object that reflects the specified
constructor of the class or interface represented by this
Class object. |
Method |
Class.getDeclaredMethod(String name,
Class[] parameterTypes)
Returns a
Method object that reflects the specified
declared method of the class or interface represented by this
Class object. |
Method |
Class.getMethod(String name,
Class[] parameterTypes)
Returns a
Method object that reflects the specified public
member method of the class or interface represented by this
Class object. |
boolean |
Class.isAssignableFrom(Class cls)
Determines if the class or interface represented by this
Class object is either the same as, or is a superclass or
superinterface of, the class or interface represented by the specified
Class parameter. |
protected void |
ClassLoader.resolveClass(Class c)
Links the specified class.
|
protected void |
ClassLoader.setSigners(Class c,
Object[] signers)
Sets the signers of a class.
|
| Modifier and Type | Method and Description |
|---|---|
Class |
Method.getDeclaringClass()
Returns the
Class object representing the class or interface
that declares the method represented by this Method object. |
Class |
Member.getDeclaringClass()
Returns the Class object representing the class or interface
that declares the member or constructor represented by this Member.
|
Class |
Field.getDeclaringClass()
Returns the
Class object representing the class or interface
that declares the field represented by this Field object. |
Class |
Constructor.getDeclaringClass()
Returns the
Class object representing the class that declares
the constructor represented by this Constructor object. |
Class[] |
Method.getExceptionTypes()
Returns an array of
Class objects that represent
the types of the exceptions declared to be thrown
by the underlying method
represented by this Method object. |
Class[] |
Constructor.getExceptionTypes()
Returns an array of
Class objects that represent the types of
of exceptions declared to be thrown by the underlying constructor
represented by this Constructor object. |
Class[] |
Method.getParameterTypes()
Returns an array of
Class objects that represent the formal
parameter types, in declaration order, of the method
represented by this Method object. |
Class[] |
Constructor.getParameterTypes()
Returns an array of
Class objects that represent the formal
parameter types, in declaration order, of the constructor
represented by this Constructor object. |
static Class |
Proxy.getProxyClass(ClassLoader loader,
Class[] interfaces)
Returns the
java.lang.Class object for a proxy class
given a class loader and an array of interfaces. |
Class |
Method.getReturnType()
Returns a
Class object that represents the formal return type
of the method represented by this Method object. |
Class |
Field.getType()
Returns a
Class object that identifies the
declared type for the field represented by this
Field object. |
| Modifier and Type | Method and Description |
|---|---|
static Class |
Proxy.getProxyClass(ClassLoader loader,
Class[] interfaces)
Returns the
java.lang.Class object for a proxy class
given a class loader and an array of interfaces. |
static boolean |
Proxy.isProxyClass(Class cl)
Returns true if and only if the specified class was dynamically
generated to be a proxy class using the
getProxyClass
method or the newProxyInstance method. |
static Object |
Array.newInstance(Class componentType,
int length)
Creates a new array with the specified component type and
length.
|
static Object |
Array.newInstance(Class componentType,
int[] dimensions)
Creates a new array
with the specified component type and dimensions.
|
static Object |
Proxy.newProxyInstance(ClassLoader loader,
Class[] interfaces,
InvocationHandler h)
Returns an instance of a proxy class for the specified interfaces
that dispatches method invocations to the specified invocation
handler.
|
| Modifier and Type | Method and Description |
|---|---|
protected Class |
URLClassLoader.findClass(String name)
Finds and loads the class with the specified name from the URL search
path.
|
| Modifier and Type | Method and Description |
|---|---|
Object |
URLConnection.getContent(Class[] classes)
Retrieves the contents of this URL connection.
|
Object |
URL.getContent(Class[] classes)
Gets the contents of this URL.
|
Object |
ContentHandler.getContent(URLConnection urlc,
Class[] classes)
Given a URL connect stream positioned at the beginning of the
representation of an object, this method reads that stream and
creates an object that matches one of the types specified.
|
| Modifier and Type | Method and Description |
|---|---|
protected Class |
SecureClassLoader.defineClass(String name,
byte[] b,
int off,
int len,
CodeSource cs)
Converts an array of bytes into an instance of class Class,
with an optional CodeSource.
|
| Modifier and Type | Method and Description |
|---|---|
protected abstract KeySpec |
KeyFactorySpi.engineGetKeySpec(Key key,
Class keySpec)
Returns a specification (key material) of the given key
object.
|
protected abstract AlgorithmParameterSpec |
AlgorithmParametersSpi.engineGetParameterSpec(Class paramSpec)
Returns a (transparent) specification of this parameters
object.
|
KeySpec |
KeyFactory.getKeySpec(Key key,
Class keySpec)
Returns a specification (key material) of the given key object.
|
AlgorithmParameterSpec |
AlgorithmParameters.getParameterSpec(Class paramSpec)
Returns a (transparent) specification of this parameter object.
|
| Modifier and Type | Method and Description |
|---|---|
void |
Hierarchy.addRenderer(Class classToRender,
ObjectRenderer or)
Add an object renderer for a specific class.
|
static Category |
Category.getInstance(Class clazz)
Deprecated.
Please make sure to use
Logger.getLogger(Class) instead. |
static Logger |
LogManager.getLogger(Class clazz)
Retrieve the appropriate
Logger instance. |
static Logger |
Logger.getLogger(Class clazz)
Shorthand for
getLogger(clazz.getName()). |
static Logger |
Logger.getLogger(Class clazz,
String group)
Shorthand for
getLogger(clazz.getName()). |
void |
Hierarchy.setRenderer(Class renderedClass,
ObjectRenderer renderer)
Used by subclasses to add a renderer to the hierarchy passed as parameter.
|
| Modifier and Type | Method and Description |
|---|---|
ObjectRenderer |
RendererMap.get(Class clazz)
Search the parents of
clazz for a renderer. |
void |
RendererMap.put(Class clazz,
ObjectRenderer or)
Register an
ObjectRenderer for clazz. |
| Modifier and Type | Method and Description |
|---|---|
void |
RendererSupport.setRenderer(Class renderedClass,
ObjectRenderer renderer) |
| Modifier and Type | Method and Description |
|---|---|
static Object |
DOMConfigurator.parseElement(Element element,
Properties props,
Class expectedClass)
Creates an object and processes any nested param elements
but does not call activateOptions.
|
| Modifier and Type | Method and Description |
|---|---|
Class |
DVBClassLoader.findClass(String name)
Finds and loads the class with the specified name from the URL
search path.
|
| Modifier and Type | Method and Description |
|---|---|
Class[] |
Provider.getServiceProviderInterfaces()
Gives a list of the SPI's implemented by this provider.
|
Copyright © 2012 CableLabs. All Rights Reserved.