| Package | Description |
|---|---|
| java.lang |
Provides classes that are fundamental to the design of the Java
programming language.
|
| Modifier and Type | Class and Description |
|---|---|
class |
UnsupportedClassVersionError
Thrown when the Java Virtual Machine attempts to read a class
file and determines that the major and minor version numbers
in the file are not supported.
|
| Modifier and Type | Method and Description |
|---|---|
protected Class |
ClassLoader.defineClass(String name,
byte[] b,
int off,
int len)
Converts an array of bytes into an instance of class Class.
|
protected Class |
ClassLoader.defineClass(String name,
byte[] b,
int off,
int len,
ProtectionDomain protectionDomain)
Converts an array of bytes into an instance of class Class,
with an optional ProtectionDomain.
|
Copyright © 2012 CableLabs. All Rights Reserved.