| Package | Description |
|---|---|
| java.lang |
Provides classes that are fundamental to the design of the Java
programming language.
|
| java.security |
Provides the classes and interfaces for the security framework.
|
| java.util |
Contains the collections framework, legacy collection classes, event model,
date and time facilities, internationalization, and miscellaneous utility
classes (a string tokenizer, a random-number generator, and a bit array).
|
| Modifier and Type | Method and Description |
|---|---|
protected Object |
Object.clone()
Creates and returns a copy of this object.
|
| Modifier and Type | Method and Description |
|---|---|
Object |
SignatureSpi.clone()
Returns a clone if the implementation is cloneable.
|
Object |
Signature.clone()
Returns a clone if the implementation is cloneable.
|
Object |
MessageDigestSpi.clone()
Returns a clone if the implementation is cloneable.
|
Object |
MessageDigest.clone()
Returns a clone if the implementation is cloneable.
|
| Modifier and Type | Method and Description |
|---|---|
protected Object |
AbstractMap.clone()
Returns a shallow copy of this AbstractMap instance: the keys
and values themselves are not cloned.
|
Copyright © 2013 CableLabs. All rights reserved.