| Package | Description |
|---|---|
| java.awt |
Contains all of the classes for creating user
interfaces and for painting graphics and images.
|
| java.awt.image |
Provides classes for creating and modifying images.
|
| java.security |
Provides the classes and interfaces for the security framework.
|
| java.security.acl |
The classes and interfaces in this package have been
superseded by classes in the java.security package.
|
| java.text |
Provides classes and interfaces for handling text, dates, numbers, and messages
in a manner independent of natural languages.
|
| java.util |
Contains the collections framework, legacy collection classes, event model,
date and time facilities, internationalization, and miscellaneous utility
classes (a string tokenizer, a random-number generator, and a bit array).
|
| java.util.jar |
Provides classes for reading and writing the JAR (Java ARchive) file
format, which is based on the standard ZIP file format with an
optional manifest file.
|
| java.util.zip |
Provides classes for reading and writing the standard ZIP and GZIP
file formats.
|
| org.davic.mpeg.sections |
Provides access to MPEG-2 section filtering.
|
| org.havi.ui |
Provides user interfaces to HAVI components.
|
| Modifier and Type | Class and Description |
|---|---|
class |
Dimension
The
Dimension class encapsulates the width and
height of a component (in integer precision) in a single object. |
class |
GridBagConstraints
The
GridBagConstraints class specifies constraints
for components that are laid out using the
GridBagLayout class. |
class |
ImageCapabilities
Capabilities and properties of images.
|
class |
Insets
An
Insets object is a representation of the borders
of a container. |
class |
Point
A point representing a location in (x, y) coordinate space, specified
in integer precision.
|
class |
Rectangle
A
Rectangle specifies an area in a coordinate space that is
enclosed by the Rectangle object's top-left point
(x, y)
in the coordinate space, its width, and its height. |
| Modifier and Type | Class and Description |
|---|---|
class |
AreaAveragingScaleFilter
An ImageFilter class for scaling images using a simple area averaging
algorithm that produces smoother results than the nearest neighbor
algorithm.
|
class |
CropImageFilter
An ImageFilter class for cropping images.
|
class |
ImageFilter
This class implements a filter for the set of interface methods that
are used to deliver data from an ImageProducer to an ImageConsumer.
|
class |
ReplicateScaleFilter
An ImageFilter class for scaling images using the simplest algorithm.
|
class |
RGBImageFilter
This class provides an easy way to create an ImageFilter which modifies
the pixels of an image in the default RGB ColorModel.
|
| Modifier and Type | Class and Description |
|---|---|
class |
Provider
This class represents a "provider" for the
Java Security API, where a provider implements some or all parts of
Java Security.
|
| Modifier and Type | Interface and Description |
|---|---|
interface |
AclEntry
This is the interface used for representing one entry in an Access
Control List (ACL).
|
| Modifier and Type | Interface and Description |
|---|---|
interface |
AttributedCharacterIterator
An AttributedCharacterIterator allows iteration through both text and
related attribute information.
|
interface |
CharacterIterator
This interface defines a protocol for bidirectional iteration over text.
|
| Modifier and Type | Class and Description |
|---|---|
class |
BreakIterator
The
BreakIterator class implements methods for finding
the location of boundaries in text. |
class |
ChoiceFormat
A
ChoiceFormat allows you to attach a format to a range of numbers. |
class |
Collator
The
Collator class performs locale-sensitive
String comparison. |
class |
DateFormat
DateFormat is an abstract class for date/time formatting subclasses which
formats and parses dates or time in a language-independent manner.
|
class |
DateFormatSymbols
DateFormatSymbols is a public class for encapsulating
localizable date-time formatting data, such as the names of the
months, the names of the days of the week, and the time zone data. |
class |
DecimalFormat
DecimalFormat is a concrete subclass of
NumberFormat that formats decimal numbers. |
class |
DecimalFormatSymbols
This class represents the set of symbols (such as the decimal separator,
the grouping separator, and so on) needed by
DecimalFormat
to format numbers. |
class |
Format
Format is an abstract base class for formatting locale-sensitive
information such as dates, messages, and numbers. |
class |
MessageFormat
MessageFormat provides a means to produce concatenated
messages in language-neutral way. |
class |
NumberFormat
NumberFormat is the abstract base class for all number
formats. |
class |
RuleBasedCollator
The
RuleBasedCollator class is a concrete subclass of
Collator that provides a simple, data-driven, table
collator. |
class |
SimpleDateFormat
SimpleDateFormat is a concrete class for formatting and
parsing dates in a locale-sensitive manner. |
class |
StringCharacterIterator
StringCharacterIterator implements the
CharacterIterater protocol for a String. |
| Modifier and Type | Class and Description |
|---|---|
class |
ArrayList
Resizable-array implementation of the List interface.
|
class |
BitSet
This class implements a vector of bits that grows as needed.
|
class |
Calendar
Calendar is an abstract base class for converting between
a Date object and a set of integer fields such as
YEAR, MONTH, DAY, HOUR,
and so on. |
class |
Date
The class
Date represents a specific instant
in time, with millisecond precision. |
class |
GregorianCalendar
GregorianCalendar is a concrete subclass of
Calendar
and provides the standard calendar used by most of the world. |
class |
HashMap
Hash table based implementation of the Map interface.
|
class |
HashSet
This class implements the Set interface, backed by a hash table
(actually a HashMap instance).
|
class |
Hashtable
This class implements a hashtable, which maps keys to values.
|
class |
IdentityHashMap
This class implements the Map interface with a hash table, using
reference-equality in place of object-equality when comparing keys (and
values).
|
class |
LinkedHashMap
Hash table and linked list implementation of the Map interface,
with predictable iteration order.
|
class |
LinkedHashSet
Hash table and linked list implementation of the Set interface,
with predictable iteration order.
|
class |
LinkedList
Linked list implementation of the List interface.
|
class |
Locale
A
Locale object represents a specific geographical, political,
or cultural region. |
class |
Properties
The
Properties class represents a persistent set of
properties. |
class |
SimpleTimeZone
SimpleTimeZone is a concrete subclass of TimeZone
that represents a time zone for use with a Gregorian calendar. |
class |
Stack
The
Stack class represents a last-in-first-out
(LIFO) stack of objects. |
class |
TimeZone
TimeZone represents a time zone offset, and also figures out daylight
savings. |
class |
TreeMap
Red-Black tree based implementation of the SortedMap interface.
|
class |
TreeSet
This class implements the Set interface, backed by a
TreeMap instance.
|
class |
Vector
The
Vector class implements a growable array of
objects. |
| Modifier and Type | Class and Description |
|---|---|
class |
Attributes
The Attributes class maps Manifest attribute names to associated string
values.
|
class |
JarEntry
This class is used to represent a JAR file entry.
|
class |
Manifest
The Manifest class is used to maintain Manifest entry names and their
associated Attributes.
|
| Modifier and Type | Class and Description |
|---|---|
class |
ZipEntry
This class is used to represent a ZIP file entry.
|
| Modifier and Type | Class and Description |
|---|---|
class |
Section
This class describes a single section as filtered from an MPEG transport stream.
|
| Modifier and Type | Interface and Description |
|---|---|
interface |
HAdjustableLook
The
HAdjustableLook interface is implemented by
all platform looks which support orientable components (i.e. |
interface |
HExtendedLook
The
HExtendedLook interface is derived
from the HLook interface and abstracts
out the drawing of the look into separate background, border
and visible data components. |
interface |
HLook
The
HLook interface defines the
"look" of a component and may be regarded as a mechanism
to allow a "pluggable" paint method to be attached to the
component. |
| Modifier and Type | Class and Description |
|---|---|
class |
HAnimateLook
The HAnimateLook
class is used by any
HVisible
component to display animated graphical content. |
class |
HGraphicLook
The
HGraphicLook
class is used by any HVisible component to display static graphical content. |
class |
HListGroupLook
The
HListGroupLook class is used by the HListGroup component to display both the
HListGroup itself (potentially
including a scrollbar component) and graphical or textual list
content held on the HListGroup. |
class |
HMultilineEntryLook
The
HMultilineEntryLook
class is used by the HMultilineEntry component to display the entering of text. |
class |
HRangeLook
The
HRangeLook class is used to
display a slider or scrollbar type range control on screen. |
class |
HSinglelineEntryLook
The
HSinglelineEntryLook
class is used by the HSinglelineEntry component to display the entering of text. |
class |
HTextLook
|
Copyright © 2013 CableLabs. All rights reserved.