| Package | Description |
|---|---|
| java.io |
Provides for system input and output through data streams,
serialization and the file system.
|
| java.lang |
Provides classes that are fundamental to the design of the Java
programming language.
|
| java.math |
Provides classes for performing arbitrary-precision integer arithmetic
(BigInteger) and arbitrary-precision decimal arithmetic (BigDecimal).
|
| java.net |
Provides the classes for implementing networking applications.
|
| java.text |
Provides classes and interfaces for handling text, dates, numbers, and messages
in a manner independent of natural languages.
|
| java.util |
Contains the collections framework, legacy collection classes, event model,
date and time facilities, internationalization, and miscellaneous utility
classes (a string tokenizer, a random-number generator, and a bit array).
|
| org.dvb.dsmcc |
Provides extended access to files carried in the broadcast
stream.
|
| Modifier and Type | Class and Description |
|---|---|
class |
File
An abstract representation of file and directory pathnames.
|
class |
ObjectStreamField
A description of a Serializable field from a Serializable class.
|
| Modifier and Type | Class and Description |
|---|---|
class |
Byte
The
Byte class wraps a value of primitive type
byte in an object. |
class |
Character
The
Character class wraps a value of the primitive
type char in an object. |
class |
Double
The
Double class wraps a value of the primitive type
double in an object. |
class |
Float
The
Float class wraps a value of primitive type
float in an object. |
class |
Integer
The
Integer class wraps a value of the primitive type
int in an object. |
class |
Long
The
Long class wraps a value of the primitive type
long in an object. |
class |
Short
The
Short class wraps a value of primitive type
short in an object. |
class |
String
The
String class represents character strings. |
| Modifier and Type | Class and Description |
|---|---|
class |
BigDecimal
Immutable, arbitrary-precision signed decimal numbers.
|
class |
BigInteger
Immutable arbitrary-precision integers.
|
| Modifier and Type | Class and Description |
|---|---|
class |
URI
Represents a Uniform Resource Identifier (URI) reference.
|
| Modifier and Type | Class and Description |
|---|---|
class |
CollationKey
A
CollationKey represents a String under the
rules of a specific Collator object. |
| Modifier and Type | Class and Description |
|---|---|
class |
Date
The class
Date represents a specific instant
in time, with millisecond precision. |
| Modifier and Type | Class and Description |
|---|---|
class |
DSMCCObject
A DSMCCObject is an object which belongs to a DSMCC ServiceDomain.
|
Copyright © 2012 CableLabs. All Rights Reserved.