| Package | Description |
|---|---|
| java.awt |
Contains all of the classes for creating user
interfaces and for painting graphics and images.
|
| java.lang |
Provides classes that are fundamental to the design of the Java
programming language.
|
| javax.media |
Provides media players, means of controlling playback and being notified of playback state changes.
|
| javax.xml.parsers |
The javax.xml.parsers package contains the Java API for XML Processing (JAXP)
subset defined by JSR 280.
|
| Modifier and Type | Class and Description |
|---|---|
class |
AWTError
Thrown when a serious Abstract Window Toolkit error has occurred.
|
| Modifier and Type | Class and Description |
|---|---|
class |
AbstractMethodError
Thrown when an application tries to call an abstract method.
|
class |
AssertionError
Thrown to indicate that an assertion has failed.
|
class |
ClassCircularityError
Thrown when a circularity has been detected while initializing a class.
|
class |
ClassFormatError
Thrown when the Java Virtual Machine attempts to read a class
file and determines that the file is malformed or otherwise cannot
be interpreted as a class file.
|
class |
ExceptionInInitializerError
Signals that an unexpected exception has occurred in a static initializer.
|
class |
IllegalAccessError
Thrown if an application attempts to access or modify a field, or
to call a method that it does not have access to.
|
class |
IncompatibleClassChangeError
Thrown when an incompatible class change has occurred to some class
definition.
|
class |
InstantiationError
Thrown when an application tries to use the Java
new
construct to instantiate an abstract class or an interface. |
class |
InternalError
Thrown to indicate some unexpected internal error has occurred in
the Java Virtual Machine.
|
class |
LinkageError
Subclasses of
LinkageError indicate that a class has
some dependency on another class; however, the latter class has
incompatibly changed after the compilation of the former class. |
class |
NoClassDefFoundError
Thrown if the Java Virtual Machine or a
ClassLoader instance
tries to load in the definition of a class (as part of a normal method call
or as part of creating a new instance using the new expression)
and no definition of the class could be found. |
class |
NoSuchFieldError
Thrown if an application tries to access or modify a specified
field of an object, and that object no longer has that field.
|
class |
NoSuchMethodError
Thrown if an application tries to call a specified method of a
class (either static or instance), and that class no longer has a
definition of that method.
|
class |
OutOfMemoryError
Thrown when the Java Virtual Machine cannot allocate an object
because it is out of memory, and no more memory could be made
available by the garbage collector.
|
class |
StackOverflowError
Thrown when a stack overflow occurs because an application
recurses too deeply.
|
class |
ThreadDeath
An instance of
ThreadDeath is thrown in the victim
thread when the stop method with zero arguments in
class Thread is called. |
class |
UnknownError
Thrown when an unknown but serious exception has occurred in the
Java Virtual Machine.
|
class |
UnsatisfiedLinkError
Thrown if the Java Virtual Machine cannot find an appropriate
native-language definition of a method declared
native. |
class |
UnsupportedClassVersionError
Thrown when the Java Virtual Machine attempts to read a class
file and determines that the major and minor version numbers
in the file are not supported.
|
class |
VerifyError
Thrown when the "verifier" detects that a class file,
though well formed, contains some sort of internal inconsistency
or security problem.
|
class |
VirtualMachineError
Thrown to indicate that the Java Virtual Machine is broken or has
run out of resources necessary for it to continue operating.
|
| Modifier and Type | Class and Description |
|---|---|
class |
ClockStartedError
ClockStartedError is thrown by a Started Clock
when a method is invoked that is not legal on a Clock in the Started
state. |
class |
MediaError
A
MediaError indicates an error condition that
occurred through incorrect usage of the API. |
class |
NotPrefetchedError
NotPrefetchedError is thrown when a method that
requires a Controller to be in the Prefetched state is called
and the Controller has not been Prefetched. |
class |
NotRealizedError
NotRealizedError is thrown when a method that
requires a Controller to be in the Realized state is called
and the Controller is not Realized. |
class |
StopTimeSetError
StopTimeSetError is thrown when the stop time
has been set on a Started Clock and setStopTime is invoked
again. |
| Modifier and Type | Class and Description |
|---|---|
class |
FactoryConfigurationError
Thrown when a problem with configuration with the Parser Factories
exists.
|
Copyright © 2013 CableLabs. All rights reserved.