| Package | Description |
|---|---|
| java.lang |
Provides classes that are fundamental to the design of the Java
programming language.
|
| org.davic.media |
Provides various extensions to the Java Media Framework for
the control of TV oriented audio / video content.
|
| org.davic.mpeg |
Provides utility classes for common MPEG concepts.
|
| org.davic.mpeg.sections |
Provides access to MPEG-2 section filtering.
|
| Modifier and Type | Class and Description |
|---|---|
class |
ArrayIndexOutOfBoundsException
Thrown to indicate that an array has been accessed with an
illegal index.
|
class |
StringIndexOutOfBoundsException
Thrown by
String methods to indicate that an index
is either negative or greater than the size of the string. |
| Modifier and Type | Method and Description |
|---|---|
int[] |
NotAuthorizedMediaException.getReason(int index)
Returns the reason(s) why descrambling was not possible.
|
| Modifier and Type | Method and Description |
|---|---|
int[] |
NotAuthorizedInterface.getReason(int index)
Returns the reason(s) why descrambling was not possible.
|
int[] |
NotAuthorizedException.getReason(int index)
Returns the reason(s) why descrambling was not possible.
|
| Modifier and Type | Method and Description |
|---|---|
byte |
Section.getByteAt(int index)
This method returns one byte from the filtered data.
|
byte[] |
Section.getData(int index,
int length)
This method returns the specified part of the filtered data.
|
Copyright © 2012. All Rights Reserved.