| Package | Description |
|---|---|
| java.lang |
Provides classes that are fundamental to the design of the Java
programming language.
|
| java.lang.reflect |
Provides classes and interfaces for obtaining reflective
information about classes and objects.
|
| Modifier and Type | Method and Description |
|---|---|
Object |
Class.newInstance()
Creates a new instance of the class represented by this Class
object.
|
| Modifier and Type | Method and Description |
|---|---|
Object |
Constructor.newInstance(Object[] initargs)
Uses the constructor represented by this
Constructor object to
create and initialize a new instance of the constructor's
declaring class, with the specified initialization parameters. |
Copyright © 2013 CableLabs. All rights reserved.