| Package | Description |
|---|---|
| java.awt |
Contains all of the classes for creating user
interfaces and for painting graphics and images.
|
| java.awt.image |
Provides classes for creating and modifying images.
|
| java.lang |
Provides classes that are fundamental to the design of the Java
programming language.
|
| java.lang.ref |
Provides reference-object classes, which support a limited degree of
interaction with the garbage collector.
|
| Modifier and Type | Method and Description |
|---|---|
AWTEvent |
EventQueue.getNextEvent()
Removes an event from the
EventQueue and
returns it. |
static void |
EventQueue.invokeAndWait(Runnable runnable)
Causes
runnable to have its run
method called in the dispatch thread of the EventQueue. |
void |
MediaTracker.waitForAll()
Starts loading all images tracked by this media tracker.
|
boolean |
MediaTracker.waitForAll(long ms)
Starts loading all images tracked by this media tracker.
|
void |
MediaTracker.waitForID(int id)
Starts loading all images tracked by this media tracker with the
specified identifier.
|
boolean |
MediaTracker.waitForID(int id,
long ms)
Starts loading all images tracked by this media tracker with the
specified identifier.
|
| Modifier and Type | Method and Description |
|---|---|
boolean |
PixelGrabber.grabPixels()
Request the Image or ImageProducer to start delivering pixels and
wait for all of the pixels in the rectangle of interest to be
delivered.
|
boolean |
PixelGrabber.grabPixels(long ms)
Request the Image or ImageProducer to start delivering pixels and
wait for all of the pixels in the rectangle of interest to be
delivered or until the specified timeout has elapsed.
|
| Modifier and Type | Method and Description |
|---|---|
void |
Thread.join()
Waits for this thread to die.
|
void |
Thread.join(long millis)
Waits at most
millis milliseconds for this thread to
die. |
void |
Thread.join(long millis,
int nanos)
Waits at most
millis milliseconds plus
nanos nanoseconds for this thread to die. |
static void |
Thread.sleep(long millis)
Causes the currently executing thread to sleep (temporarily cease
execution) for the specified number of milliseconds.
|
static void |
Thread.sleep(long millis,
int nanos)
Causes the currently executing thread to sleep (cease execution)
for the specified number of milliseconds plus the specified number
of nanoseconds.
|
void |
Object.wait()
Causes current thread to wait until another thread invokes the
Object.notify() method or the
Object.notifyAll() method for this object. |
void |
Object.wait(long timeout)
Causes current thread to wait until either another thread invokes the
Object.notify() method or the
Object.notifyAll() method for this object, or a
specified amount of time has elapsed. |
void |
Object.wait(long timeout,
int nanos)
Causes current thread to wait until another thread invokes the
Object.notify() method or the
Object.notifyAll() method for this object, or
some other thread interrupts the current thread, or a certain
amount of real time has elapsed. |
abstract int |
Process.waitFor()
causes the current thread to wait, if necessary, until the
process represented by this
Process object has
terminated. |
| Modifier and Type | Method and Description |
|---|---|
Reference |
ReferenceQueue.remove()
Removes the next reference object in this queue, blocking until one
becomes available.
|
Reference |
ReferenceQueue.remove(long timeout)
Removes the next reference object in this queue, blocking until either
one becomes available or the given timeout period expires.
|
Copyright © 2013 CableLabs. All rights reserved.