| Package | Description |
|---|---|
| java.lang |
Provides classes that are fundamental to the design of the Java
programming language.
|
| Modifier and Type | Method and Description |
|---|---|
Field |
Class.getDeclaredField(String name)
Returns a
Field object that reflects the specified declared
field of the class or interface represented by this Class
object. |
Field |
Class.getField(String name)
Returns a
Field object that reflects the specified public
member field of the class or interface represented by this
Class object. |
Copyright © 2012. All Rights Reserved.