| Package | Description |
|---|---|
| java.lang |
Provides classes that are fundamental to the design of the Java
programming language.
|
| Modifier and Type | Method and Description |
|---|---|
Constructor |
Class.getConstructor(Class[] parameterTypes)
Returns a
Constructor object that reflects the specified
public constructor of the class represented by this Class
object. |
Constructor |
Class.getDeclaredConstructor(Class[] parameterTypes)
Returns a
Constructor object that reflects the specified
constructor of the class or interface represented by this
Class object. |
Method |
Class.getDeclaredMethod(String name,
Class[] parameterTypes)
Returns a
Method object that reflects the specified
declared method of the class or interface represented by this
Class object. |
Method |
Class.getMethod(String name,
Class[] parameterTypes)
Returns a
Method object that reflects the specified public
member method of the class or interface represented by this
Class object. |
Copyright © 2013 CableLabs. All rights reserved.