| Package | Description |
|---|---|
| java.lang |
Provides classes that are fundamental to the design of the Java
programming language.
|
| java.math |
Provides classes for performing arbitrary-precision integer arithmetic
(BigInteger) and arbitrary-precision decimal arithmetic (BigDecimal).
|
| java.text |
Provides classes and interfaces for handling text, dates, numbers, and messages
in a manner independent of natural languages.
|
| Modifier and Type | Class and Description |
|---|---|
class |
Byte
The
Byte class wraps a value of primitive type
byte in an object. |
class |
Double
The
Double class wraps a value of the primitive type
double in an object. |
class |
Float
The
Float class wraps a value of primitive type
float in an object. |
class |
Integer
The
Integer class wraps a value of the primitive type
int in an object. |
class |
Long
The
Long class wraps a value of the primitive type
long in an object. |
class |
Short
The
Short class wraps a value of primitive type
short in an object. |
| Modifier and Type | Class and Description |
|---|---|
class |
BigDecimal
Immutable, arbitrary-precision signed decimal numbers.
|
class |
BigInteger
Immutable arbitrary-precision integers.
|
| Modifier and Type | Method and Description |
|---|---|
Number |
NumberFormat.parse(String source)
Parses text from the beginning of the given string to produce a number.
|
abstract Number |
NumberFormat.parse(String source,
ParsePosition parsePosition)
Returns a Long if possible (e.g., within the range [Long.MIN_VALUE,
Long.MAX_VALUE] and with no decimals), otherwise a Double.
|
Number |
DecimalFormat.parse(String text,
ParsePosition pos)
Parses text from a string to produce a
Number. |
Number |
ChoiceFormat.parse(String text,
ParsePosition status)
Parses a Number from the input text.
|
Copyright © 2013 CableLabs. All rights reserved.