| Package | Description |
|---|---|
| java.awt |
Contains all of the classes for creating user
interfaces and for painting graphics and images.
|
| java.awt.event |
Provides interfaces and classes for dealing with different
types of events fired by AWT components.
|
| java.lang |
Provides classes that are fundamental to the design of the Java
programming language.
|
| java.util |
Contains the collections framework, legacy collection classes, event model,
date and time facilities, internationalization, and miscellaneous utility
classes (a string tokenizer, a random-number generator, and a bit array).
|
| Modifier and Type | Method and Description |
|---|---|
static void |
EventQueue.invokeAndWait(Runnable runnable)
Causes
runnable to have its run
method called in the dispatch thread of the EventQueue. |
static void |
EventQueue.invokeLater(Runnable runnable)
Causes
runnable to have its run
method called in the dispatch thread of the EventQueue. |
| Modifier and Type | Field and Description |
|---|---|
protected Runnable |
InvocationEvent.runnable
The Runnable whose run() method will be called.
|
| Constructor and Description |
|---|
InvocationEvent(Object source,
int id,
Runnable runnable,
Object notifier,
boolean catchExceptions)
Constructs an
InvocationEvent with the specified
source and ID which will execute the runnable's run
method when dispatched. |
InvocationEvent(Object source,
Runnable runnable)
Constructs an
InvocationEvent with the specified
source which will execute the runnable's run
method when dispatched. |
InvocationEvent(Object source,
Runnable runnable,
Object notifier,
boolean catchExceptions)
Constructs an
InvocationEvent with the specified
source which will execute the runnable's run
method when dispatched. |
| Modifier and Type | Class and Description |
|---|---|
class |
Thread
A thread is a thread of execution in a program.
|
| Constructor and Description |
|---|
Thread(Runnable target)
Allocates a new
Thread object. |
Thread(Runnable target,
String name)
Allocates a new
Thread object. |
Thread(ThreadGroup group,
Runnable target)
Allocates a new
Thread object. |
Thread(ThreadGroup group,
Runnable target,
String name)
Allocates a new
Thread object so that it has
target as its run object, has the specified
name as its name, and belongs to the thread group
referred to by group. |
Thread(ThreadGroup group,
Runnable target,
String name,
long stackSize)
Allocates a new
Thread object so that it has
target as its run object, has the specified
name as its name, belongs to the thread group referred to
by group, and has the specified stack size. |
| Modifier and Type | Class and Description |
|---|---|
class |
TimerTask
A task that can be scheduled for one-time or repeated execution by a Timer.
|
Copyright © 2013 CableLabs. All rights reserved.