| Package | Description |
|---|---|
| java.awt |
Contains all of the classes for creating user
interfaces and for painting graphics and images.
|
| java.awt.image |
Provides classes for creating and modifying images.
|
| java.lang |
Provides classes that are fundamental to the design of the Java
programming language.
|
| java.lang.reflect |
Provides classes and interfaces for obtaining reflective
information about classes and objects.
|
| java.security |
Provides the classes and interfaces for the security framework.
|
| java.util |
Contains the collections framework, legacy collection classes, event model,
date and time facilities, internationalization, and miscellaneous utility
classes (a string tokenizer, a random-number generator, and a bit array).
|
| org.w3c.dom |
The org.w3c.dom package provides the Java ME DOM API defined by
JSR 280.
|
| org.w3c.dom.events |
The org.w3c.dom.events package provides the Java ME DOM Events API subset
defined by JSR 280.
|
| Modifier and Type | Class and Description |
|---|---|
class |
HeadlessException
Thrown when code that is dependent on a keyboard, display, or mouse
is called in an environment that does not support a keyboard, display,
or mouse.
|
class |
IllegalComponentStateException
Signals that an AWT component is not in an appropriate state for
the requested operation.
|
| Modifier and Type | Class and Description |
|---|---|
class |
RasterFormatException
The
RasterFormatException is thrown if there is
invalid layout information in a BufferedImage. |
| Modifier and Type | Class and Description |
|---|---|
class |
ArithmeticException
Thrown when an exceptional arithmetic condition has occurred.
|
class |
ArrayIndexOutOfBoundsException
Thrown to indicate that an array has been accessed with an
illegal index.
|
class |
ArrayStoreException
Thrown to indicate that an attempt has been made to store the
wrong type of object into an array of objects.
|
class |
ClassCastException
Thrown to indicate that the code has attempted to cast an object
to a subclass of which it is not an instance.
|
class |
IllegalArgumentException
Thrown to indicate that a method has been passed an illegal or
inappropriate argument.
|
class |
IllegalMonitorStateException
Thrown to indicate that a thread has attempted to wait on an
object's monitor or to notify other threads waiting on an object's
monitor without owning the specified monitor.
|
class |
IllegalStateException
Signals that a method has been invoked at an illegal or
inappropriate time.
|
class |
IllegalThreadStateException
Thrown to indicate that a thread is not in an appropriate state
for the requested operation.
|
class |
IndexOutOfBoundsException
Thrown to indicate that an index of some sort (such as to an array, to a
string, or to a vector) is out of range.
|
class |
NegativeArraySizeException
Thrown if an application tries to create an array with negative size.
|
class |
NullPointerException
Thrown when an application attempts to use
null in a
case where an object is required. |
class |
NumberFormatException
Thrown to indicate that the application has attempted to convert
a string to one of the numeric types, but that the string does not
have the appropriate format.
|
class |
SecurityException
Thrown by the security manager to indicate a security violation.
|
class |
StringIndexOutOfBoundsException
Thrown by
String methods to indicate that an index
is either negative or greater than the size of the string. |
class |
UnsupportedOperationException
Thrown to indicate that the requested operation is not supported.
|
| Modifier and Type | Class and Description |
|---|---|
class |
UndeclaredThrowableException
Thrown by a method invocation on a proxy instance if its invocation
handler's
invoke method throws a
checked exception (a Throwable that is not assignable
to RuntimeException or Error) that
is not assignable to any of the exception types declared in the
throws clause of the method that was invoked on the
proxy instance and dispatched to the invocation handler. |
| Modifier and Type | Class and Description |
|---|---|
class |
AccessControlException
This exception is thrown by the AccessController to indicate
that a requested access (to a critical system resource such as the
file system or the network) is denied.
|
class |
InvalidParameterException
This exception, designed for use by the JCA/JCE engine classes,
is thrown when an invalid parameter is passed
to a method.
|
class |
ProviderException
A runtime exception for Provider exceptions (such as
misconfiguration errors), which may be subclassed by Providers to
throw specialized, provider-specific runtime errors.
|
| Modifier and Type | Class and Description |
|---|---|
class |
ConcurrentModificationException
This exception may be thrown by methods that have detected concurrent
modification of an object when such modification is not permissible.
|
class |
EmptyStackException
Thrown by methods in the
Stack class to indicate
that the stack is empty. |
class |
MissingResourceException
Signals that a resource is missing.
|
class |
NoSuchElementException
Thrown by the
nextElement method of an
Enumeration to indicate that there are no more
elements in the enumeration. |
| Modifier and Type | Class and Description |
|---|---|
class |
DOMException
DOM operations only raise exceptions in "exceptional" circumstances, i.e.,
when an operation is impossible to perform (either for logical reasons,
because data is lost, or because the implementation has become unstable).
|
| Modifier and Type | Class and Description |
|---|---|
class |
EventException
Event operations may throw an
EventException as specified in
their method descriptions. |
Copyright © 2013 CableLabs. All rights reserved.