| Package | Description |
|---|---|
| java.io |
Provides for system input and output through data streams,
serialization and the file system.
|
| java.lang |
Provides classes that are fundamental to the design of the Java
programming language.
|
| java.lang.reflect |
Provides classes and interfaces for obtaining reflective
information about classes and objects.
|
| java.security |
Provides the classes and interfaces for the security framework.
|
| javax.tv.media |
Provides controls and events for the management of real-time media
in a television environment.
|
| javax.tv.service |
Provides mechanisms for accessing the service information (SI) database
and APIs representing the SI elements it contains.
|
| javax.tv.service.guide |
Provides APIs to support electronic program guides (EPGs), including program
schedules, program events and program ratings.
|
| javax.tv.service.selection |
Provides a mechanism to select a Service for
presentation.
|
| javax.tv.service.transport |
Provides additional information about the transport mechanisms that
deliver the content the SI data describes.
|
| org.havi.ui |
Provides user interfaces to HAVI components.
|
| org.ocap.hn.upnp.client |
Provides UPnP client functionality, permitting access to devices and
services on a home network.
|
| org.ocap.hn.upnp.server |
Provides UPnP server functionality, permitting management of devices and services in the local Host device.
|
| Modifier and Type | Method and Description |
|---|---|
protected boolean |
ObjectOutputStream.enableReplaceObject(boolean enable)
Enable the stream to do replacement of objects in the stream.
|
protected boolean |
ObjectInputStream.enableResolveObject(boolean enable)
Enable the stream to allow objects read from the stream to be replaced.
|
| Constructor and Description |
|---|
ObjectInputStream()
Provide a way for subclasses that are completely reimplementing
ObjectInputStream to not have to allocate private data just used by
this implementation of ObjectInputStream.
|
ObjectOutputStream()
Provide a way for subclasses that are completely reimplementing
ObjectOutputStream to not have to allocate private data just used by
this implementation of ObjectOutputStream.
|
| Modifier and Type | Method and Description |
|---|---|
Constructor |
Class.getConstructor(Class[] parameterTypes)
Returns a
Constructor object that reflects the specified
public constructor of the class represented by this Class
object. |
Constructor[] |
Class.getConstructors()
Returns an array containing
Constructor objects reflecting
all the public constructors of the class represented by this
Class object. |
Class[] |
Class.getDeclaredClasses()
Returns an array of
Class objects reflecting all the
classes and interfaces declared as members of the class represented by
this Class object. |
Constructor |
Class.getDeclaredConstructor(Class[] parameterTypes)
Returns a
Constructor object that reflects the specified
constructor of the class or interface represented by this
Class object. |
Constructor[] |
Class.getDeclaredConstructors()
Returns an array of
Constructor objects reflecting all the
constructors declared by the class represented by this
Class object. |
Field |
Class.getDeclaredField(String name)
Returns a
Field object that reflects the specified declared
field of the class or interface represented by this Class
object. |
Field[] |
Class.getDeclaredFields()
Returns an array of
Field objects reflecting all the fields
declared by the class or interface represented by this
Class object. |
Method |
Class.getDeclaredMethod(String name,
Class[] parameterTypes)
Returns a
Method object that reflects the specified
declared method of the class or interface represented by this
Class object. |
Method[] |
Class.getDeclaredMethods()
Returns an array of
Method objects reflecting all the
methods declared by the class or interface represented by this
Class object. |
Field |
Class.getField(String name)
Returns a
Field object that reflects the specified public
member field of the class or interface represented by this
Class object. |
Field[] |
Class.getFields()
Returns an array containing
Field objects reflecting all
the accessible public fields of the class or interface represented by
this Class object. |
Method |
Class.getMethod(String name,
Class[] parameterTypes)
Returns a
Method object that reflects the specified public
member method of the class or interface represented by this
Class object. |
Method[] |
Class.getMethods()
Returns an array containing
Method objects reflecting all
the public member methods of the class or interface represented
by this Class object, including those declared by the class
or interface and and those inherited from superclasses and
superinterfaces. |
| Modifier and Type | Method and Description |
|---|---|
static void |
AccessibleObject.setAccessible(AccessibleObject[] array,
boolean flag)
Convenience method to set the accessible flag for an
array of objects with a single security check (for efficiency).
|
void |
AccessibleObject.setAccessible(boolean flag)
Set the accessible flag for this object to
the indicated boolean value.
|
| Modifier and Type | Class and Description |
|---|---|
class |
AccessControlException
This exception is thrown by the AccessController to indicate
that a requested access (to a critical system resource such as the
file system or the network) is denied.
|
| Modifier and Type | Method and Description |
|---|---|
void |
Permission.checkGuard(Object object)
Implements the guard interface for a permission.
|
void |
Guard.checkGuard(Object object)
Determines whether or not to allow access to the guarded object
object. |
Object |
GuardedObject.getObject()
Retrieves the guarded object, or throws an exception if access
to the guarded object is denied by the guard.
|
| Modifier and Type | Method and Description |
|---|---|
void |
MediaSelectControl.add(Locator component)
Adds a service component (for example, subtitles) to the
presentation.
|
void |
MediaSelectControl.remove(Locator component)
Removes a service component from the presentation.
|
void |
MediaSelectControl.replace(Locator fromComponent,
Locator toComponent)
Replaces a service component in the presentation.
|
void |
MediaSelectControl.select(Locator component)
Selects a new service component for presentation.
|
void |
MediaSelectControl.select(Locator[] components)
Selects one or more service components for presentation.
|
| Modifier and Type | Method and Description |
|---|---|
abstract Service |
SIManager.getService(Locator locator)
Provides the
Service identified by a given
Locator. |
abstract void |
SIManager.registerInterest(Locator locator,
boolean active)
Provides a hint to the SI database that the application desires
SI information as complete as possible about the specified
SIElement. |
abstract SIRequest |
SIManager.retrieveProgramEvent(Locator locator,
SIRequestor requestor)
Retrieves the
ProgramEvent corresponding to the
given Locator. |
abstract SIRequest |
SIManager.retrieveServiceDetails(Locator locator,
SIRequestor requestor)
Retrieves the
ServiceDetails object corresponding to
the given Locator. |
abstract SIRequest |
SIManager.retrieveSIElement(Locator locator,
SIRequestor requestor)
Retrieves the
SIElement corresponding to the
specified Locator. |
| Modifier and Type | Method and Description |
|---|---|
SIRequest |
ProgramSchedule.retrieveProgramEvent(Locator locator,
SIRequestor requestor)
Retrieves a program event matching the locator.
|
| Modifier and Type | Method and Description |
|---|---|
abstract ServiceContext |
ServiceContextFactory.createServiceContext()
Creates a
ServiceContext object. |
void |
ServiceContext.destroy()
Causes the
ServiceContext to release all resources
and enter the destroyed state. |
ServiceContentHandler[] |
ServiceContext.getServiceContentHandlers()
Reports the current collection of ServiceContentHandlers.
|
abstract ServiceContext |
ServiceContextFactory.getServiceContext(XletContext ctx)
Reports the
ServiceContext in which the
Xlet corresponding to the specified
XletContext is running. |
void |
ServiceContext.select(Locator[] components)
Selects content by specifying the parts of a service to be
presented.
|
void |
ServiceContext.select(Service selection)
Selects a service to be presented in this
ServiceContext. |
void |
ServiceContext.stop()
Causes the
ServiceContext to stop presenting content
and enter the not presenting state. |
| Modifier and Type | Method and Description |
|---|---|
SIRequest |
BouquetCollection.retrieveBouquet(Locator locator,
SIRequestor requestor)
Retrieves the specified
Bouquet from the collection. |
SIRequest |
NetworkCollection.retrieveNetwork(Locator locator,
SIRequestor requestor)
Retrieves the specified
Network from the collection. |
SIRequest |
TransportStreamCollection.retrieveTransportStream(Locator locator,
SIRequestor requestor)
Retrieves the specified
TransportStream from the
collection. |
| Modifier and Type | Method and Description |
|---|---|
Object |
HVideoDevice.getVideoController()
Obtain a reference to the object which controls the
presentation of the video.
|
Object |
HVideoDevice.getVideoSource()
Obtain a reference to the source of the video being presented
by this device at this moment.
|
void |
HSound.load(String location)
Loads data synchronously into an
HSound object from an audio sample in the specified file. |
void |
HSound.load(URL contents)
Loads data synchronously into an
HSound object from an audio sample indicated by a URL. |
boolean |
HBackgroundDevice.setBackgroundConfiguration(HBackgroundConfiguration hbc)
Set the background configuration for the device.
|
boolean |
HScreen.setCoherentScreenConfigurations(HScreenConfiguration[] hsca)
Modify the settings for a set of
HScreenDevices, based on their HScreenConfigurations supplied. |
boolean |
HEmulatedGraphicsDevice.setGraphicsConfiguration(HEmulatedGraphicsConfiguration hegc)
Set the graphics configuration for the device.
|
boolean |
HGraphicsDevice.setGraphicsConfiguration(HGraphicsConfiguration hgc)
Set the graphics configuration for the device.
|
boolean |
HVideoDevice.setVideoConfiguration(HVideoConfiguration hvc)
Set the video configuration for the device.
|
| Modifier and Type | Method and Description |
|---|---|
void |
UPnPControlPoint.setIncomingMessageHandler(UPnPIncomingMessageHandler inHandler)
Sets a message handler for incoming messages (advertisements,
evented state variables, action responses, device and service
descriptions).
|
InetAddress[] |
UPnPControlPoint.setInetAddresses(InetAddress[] addresses)
Sets the InetAddresses that the
UPnPControlPoint is associated with. |
void |
UPnPControlPoint.setOutgoingMessageHandler(UPnPOutgoingMessageHandler outHandler)
Sets a message handler for outgoing messages (action
invocations, subscription requests, device and service
retrievals).
|
| Modifier and Type | Method and Description |
|---|---|
UPnPManagedDevice |
UPnPDeviceManager.createDevice(UPnPManagedDevice parent,
InputStream description,
UPnPManagedDeviceIcon[] icons)
Creates a UPnP device in the local host.
|
UPnPManagedService |
UPnPManagedDevice.createService(String serviceType,
InputStream description,
UPnPActionHandler handler)
Creates a UPnP service associated with this device.
|
void |
UPnPManagedService.respondToQueries(boolean respond)
Control whether the service responds to UPnP
QueryStateVariable actions.
|
void |
UPnPManagedDevice.sendAlive()
Sends UPnP ssdp:alive messages from the physical device.
|
void |
UPnPManagedDevice.sendByeBye()
Sends UPnP ssdp:byebye messages from this device.
|
UPnPActionHandler |
UPnPManagedService.setActionHandler(UPnPActionHandler handler)
Sets an action handler for this service, replacing any prior
action handler.
|
boolean |
UPnPManagedDevice.setDeviceType(String type)
Sets the UPnP deviceType of this device.
|
boolean |
UPnPManagedDevice.setFriendlyName(String friendlyName)
Sets the UPnP friendlyName of this device.
|
UPnPManagedDeviceIcon[] |
UPnPManagedDevice.setIcons(UPnPManagedDeviceIcon[] icons)
Sets the Icons for this device.
|
void |
UPnPDeviceManager.setIncomingMessageHandler(UPnPIncomingMessageHandler inHandler)
Sets a message handler for incoming messages (advertisements,
evented state variables, action responses, device and service
descriptions).
|
InetAddress[] |
UPnPManagedDevice.setInetAddresses(InetAddress[] addresses)
Sets the InetAddresses that this
UPnPManagedDevice
is associated with. |
boolean |
UPnPManagedDevice.setManufacturer(String manufacturer)
Sets the UPnP manufacturer of this device.
|
boolean |
UPnPManagedDevice.setManufacturerURL(String manufacturerURL)
Sets the UPnP manufacturer URL of this device.
|
boolean |
UPnPManagedDevice.setModelDescription(String modelDescription)
Sets the UPnP model description of this device.
|
boolean |
UPnPManagedDevice.setModelName(String modelName)
Sets the UPnP model name of this device.
|
boolean |
UPnPManagedDevice.setModelNumber(String modelNumber)
Sets the UPnP model number of this device.
|
boolean |
UPnPManagedDevice.setModelURL(String modelURL)
Sets the UPnP model URL of this device.
|
void |
UPnPManagedStateVariable.setModerationDelta(int delta)
Sets the moderation delta of this state variable.
|
void |
UPnPManagedStateVariable.setModerationInterval(int interval)
Sets the moderation interval of this state variable, in
milliseconds.
|
void |
UPnPDeviceManager.setOutgoingMessageHandler(UPnPOutgoingMessageHandler outHandler)
Sets a message handler for outgoing messages (action
invocations, subscription requests, device and service
retrievals).
|
boolean |
UPnPManagedDevice.setSerialNumber(String serialNumber)
Sets the UPnP serial number of this device.
|
boolean |
UPnPManagedDevice.setUDN(String UDN)
Sets the UPnP Unique Device Number of this device.
|
boolean |
UPnPManagedDevice.setUPC(String UPC)
Sets the UPnP Universal Product Code of this device.
|
void |
UPnPManagedStateVariable.setValue(String value)
Sets the value of this state variable.
|
Copyright © 2013 CableLabs. All rights reserved.