| Package | Description |
|---|---|
| java.io |
Provides for system input and output through data streams,
serialization and the file system.
|
| java.lang |
Provides classes that are fundamental to the design of the Java
programming language.
|
| java.text |
Provides classes and interfaces for handling text, dates, numbers, and messages
in a manner independent of natural languages.
|
| Modifier and Type | Method and Description |
|---|---|
StringBuffer |
StringWriter.getBuffer()
Return the string buffer itself.
|
| Modifier and Type | Method and Description |
|---|---|
StringBuffer |
StringBuffer.append(boolean b)
Appends the string representation of the
boolean
argument to the string buffer. |
StringBuffer |
StringBuffer.append(char c)
Appends the string representation of the
char
argument to this string buffer. |
StringBuffer |
StringBuffer.append(char[] str)
Appends the string representation of the
char array
argument to this string buffer. |
StringBuffer |
StringBuffer.append(char[] str,
int offset,
int len)
Appends the string representation of a subarray of the
char array argument to this string buffer. |
StringBuffer |
StringBuffer.append(double d)
Appends the string representation of the
double
argument to this string buffer. |
StringBuffer |
StringBuffer.append(float f)
Appends the string representation of the
float
argument to this string buffer. |
StringBuffer |
StringBuffer.append(int i)
Appends the string representation of the
int
argument to this string buffer. |
StringBuffer |
StringBuffer.append(long l)
Appends the string representation of the
long
argument to this string buffer. |
StringBuffer |
StringBuffer.append(Object obj)
Appends the string representation of the
Object
argument to this string buffer. |
StringBuffer |
StringBuffer.append(String str)
Appends the string to this string buffer.
|
StringBuffer |
StringBuffer.append(StringBuffer sb)
Appends the specified StringBuffer to this
StringBuffer.
|
StringBuffer |
StringBuffer.delete(int start,
int end)
Removes the characters in a substring of this
StringBuffer. |
StringBuffer |
StringBuffer.deleteCharAt(int index)
Removes the character at the specified position in this
StringBuffer (shortening the StringBuffer
by one character). |
StringBuffer |
StringBuffer.insert(int offset,
boolean b)
Inserts the string representation of the
boolean
argument into this string buffer. |
StringBuffer |
StringBuffer.insert(int offset,
char c)
Inserts the string representation of the
char
argument into this string buffer. |
StringBuffer |
StringBuffer.insert(int offset,
char[] str)
Inserts the string representation of the
char array
argument into this string buffer. |
StringBuffer |
StringBuffer.insert(int index,
char[] str,
int offset,
int len)
Inserts the string representation of a subarray of the
str
array argument into this string buffer. |
StringBuffer |
StringBuffer.insert(int offset,
double d)
Inserts the string representation of the
double
argument into this string buffer. |
StringBuffer |
StringBuffer.insert(int offset,
float f)
Inserts the string representation of the
float
argument into this string buffer. |
StringBuffer |
StringBuffer.insert(int offset,
int i)
Inserts the string representation of the second
int
argument into this string buffer. |
StringBuffer |
StringBuffer.insert(int offset,
long l)
Inserts the string representation of the
long
argument into this string buffer. |
StringBuffer |
StringBuffer.insert(int offset,
Object obj)
Inserts the string representation of the
Object
argument into this string buffer. |
StringBuffer |
StringBuffer.insert(int offset,
String str)
Inserts the string into this string buffer.
|
StringBuffer |
StringBuffer.replace(int start,
int end,
String str)
Replaces the characters in a substring of this
StringBuffer
with characters in the specified String. |
StringBuffer |
StringBuffer.reverse()
The character sequence contained in this string buffer is
replaced by the reverse of the sequence.
|
| Modifier and Type | Method and Description |
|---|---|
StringBuffer |
StringBuffer.append(StringBuffer sb)
Appends the specified StringBuffer to this
StringBuffer.
|
boolean |
String.contentEquals(StringBuffer sb)
Returns true if and only if this String represents
the same sequence of characters as the specified StringBuffer.
|
| Constructor and Description |
|---|
String(StringBuffer buffer)
Allocates a new string that contains the sequence of characters
currently contained in the string buffer argument.
|
| Modifier and Type | Method and Description |
|---|---|
StringBuffer |
SimpleDateFormat.format(Date date,
StringBuffer toAppendTo,
FieldPosition pos)
Formats the given
Date into a date/time string and appends
the result to the given StringBuffer. |
abstract StringBuffer |
DateFormat.format(Date date,
StringBuffer toAppendTo,
FieldPosition fieldPosition)
Formats a Date into a date/time string.
|
abstract StringBuffer |
NumberFormat.format(double number,
StringBuffer toAppendTo,
FieldPosition pos)
Specialization of format.
|
StringBuffer |
DecimalFormat.format(double number,
StringBuffer result,
FieldPosition fieldPosition)
Formats a double to produce a string.
|
StringBuffer |
ChoiceFormat.format(double number,
StringBuffer toAppendTo,
FieldPosition status)
Returns pattern with formatted double.
|
abstract StringBuffer |
NumberFormat.format(long number,
StringBuffer toAppendTo,
FieldPosition pos)
Specialization of format.
|
StringBuffer |
DecimalFormat.format(long number,
StringBuffer result,
FieldPosition fieldPosition)
Format a long to produce a string.
|
StringBuffer |
ChoiceFormat.format(long number,
StringBuffer toAppendTo,
FieldPosition status)
Specialization of format.
|
StringBuffer |
MessageFormat.format(Object[] arguments,
StringBuffer result,
FieldPosition pos)
Formats an array of objects and appends the
MessageFormat's
pattern, with format elements replaced by the formatted objects, to the
provided StringBuffer. |
StringBuffer |
NumberFormat.format(Object number,
StringBuffer toAppendTo,
FieldPosition pos)
Formats an object to produce a string.
|
StringBuffer |
MessageFormat.format(Object arguments,
StringBuffer result,
FieldPosition pos)
Formats an array of objects and appends the
MessageFormat's
pattern, with format elements replaced by the formatted objects, to the
provided StringBuffer. |
abstract StringBuffer |
Format.format(Object obj,
StringBuffer toAppendTo,
FieldPosition pos)
Formats an object and appends the resulting text to a given string
buffer.
|
StringBuffer |
DateFormat.format(Object obj,
StringBuffer toAppendTo,
FieldPosition fieldPosition)
Overrides Format.
|
| Modifier and Type | Method and Description |
|---|---|
StringBuffer |
SimpleDateFormat.format(Date date,
StringBuffer toAppendTo,
FieldPosition pos)
Formats the given
Date into a date/time string and appends
the result to the given StringBuffer. |
abstract StringBuffer |
DateFormat.format(Date date,
StringBuffer toAppendTo,
FieldPosition fieldPosition)
Formats a Date into a date/time string.
|
abstract StringBuffer |
NumberFormat.format(double number,
StringBuffer toAppendTo,
FieldPosition pos)
Specialization of format.
|
StringBuffer |
DecimalFormat.format(double number,
StringBuffer result,
FieldPosition fieldPosition)
Formats a double to produce a string.
|
StringBuffer |
ChoiceFormat.format(double number,
StringBuffer toAppendTo,
FieldPosition status)
Returns pattern with formatted double.
|
abstract StringBuffer |
NumberFormat.format(long number,
StringBuffer toAppendTo,
FieldPosition pos)
Specialization of format.
|
StringBuffer |
DecimalFormat.format(long number,
StringBuffer result,
FieldPosition fieldPosition)
Format a long to produce a string.
|
StringBuffer |
ChoiceFormat.format(long number,
StringBuffer toAppendTo,
FieldPosition status)
Specialization of format.
|
StringBuffer |
MessageFormat.format(Object[] arguments,
StringBuffer result,
FieldPosition pos)
Formats an array of objects and appends the
MessageFormat's
pattern, with format elements replaced by the formatted objects, to the
provided StringBuffer. |
StringBuffer |
NumberFormat.format(Object number,
StringBuffer toAppendTo,
FieldPosition pos)
Formats an object to produce a string.
|
StringBuffer |
MessageFormat.format(Object arguments,
StringBuffer result,
FieldPosition pos)
Formats an array of objects and appends the
MessageFormat's
pattern, with format elements replaced by the formatted objects, to the
provided StringBuffer. |
abstract StringBuffer |
Format.format(Object obj,
StringBuffer toAppendTo,
FieldPosition pos)
Formats an object and appends the resulting text to a given string
buffer.
|
StringBuffer |
DateFormat.format(Object obj,
StringBuffer toAppendTo,
FieldPosition fieldPosition)
Overrides Format.
|
Copyright © 2013 CableLabs. All rights reserved.