| Package | Description |
|---|---|
| java.lang |
Provides classes that are fundamental to the design of the Java
programming language.
|
| Modifier and Type | Method and Description |
|---|---|
static Thread |
Thread.currentThread()
Returns a reference to the currently executing thread object.
|
| Modifier and Type | Method and Description |
|---|---|
void |
Runtime.addShutdownHook(Thread hook)
Registers a new virtual-machine shutdown hook.
|
void |
SecurityManager.checkAccess(Thread t)
Throws a
SecurityException if the
calling thread is not allowed to modify the thread argument. |
int |
ThreadGroup.enumerate(Thread[] list)
Copies into the specified array every active thread in this
thread group and its subgroups.
|
static int |
Thread.enumerate(Thread[] tarray)
Copies into the specified array every active thread in
the current thread's thread group and its subgroups.
|
int |
ThreadGroup.enumerate(Thread[] list,
boolean recurse)
Copies into the specified array every active thread in this
thread group.
|
boolean |
Runtime.removeShutdownHook(Thread hook)
De-registers a previously-registered virtual-machine shutdown hook.
|
void |
ThreadGroup.uncaughtException(Thread t,
Throwable e)
Called by the Java Virtual Machine when a thread in this
thread group stops because of an uncaught exception.
|
Copyright © 2013 CableLabs. All rights reserved.