| Package | Description |
|---|---|
| java.awt |
Contains all of the classes for creating user
interfaces and for painting graphics and images.
|
| java.awt.image |
Provides classes for creating and modifying images.
|
| java.beans |
Contains classes for run-time Java Beans support.
|
| java.io |
Provides for system input and output through data streams,
serialization and the file system.
|
| java.lang |
Provides classes that are fundamental to the design of the Java
programming language.
|
| java.lang.reflect |
Provides classes and interfaces for obtaining reflective
information about classes and objects.
|
| java.net |
Provides the classes for implementing networking applications.
|
| java.rmi |
Provides the RMI package.
|
| java.security |
Provides the classes and interfaces for the security framework.
|
| java.security.acl |
The classes and interfaces in this package have been
superseded by classes in the java.security package.
|
| java.security.cert |
Provides classes and interfaces for parsing and managing
certificates, certificate revocation lists (CRLs), and
certification paths.
|
| java.security.spec |
Provides classes and interfaces for key specifications and algorithm
parameter specifications.
|
| java.text |
Provides classes and interfaces for handling text, dates, numbers, and messages
in a manner independent of natural languages.
|
| java.util |
Contains the collections framework, legacy collection classes, event model,
date and time facilities, internationalization, and miscellaneous utility
classes (a string tokenizer, a random-number generator, and a bit array).
|
| java.util.jar |
Provides classes for reading and writing the JAR (Java ARchive) file
format, which is based on the standard ZIP file format with an
optional manifest file.
|
| java.util.zip |
Provides classes for reading and writing the standard ZIP and GZIP
file formats.
|
| javax.media |
Provides media players, means of controlling playback and being notified of playback state changes.
|
| javax.microedition.io |
Provides a simplified mechanism for applications to use various types of I/O
protocols in resource-constrained environments.
|
| javax.microedition.xlet |
Provides interfaces used by applications and the application manager
to communicate.
|
| javax.microedition.xlet.ixc |
Provides facilities for inter-Xlet communication (IXC).
|
| javax.net.ssl |
Provides classes for the secure socket package.
|
| javax.security.cert |
Provides classes for public key certificates.
|
| javax.tv.locator |
Provides a means for referencing data and resources accessible via the
Java TV APIs.
|
| javax.tv.service |
Provides mechanisms for accessing the service information (SI) database
and APIs representing the SI elements it contains.
|
| javax.tv.service.navigation |
Provides APIs to navigate through services and hierarchical service information.
|
| javax.tv.service.selection |
Provides a mechanism to select a Service for
presentation.
|
| javax.tv.util |
Provides APIs for creating and managing timer events.
|
| javax.xml.parsers |
The javax.xml.parsers package contains the Java API for XML Processing (JAXP)
subset defined by JSR 280.
|
| javax.xml.stream |
This package provides the Streaming API for XML (StAX, or JSR 173) subset
defined by JSR 280.
|
| org.apache.log4j | |
| org.apache.log4j.spi | |
| org.davic.media |
Provides various extensions to the Java Media Framework for
the control of TV oriented audio / video content.
|
| org.davic.mpeg |
Provides utility classes for common MPEG concepts.
|
| org.davic.mpeg.sections |
Provides access to MPEG-2 section filtering.
|
| org.davic.net.tuning |
Provides access to tuning - MPEG multiplex selection.
|
| org.dvb.application |
Provides access to lists of applications which are available
in this context and the ability to launch those applications.
|
| org.dvb.dsmcc |
Provides extended access to files carried in the broadcast
stream.
|
| org.dvb.media |
Provides DVB specific extensions to the Java Media Framework.
|
| org.dvb.net.rc |
Provides session management for bi-directional IP connections
which are session based from the point of view of an application.
|
| org.dvb.spi |
This package defines a central registry for all DVB Service Provider Interface
(SPI) providers.
|
| org.dvb.ui |
Provides extended graphics functionality.
|
| org.dvb.user |
Provides access to settings and preferences configured by the end-user.
|
| org.havi.ui |
Provides user interfaces to HAVI components.
|
| org.ocap.hardware.device |
Provides extension classes and interfaces related to accessing and controlling
certain device parameters that are normally controlled by a
device manufacturer specific application.
|
| org.ocap.hn.content |
Provides representation of the content and content containers, and means of identifying content type.
|
| org.ocap.shared.dvr |
The shared DVR API for scheduling and managing recording requests.
|
| org.ocap.shared.media |
Extensions to JMF to support DVR playback.
|
| org.ocap.system.event |
The org.ocap.system.event package defines various system events. |
| org.w3c.dom |
The org.w3c.dom package provides the Java ME DOM API defined by
JSR 280.
|
| org.w3c.dom.events |
The org.w3c.dom.events package provides the Java ME DOM Events API subset
defined by JSR 280.
|
| org.xml.sax |
| Modifier and Type | Class and Description |
|---|---|
class |
AWTError
Thrown when a serious Abstract Window Toolkit error has occurred.
|
class |
AWTException
Signals that an Absract Window Toolkit exception has occurred.
|
class |
HeadlessException
Thrown when code that is dependent on a keyboard, display, or mouse
is called in an environment that does not support a keyboard, display,
or mouse.
|
class |
IllegalComponentStateException
Signals that an AWT component is not in an appropriate state for
the requested operation.
|
| Modifier and Type | Method and Description |
|---|---|
protected void |
Cursor.finalize() |
| Modifier and Type | Class and Description |
|---|---|
class |
RasterFormatException
The
RasterFormatException is thrown if there is
invalid layout information in a BufferedImage. |
| Modifier and Type | Class and Description |
|---|---|
class |
PropertyVetoException
A PropertyVetoException is thrown when a proposed change to a
property represents an unacceptable value.
|
| Modifier and Type | Class and Description |
|---|---|
class |
CharConversionException
Base class for character conversion exceptions.
|
class |
EOFException
Signals that an end of file or end of stream has been reached
unexpectedly during input.
|
class |
FileNotFoundException
Signals that an attempt to open the file denoted by a specified pathname
has failed.
|
class |
InterruptedIOException
Signals that an I/O operation has been interrupted.
|
class |
InvalidClassException
Thrown when the Serialization runtime detects one of the following
problems with a Class.
|
class |
InvalidObjectException
Indicates that one or more deserialized objects failed validation
tests.
|
class |
IOException
Signals that an I/O exception of some sort has occurred.
|
class |
NotActiveException
Thrown when serialization or deserialization is not active.
|
class |
NotSerializableException
Thrown when an instance is required to have a Serializable interface.
|
class |
ObjectStreamException
Superclass of all exceptions specific to Object Stream classes.
|
class |
OptionalDataException
Exception indicating the failure of an object read operation due to
unread primitive data, or the end of data belonging to a serialized
object in the stream.
|
class |
StreamCorruptedException
Thrown when control information that was read from an object stream
violates internal consistency checks.
|
class |
SyncFailedException
Signals that a sync operation has failed.
|
class |
UnsupportedEncodingException
The Character Encoding is not supported.
|
class |
UTFDataFormatException
Signals that a malformed UTF-8 string has been read in a data
input stream or by any class that implements the data input
interface.
|
class |
WriteAbortedException
Signals that one of the ObjectStreamExceptions was thrown during a
write operation.
|
| Modifier and Type | Method and Description |
|---|---|
Throwable |
WriteAbortedException.getCause()
Returns the exception that terminated the operation (the cause).
|
| Modifier and Type | Class and Description |
|---|---|
class |
AbstractMethodError
Thrown when an application tries to call an abstract method.
|
class |
ArithmeticException
Thrown when an exceptional arithmetic condition has occurred.
|
class |
ArrayIndexOutOfBoundsException
Thrown to indicate that an array has been accessed with an
illegal index.
|
class |
ArrayStoreException
Thrown to indicate that an attempt has been made to store the
wrong type of object into an array of objects.
|
class |
AssertionError
Thrown to indicate that an assertion has failed.
|
class |
ClassCastException
Thrown to indicate that the code has attempted to cast an object
to a subclass of which it is not an instance.
|
class |
ClassCircularityError
Thrown when a circularity has been detected while initializing a class.
|
class |
ClassFormatError
Thrown when the Java Virtual Machine attempts to read a class
file and determines that the file is malformed or otherwise cannot
be interpreted as a class file.
|
class |
ClassNotFoundException
Thrown when an application tries to load in a class through its
string name using:
The
forName method in class Class. |
class |
CloneNotSupportedException
Thrown to indicate that the
clone method in class
Object has been called to clone an object, but that
the object's class does not implement the Cloneable
interface. |
class |
Error
An
Error is a subclass of Throwable
that indicates serious problems that a reasonable application
should not try to catch. |
class |
Exception
The class
Exception and its subclasses are a form of
Throwable that indicates conditions that a reasonable
application might want to catch. |
class |
ExceptionInInitializerError
Signals that an unexpected exception has occurred in a static initializer.
|
class |
IllegalAccessError
Thrown if an application attempts to access or modify a field, or
to call a method that it does not have access to.
|
class |
IllegalAccessException
An IllegalAccessException is thrown when an application tries
to reflectively create an instance (other than an array),
set or get a field, or invoke a method, but the currently
executing method does not have access to the definition of
the specified class, field, method or constructor.
|
class |
IllegalArgumentException
Thrown to indicate that a method has been passed an illegal or
inappropriate argument.
|
class |
IllegalMonitorStateException
Thrown to indicate that a thread has attempted to wait on an
object's monitor or to notify other threads waiting on an object's
monitor without owning the specified monitor.
|
class |
IllegalStateException
Signals that a method has been invoked at an illegal or
inappropriate time.
|
class |
IllegalThreadStateException
Thrown to indicate that a thread is not in an appropriate state
for the requested operation.
|
class |
IncompatibleClassChangeError
Thrown when an incompatible class change has occurred to some class
definition.
|
class |
IndexOutOfBoundsException
Thrown to indicate that an index of some sort (such as to an array, to a
string, or to a vector) is out of range.
|
class |
InstantiationError
Thrown when an application tries to use the Java
new
construct to instantiate an abstract class or an interface. |
class |
InstantiationException
Thrown when an application tries to create an instance of a class
using the
newInstance method in class
Class, but the specified class object cannot be
instantiated because it is an interface or is an abstract class. |
class |
InternalError
Thrown to indicate some unexpected internal error has occurred in
the Java Virtual Machine.
|
class |
InterruptedException
Thrown when a thread is waiting, sleeping, or otherwise paused for
a long time and another thread interrupts it using the
interrupt method in class Thread. |
class |
LinkageError
Subclasses of
LinkageError indicate that a class has
some dependency on another class; however, the latter class has
incompatibly changed after the compilation of the former class. |
class |
NegativeArraySizeException
Thrown if an application tries to create an array with negative size.
|
class |
NoClassDefFoundError
Thrown if the Java Virtual Machine or a
ClassLoader instance
tries to load in the definition of a class (as part of a normal method call
or as part of creating a new instance using the new expression)
and no definition of the class could be found. |
class |
NoSuchFieldError
Thrown if an application tries to access or modify a specified
field of an object, and that object no longer has that field.
|
class |
NoSuchFieldException
Signals that the class doesn't have a field of a specified name.
|
class |
NoSuchMethodError
Thrown if an application tries to call a specified method of a
class (either static or instance), and that class no longer has a
definition of that method.
|
class |
NoSuchMethodException
Thrown when a particular method cannot be found.
|
class |
NullPointerException
Thrown when an application attempts to use
null in a
case where an object is required. |
class |
NumberFormatException
Thrown to indicate that the application has attempted to convert
a string to one of the numeric types, but that the string does not
have the appropriate format.
|
class |
OutOfMemoryError
Thrown when the Java Virtual Machine cannot allocate an object
because it is out of memory, and no more memory could be made
available by the garbage collector.
|
class |
RuntimeException
RuntimeException is the superclass of those
exceptions that can be thrown during the normal operation of the
Java Virtual Machine. |
class |
SecurityException
Thrown by the security manager to indicate a security violation.
|
class |
StackOverflowError
Thrown when a stack overflow occurs because an application
recurses too deeply.
|
class |
StringIndexOutOfBoundsException
Thrown by
String methods to indicate that an index
is either negative or greater than the size of the string. |
class |
ThreadDeath
An instance of
ThreadDeath is thrown in the victim
thread when the stop method with zero arguments in
class Thread is called. |
class |
UnknownError
Thrown when an unknown but serious exception has occurred in the
Java Virtual Machine.
|
class |
UnsatisfiedLinkError
Thrown if the Java Virtual Machine cannot find an appropriate
native-language definition of a method declared
native. |
class |
UnsupportedClassVersionError
Thrown when the Java Virtual Machine attempts to read a class
file and determines that the major and minor version numbers
in the file are not supported.
|
class |
UnsupportedOperationException
Thrown to indicate that the requested operation is not supported.
|
class |
VerifyError
Thrown when the "verifier" detects that a class file,
though well formed, contains some sort of internal inconsistency
or security problem.
|
class |
VirtualMachineError
Thrown to indicate that the Java Virtual Machine is broken or has
run out of resources necessary for it to continue operating.
|
| Modifier and Type | Method and Description |
|---|---|
Throwable |
Throwable.fillInStackTrace()
Fills in the execution stack trace.
|
Throwable |
Throwable.getCause()
Returns the cause of this throwable or
null if the
cause is nonexistent or unknown. |
Throwable |
ExceptionInInitializerError.getCause()
Returns the cause of this error (the exception that occurred
during a static initialization that caused this error to be created).
|
Throwable |
ClassNotFoundException.getCause()
Returns the the cause of this exception (the exception that was raised
if an error occurred while attempting to load the class; otherwise
null).
|
Throwable |
ExceptionInInitializerError.getException()
Returns the exception that occurred during a static initialization that
caused this error to be created.
|
Throwable |
ClassNotFoundException.getException()
Returns the exception that was raised if an error occurred while
attempting to load the class.
|
Throwable |
Throwable.initCause(Throwable cause)
Initializes the cause of this throwable to the specified value.
|
| Modifier and Type | Method and Description |
|---|---|
Throwable |
Throwable.initCause(Throwable cause)
Initializes the cause of this throwable to the specified value.
|
void |
ThreadGroup.uncaughtException(Thread t,
Throwable e)
Called by the Java Virtual Machine when a thread in this
thread group stops because of an uncaught exception.
|
| Modifier and Type | Method and Description |
|---|---|
protected void |
Object.finalize()
Called by the garbage collector on an object when garbage collection
determines that there are no more references to the object.
|
| Constructor and Description |
|---|
ClassNotFoundException(String s,
Throwable ex)
Constructs a
ClassNotFoundException with the
specified detail message and optional exception that was
raised while loading the class. |
Error(String message,
Throwable cause)
Constructs a new error with the specified detail message and
cause.
|
Error(Throwable cause)
Constructs a new error with the specified cause and a detail
message of (cause==null ? null : cause.toString()) (which
typically contains the class and detail message of cause).
|
Exception(String message,
Throwable cause)
Constructs a new exception with the specified detail message and
cause.
|
Exception(Throwable cause)
Constructs a new exception with the specified cause and a detail
message of (cause==null ? null : cause.toString()) (which
typically contains the class and detail message of cause).
|
ExceptionInInitializerError(Throwable thrown)
Constructs a new
ExceptionInInitializerError class by
saving a reference to the Throwable object thrown for
later retrieval by the ExceptionInInitializerError.getException() method. |
RuntimeException(String message,
Throwable cause)
Constructs a new runtime exception with the specified detail message and
cause.
|
RuntimeException(Throwable cause)
Constructs a new runtime exception with the specified cause and a
detail message of (cause==null ? null : cause.toString())
(which typically contains the class and detail message of
cause).
|
Throwable(String message,
Throwable cause)
Constructs a new throwable with the specified detail message and
cause.
|
Throwable(Throwable cause)
Constructs a new throwable with the specified cause and a detail
message of (cause==null ? null : cause.toString()) (which
typically contains the class and detail message of cause).
|
| Modifier and Type | Class and Description |
|---|---|
class |
InvocationTargetException
InvocationTargetException is a checked exception that wraps
an exception thrown by an invoked method or constructor.
|
class |
UndeclaredThrowableException
Thrown by a method invocation on a proxy instance if its invocation
handler's
invoke method throws a
checked exception (a Throwable that is not assignable
to RuntimeException or Error) that
is not assignable to any of the exception types declared in the
throws clause of the method that was invoked on the
proxy instance and dispatched to the invocation handler. |
| Modifier and Type | Method and Description |
|---|---|
Throwable |
UndeclaredThrowableException.getCause()
Returns the the cause of this exception (the
Throwable
instance wrapped in this UndeclaredThrowableException,
which may be null). |
Throwable |
InvocationTargetException.getCause()
Returns the the cause of this exception (the thrown target exception,
which may be null).
|
Throwable |
InvocationTargetException.getTargetException()
Get the thrown target exception.
|
Throwable |
UndeclaredThrowableException.getUndeclaredThrowable()
Returns the
Throwable instance wrapped in this
UndeclaredThrowableException, which may be null. |
| Modifier and Type | Method and Description |
|---|---|
Object |
InvocationHandler.invoke(Object proxy,
Method method,
Object[] args)
Processes a method invocation on a proxy instance and returns
the result.
|
| Constructor and Description |
|---|
InvocationTargetException(Throwable target)
Constructs a InvocationTargetException with a target exception.
|
InvocationTargetException(Throwable target,
String s)
Constructs a InvocationTargetException with a target exception
and a detail message.
|
UndeclaredThrowableException(Throwable undeclaredThrowable)
Constructs an
UndeclaredThrowableException with the
specified Throwable. |
UndeclaredThrowableException(Throwable undeclaredThrowable,
String s)
Constructs an
UndeclaredThrowableException with the
specified Throwable and a detail message. |
| Modifier and Type | Class and Description |
|---|---|
class |
BindException
Signals that an error occurred while attempting to bind a
socket to a local address and port.
|
class |
ConnectException
Signals that an error occurred while attempting to connect a
socket to a remote address and port.
|
class |
MalformedURLException
Thrown to indicate that a malformed URL has occurred.
|
class |
NoRouteToHostException
Signals that an error occurred while attempting to connect a
socket to a remote address and port.
|
class |
PortUnreachableException
Signals that an ICMP Port Unreachable message has been
received on a connected datagram.
|
class |
ProtocolException
Thrown to indicate that there is an error in the underlying
protocol, such as a TCP error.
|
class |
SocketException
Thrown to indicate that there is an error in the underlying
protocol, such as a TCP error.
|
class |
SocketTimeoutException
Signals that a timeout has occurred on a socket read or accept.
|
class |
UnknownHostException
Thrown to indicate that the IP address of a host could not be determined.
|
class |
UnknownServiceException
Thrown to indicate that an unknown service exception has
occurred.
|
class |
URISyntaxException
Checked exception thrown to indicate that a string could not be parsed as a
URI reference.
|
| Modifier and Type | Class and Description |
|---|---|
class |
AccessException
An
AccessException is thrown to
indicate that the caller does not have permission to perform the action
requested by the method call. |
class |
AlreadyBoundException
An
AlreadyBoundException is thrown if an attempt
is made to bind an object in the registry to a name that already
has an associated binding. |
class |
NotBoundException
A
NotBoundException is thrown if an attempt
is made to lookup or unbind in the registry a name that has
no associated binding. |
class |
RemoteException
A
RemoteException is the common superclass for a number of
communication-related exceptions that may occur during the execution of a
remote method call. |
class |
UnexpectedException
An
UnexpectedException is thrown if the client of a
remote method call receives, as a result of the call, a checked
exception that is not among the checked exception types declared in the
throws clause of the method in the remote interface. |
| Modifier and Type | Field and Description |
|---|---|
Throwable |
RemoteException.detail
Nested Exception to hold wrapped remote exception.
|
| Modifier and Type | Method and Description |
|---|---|
Throwable |
RemoteException.getCause()
Returns the wrapped remote exception (the cause).
|
| Constructor and Description |
|---|
RemoteException(String s,
Throwable ex)
Constructs a
RemoteException with the specified
detail message and nested exception. |
| Modifier and Type | Class and Description |
|---|---|
class |
AccessControlException
This exception is thrown by the AccessController to indicate
that a requested access (to a critical system resource such as the
file system or the network) is denied.
|
class |
DigestException
This is the generic Message Digest exception.
|
class |
GeneralSecurityException
The
GeneralSecurityException class is a generic
security exception class that provides type safety for all the
security-related exception classes that extend from it. |
class |
InvalidAlgorithmParameterException
This is the exception for invalid or inappropriate algorithm parameters.
|
class |
InvalidKeyException
This is the exception for invalid Keys (invalid encoding, wrong
length, uninitialized, etc).
|
class |
InvalidParameterException
This exception, designed for use by the JCA/JCE engine classes,
is thrown when an invalid parameter is passed
to a method.
|
class |
KeyException
This is the basic key exception.
|
class |
KeyManagementException
This is the general key management exception for all operations
dealing with key management.
|
class |
KeyStoreException
This is the generic KeyStore exception.
|
class |
NoSuchAlgorithmException
This exception is thrown when a particular cryptographic algorithm is
requested but is not available in the environment.
|
class |
NoSuchProviderException
This exception is thrown when a particular security provider is
requested but is not available in the environment.
|
class |
PrivilegedActionException
This exception is thrown by
doPrivileged(PrivilegedExceptionAction) and
doPrivileged(PrivilegedExceptionAction,
AccessControlContext context) to indicate
that the action being performed threw a checked exception. |
class |
ProviderException
A runtime exception for Provider exceptions (such as
misconfiguration errors), which may be subclassed by Providers to
throw specialized, provider-specific runtime errors.
|
class |
SignatureException
This is the generic Signature exception.
|
class |
UnrecoverableKeyException
This exception is thrown if a key in the keystore cannot be recovered.
|
| Modifier and Type | Method and Description |
|---|---|
Throwable |
PrivilegedActionException.getCause()
Returns the the cause of this exception (the exception thrown by
the privileged computation that resulted in this
PrivilegedActionException). |
| Modifier and Type | Class and Description |
|---|---|
class |
AclNotFoundException
This is an exception that is thrown whenever a reference is made to a
non-existent ACL (Access Control List).
|
class |
LastOwnerException
This is an exception that is thrown whenever an attempt is made to delete
the last owner of an Access Control List.
|
class |
NotOwnerException
This is an exception that is thrown whenever the modification of an object
(such as an Access Control List) is only allowed to be done by an owner of
the object, but the Principal attempting the modification is not an owner.
|
| Modifier and Type | Class and Description |
|---|---|
class |
CRLException
CRL (Certificate Revocation List) Exception.
|
| Modifier and Type | Class and Description |
|---|---|
class |
InvalidKeySpecException
This is the exception for invalid key specifications.
|
class |
InvalidParameterSpecException
This is the exception for invalid parameter specifications.
|
| Modifier and Type | Class and Description |
|---|---|
class |
ParseException
Signals that an error has been reached unexpectedly
while parsing.
|
| Modifier and Type | Class and Description |
|---|---|
class |
ConcurrentModificationException
This exception may be thrown by methods that have detected concurrent
modification of an object when such modification is not permissible.
|
class |
EmptyStackException
Thrown by methods in the
Stack class to indicate
that the stack is empty. |
class |
MissingResourceException
Signals that a resource is missing.
|
class |
NoSuchElementException
Thrown by the
nextElement method of an
Enumeration to indicate that there are no more
elements in the enumeration. |
class |
TooManyListenersException
The
TooManyListenersException Exception is used as part of
the Java Event model to annotate and implement a unicast special case of
a multicast Event Source. |
| Modifier and Type | Class and Description |
|---|---|
class |
JarException
Signals that an error of some sort has occurred while reading from
or writing to a JAR file.
|
| Modifier and Type | Class and Description |
|---|---|
class |
DataFormatException
Signals that a data format error has occurred.
|
class |
ZipException
Signals that a Zip exception of some sort has occurred.
|
| Modifier and Type | Class and Description |
|---|---|
class |
ClockStartedError
ClockStartedError is thrown by a Started Clock
when a method is invoked that is not legal on a Clock in the Started
state. |
class |
ClockStoppedException
A
ClockStoppedException is thrown when a method that
expects the Clock to be Started is
called on a Stopped Clock. |
class |
IncompatibleSourceException
An
IncompatibleSourceException is thrown
by a MediaHandler when setSource
is invoked and the MediaHandler cannot
support the DataSource. |
class |
IncompatibleTimeBaseException
An
IncompatibleTimeBaseException is generated
when Clock.setTimeBase is invoked
using a TimeBase that the Clock cannot support. |
class |
MediaError
A
MediaError indicates an error condition that
occurred through incorrect usage of the API. |
class |
MediaException
A
MediaException indicates an unexpected error
condition in a JavaMedia method. |
class |
NoDataSourceException
A
NoDataSourceException is thrown when a DataSource
can't be found for a particular URL or MediaLocator. |
class |
NoPlayerException
A
NoPlayerException is thrown when a PlayerFactory
can't find a Player for a
particular URL or MediaLocator. |
class |
NotPrefetchedError
NotPrefetchedError is thrown when a method that
requires a Controller to be in the Prefetched state is called
and the Controller has not been Prefetched. |
class |
NotRealizedError
NotRealizedError is thrown when a method that
requires a Controller to be in the Realized state is called
and the Controller is not Realized. |
class |
StopTimeSetError
StopTimeSetError is thrown when the stop time
has been set on a Started Clock and setStopTime is invoked
again. |
| Modifier and Type | Class and Description |
|---|---|
class |
ConnectionNotFoundException
This class is used to signal that a connection target
cannot be found, or the protocol type is not supported.
|
| Modifier and Type | Class and Description |
|---|---|
class |
UnavailableContainerException
Signals that no Container can be provided for the Xlet to use at this
time.
|
class |
XletStateChangeException
Signals that a requested Xlet state change failed.
|
| Modifier and Type | Class and Description |
|---|---|
class |
StubException
StubException is thrown whenever stub class generation fails
for inter-Xlet communication.
|
| Constructor and Description |
|---|
StubException(String s,
Throwable ex)
Constructs a
StubException with the specified
detail message and nested exception. |
| Modifier and Type | Class and Description |
|---|---|
class |
SSLException
Indicates some kind of error detected by an SSL subsystem.
|
class |
SSLHandshakeException
Indicates that the client and server could not negotiate the
desired level of security.
|
class |
SSLKeyException
Reports a bad SSL key.
|
class |
SSLPeerUnverifiedException
Indicates that the peer's identity has not been verified.
|
class |
SSLProtocolException
Reports an error in the operation of the SSL protocol.
|
| Modifier and Type | Class and Description |
|---|---|
class |
CertificateEncodingException
Certificate Encoding Exception.
|
class |
CertificateException
This exception indicates one of a variety of certificate problems.
|
class |
CertificateExpiredException
Certificate Expired Exception.
|
class |
CertificateNotYetValidException
Certificate is not yet valid exception.
|
class |
CertificateParsingException
Certificate Parsing Exception.
|
| Modifier and Type | Class and Description |
|---|---|
class |
InvalidLocatorException
This exception is thrown when a
Locator is not valid
in a particular context. |
class |
MalformedLocatorException
This exception is thrown to indicate that a malformed locator
string has been used.
|
| Modifier and Type | Class and Description |
|---|---|
class |
SIException
The base class for exceptions related to service information.
|
| Modifier and Type | Class and Description |
|---|---|
class |
FilterNotSupportedException
This exception indicates that the specified
ServiceFilter is
not supported. |
class |
SortNotAvailableException
This exception indicates that the requested sorting method is not
available for the particular
ServiceList, for example,
sorting by service numbers. |
| Modifier and Type | Class and Description |
|---|---|
class |
InvalidServiceComponentException
This exception is thrown when one or more service components are
not valid for usage in a particular context.
|
class |
ServiceContextException
The base class for exceptions related to service contexts.
|
| Modifier and Type | Class and Description |
|---|---|
class |
TVTimerScheduleFailedException
An exception thrown by the
TVTimer.schedule() method
when a timer specification cannot be met. |
| Modifier and Type | Class and Description |
|---|---|
class |
FactoryConfigurationError
Thrown when a problem with configuration with the Parser Factories
exists.
|
class |
ParserConfigurationException
Indicates a serious configuration error.
|
| Modifier and Type | Class and Description |
|---|---|
class |
XMLStreamException
The base exception for unexpected processing errors.
|
| Modifier and Type | Field and Description |
|---|---|
protected Throwable |
XMLStreamException.nested |
| Modifier and Type | Method and Description |
|---|---|
Throwable |
XMLStreamException.getNestedException()
Gets the nested exception.
|
| Constructor and Description |
|---|
XMLStreamException(String msg,
Location location,
Throwable th)
Construct an exception with the associated message, exception and location.
|
XMLStreamException(String msg,
Throwable th)
Construct an exception with the associated message and exception
|
XMLStreamException(Throwable th)
Construct an exception with the associated exception
|
| Modifier and Type | Method and Description |
|---|---|
void |
Category.debug(Object message,
Throwable t)
Log a message object with the
DEBUG level including
the stack trace of the Throwable t passed as
parameter. |
void |
Logger.debug(String pattern,
Object argument,
Throwable t)
Log a parameterized message at debug level.
|
void |
Logger.debug(Throwable t,
String pattern,
Object[] arguments)
Log a parameterized message at debug level.
|
void |
Category.error(Object message,
Throwable t)
Log a message object with the
ERROR level including
the stack trace of the Throwable t passed as
parameter. |
void |
Logger.error(Throwable t,
String pattern,
Object[] arguments)
Log a parameterized message at error level.
|
void |
Category.fatal(Object message,
Throwable t)
Log a message object with the
FATAL level including
the stack trace of the Throwable t passed as
parameter. |
void |
Logger.fatal(Throwable t,
String pattern,
Object[] arguments)
Log a parameterized message at fatal level.
|
protected void |
Category.forcedLog(String fqcn,
Level level,
Object message,
Throwable t)
This method creates a new logging event and logs the event
without further checks.
|
void |
Category.info(Object message,
Throwable t)
Log a message object with the
INFO level including
the stack trace of the Throwable t passed as
parameter. |
void |
Logger.info(String pattern,
Object argument,
Throwable t)
Log a parameterized message at info level.
|
void |
Logger.info(Throwable t,
String pattern,
Object[] arguments)
Log a parameterized message at info level.
|
void |
Category.l7dlog(Level level,
String key,
Object[] params,
Throwable t)
Log a localized and parameterized message.
|
void |
Category.l7dlog(Level level,
String key,
Throwable t)
Log a localized message.
|
void |
Category.log(Level level,
Object message,
Throwable t)
This generic form is intended to be used by wrappers.
|
void |
Logger.log(Level level,
Throwable t,
String pattern,
Object[] parameters)
Log a parameterized message at specified level.
|
void |
Category.log(String callerFQCN,
Level level,
Object message,
Throwable t)
This is the most generic printing method.
|
void |
Logger.logrb(Level level,
Throwable t,
String bundleName,
String key,
Object[] parameters)
Log a parameterized message using a pattern from a resource bundle.
|
void |
Logger.trace(Object message,
Throwable t)
Log a message object with the
TRACE level including the
stack trace of the Throwablet passed as parameter. |
void |
Logger.trace(Throwable t,
String pattern,
Object[] arguments)
Log a parameterized message at trace level.
|
void |
Category.warn(Object message,
Throwable t)
|
void |
Logger.warn(String pattern,
Object argument,
Throwable t)
Log a parameterized message at warn level.
|
void |
Logger.warn(Throwable t,
String pattern,
Object[] arguments)
Log a parameterized message at warn level.
|
| Modifier and Type | Method and Description |
|---|---|
Throwable |
ThrowableInformation.getThrowable() |
| Modifier and Type | Method and Description |
|---|---|
String[] |
ThrowableRenderer.doRender(Throwable t)
Render Throwable.
|
| Constructor and Description |
|---|
LocationInfo(Throwable t,
String fqnOfCallingClass)
Instantiate location information based on a Throwable.
|
LoggingEvent(String fqnOfCategoryClass,
Category logger,
long timeStamp,
Priority level,
Object message,
Throwable throwable)
Instantiate a LoggingEvent from the supplied parameters.
|
LoggingEvent(String fqnOfCategoryClass,
Category logger,
Priority level,
Object message,
Throwable throwable)
Instantiate a LoggingEvent from the supplied parameters.
|
ThrowableInformation(Throwable throwable) |
ThrowableInformation(Throwable throwable,
Category category)
Create a new instance.
|
| Modifier and Type | Class and Description |
|---|---|
class |
MediaFreezeException
This exception indicates that either the freeze method or the resume method was unsuccessful.
|
class |
NotAuthorizedMediaException
This exception indicates that the source can not be accessed in order to reference the new content,
the source has not been accepted.
|
| Modifier and Type | Class and Description |
|---|---|
class |
NotAuthorizedException
This class is thrown by MPEG related APIs when access is requested to
information which is scrambled and to which access is not permitted by
the security system.
|
class |
ObjectUnavailableException
This exception must be thrown by MPEG related APIs when an object is
not available.
|
class |
ResourceException
This exception must be thrown by MPEG related APIs when an operation
could not be performed due to lack of resources.
|
class |
TuningException |
| Modifier and Type | Class and Description |
|---|---|
class |
ConnectionLostException
Signals that a SectionFilterGroup has lost its connection or resources and hence is unable to satisfy
a call to a startFiltering method.
|
class |
FilteringInterruptedException
Signals that a filtering operation was interrupted before any data had been filtered.
|
class |
FilterResourceException
Signals that inadequate resources are available to support the requested operation
when a SectionFilterGroup is in the connected or disconnected states.
|
class |
IllegalFilterDefinitionException
Signals that a requested filter definition is not valid.
|
class |
InvalidSourceException
Signals that the section source specified is not valid for some reason.
|
class |
NoDataAvailableException
Signals that no data is available from a Section object.
|
class |
SectionFilterException
This is the base class for exceptions in the section filter API.
|
| Modifier and Type | Class and Description |
|---|---|
class |
IncorrectLocatorException
This exception is raised when a Locator given
is of an inappropriate type.
|
class |
NetworkInterfaceException
Base class for the NetworkInterfaceExceptions
|
class |
NoFreeInterfaceException
This exception is raised when a NetworkInterface
that could be reserved by the application,
cannot be found.
|
class |
NotTunedException
This exception is raised when a method that requires access
to a transport stream is called on a network interface that
is not tuned to any transport stream.
|
class |
StreamNotFoundException
This exception is raised when a reference to a transport stream
from a Locator can not be resolved because
the transport stream does not exist in the database of known
transport streams.
|
| Modifier and Type | Class and Description |
|---|---|
class |
IllegalProfileParameterException
The
IllegalProfileParameter exception is thrown if the
application attempts to ask for a version number for a profile not
specified for the application. |
class |
LanguageNotAvailableException
The
LanguageNotAvailableException exception is thrown if the
application asks for the name of an application in a language not signalled
in the AIT. |
| Modifier and Type | Class and Description |
|---|---|
class |
DSMCCException
The DSMCCException is the root class of all DSMCC related exceptions
|
class |
IllegalObjectTypeException
This Exception is thrown when the application attempted to create
a DSMCCStream or DSMCCStreamEvent object with an object or a path
that did not correspond to a DSMCC Stream or DSMCC StreamEvent respectively
|
class |
InsufficientResourcesException
This exception gets thrown when a request to perform a DSMCC related operation
cannot be completed due to resource limitations.
|
class |
InvalidAddressException
An InvalidAddressException is thrown when the format of an NSAP address
is not recognized.
|
class |
InvalidFormatException
An InvalidFormatException is thrown when an inconsistent DSMCC message is
received.
|
class |
InvalidPathNameException
The InvalidPathNameException is thrown when the path name to a DSMCCObject
does not exist or if the ServiceDomain has been detached.
|
class |
MPEGDeliveryException
An MPEGDEliveryException is thrown when an error
(for instance, a time out or accessing the data would
require tuning)
occurs while loading data from an MPEG Stream.
|
class |
NotEntitledException
This Exception is thrown when the user is not entitled to access
the content of the object (the Elementary Stream is scrambled and the user
is not entitled).
|
class |
NothingToAbortException
A NothingToAbortException is thrown when the abort method is called and
there is no loading in progress.
|
class |
NotLoadedException
A NotLoadedException is thrown when an operation fails
because information which is required to be loaded has not been.
|
class |
ServerDeliveryException
A ServerDeliveryException is thrown when the local machine can not
communicate with the server.
|
class |
ServiceXFRException
A ServiceXFRException is thrown when a DSMCC Object can not be loaded in the
current ServiceDomain but is available in an alternate ServiceDomain
(i.e.
|
class |
UnknownEventException
The
UnknownEventException is thrown when a method tries to access to
an unknown event. |
| Modifier and Type | Class and Description |
|---|---|
class |
CAException
This exception is thrown when access to a media stream is denied by the CA system.
|
| Modifier and Type | Class and Description |
|---|---|
class |
IncompleteTargetException
Thrown when the target for a connection is incompletely specified.
|
class |
PermissionDeniedException
Thrown when an application calls a method which it does not
have permission to call at that time.
|
| Modifier and Type | Class and Description |
|---|---|
class |
ProviderFailedInstallationException
Thrown when there is a problem installing a provider.
|
| Modifier and Type | Class and Description |
|---|---|
class |
DVBRasterFormatException
This exception is thrown for some invalid operations on instances of
DVBBufferedImage. |
class |
FontFormatException
Thrown when attempt is made to read a file describing a font when the
contents of that file are not valid.
|
class |
FontNotAvailableException
Thrown when attempt is made to instantiate a font that cannot be located.
|
class |
UnsupportedDrawingOperationException
The
UnsupportedDrawingOperationException class represents
an exception that is thrown if an drawing operation is not supported
on this platform. |
| Modifier and Type | Class and Description |
|---|---|
class |
UnsupportedPreferenceException
Thrown when a non-supported preference is used.
|
| Modifier and Type | Class and Description |
|---|---|
class |
HConfigurationException
Thrown when an application requests an
HScreenConfiguration that cannot
be satisfied -- either because the HScreenConfiguration does not
have the functionality, or because the requested HScreenConfiguration is otherwise
invalid, e.g. |
class |
HInvalidLookException
|
class |
HMatteException
An
HMatteException is an
exception that is thrown when a Component is unable to support the
desired HMatte effect. |
class |
HPermissionDeniedException
Thrown when an application attempts to control a device or feature
it does not have the right to do at the time of making the
call.
|
class |
HUIException
HUIException is a generic
exception that indicates that the desired user-interface mechanism
cannot be performed for some reason. |
| Modifier and Type | Class and Description |
|---|---|
class |
FeatureNotSupportedException
Thrown when an application attempts to query/set/get a feature
not supported on the device.
|
| Modifier and Type | Class and Description |
|---|---|
class |
DatabaseException
Exception that is thrown when a database error occurs
|
| Modifier and Type | Class and Description |
|---|---|
class |
AccessDeniedException
Exception thrown when an application is blocked from operating
on a RecordingRequest by security attributes associated with that
RecordingRequest.
|
class |
NoMoreDataEntriesException
No more data entries allowed for this recording request.
|
class |
RecordingFailedException
This exception is returned when applications call the
getFailedException() for a failed recording request or
an incomplete recording request.
|
| Modifier and Type | Class and Description |
|---|---|
class |
TimeLineInvalidException
This exception is returned when a time line is no longer valid in a
the piece of content for which it was obtained.
|
class |
TimeOutOfRangeException
This exception is returned when a time or media time is outside the
valid range for a particular time line.
|
| Constructor and Description |
|---|
ErrorEvent(int typeCode,
Throwable throwable)
Class constructor specifying the event type code, and throwable condition.
|
| Modifier and Type | Class and Description |
|---|---|
class |
DOMException
DOM operations only raise exceptions in "exceptional" circumstances, i.e.,
when an operation is impossible to perform (either for logical reasons,
because data is lost, or because the implementation has become unstable).
|
| Modifier and Type | Class and Description |
|---|---|
class |
EventException
Event operations may throw an
EventException as specified in
their method descriptions. |
| Modifier and Type | Class and Description |
|---|---|
class |
SAXException
Encapsulate a general SAX error or warning.
|
class |
SAXNotRecognizedException
Exception class for an unrecognized identifier.
|
class |
SAXNotSupportedException
Exception class for an unsupported operation.
|
class |
SAXParseException
Encapsulate an XML parse error or warning.
|
Copyright © 2013 CableLabs. All rights reserved.