| Package | Description |
|---|---|
| java.awt |
Contains all of the classes for creating user
interfaces and for painting graphics and images.
|
| javax.net.ssl |
Provides classes for the secure socket package.
|
| Modifier and Type | Class and Description |
|---|---|
class |
HeadlessException
Thrown when code that is dependent on a keyboard, display, or mouse
is called in an environment that does not support a keyboard, display,
or mouse.
|
| Modifier and Type | Method and Description |
|---|---|
static ServerSocketFactory |
SSLServerSocketFactory.getDefault()
Returns the default SSL server socket factory.
|
SSLServerSocketFactory |
SSLContext.getServerSocketFactory()
Returns a
ServerSocketFactory object for
this context. |
Copyright © 2012 CableLabs. All Rights Reserved.