| Package | Description |
|---|---|
| java.awt |
Contains all of the classes for creating user
interfaces and for painting graphics and images.
|
| java.awt.color |
Provides classes for color spaces.
|
| java.awt.event |
Provides interfaces and classes for dealing with different
types of events fired by AWT components.
|
| java.awt.font |
Provides classes and interface relating to fonts.
|
| java.awt.im |
Provides classes and interfaces for the input method framework.
|
| java.awt.image |
Provides classes for creating and modifying images.
|
| java.beans |
Contains classes for run-time Java Beans support.
|
| java.io |
Provides for system input and output through data streams,
serialization and the file system.
|
| java.lang |
Provides classes that are fundamental to the design of the Java
programming language.
|
| java.lang.ref |
Provides reference-object classes, which support a limited degree of
interaction with the garbage collector.
|
| java.lang.reflect |
Provides classes and interfaces for obtaining reflective
information about classes and objects.
|
| java.math |
Provides classes for performing arbitrary-precision integer arithmetic
(BigInteger) and arbitrary-precision decimal arithmetic (BigDecimal).
|
| java.net |
Provides the classes for implementing networking applications.
|
| java.rmi |
Provides the RMI package.
|
| java.rmi.registry |
Provides APIs related to the RMI registry.
|
| java.security |
Provides the classes and interfaces for the security framework.
|
| java.security.acl |
The classes and interfaces in this package have been
superseded by classes in the java.security package.
|
| java.security.cert |
Provides classes and interfaces for parsing and managing
certificates, certificate revocation lists (CRLs), and
certification paths.
|
| java.security.spec |
Provides classes and interfaces for key specifications and algorithm
parameter specifications.
|
| java.text |
Provides classes and interfaces for handling text, dates, numbers, and messages
in a manner independent of natural languages.
|
| java.util |
Contains the collections framework, legacy collection classes, event model,
date and time facilities, internationalization, and miscellaneous utility
classes (a string tokenizer, a random-number generator, and a bit array).
|
| java.util.jar |
Provides classes for reading and writing the JAR (Java ARchive) file
format, which is based on the standard ZIP file format with an
optional manifest file.
|
| java.util.zip |
Provides classes for reading and writing the standard ZIP and GZIP
file formats.
|
| javax.media |
Provides media players, means of controlling playback and being notified of playback state changes.
|
| javax.media.protocol |
Provides several means of streaming data for playback, as well as controlling that streaming.
|
| javax.microedition.io |
Provides a simplified mechanism for applications to use various types of I/O
protocols in resource-constrained environments.
|
| javax.microedition.xlet |
Provides interfaces used by applications and the application manager
to communicate.
|
| javax.microedition.xlet.ixc |
Provides facilities for inter-Xlet communication (IXC).
|
| javax.net |
Provides classes for networking applications.
|
| javax.net.ssl |
Provides classes for the secure socket package.
|
| javax.security.auth.x500 |
This package contains the classes that should be used to store
X500 Principal and X500 Private Crendentials in a
Subject.
|
| javax.security.cert |
Provides classes for public key certificates.
|
| javax.tv.graphics |
Provides a mechanism by which Xlets may discover their root container and
describes a mechanism for alpha blending.
|
| javax.tv.locator |
Provides a means for referencing data and resources accessible via the
Java TV APIs.
|
| javax.tv.media |
Provides controls and events for the management of real-time media
in a television environment.
|
| javax.tv.net |
Provides access to IP datagrams transmitted in the broadcast stream.
|
| javax.tv.service |
Provides mechanisms for accessing the service information (SI) database
and APIs representing the SI elements it contains.
|
| javax.tv.service.guide |
Provides APIs to support electronic program guides (EPGs), including program
schedules, program events and program ratings.
|
| javax.tv.service.navigation |
Provides APIs to navigate through services and hierarchical service information.
|
| javax.tv.service.selection |
Provides a mechanism to select a Service for
presentation.
|
| javax.tv.service.transport |
Provides additional information about the transport mechanisms that
deliver the content the SI data describes.
|
| javax.tv.util |
Provides APIs for creating and managing timer events.
|
| javax.xml | |
| javax.xml.parsers |
The javax.xml.parsers package contains the Java API for XML Processing (JAXP)
subset defined by JSR 280.
|
| javax.xml.stream |
This package provides the Streaming API for XML (StAX, or JSR 173) subset
defined by JSR 280.
|
| org.apache.log4j | |
| org.apache.log4j.config | |
| org.apache.log4j.or | |
| org.apache.log4j.spi | |
| org.apache.log4j.xml | |
| org.davic.media |
Provides various extensions to the Java Media Framework for
the control of TV oriented audio / video content.
|
| org.davic.mpeg |
Provides utility classes for common MPEG concepts.
|
| org.davic.mpeg.sections |
Provides access to MPEG-2 section filtering.
|
| org.davic.net |
Provides general content referencing.
|
| org.davic.net.tuning |
Provides access to tuning - MPEG multiplex selection.
|
| org.davic.resources |
Provides a framework for scarce resource management.
|
| org.dvb.application |
Provides access to lists of applications which are available
in this context and the ability to launch those applications.
|
| org.dvb.dsmcc |
Provides extended access to files carried in the broadcast
stream.
|
| org.dvb.event |
Provides access to user input events before they
are processed through the event mechanism of the java.awt package.
|
| org.dvb.io.persistent |
Provides extensions to the java.io package for access to files
held in persistent storage.
|
| org.dvb.lang |
Provides those core platform related features not found
in the java.lang package.
|
| org.dvb.media |
Provides DVB specific extensions to the Java Media Framework.
|
| org.dvb.net |
Provides general networking features not found elsewhere.
|
| org.dvb.net.rc |
Provides session management for bi-directional IP connections
which are session based from the point of view of an application.
|
| org.dvb.net.tuning |
Provides extensions to the tuning API from DAVIC.
|
| org.dvb.spi |
This package defines a central registry for all DVB Service Provider Interface
(SPI) providers.
|
| org.dvb.spi.selection |
This package defines an SPI for selection of services and service
components.
|
| org.dvb.spi.util |
Utility classes used by other providers.
|
| org.dvb.test |
Broadcast model
|
| org.dvb.ui |
Provides extended graphics functionality.
|
| org.dvb.user |
Provides access to settings and preferences configured by the end-user.
|
| org.havi.ui |
Provides user interfaces to HAVI components.
|
| org.havi.ui.event |
Provides ability to receive HAVI UI events.
|
| org.ocap |
Provides system utility functions
|
| org.ocap.application |
|
| org.ocap.diagnostics |
The org.ocap.diagnostics package provides diagnostic MIBs.
|
| org.ocap.dvr |
OCAP Specific extensions to the shared DVR API.
|
| org.ocap.dvr.event |
Provides ability to receive DVR events.
|
| org.ocap.dvr.storage |
Extensions to the OCAP Storage API to support Media Storage and Time-shift buffer.
|
| org.ocap.environment |
Represents an environment that provides the context in which applications run.
|
| org.ocap.event |
The org.ocap.event package manages user events.
|
| org.ocap.hardware |
The org.ocap.hardware package provides representations of several aspects of the hardware.
|
| org.ocap.hardware.device |
Provides extension classes and interfaces related to accessing and controlling
certain device parameters that are normally controlled by a
device manufacturer specific application.
|
| org.ocap.hardware.frontpanel |
Represents various aspects of front panel displays .
|
| org.ocap.hardware.pod |
This package provides a way to set and get OpenCable CableCARD Resource related parameters. |
| org.ocap.hn |
Provides representation of the main components of HN, such as servers, actions, action responses, and change listeners.
|
| org.ocap.hn.content |
Provides representation of the content and content containers, and means of identifying content type.
|
| org.ocap.hn.content.navigation |
Provides ways to search for content and filter results.
|
| org.ocap.hn.profiles.upnp |
Constants that are specific to UPnP.
|
| org.ocap.hn.recording |
Provides control and listing of recorded content.
|
| org.ocap.hn.resource | |
| org.ocap.hn.ruihsrc | |
| org.ocap.hn.security |
Provides access to home network security capabilities.
|
| org.ocap.hn.service |
A service which is hosted or provided by another device on the home network.
|
| org.ocap.hn.transformation | |
| org.ocap.hn.upnp.client |
Provides UPnP client functionality, permitting access to devices and
services on a home network.
|
| org.ocap.hn.upnp.common |
Provides UPnP APIs common to client- and server-side use.
|
| org.ocap.hn.upnp.server |
Provides UPnP server functionality, permitting management of devices and services in the local Host device.
|
| org.ocap.logging | |
| org.ocap.media |
The org.ocap.media package is a collection of classes and interfaces for controlling access to various kinds of media components
|
| org.ocap.mpeg |
The org.ocap.mpeg package provides access to private data sections in the extended channel
|
| org.ocap.net |
The org.ocap.net package provides locators for accessing various types of items in the transport stream.
|
| org.ocap.resource |
|
| org.ocap.service |
The org.ocap.service package represents various aspects of a service.
|
| org.ocap.shared.dvr |
The shared DVR API for scheduling and managing recording requests.
|
| org.ocap.shared.dvr.navigation |
Provides support for Navigation of recording lists.
|
| org.ocap.shared.media |
Extensions to JMF to support DVR playback.
|
| org.ocap.si |
The org.ocap.si package represents MPEG-2 PSI data.
|
| org.ocap.storage |
The org.ocap.storage package represents storage devices.
|
| org.ocap.system |
This API is used to access
system modules. |
| org.ocap.system.event |
The org.ocap.system.event package defines various system events. |
| org.ocap.test |
OCAP testing communications.
|
| org.ocap.ui |
Extensions to HAVi User Interface functionality.
|
| org.ocap.ui.event |
Extensions to HAVi User Interface Event classes, including OCAP
specific remote control events and multiscreen management events.
|
| org.w3c.dom |
The org.w3c.dom package provides the Java ME DOM API defined by
JSR 280.
|
| org.w3c.dom.events |
The org.w3c.dom.events package provides the Java ME DOM Events API subset
defined by JSR 280.
|
| org.xml.sax | |
| org.xml.sax.ext | |
| org.xml.sax.helpers |
| Class and Description |
|---|
| Character
The
Character class wraps a value of the primitive
type char in an object. |
| Class
Instances of the class
Class represent classes and interfaces
in a running Java application. |
| Cloneable
A class implements the
Cloneable interface to
indicate to the Object.clone() method that it
is legal for that method to make a
field-for-field copy of instances of that class. |
| Error
An
Error is a subclass of Throwable
that indicates serious problems that a reasonable application
should not try to catch. |
| Exception
The class
Exception and its subclasses are a form of
Throwable that indicates conditions that a reasonable
application might want to catch. |
| IllegalStateException
Signals that a method has been invoked at an illegal or
inappropriate time.
|
| InterruptedException
Thrown when a thread is waiting, sleeping, or otherwise paused for
a long time and another thread interrupts it using the
interrupt method in class Thread. |
| NumberFormatException
Thrown to indicate that the application has attempted to convert
a string to one of the numeric types, but that the string does not
have the appropriate format.
|
| Object
Class
Object is the root of the class hierarchy. |
| Runnable
The
Runnable interface should be implemented by any
class whose instances are intended to be executed by a thread. |
RuntimeException
RuntimeException is the superclass of those
exceptions that can be thrown during the normal operation of the
Java Virtual Machine. |
| String
The
String class represents character strings. |
| Throwable
The
Throwable class is the superclass of all errors and
exceptions in the Java language. |
| UnsupportedOperationException
Thrown to indicate that the requested operation is not supported.
|
| Class and Description |
|---|
| Object
Class
Object is the root of the class hierarchy. |
| String
The
String class represents character strings. |
| Class and Description |
|---|
| Exception
The class
Exception and its subclasses are a form of
Throwable that indicates conditions that a reasonable
application might want to catch. |
| Object
Class
Object is the root of the class hierarchy. |
| Runnable
The
Runnable interface should be implemented by any
class whose instances are intended to be executed by a thread. |
| String
The
String class represents character strings. |
| Class and Description |
|---|
| Boolean
The Boolean class wraps a value of the primitive type
boolean in an object. |
| Float
The
Float class wraps a value of primitive type
float in an object. |
| Integer
The
Integer class wraps a value of the primitive type
int in an object. |
| Object
Class
Object is the root of the class hierarchy. |
| String
The
String class represents character strings. |
| Class and Description |
|---|
| Character.Subset
Instances of this class represent particular subsets of the Unicode
character set.
|
| Object
Class
Object is the root of the class hierarchy. |
| Class and Description |
|---|
| Cloneable
A class implements the
Cloneable interface to
indicate to the Object.clone() method that it
is legal for that method to make a
field-for-field copy of instances of that class. |
| Exception
The class
Exception and its subclasses are a form of
Throwable that indicates conditions that a reasonable
application might want to catch. |
| InterruptedException
Thrown when a thread is waiting, sleeping, or otherwise paused for
a long time and another thread interrupts it using the
interrupt method in class Thread. |
| Object
Class
Object is the root of the class hierarchy. |
RuntimeException
RuntimeException is the superclass of those
exceptions that can be thrown during the normal operation of the
Java Virtual Machine. |
| String
The
String class represents character strings. |
| Throwable
The
Throwable class is the superclass of all errors and
exceptions in the Java language. |
| Class and Description |
|---|
| ClassLoader
A class loader is an object that is responsible for loading classes.
|
| ClassNotFoundException
Thrown when an application tries to load in a class through its
string name using:
The
forName method in class Class. |
| Exception
The class
Exception and its subclasses are a form of
Throwable that indicates conditions that a reasonable
application might want to catch. |
| Object
Class
Object is the root of the class hierarchy. |
| String
The
String class represents character strings. |
| Throwable
The
Throwable class is the superclass of all errors and
exceptions in the Java language. |
| Class and Description |
|---|
| Class
Instances of the class
Class represent classes and interfaces
in a running Java application. |
| ClassNotFoundException
Thrown when an application tries to load in a class through its
string name using:
The
forName method in class Class. |
| Comparable
This interface imposes a total ordering on the objects of each class that
implements it.
|
| Exception
The class
Exception and its subclasses are a form of
Throwable that indicates conditions that a reasonable
application might want to catch. |
| IllegalArgumentException
Thrown to indicate that a method has been passed an illegal or
inappropriate argument.
|
| Object
Class
Object is the root of the class hierarchy. |
| SecurityException
Thrown by the security manager to indicate a security violation.
|
| String
The
String class represents character strings. |
| StringBuffer
A string buffer implements a mutable sequence of characters.
|
| Throwable
The
Throwable class is the superclass of all errors and
exceptions in the Java language. |
| Class and Description |
|---|
| Boolean
The Boolean class wraps a value of the primitive type
boolean in an object. |
| Byte
The
Byte class wraps a value of primitive type
byte in an object. |
| Character
The
Character class wraps a value of the primitive
type char in an object. |
| Character.Subset
Instances of this class represent particular subsets of the Unicode
character set.
|
| Character.UnicodeBlock
A family of character subsets representing the character blocks in the
Unicode specification.
|
| CharSequence
A CharSequence is a readable sequence of characters.
|
| Class
Instances of the class
Class represent classes and interfaces
in a running Java application. |
| ClassFormatError
Thrown when the Java Virtual Machine attempts to read a class
file and determines that the file is malformed or otherwise cannot
be interpreted as a class file.
|
| ClassLoader
A class loader is an object that is responsible for loading classes.
|
| ClassNotFoundException
Thrown when an application tries to load in a class through its
string name using:
The
forName method in class Class. |
| CloneNotSupportedException
Thrown to indicate that the
clone method in class
Object has been called to clone an object, but that
the object's class does not implement the Cloneable
interface. |
| Comparable
This interface imposes a total ordering on the objects of each class that
implements it.
|
| Double
The
Double class wraps a value of the primitive type
double in an object. |
| Error
An
Error is a subclass of Throwable
that indicates serious problems that a reasonable application
should not try to catch. |
| Exception
The class
Exception and its subclasses are a form of
Throwable that indicates conditions that a reasonable
application might want to catch. |
| Float
The
Float class wraps a value of primitive type
float in an object. |
| IllegalAccessException
An IllegalAccessException is thrown when an application tries
to reflectively create an instance (other than an array),
set or get a field, or invoke a method, but the currently
executing method does not have access to the definition of
the specified class, field, method or constructor.
|
| IllegalArgumentException
Thrown to indicate that a method has been passed an illegal or
inappropriate argument.
|
| IncompatibleClassChangeError
Thrown when an incompatible class change has occurred to some class
definition.
|
| IndexOutOfBoundsException
Thrown to indicate that an index of some sort (such as to an array, to a
string, or to a vector) is out of range.
|
| InstantiationException
Thrown when an application tries to create an instance of a class
using the
newInstance method in class
Class, but the specified class object cannot be
instantiated because it is an interface or is an abstract class. |
| Integer
The
Integer class wraps a value of the primitive type
int in an object. |
| InterruptedException
Thrown when a thread is waiting, sleeping, or otherwise paused for
a long time and another thread interrupts it using the
interrupt method in class Thread. |
| LinkageError
Subclasses of
LinkageError indicate that a class has
some dependency on another class; however, the latter class has
incompatibly changed after the compilation of the former class. |
| Long
The
Long class wraps a value of the primitive type
long in an object. |
| NoSuchFieldException
Signals that the class doesn't have a field of a specified name.
|
| NoSuchMethodException
Thrown when a particular method cannot be found.
|
| Number
The abstract class
Number is the superclass of classes
BigDecimal, BigInteger,
Byte, Double, Float,
Integer, Long, and Short. |
| NumberFormatException
Thrown to indicate that the application has attempted to convert
a string to one of the numeric types, but that the string does not
have the appropriate format.
|
| Object
Class
Object is the root of the class hierarchy. |
Package
Package objects contain version information
about the implementation and specification of a Java package. |
| Process
The
Runtime.exec methods create a native process and
return an instance of a subclass of Process that can
be used to control the process and obtain information about it. |
| Runnable
The
Runnable interface should be implemented by any
class whose instances are intended to be executed by a thread. |
| Runtime
Every Java application has a single instance of class
Runtime that allows the application to interface with
the environment in which the application is running. |
RuntimeException
RuntimeException is the superclass of those
exceptions that can be thrown during the normal operation of the
Java Virtual Machine. |
| SecurityException
Thrown by the security manager to indicate a security violation.
|
| SecurityManager
The security manager is a class that allows
applications to implement a security policy.
|
| Short
The
Short class wraps a value of primitive type
short in an object. |
| StackTraceElement
An element in a stack trace, as returned by
Throwable.getStackTrace(). |
| String
The
String class represents character strings. |
| StringBuffer
A string buffer implements a mutable sequence of characters.
|
| Thread
A thread is a thread of execution in a program.
|
| ThreadGroup
A thread group represents a set of threads.
|
| ThreadLocal
This class provides thread-local variables.
|
| Throwable
The
Throwable class is the superclass of all errors and
exceptions in the Java language. |
| VirtualMachineError
Thrown to indicate that the Java Virtual Machine is broken or has
run out of resources necessary for it to continue operating.
|
| Class and Description |
|---|
| IllegalArgumentException
Thrown to indicate that a method has been passed an illegal or
inappropriate argument.
|
| InterruptedException
Thrown when a thread is waiting, sleeping, or otherwise paused for
a long time and another thread interrupts it using the
interrupt method in class Thread. |
| Object
Class
Object is the root of the class hierarchy. |
| Class and Description |
|---|
| ArrayIndexOutOfBoundsException
Thrown to indicate that an array has been accessed with an
illegal index.
|
| Class
Instances of the class
Class represent classes and interfaces
in a running Java application. |
| ClassLoader
A class loader is an object that is responsible for loading classes.
|
| Exception
The class
Exception and its subclasses are a form of
Throwable that indicates conditions that a reasonable
application might want to catch. |
| IllegalAccessException
An IllegalAccessException is thrown when an application tries
to reflectively create an instance (other than an array),
set or get a field, or invoke a method, but the currently
executing method does not have access to the definition of
the specified class, field, method or constructor.
|
| IllegalArgumentException
Thrown to indicate that a method has been passed an illegal or
inappropriate argument.
|
| InstantiationException
Thrown when an application tries to create an instance of a class
using the
newInstance method in class
Class, but the specified class object cannot be
instantiated because it is an interface or is an abstract class. |
| NegativeArraySizeException
Thrown if an application tries to create an array with negative size.
|
| Object
Class
Object is the root of the class hierarchy. |
RuntimeException
RuntimeException is the superclass of those
exceptions that can be thrown during the normal operation of the
Java Virtual Machine. |
| SecurityException
Thrown by the security manager to indicate a security violation.
|
| String
The
String class represents character strings. |
| Throwable
The
Throwable class is the superclass of all errors and
exceptions in the Java language. |
| Class and Description |
|---|
| Comparable
This interface imposes a total ordering on the objects of each class that
implements it.
|
| Number
The abstract class
Number is the superclass of classes
BigDecimal, BigInteger,
Byte, Double, Float,
Integer, Long, and Short. |
| Object
Class
Object is the root of the class hierarchy. |
| String
The
String class represents character strings. |
| Class and Description |
|---|
| Class
Instances of the class
Class represent classes and interfaces
in a running Java application. |
| ClassLoader
A class loader is an object that is responsible for loading classes.
|
| ClassNotFoundException
Thrown when an application tries to load in a class through its
string name using:
The
forName method in class Class. |
| Comparable
This interface imposes a total ordering on the objects of each class that
implements it.
|
| Exception
The class
Exception and its subclasses are a form of
Throwable that indicates conditions that a reasonable
application might want to catch. |
| IllegalArgumentException
Thrown to indicate that a method has been passed an illegal or
inappropriate argument.
|
| Object
Class
Object is the root of the class hierarchy. |
Package
Package objects contain version information
about the implementation and specification of a Java package. |
| String
The
String class represents character strings. |
| Throwable
The
Throwable class is the superclass of all errors and
exceptions in the Java language. |
| Class and Description |
|---|
| Exception
The class
Exception and its subclasses are a form of
Throwable that indicates conditions that a reasonable
application might want to catch. |
| Object
Class
Object is the root of the class hierarchy. |
| String
The
String class represents character strings. |
| Throwable
The
Throwable class is the superclass of all errors and
exceptions in the Java language. |
| Class and Description |
|---|
| String
The
String class represents character strings. |
| Class and Description |
|---|
| Class
Instances of the class
Class represent classes and interfaces
in a running Java application. |
| ClassLoader
A class loader is an object that is responsible for loading classes.
|
| ClassNotFoundException
Thrown when an application tries to load in a class through its
string name using:
The
forName method in class Class. |
| Cloneable
A class implements the
Cloneable interface to
indicate to the Object.clone() method that it
is legal for that method to make a
field-for-field copy of instances of that class. |
| CloneNotSupportedException
Thrown to indicate that the
clone method in class
Object has been called to clone an object, but that
the object's class does not implement the Cloneable
interface. |
| Exception
The class
Exception and its subclasses are a form of
Throwable that indicates conditions that a reasonable
application might want to catch. |
| IllegalArgumentException
Thrown to indicate that a method has been passed an illegal or
inappropriate argument.
|
| Object
Class
Object is the root of the class hierarchy. |
RuntimeException
RuntimeException is the superclass of those
exceptions that can be thrown during the normal operation of the
Java Virtual Machine. |
| SecurityException
Thrown by the security manager to indicate a security violation.
|
| String
The
String class represents character strings. |
| Throwable
The
Throwable class is the superclass of all errors and
exceptions in the Java language. |
| Class and Description |
|---|
| Cloneable
A class implements the
Cloneable interface to
indicate to the Object.clone() method that it
is legal for that method to make a
field-for-field copy of instances of that class. |
| Exception
The class
Exception and its subclasses are a form of
Throwable that indicates conditions that a reasonable
application might want to catch. |
| Object
Class
Object is the root of the class hierarchy. |
| String
The
String class represents character strings. |
| Throwable
The
Throwable class is the superclass of all errors and
exceptions in the Java language. |
| Class and Description |
|---|
| Exception
The class
Exception and its subclasses are a form of
Throwable that indicates conditions that a reasonable
application might want to catch. |
| Object
Class
Object is the root of the class hierarchy. |
| String
The
String class represents character strings. |
| Throwable
The
Throwable class is the superclass of all errors and
exceptions in the Java language. |
| Class and Description |
|---|
| Exception
The class
Exception and its subclasses are a form of
Throwable that indicates conditions that a reasonable
application might want to catch. |
| Object
Class
Object is the root of the class hierarchy. |
| String
The
String class represents character strings. |
| Throwable
The
Throwable class is the superclass of all errors and
exceptions in the Java language. |
| Class and Description |
|---|
| Cloneable
A class implements the
Cloneable interface to
indicate to the Object.clone() method that it
is legal for that method to make a
field-for-field copy of instances of that class. |
| Comparable
This interface imposes a total ordering on the objects of each class that
implements it.
|
| Exception
The class
Exception and its subclasses are a form of
Throwable that indicates conditions that a reasonable
application might want to catch. |
| Number
The abstract class
Number is the superclass of classes
BigDecimal, BigInteger,
Byte, Double, Float,
Integer, Long, and Short. |
| Object
Class
Object is the root of the class hierarchy. |
| String
The
String class represents character strings. |
| StringBuffer
A string buffer implements a mutable sequence of characters.
|
| Throwable
The
Throwable class is the superclass of all errors and
exceptions in the Java language. |
| Class and Description |
|---|
| ClassLoader
A class loader is an object that is responsible for loading classes.
|
| Cloneable
A class implements the
Cloneable interface to
indicate to the Object.clone() method that it
is legal for that method to make a
field-for-field copy of instances of that class. |
| CloneNotSupportedException
Thrown to indicate that the
clone method in class
Object has been called to clone an object, but that
the object's class does not implement the Cloneable
interface. |
| Comparable
This interface imposes a total ordering on the objects of each class that
implements it.
|
| Exception
The class
Exception and its subclasses are a form of
Throwable that indicates conditions that a reasonable
application might want to catch. |
| Object
Class
Object is the root of the class hierarchy. |
| Runnable
The
Runnable interface should be implemented by any
class whose instances are intended to be executed by a thread. |
RuntimeException
RuntimeException is the superclass of those
exceptions that can be thrown during the normal operation of the
Java Virtual Machine. |
| String
The
String class represents character strings. |
| Throwable
The
Throwable class is the superclass of all errors and
exceptions in the Java language. |
| Class and Description |
|---|
| Cloneable
A class implements the
Cloneable interface to
indicate to the Object.clone() method that it
is legal for that method to make a
field-for-field copy of instances of that class. |
| Exception
The class
Exception and its subclasses are a form of
Throwable that indicates conditions that a reasonable
application might want to catch. |
| Object
Class
Object is the root of the class hierarchy. |
| String
The
String class represents character strings. |
| Throwable
The
Throwable class is the superclass of all errors and
exceptions in the Java language. |
| Class and Description |
|---|
| Cloneable
A class implements the
Cloneable interface to
indicate to the Object.clone() method that it
is legal for that method to make a
field-for-field copy of instances of that class. |
| Exception
The class
Exception and its subclasses are a form of
Throwable that indicates conditions that a reasonable
application might want to catch. |
| Object
Class
Object is the root of the class hierarchy. |
| String
The
String class represents character strings. |
| Throwable
The
Throwable class is the superclass of all errors and
exceptions in the Java language. |
| Class and Description |
|---|
| Error
An
Error is a subclass of Throwable
that indicates serious problems that a reasonable application
should not try to catch. |
| Exception
The class
Exception and its subclasses are a form of
Throwable that indicates conditions that a reasonable
application might want to catch. |
| Object
Class
Object is the root of the class hierarchy. |
| String
The
String class represents character strings. |
| Throwable
The
Throwable class is the superclass of all errors and
exceptions in the Java language. |
| Class and Description |
|---|
| Object
Class
Object is the root of the class hierarchy. |
| String
The
String class represents character strings. |
| Class and Description |
|---|
| Exception
The class
Exception and its subclasses are a form of
Throwable that indicates conditions that a reasonable
application might want to catch. |
| IllegalArgumentException
Thrown to indicate that a method has been passed an illegal or
inappropriate argument.
|
| Object
Class
Object is the root of the class hierarchy. |
| String
The
String class represents character strings. |
| Throwable
The
Throwable class is the superclass of all errors and
exceptions in the Java language. |
| Class and Description |
|---|
| ClassLoader
A class loader is an object that is responsible for loading classes.
|
| Exception
The class
Exception and its subclasses are a form of
Throwable that indicates conditions that a reasonable
application might want to catch. |
| Object
Class
Object is the root of the class hierarchy. |
| String
The
String class represents character strings. |
| Throwable
The
Throwable class is the superclass of all errors and
exceptions in the Java language. |
| Class and Description |
|---|
| Exception
The class
Exception and its subclasses are a form of
Throwable that indicates conditions that a reasonable
application might want to catch. |
| Object
Class
Object is the root of the class hierarchy. |
| String
The
String class represents character strings. |
| Throwable
The
Throwable class is the superclass of all errors and
exceptions in the Java language. |
| Class and Description |
|---|
| Object
Class
Object is the root of the class hierarchy. |
| String
The
String class represents character strings. |
| Class and Description |
|---|
| Exception
The class
Exception and its subclasses are a form of
Throwable that indicates conditions that a reasonable
application might want to catch. |
| IllegalArgumentException
Thrown to indicate that a method has been passed an illegal or
inappropriate argument.
|
| Object
Class
Object is the root of the class hierarchy. |
| String
The
String class represents character strings. |
| Throwable
The
Throwable class is the superclass of all errors and
exceptions in the Java language. |
| UnsupportedOperationException
Thrown to indicate that the requested operation is not supported.
|
| Class and Description |
|---|
| Object
Class
Object is the root of the class hierarchy. |
| String
The
String class represents character strings. |
| Class and Description |
|---|
| Exception
The class
Exception and its subclasses are a form of
Throwable that indicates conditions that a reasonable
application might want to catch. |
| Object
Class
Object is the root of the class hierarchy. |
| Throwable
The
Throwable class is the superclass of all errors and
exceptions in the Java language. |
| Class and Description |
|---|
| Object
Class
Object is the root of the class hierarchy. |
| Class and Description |
|---|
| Exception
The class
Exception and its subclasses are a form of
Throwable that indicates conditions that a reasonable
application might want to catch. |
| Object
Class
Object is the root of the class hierarchy. |
| String
The
String class represents character strings. |
| Throwable
The
Throwable class is the superclass of all errors and
exceptions in the Java language. |
| Class and Description |
|---|
| Object
Class
Object is the root of the class hierarchy. |
| SecurityException
Thrown by the security manager to indicate a security violation.
|
| String
The
String class represents character strings. |
| Class and Description |
|---|
| Object
Class
Object is the root of the class hierarchy. |
| Class and Description |
|---|
| Exception
The class
Exception and its subclasses are a form of
Throwable that indicates conditions that a reasonable
application might want to catch. |
| Object
Class
Object is the root of the class hierarchy. |
| SecurityException
Thrown by the security manager to indicate a security violation.
|
| String
The
String class represents character strings. |
| Throwable
The
Throwable class is the superclass of all errors and
exceptions in the Java language. |
| Class and Description |
|---|
| Object
Class
Object is the root of the class hierarchy. |
| SecurityException
Thrown by the security manager to indicate a security violation.
|
| String
The
String class represents character strings. |
| Class and Description |
|---|
| Exception
The class
Exception and its subclasses are a form of
Throwable that indicates conditions that a reasonable
application might want to catch. |
| Object
Class
Object is the root of the class hierarchy. |
| String
The
String class represents character strings. |
| Throwable
The
Throwable class is the superclass of all errors and
exceptions in the Java language. |
| Class and Description |
|---|
| Exception
The class
Exception and its subclasses are a form of
Throwable that indicates conditions that a reasonable
application might want to catch. |
| Object
Class
Object is the root of the class hierarchy. |
| SecurityException
Thrown by the security manager to indicate a security violation.
|
| String
The
String class represents character strings. |
| Throwable
The
Throwable class is the superclass of all errors and
exceptions in the Java language. |
| Class and Description |
|---|
| Object
Class
Object is the root of the class hierarchy. |
| SecurityException
Thrown by the security manager to indicate a security violation.
|
| String
The
String class represents character strings. |
| Class and Description |
|---|
| Exception
The class
Exception and its subclasses are a form of
Throwable that indicates conditions that a reasonable
application might want to catch. |
| Object
Class
Object is the root of the class hierarchy. |
| String
The
String class represents character strings. |
| Throwable
The
Throwable class is the superclass of all errors and
exceptions in the Java language. |
| Class and Description |
|---|
| Object
Class
Object is the root of the class hierarchy. |
| String
The
String class represents character strings. |
| Class and Description |
|---|
| Error
An
Error is a subclass of Throwable
that indicates serious problems that a reasonable application
should not try to catch. |
| Exception
The class
Exception and its subclasses are a form of
Throwable that indicates conditions that a reasonable
application might want to catch. |
| IllegalArgumentException
Thrown to indicate that a method has been passed an illegal or
inappropriate argument.
|
| Object
Class
Object is the root of the class hierarchy. |
| String
The
String class represents character strings. |
| Throwable
The
Throwable class is the superclass of all errors and
exceptions in the Java language. |
| Class and Description |
|---|
| Exception
The class
Exception and its subclasses are a form of
Throwable that indicates conditions that a reasonable
application might want to catch. |
| IllegalArgumentException
Thrown to indicate that a method has been passed an illegal or
inappropriate argument.
|
| Object
Class
Object is the root of the class hierarchy. |
| String
The
String class represents character strings. |
| Throwable
The
Throwable class is the superclass of all errors and
exceptions in the Java language. |
| Class and Description |
|---|
| Class
Instances of the class
Class represent classes and interfaces
in a running Java application. |
| IllegalArgumentException
Thrown to indicate that a method has been passed an illegal or
inappropriate argument.
|
| Object
Class
Object is the root of the class hierarchy. |
| String
The
String class represents character strings. |
| Throwable
The
Throwable class is the superclass of all errors and
exceptions in the Java language. |
| Class and Description |
|---|
| Object
Class
Object is the root of the class hierarchy. |
| String
The
String class represents character strings. |
| Class and Description |
|---|
| Class
Instances of the class
Class represent classes and interfaces
in a running Java application. |
| Object
Class
Object is the root of the class hierarchy. |
| String
The
String class represents character strings. |
| Class and Description |
|---|
| Class
Instances of the class
Class represent classes and interfaces
in a running Java application. |
| Exception
The class
Exception and its subclasses are a form of
Throwable that indicates conditions that a reasonable
application might want to catch. |
| Object
Class
Object is the root of the class hierarchy. |
| String
The
String class represents character strings. |
| Throwable
The
Throwable class is the superclass of all errors and
exceptions in the Java language. |
| Class and Description |
|---|
| Class
Instances of the class
Class represent classes and interfaces
in a running Java application. |
| Exception
The class
Exception and its subclasses are a form of
Throwable that indicates conditions that a reasonable
application might want to catch. |
| Object
Class
Object is the root of the class hierarchy. |
| String
The
String class represents character strings. |
| Class and Description |
|---|
| Exception
The class
Exception and its subclasses are a form of
Throwable that indicates conditions that a reasonable
application might want to catch. |
| IndexOutOfBoundsException
Thrown to indicate that an index of some sort (such as to an array, to a
string, or to a vector) is out of range.
|
| Object
Class
Object is the root of the class hierarchy. |
| String
The
String class represents character strings. |
| Throwable
The
Throwable class is the superclass of all errors and
exceptions in the Java language. |
| Class and Description |
|---|
| Exception
The class
Exception and its subclasses are a form of
Throwable that indicates conditions that a reasonable
application might want to catch. |
| IndexOutOfBoundsException
Thrown to indicate that an index of some sort (such as to an array, to a
string, or to a vector) is out of range.
|
| Integer
The
Integer class wraps a value of the primitive type
int in an object. |
| Object
Class
Object is the root of the class hierarchy. |
| String
The
String class represents character strings. |
| Throwable
The
Throwable class is the superclass of all errors and
exceptions in the Java language. |
| Class and Description |
|---|
| Cloneable
A class implements the
Cloneable interface to
indicate to the Object.clone() method that it
is legal for that method to make a
field-for-field copy of instances of that class. |
| Exception
The class
Exception and its subclasses are a form of
Throwable that indicates conditions that a reasonable
application might want to catch. |
| IllegalArgumentException
Thrown to indicate that a method has been passed an illegal or
inappropriate argument.
|
| IndexOutOfBoundsException
Thrown to indicate that an index of some sort (such as to an array, to a
string, or to a vector) is out of range.
|
| Object
Class
Object is the root of the class hierarchy. |
| String
The
String class represents character strings. |
| Throwable
The
Throwable class is the superclass of all errors and
exceptions in the Java language. |
| Class and Description |
|---|
| Object
Class
Object is the root of the class hierarchy. |
| Class and Description |
|---|
| Exception
The class
Exception and its subclasses are a form of
Throwable that indicates conditions that a reasonable
application might want to catch. |
| Object
Class
Object is the root of the class hierarchy. |
| String
The
String class represents character strings. |
| Throwable
The
Throwable class is the superclass of all errors and
exceptions in the Java language. |
| Class and Description |
|---|
| Object
Class
Object is the root of the class hierarchy. |
| Class and Description |
|---|
| Exception
The class
Exception and its subclasses are a form of
Throwable that indicates conditions that a reasonable
application might want to catch. |
| Object
Class
Object is the root of the class hierarchy. |
| String
The
String class represents character strings. |
| Throwable
The
Throwable class is the superclass of all errors and
exceptions in the Java language. |
| Class and Description |
|---|
| Comparable
This interface imposes a total ordering on the objects of each class that
implements it.
|
| Exception
The class
Exception and its subclasses are a form of
Throwable that indicates conditions that a reasonable
application might want to catch. |
| Object
Class
Object is the root of the class hierarchy. |
| String
The
String class represents character strings. |
| Throwable
The
Throwable class is the superclass of all errors and
exceptions in the Java language. |
| Class and Description |
|---|
| Object
Class
Object is the root of the class hierarchy. |
| String
The
String class represents character strings. |
| Class and Description |
|---|
| Object
Class
Object is the root of the class hierarchy. |
| Class and Description |
|---|
| Class
Instances of the class
Class represent classes and interfaces
in a running Java application. |
| ClassLoader
A class loader is an object that is responsible for loading classes.
|
| ClassNotFoundException
Thrown when an application tries to load in a class through its
string name using:
The
forName method in class Class. |
| Object
Class
Object is the root of the class hierarchy. |
| String
The
String class represents character strings. |
| Class and Description |
|---|
| Exception
The class
Exception and its subclasses are a form of
Throwable that indicates conditions that a reasonable
application might want to catch. |
| Object
Class
Object is the root of the class hierarchy. |
| String
The
String class represents character strings. |
| Throwable
The
Throwable class is the superclass of all errors and
exceptions in the Java language. |
| Class and Description |
|---|
| Object
Class
Object is the root of the class hierarchy. |
| Class and Description |
|---|
| Exception
The class
Exception and its subclasses are a form of
Throwable that indicates conditions that a reasonable
application might want to catch. |
| Object
Class
Object is the root of the class hierarchy. |
| String
The
String class represents character strings. |
| Throwable
The
Throwable class is the superclass of all errors and
exceptions in the Java language. |
| Class and Description |
|---|
| Object
Class
Object is the root of the class hierarchy. |
| String
The
String class represents character strings. |
| Class and Description |
|---|
| Class
Instances of the class
Class represent classes and interfaces
in a running Java application. |
| Exception
The class
Exception and its subclasses are a form of
Throwable that indicates conditions that a reasonable
application might want to catch. |
| Object
Class
Object is the root of the class hierarchy. |
| String
The
String class represents character strings. |
| Throwable
The
Throwable class is the superclass of all errors and
exceptions in the Java language. |
| Class and Description |
|---|
| Object
Class
Object is the root of the class hierarchy. |
| String
The
String class represents character strings. |
| Class and Description |
|---|
| Object
Class
Object is the root of the class hierarchy. |
| String
The
String class represents character strings. |
| Class and Description |
|---|
| Object
Class
Object is the root of the class hierarchy. |
| String
The
String class represents character strings. |
| Class and Description |
|---|
| Exception
The class
Exception and its subclasses are a form of
Throwable that indicates conditions that a reasonable
application might want to catch. |
| Object
Class
Object is the root of the class hierarchy. |
| String
The
String class represents character strings. |
| Throwable
The
Throwable class is the superclass of all errors and
exceptions in the Java language. |
| Class and Description |
|---|
| Exception
The class
Exception and its subclasses are a form of
Throwable that indicates conditions that a reasonable
application might want to catch. |
| IllegalArgumentException
Thrown to indicate that a method has been passed an illegal or
inappropriate argument.
|
| Object
Class
Object is the root of the class hierarchy. |
| String
The
String class represents character strings. |
| Throwable
The
Throwable class is the superclass of all errors and
exceptions in the Java language. |
| Class and Description |
|---|
| Cloneable
A class implements the
Cloneable interface to
indicate to the Object.clone() method that it
is legal for that method to make a
field-for-field copy of instances of that class. |
| Exception
The class
Exception and its subclasses are a form of
Throwable that indicates conditions that a reasonable
application might want to catch. |
| IllegalStateException
Signals that a method has been invoked at an illegal or
inappropriate time.
|
| Integer
The
Integer class wraps a value of the primitive type
int in an object. |
| Object
Class
Object is the root of the class hierarchy. |
| SecurityException
Thrown by the security manager to indicate a security violation.
|
| String
The
String class represents character strings. |
| Throwable
The
Throwable class is the superclass of all errors and
exceptions in the Java language. |
| Class and Description |
|---|
| Object
Class
Object is the root of the class hierarchy. |
| String
The
String class represents character strings. |
| Class and Description |
|---|
| Object
Class
Object is the root of the class hierarchy. |
| Class and Description |
|---|
| Object
Class
Object is the root of the class hierarchy. |
| String
The
String class represents character strings. |
| Class and Description |
|---|
| Object
Class
Object is the root of the class hierarchy. |
| String
The
String class represents character strings. |
| Class and Description |
|---|
| Object
Class
Object is the root of the class hierarchy. |
| String
The
String class represents character strings. |
| Class and Description |
|---|
| Object
Class
Object is the root of the class hierarchy. |
| String
The
String class represents character strings. |
| Class and Description |
|---|
| String
The
String class represents character strings. |
| Class and Description |
|---|
| Object
Class
Object is the root of the class hierarchy. |
| String
The
String class represents character strings. |
| Class and Description |
|---|
| Object
Class
Object is the root of the class hierarchy. |
| Class and Description |
|---|
| Object
Class
Object is the root of the class hierarchy. |
| String
The
String class represents character strings. |
| Class and Description |
|---|
| Exception
The class
Exception and its subclasses are a form of
Throwable that indicates conditions that a reasonable
application might want to catch. |
| Object
Class
Object is the root of the class hierarchy. |
| String
The
String class represents character strings. |
| Throwable
The
Throwable class is the superclass of all errors and
exceptions in the Java language. |
| Class and Description |
|---|
| IllegalArgumentException
Thrown to indicate that a method has been passed an illegal or
inappropriate argument.
|
| IllegalStateException
Signals that a method has been invoked at an illegal or
inappropriate time.
|
| Object
Class
Object is the root of the class hierarchy. |
| String
The
String class represents character strings. |
| Class and Description |
|---|
| Object
Class
Object is the root of the class hierarchy. |
| String
The
String class represents character strings. |
| Class and Description |
|---|
| Object
Class
Object is the root of the class hierarchy. |
| String
The
String class represents character strings. |
| Class and Description |
|---|
| Exception
The class
Exception and its subclasses are a form of
Throwable that indicates conditions that a reasonable
application might want to catch. |
| Object
Class
Object is the root of the class hierarchy. |
| String
The
String class represents character strings. |
| Throwable
The
Throwable class is the superclass of all errors and
exceptions in the Java language. |
| Class and Description |
|---|
| Object
Class
Object is the root of the class hierarchy. |
| String
The
String class represents character strings. |
| Class and Description |
|---|
| String
The
String class represents character strings. |
| Class and Description |
|---|
| Object
Class
Object is the root of the class hierarchy. |
| String
The
String class represents character strings. |
| Class and Description |
|---|
| String
The
String class represents character strings. |
| Class and Description |
|---|
| Object
Class
Object is the root of the class hierarchy. |
| Class and Description |
|---|
| Object
Class
Object is the root of the class hierarchy. |
| String
The
String class represents character strings. |
| Class and Description |
|---|
| Object
Class
Object is the root of the class hierarchy. |
| String
The
String class represents character strings. |
| Class and Description |
|---|
| Object
Class
Object is the root of the class hierarchy. |
| Class and Description |
|---|
| Object
Class
Object is the root of the class hierarchy. |
| SecurityException
Thrown by the security manager to indicate a security violation.
|
| String
The
String class represents character strings. |
| Class and Description |
|---|
| Object
Class
Object is the root of the class hierarchy. |
| String
The
String class represents character strings. |
| Class and Description |
|---|
| Object
Class
Object is the root of the class hierarchy. |
| SecurityException
Thrown by the security manager to indicate a security violation.
|
| String
The
String class represents character strings. |
| Class and Description |
|---|
| Object
Class
Object is the root of the class hierarchy. |
| String
The
String class represents character strings. |
| Class and Description |
|---|
| Object
Class
Object is the root of the class hierarchy. |
| Class and Description |
|---|
| Object
Class
Object is the root of the class hierarchy. |
| Class and Description |
|---|
| Object
Class
Object is the root of the class hierarchy. |
| String
The
String class represents character strings. |
| Class and Description |
|---|
| Object
Class
Object is the root of the class hierarchy. |
| String
The
String class represents character strings. |
| Class and Description |
|---|
| Object
Class
Object is the root of the class hierarchy. |
| String
The
String class represents character strings. |
| Class and Description |
|---|
| Exception
The class
Exception and its subclasses are a form of
Throwable that indicates conditions that a reasonable
application might want to catch. |
| IllegalArgumentException
Thrown to indicate that a method has been passed an illegal or
inappropriate argument.
|
| IllegalStateException
Signals that a method has been invoked at an illegal or
inappropriate time.
|
| Object
Class
Object is the root of the class hierarchy. |
| String
The
String class represents character strings. |
| Throwable
The
Throwable class is the superclass of all errors and
exceptions in the Java language. |
| Class and Description |
|---|
| IndexOutOfBoundsException
Thrown to indicate that an index of some sort (such as to an array, to a
string, or to a vector) is out of range.
|
| Object
Class
Object is the root of the class hierarchy. |
| Class and Description |
|---|
| Exception
The class
Exception and its subclasses are a form of
Throwable that indicates conditions that a reasonable
application might want to catch. |
| Object
Class
Object is the root of the class hierarchy. |
| Throwable
The
Throwable class is the superclass of all errors and
exceptions in the Java language. |
| Class and Description |
|---|
| Object
Class
Object is the root of the class hierarchy. |
| String
The
String class represents character strings. |
| Class and Description |
|---|
| Object
Class
Object is the root of the class hierarchy. |
| String
The
String class represents character strings. |
| Class and Description |
|---|
| Object
Class
Object is the root of the class hierarchy. |
| String
The
String class represents character strings. |
| Class and Description |
|---|
| Object
Class
Object is the root of the class hierarchy. |
| String
The
String class represents character strings. |
| Throwable
The
Throwable class is the superclass of all errors and
exceptions in the Java language. |
| Class and Description |
|---|
| Object
Class
Object is the root of the class hierarchy. |
| Class and Description |
|---|
| Object
Class
Object is the root of the class hierarchy. |
| Class and Description |
|---|
| Object
Class
Object is the root of the class hierarchy. |
| Class and Description |
|---|
| Exception
The class
Exception and its subclasses are a form of
Throwable that indicates conditions that a reasonable
application might want to catch. |
| Object
Class
Object is the root of the class hierarchy. |
RuntimeException
RuntimeException is the superclass of those
exceptions that can be thrown during the normal operation of the
Java Virtual Machine. |
| String
The
String class represents character strings. |
| Throwable
The
Throwable class is the superclass of all errors and
exceptions in the Java language. |
| Class and Description |
|---|
| Exception
The class
Exception and its subclasses are a form of
Throwable that indicates conditions that a reasonable
application might want to catch. |
| Object
Class
Object is the root of the class hierarchy. |
RuntimeException
RuntimeException is the superclass of those
exceptions that can be thrown during the normal operation of the
Java Virtual Machine. |
| String
The
String class represents character strings. |
| Throwable
The
Throwable class is the superclass of all errors and
exceptions in the Java language. |
| Class and Description |
|---|
| Exception
The class
Exception and its subclasses are a form of
Throwable that indicates conditions that a reasonable
application might want to catch. |
| Object
Class
Object is the root of the class hierarchy. |
| String
The
String class represents character strings. |
| Throwable
The
Throwable class is the superclass of all errors and
exceptions in the Java language. |
| Class and Description |
|---|
| String
The
String class represents character strings. |
| Class and Description |
|---|
| Object
Class
Object is the root of the class hierarchy. |
| String
The
String class represents character strings. |
Copyright © 2013 CableLabs. All rights reserved.