public class PhantomReference extends Reference
If the garbage collector determines at a certain point in time that the referent of a phantom reference is phantom reachable, then at that time or at some later time it will enqueue the reference.
In order to ensure that a reclaimable object remains so, the referent of
a phantom reference may not be retrieved: The get method of a
phantom reference always returns null.
Unlike soft and weak references, phantom references are not automatically cleared by the garbage collector as they are enqueued. An object that is reachable via phantom references will remain so until all such references are cleared or themselves become unreachable.
| Constructor and Description |
|---|
PhantomReference(Object referent,
ReferenceQueue q)
Creates a new phantom reference that refers to the given object and
is registered with the given queue.
|
public PhantomReference(Object referent, ReferenceQueue q)
referent - the object the new phantom reference will refer toq - queue the phantom reference is registered withNullPointerException - If the queue argument
is nullCopyright © 2013 CableLabs. All rights reserved.