public abstract class Reference extends Object
| Modifier and Type | Method and Description |
|---|---|
void |
clear()
Clears this reference object.
|
boolean |
enqueue()
Adds this reference object to the queue with which it is registered,
if any.
|
Object |
get()
Returns this reference object's referent.
|
boolean |
isEnqueued()
Tells whether or not this reference object has been enqueued, either by
the program or by the garbage collector.
|
public Object get()
null.null if this reference object has been clearedpublic void clear()
public boolean isEnqueued()
false.true if and only if this reference object has
been enqueuedpublic boolean enqueue()
true if this reference object was successfully
enqueued; false if it was already enqueued or if
it was not registered with a queue when it was createdCopyright © 2013 CableLabs. All rights reserved.