public class WeakReference extends Reference
Suppose that the garbage collector determines at a certain point in time that an object is weakly reachable. At that time it will atomically clear all weak references to that object and all weak references to any other weakly-reachable objects from which that object is reachable through a chain of strong and soft references. At the same time it will declare all of the formerly weakly-reachable objects to be finalizable. At the same time or at some later time it will enqueue those newly-cleared weak references that are registered with reference queues.
| Constructor and Description |
|---|
WeakReference(Object referent)
Creates a new weak reference that refers to the given object.
|
WeakReference(Object referent,
ReferenceQueue q)
Creates a new weak reference that refers to the given object and is
registered with the given queue.
|
public WeakReference(Object referent)
referent - object the new weak reference will refer topublic WeakReference(Object referent, ReferenceQueue q)
referent - object the new weak reference will refer toq - queue the weak reference is registered withNullPointerException - If the queue argument
is nullCopyright © 2013 CableLabs. All rights reserved.