public class AccessibleObject extends Object
Setting the accessible flag in a reflected object permits sophisticated applications with sufficient privilege, such as Java Object Serialization or other persistence mechanisms, to manipulate objects in a manner that would normally be prohibited.
Field,
Method,
Constructor,
ReflectPermission| Modifier | Constructor and Description |
|---|---|
protected |
AccessibleObject()
Constructor: only used by the Java Virtual Machine.
|
| Modifier and Type | Method and Description |
|---|---|
boolean |
isAccessible()
Get the value of the accessible flag for this object.
|
static void |
setAccessible(AccessibleObject[] array,
boolean flag)
Convenience method to set the accessible flag for an
array of objects with a single security check (for efficiency).
|
void |
setAccessible(boolean flag)
Set the accessible flag for this object to
the indicated boolean value.
|
protected AccessibleObject()
public static void setAccessible(AccessibleObject[] array, boolean flag) throws SecurityException
First, if there is a security manager, its
checkPermission method is called with a
ReflectPermission("suppressAccessChecks") permission.
A SecurityException is raised if flag is
true but accessibility of any of the elements of the input
array may not be changed (for example, if the element
object is a Constructor object for the class Class). In the event of such a SecurityException, the
accessiblity of objects is set to flag for array elements
upto (and excluding) the element for which the exception occurred; the
accessiblity of elements beyond (and including) the element for which
the exception occurred is unchanged.
array - the array of AccessibleObjectsflag - the new value for the accessible flag
in each objectSecurityException - if the request is denied.SecurityManager.checkPermission(java.security.Permission),
RuntimePermissionpublic void setAccessible(boolean flag)
throws SecurityException
First, if there is a security manager, its
checkPermission method is called with a
ReflectPermission("suppressAccessChecks") permission.
A SecurityException is raised if flag is
true but accessibility of this object may not be changed
(for example, if this element object is a Constructor object for
the class Class).
A SecurityException is raised if this object is a Constructor object for the class
java.lang.Class, and flag is true.
flag - the new value for the accessible flagSecurityException - if the request is denied.SecurityManager.checkPermission(java.security.Permission),
RuntimePermissionpublic boolean isAccessible()
Copyright © 2013 CableLabs. All rights reserved.