public final class ReflectPermission extends BasicPermission
The following table provides a summary description of what the permission allows, and discusses the risks of granting code the permission.
| Permission Target Name | What the Permission Allows | Risks of Allowing this Permission |
|---|---|---|
| suppressAccessChecks | ability to access fields and invoke methods in a class. Note that this includes not only public, but protected and private fields and methods as well. | This is dangerous in that information (possibly confidential) and methods normally unavailable would be accessible to malicious code. |
| Constructor and Description |
|---|
ReflectPermission(String name)
Constructs a ReflectPermission with the specified name.
|
ReflectPermission(String name,
String actions)
Constructs a ReflectPermission with the specified name and actions.
|
equals, getActions, hashCode, implies, newPermissionCollectioncheckGuard, getName, toStringpublic ReflectPermission(String name)
name - the name of the ReflectPermissionCopyright © 2012. All Rights Reserved.