| Package | Description |
|---|---|
| java.lang |
Provides classes that are fundamental to the design of the Java
programming language.
|
| java.lang.reflect |
Provides classes and interfaces for obtaining reflective
information about classes and objects.
|
| Modifier and Type | Method and Description |
|---|---|
Method |
Class.getDeclaredMethod(String name,
Class[] parameterTypes)
Returns a
Method object that reflects the specified
declared method of the class or interface represented by this
Class object. |
Method[] |
Class.getDeclaredMethods()
Returns an array of
Method objects reflecting all the
methods declared by the class or interface represented by this
Class object. |
Method |
Class.getMethod(String name,
Class[] parameterTypes)
Returns a
Method object that reflects the specified public
member method of the class or interface represented by this
Class object. |
Method[] |
Class.getMethods()
Returns an array containing
Method objects reflecting all
the public member methods of the class or interface represented
by this Class object, including those declared by the class
or interface and and those inherited from superclasses and
superinterfaces. |
| Modifier and Type | Method and Description |
|---|---|
Object |
InvocationHandler.invoke(Object proxy,
Method method,
Object[] args)
Processes a method invocation on a proxy instance and returns
the result.
|
Copyright © 2013 CableLabs. All rights reserved.