| Package | Description |
|---|---|
| java.awt |
Contains all of the classes for creating user
interfaces and for painting graphics and images.
|
| java.lang |
Provides classes that are fundamental to the design of the Java
programming language.
|
| java.lang.reflect |
Provides classes and interfaces for obtaining reflective
information about classes and objects.
|
| Class and Description |
|---|
| InvocationTargetException
InvocationTargetException is a checked exception that wraps
an exception thrown by an invoked method or constructor.
|
| Class and Description |
|---|
Constructor
Constructor provides information about, and access to, a single
constructor for a class. |
| Field
A
Field provides information about, and dynamic access to, a
single field of a class or an interface. |
| Method
A
Method provides information about, and access to, a single method
on a class or interface. |
| Class and Description |
|---|
| AccessibleObject
The AccessibleObject class is the base class for Field, Method and
Constructor objects.
|
InvocationHandler
InvocationHandler is the interface implemented by
the invocation handler of a proxy instance. |
| InvocationTargetException
InvocationTargetException is a checked exception that wraps
an exception thrown by an invoked method or constructor.
|
| Member
Member is an interface that reflects identifying information about
a single member (a field or a method) or a constructor.
|
| Method
A
Method provides information about, and access to, a single method
on a class or interface. |
Copyright © 2012. All Rights Reserved.