| Package | Description |
|---|---|
| java.math |
Provides classes for performing arbitrary-precision integer arithmetic
(BigInteger) and arbitrary-precision decimal arithmetic (BigDecimal).
|
| java.security.cert |
Provides classes and interfaces for parsing and managing
certificates, certificate revocation lists (CRLs), and
certification paths.
|
| java.security.interfaces |
Provides interfaces for generating RSA (Rivest, Shamir and
Adleman AsymmetricCipher algorithm)
keys as defined in the RSA Laboratory Technical Note
PKCS#1, and DSA (Digital Signature
Algorithm) keys as defined in NIST's FIPS-186.
|
| java.security.spec |
Provides classes and interfaces for key specifications and algorithm
parameter specifications.
|
| javax.security.cert |
Provides classes for public key certificates.
|
| Modifier and Type | Field and Description |
|---|---|
static BigInteger |
BigInteger.ONE
The BigInteger constant one.
|
static BigInteger |
BigInteger.ZERO
The BigInteger constant zero.
|
| Modifier and Type | Method and Description |
|---|---|
BigInteger |
BigInteger.abs()
Returns a BigInteger whose value is the absolute value of this
BigInteger.
|
BigInteger |
BigInteger.add(BigInteger val)
Returns a BigInteger whose value is (this + val).
|
BigInteger |
BigInteger.and(BigInteger val)
Returns a BigInteger whose value is (this & val).
|
BigInteger |
BigInteger.andNot(BigInteger val)
Returns a BigInteger whose value is (this & ~val).
|
BigInteger |
BigInteger.clearBit(int n)
Returns a BigInteger whose value is equivalent to this BigInteger
with the designated bit cleared.
|
BigInteger |
BigInteger.divide(BigInteger val)
Returns a BigInteger whose value is (this / val).
|
BigInteger[] |
BigInteger.divideAndRemainder(BigInteger val)
Returns an array of two BigIntegers containing (this / val)
followed by (this % val).
|
BigInteger |
BigInteger.flipBit(int n)
Returns a BigInteger whose value is equivalent to this BigInteger
with the designated bit flipped.
|
BigInteger |
BigInteger.gcd(BigInteger val)
Returns a BigInteger whose value is the greatest common divisor of
abs(this) and abs(val).
|
BigInteger |
BigInteger.max(BigInteger val)
Returns the maximum of this BigInteger and val.
|
BigInteger |
BigInteger.min(BigInteger val)
Returns the minimum of this BigInteger and val.
|
BigInteger |
BigInteger.mod(BigInteger m)
Returns a BigInteger whose value is (this mod m).
|
BigInteger |
BigInteger.modInverse(BigInteger m)
Returns a BigInteger whose value is (this-1 mod m).
|
BigInteger |
BigInteger.modPow(BigInteger exponent,
BigInteger m)
Returns a BigInteger whose value is
(thisexponent mod m).
|
BigInteger |
BigInteger.multiply(BigInteger val)
Returns a BigInteger whose value is (this * val).
|
BigInteger |
BigInteger.negate()
Returns a BigInteger whose value is (-this).
|
BigInteger |
BigInteger.not()
Returns a BigInteger whose value is (~this).
|
BigInteger |
BigInteger.or(BigInteger val)
Returns a BigInteger whose value is (this | val).
|
BigInteger |
BigInteger.pow(int exponent)
Returns a BigInteger whose value is (thisexponent).
|
BigInteger |
BigInteger.remainder(BigInteger val)
Returns a BigInteger whose value is (this % val).
|
BigInteger |
BigInteger.setBit(int n)
Returns a BigInteger whose value is equivalent to this BigInteger
with the designated bit set.
|
BigInteger |
BigInteger.shiftLeft(int n)
Returns a BigInteger whose value is (this << n).
|
BigInteger |
BigInteger.shiftRight(int n)
Returns a BigInteger whose value is (this >> n).
|
BigInteger |
BigInteger.subtract(BigInteger val)
Returns a BigInteger whose value is (this - val).
|
BigInteger |
BigDecimal.toBigInteger()
Converts this BigDecimal to a BigInteger.
|
BigInteger |
BigDecimal.unscaledValue()
Returns a BigInteger whose value is the unscaled value of this
BigDecimal.
|
static BigInteger |
BigInteger.valueOf(long val)
Returns a BigInteger whose value is equal to that of the
specified
long. |
BigInteger |
BigInteger.xor(BigInteger val)
Returns a BigInteger whose value is (this ^ val).
|
| Modifier and Type | Method and Description |
|---|---|
BigInteger |
BigInteger.add(BigInteger val)
Returns a BigInteger whose value is (this + val).
|
BigInteger |
BigInteger.and(BigInteger val)
Returns a BigInteger whose value is (this & val).
|
BigInteger |
BigInteger.andNot(BigInteger val)
Returns a BigInteger whose value is (this & ~val).
|
int |
BigInteger.compareTo(BigInteger val)
Compares this BigInteger with the specified BigInteger.
|
BigInteger |
BigInteger.divide(BigInteger val)
Returns a BigInteger whose value is (this / val).
|
BigInteger[] |
BigInteger.divideAndRemainder(BigInteger val)
Returns an array of two BigIntegers containing (this / val)
followed by (this % val).
|
BigInteger |
BigInteger.gcd(BigInteger val)
Returns a BigInteger whose value is the greatest common divisor of
abs(this) and abs(val).
|
BigInteger |
BigInteger.max(BigInteger val)
Returns the maximum of this BigInteger and val.
|
BigInteger |
BigInteger.min(BigInteger val)
Returns the minimum of this BigInteger and val.
|
BigInteger |
BigInteger.mod(BigInteger m)
Returns a BigInteger whose value is (this mod m).
|
BigInteger |
BigInteger.modInverse(BigInteger m)
Returns a BigInteger whose value is (this-1 mod m).
|
BigInteger |
BigInteger.modPow(BigInteger exponent,
BigInteger m)
Returns a BigInteger whose value is
(thisexponent mod m).
|
BigInteger |
BigInteger.multiply(BigInteger val)
Returns a BigInteger whose value is (this * val).
|
BigInteger |
BigInteger.or(BigInteger val)
Returns a BigInteger whose value is (this | val).
|
BigInteger |
BigInteger.remainder(BigInteger val)
Returns a BigInteger whose value is (this % val).
|
BigInteger |
BigInteger.subtract(BigInteger val)
Returns a BigInteger whose value is (this - val).
|
BigInteger |
BigInteger.xor(BigInteger val)
Returns a BigInteger whose value is (this ^ val).
|
| Constructor and Description |
|---|
BigDecimal(BigInteger val)
Translates a BigInteger into a BigDecimal.
|
BigDecimal(BigInteger unscaledVal,
int scale)
Translates a BigInteger unscaled value and an
int
scale into a BigDecimal. |
| Modifier and Type | Method and Description |
|---|---|
abstract BigInteger |
X509Certificate.getSerialNumber()
Gets the
serialNumber value from the certificate. |
abstract BigInteger |
X509CRLEntry.getSerialNumber()
Gets the serial number from this X509CRLEntry,
the userCertificate.
|
| Modifier and Type | Method and Description |
|---|---|
abstract X509CRLEntry |
X509CRL.getRevokedCertificate(BigInteger serialNumber)
Gets the CRL entry, if any, with the given certificate serialNumber.
|
| Modifier and Type | Method and Description |
|---|---|
BigInteger |
RSAPrivateCrtKey.getCrtCoefficient()
Returns the crtCoefficient.
|
BigInteger |
DSAParams.getG()
Returns the base,
g. |
BigInteger |
RSAKey.getModulus()
Returns the modulus.
|
BigInteger |
DSAParams.getP()
Returns the prime,
p. |
BigInteger |
RSAPrivateCrtKey.getPrimeExponentP()
Returns the primeExponentP.
|
BigInteger |
RSAPrivateCrtKey.getPrimeExponentQ()
Returns the primeExponentQ.
|
BigInteger |
RSAPrivateCrtKey.getPrimeP()
Returns the primeP.
|
BigInteger |
RSAPrivateCrtKey.getPrimeQ()
Returns the primeQ.
|
BigInteger |
RSAPrivateKey.getPrivateExponent()
Returns the private exponent.
|
BigInteger |
RSAPublicKey.getPublicExponent()
Returns the public exponent.
|
BigInteger |
RSAPrivateCrtKey.getPublicExponent()
Returns the public exponent.
|
BigInteger |
DSAParams.getQ()
Returns the subprime,
q. |
BigInteger |
DSAPrivateKey.getX()
Returns the value of the private key,
x. |
BigInteger |
DSAPublicKey.getY()
Returns the value of the public key,
y. |
| Modifier and Type | Field and Description |
|---|---|
static BigInteger |
RSAKeyGenParameterSpec.F0
The public-exponent value F0 = 3.
|
static BigInteger |
RSAKeyGenParameterSpec.F4
The public exponent-value F4 = 65537.
|
| Modifier and Type | Method and Description |
|---|---|
BigInteger |
RSAPrivateCrtKeySpec.getCrtCoefficient()
Returns the crtCoefficient.
|
BigInteger |
DSAPublicKeySpec.getG()
Returns the base
g. |
BigInteger |
DSAPrivateKeySpec.getG()
Returns the base
g. |
BigInteger |
DSAParameterSpec.getG()
Returns the base
g. |
BigInteger |
RSAPublicKeySpec.getModulus()
Returns the modulus.
|
BigInteger |
RSAPrivateKeySpec.getModulus()
Returns the modulus.
|
BigInteger |
DSAPublicKeySpec.getP()
Returns the prime
p. |
BigInteger |
DSAPrivateKeySpec.getP()
Returns the prime
p. |
BigInteger |
DSAParameterSpec.getP()
Returns the prime
p. |
BigInteger |
RSAPrivateCrtKeySpec.getPrimeExponentP()
Returns the primeExponentP.
|
BigInteger |
RSAPrivateCrtKeySpec.getPrimeExponentQ()
Returns the primeExponentQ.
|
BigInteger |
RSAPrivateCrtKeySpec.getPrimeP()
Returns the primeP.
|
BigInteger |
RSAPrivateCrtKeySpec.getPrimeQ()
Returns the primeQ.
|
BigInteger |
RSAPrivateKeySpec.getPrivateExponent()
Returns the private exponent.
|
BigInteger |
RSAPublicKeySpec.getPublicExponent()
Returns the public exponent.
|
BigInteger |
RSAPrivateCrtKeySpec.getPublicExponent()
Returns the public exponent.
|
BigInteger |
RSAKeyGenParameterSpec.getPublicExponent()
Returns the public-exponent value.
|
BigInteger |
DSAPublicKeySpec.getQ()
Returns the sub-prime
q. |
BigInteger |
DSAPrivateKeySpec.getQ()
Returns the sub-prime
q. |
BigInteger |
DSAParameterSpec.getQ()
Returns the sub-prime
q. |
BigInteger |
DSAPrivateKeySpec.getX()
Returns the private key
x. |
BigInteger |
DSAPublicKeySpec.getY()
Returns the public key
y. |
| Constructor and Description |
|---|
DSAParameterSpec(BigInteger p,
BigInteger q,
BigInteger g)
Creates a new DSAParameterSpec with the specified parameter values.
|
DSAPrivateKeySpec(BigInteger x,
BigInteger p,
BigInteger q,
BigInteger g)
Creates a new DSAPrivateKeySpec with the specified parameter values.
|
DSAPublicKeySpec(BigInteger y,
BigInteger p,
BigInteger q,
BigInteger g)
Creates a new DSAPublicKeySpec with the specified parameter values.
|
RSAKeyGenParameterSpec(int keysize,
BigInteger publicExponent)
Constructs a new
RSAParameterSpec object from the
given keysize and public-exponent value. |
RSAPrivateCrtKeySpec(BigInteger modulus,
BigInteger publicExponent,
BigInteger privateExponent,
BigInteger primeP,
BigInteger primeQ,
BigInteger primeExponentP,
BigInteger primeExponentQ,
BigInteger crtCoefficient)
Creates a new
RSAPrivateCrtKeySpec
given the modulus, publicExponent, privateExponent,
primeP, primeQ, primeExponentP, primeExponentQ, and
crtCoefficient as defined in PKCS#1. |
RSAPrivateKeySpec(BigInteger modulus,
BigInteger privateExponent)
Creates a new RSAPrivateKeySpec.
|
RSAPublicKeySpec(BigInteger modulus,
BigInteger publicExponent)
Creates a new RSAPublicKeySpec.
|
| Modifier and Type | Method and Description |
|---|---|
abstract BigInteger |
X509Certificate.getSerialNumber()
Gets the
serialNumber value from the certificate. |
Copyright © 2013 CableLabs. All rights reserved.