| Package | Description |
|---|---|
| java.net |
Provides the classes for implementing networking applications.
|
| org.dvb.net |
Provides general networking features not found elsewhere.
|
| Modifier and Type | Class and Description |
|---|---|
class |
MulticastSocket
The multicast datagram socket class is useful for sending
and receiving IP multicast packets.
|
| Modifier and Type | Method and Description |
|---|---|
static int |
DatagramSocketBufferControl.getReceiveBufferSize(DatagramSocket d)
Get value of the SO_RCVBUF option for this socket, that is the
buffer size used by the platform for input on the this Socket.
|
static void |
DatagramSocketBufferControl.setReceiveBufferSize(DatagramSocket d,
int size)
Sets the SO_RCVBUF option to the specified value for this
DatagramSocket.
|
Copyright © 2013 CableLabs. All rights reserved.