| Package | Description |
|---|---|
| java.lang |
Provides classes that are fundamental to the design of the Java
programming language.
|
| java.net |
Provides the classes for implementing networking applications.
|
| javax.net |
Provides classes for networking applications.
|
| javax.net.ssl |
Provides classes for the secure socket package.
|
| javax.tv.net |
Provides access to IP datagrams transmitted in the broadcast stream.
|
| org.dvb.net.rc |
Provides session management for bi-directional IP connections
which are session based from the point of view of an application.
|
| org.ocap.hn |
Provides representation of the main components of HN, such as servers, actions, action responses, and change listeners.
|
| org.ocap.hn.recording |
Provides control and listing of recorded content.
|
| org.ocap.hn.resource | |
| org.ocap.hn.security |
Provides access to home network security capabilities.
|
| org.ocap.hn.service |
A service which is hosted or provided by another device on the home network.
|
| org.ocap.hn.upnp.client |
Provides UPnP client functionality, permitting access to devices and
services on a home network.
|
| org.ocap.hn.upnp.common |
Provides UPnP APIs common to client- and server-side use.
|
| org.ocap.hn.upnp.server |
Provides UPnP server functionality, permitting management of devices and services in the local Host device.
|
| Modifier and Type | Method and Description |
|---|---|
void |
SecurityManager.checkMulticast(InetAddress maddr)
Throws a
SecurityException if the
calling thread is not allowed to use
(join/leave/send/receive) IP multicast. |
void |
SecurityManager.checkMulticast(InetAddress maddr,
byte ttl)
Deprecated.
Use #checkPermission(java.security.Permission) instead
|
| Modifier and Type | Class and Description |
|---|---|
class |
Inet4Address
This class represents an Internet Protocol version 4 (IPv4) address.
|
class |
Inet6Address
This class represents an Internet Protocol version 6 (IPv6) address.
|
| Modifier and Type | Field and Description |
|---|---|
protected InetAddress |
SocketImpl.address
The IP address of the remote end of this socket.
|
| Modifier and Type | Method and Description |
|---|---|
InetAddress |
InetSocketAddress.getAddress()
Gets the
InetAddress. |
InetAddress |
DatagramPacket.getAddress()
Returns the IP address of the machine to which this datagram is being
sent or from which the datagram was received.
|
static InetAddress[] |
InetAddress.getAllByName(String host)
Given the name of a host, returns an array of its IP addresses,
based on the configured name service on the system.
|
static InetAddress |
InetAddress.getByAddress(byte[] addr)
Returns an
InetAddress object given the raw IP address . |
static InetAddress |
InetAddress.getByAddress(String host,
byte[] addr)
Create an InetAddress based on the provided host name and IP address
No name service is checked for the validity of the address.
|
static InetAddress |
InetAddress.getByName(String host)
Determines the IP address of a host, given the host's name.
|
protected InetAddress |
URLStreamHandler.getHostAddress(URL u)
Get the IP address of our host.
|
protected InetAddress |
SocketImpl.getInetAddress()
Returns the value of this socket's
address field. |
InetAddress |
Socket.getInetAddress()
Returns the address to which the socket is connected.
|
InetAddress |
ServerSocket.getInetAddress()
Returns the local address of this server socket.
|
InetAddress |
DatagramSocket.getInetAddress()
Returns the address to which this socket is connected.
|
InetAddress |
MulticastSocket.getInterface()
Retrieve the address of the network interface used for
multicast packets.
|
InetAddress |
Socket.getLocalAddress()
Gets the local address to which the socket is bound.
|
InetAddress |
DatagramSocket.getLocalAddress()
Gets the local address to which the socket is bound.
|
static InetAddress |
InetAddress.getLocalHost()
Returns the local host.
|
protected InetAddress |
Authenticator.getRequestingSite()
Gets the
InetAddress of the
site requesting authorization, or null
if not available. |
| Modifier and Type | Method and Description |
|---|---|
protected abstract void |
SocketImpl.bind(InetAddress host,
int port)
Binds this socket to the specified port number on the specified host.
|
protected abstract void |
DatagramSocketImpl.bind(int lport,
InetAddress laddr)
Binds a datagram socket to a local port and address.
|
protected abstract void |
SocketImpl.connect(InetAddress address,
int port)
Connects this socket to the specified port number on the specified host.
|
protected void |
DatagramSocketImpl.connect(InetAddress address,
int port)
Connects a datagram socket to a remote destination.
|
void |
DatagramSocket.connect(InetAddress address,
int port)
Connects the socket to a remote address for this socket.
|
static NetworkInterface |
NetworkInterface.getByInetAddress(InetAddress addr)
Convenience method to search for a network interface that
has the specified Internet Protocol (IP) address bound to
it.
|
protected abstract void |
DatagramSocketImpl.join(InetAddress inetaddr)
Join the multicast group.
|
void |
MulticastSocket.joinGroup(InetAddress mcastaddr)
Joins a multicast group.
|
protected abstract void |
DatagramSocketImpl.leave(InetAddress inetaddr)
Leave the multicast group.
|
void |
MulticastSocket.leaveGroup(InetAddress mcastaddr)
Leave a multicast group.
|
protected abstract int |
DatagramSocketImpl.peek(InetAddress i)
Peek at the packet to see who it is from.
|
static PasswordAuthentication |
Authenticator.requestPasswordAuthentication(InetAddress addr,
int port,
String protocol,
String prompt,
String scheme)
Ask the authenticator that has been registered with the system
for a password.
|
static PasswordAuthentication |
Authenticator.requestPasswordAuthentication(String host,
InetAddress addr,
int port,
String protocol,
String prompt,
String scheme)
Ask the authenticator that has been registered with the system
for a password.
|
void |
DatagramPacket.setAddress(InetAddress iaddr)
Sets the IP address of the machine to which this datagram
is being sent.
|
void |
MulticastSocket.setInterface(InetAddress inf)
Set the multicast network interface used by methods
whose behavior would be affected by the value of the
network interface.
|
| Constructor and Description |
|---|
DatagramPacket(byte[] buf,
int length,
InetAddress address,
int port)
Constructs a datagram packet for sending packets of length
length to the specified port number on the specified
host. |
DatagramPacket(byte[] buf,
int offset,
int length,
InetAddress address,
int port)
Constructs a datagram packet for sending packets of length
length with offset ioffsetto the
specified port number on the specified host. |
DatagramSocket(int port,
InetAddress laddr)
Creates a datagram socket, bound to the specified local
address.
|
InetSocketAddress(InetAddress addr,
int port)
Creates a socket address from an IP address and a port number.
|
ServerSocket(int port,
int backlog,
InetAddress bindAddr)
Create a server with the specified port, listen backlog, and
local IP address to bind to.
|
Socket(InetAddress address,
int port)
Creates a stream socket and connects it to the specified port
number at the specified IP address.
|
Socket(InetAddress address,
int port,
InetAddress localAddr,
int localPort)
Creates a socket and connects it to the specified remote address on
the specified remote port.
|
Socket(String host,
int port,
InetAddress localAddr,
int localPort)
Creates a socket and connects it to the specified remote host on
the specified remote port.
|
| Modifier and Type | Method and Description |
|---|---|
abstract ServerSocket |
ServerSocketFactory.createServerSocket(int port,
int backlog,
InetAddress ifAddress)
Returns a server socket bound to the specified port,
with a specified listen backlog and local IP.
|
abstract Socket |
SocketFactory.createSocket(InetAddress host,
int port)
Creates a socket and connects it to the specified port number
at the specified address.
|
abstract Socket |
SocketFactory.createSocket(InetAddress address,
int port,
InetAddress localAddress,
int localPort)
Creates a socket and connect it to the specified remote address
on the specified remote port.
|
abstract Socket |
SocketFactory.createSocket(String host,
int port,
InetAddress localHost,
int localPort)
Creates a socket and connects it to the specified remote host
on the specified remote port.
|
| Constructor and Description |
|---|
SSLServerSocket(int port,
int backlog,
InetAddress address)
Used only by subclasses.
|
SSLSocket(InetAddress address,
int port)
Used only by subclasses.
|
SSLSocket(InetAddress address,
int port,
InetAddress clientAddress,
int clientPort)
Used only by subclasses.
|
SSLSocket(String host,
int port,
InetAddress clientAddress,
int clientPort)
Used only by subclasses.
|
| Modifier and Type | Method and Description |
|---|---|
static InetAddress |
InterfaceMap.getLocalAddress(Locator locator)
Reports the local IP address assigned to the given service
component.
|
| Modifier and Type | Method and Description |
|---|---|
InetAddress[] |
ConnectionParameters.getDNSServer()
Return the addresses of the DNS servers to use for the connection
|
| Modifier and Type | Method and Description |
|---|---|
RCInterface |
RCInterfaceManager.getInterface(InetAddress addr)
Return the interface which will be used when connecting to a particular host.
|
| Constructor and Description |
|---|
ConnectionParameters(String number,
String username,
String password,
InetAddress[] dns)
Construct a set of connection parameters.
|
| Modifier and Type | Method and Description |
|---|---|
InetAddress |
NetworkInterface.getInetAddress()
Gets the
InetAddress of this interface. |
InetAddress |
Device.getInetAddress()
Returns the IP address for this device.
|
InetAddress[] |
NetworkInterface.getInetAddresses()
Gets an array of
InetAddress containing all of the IP addresses
configured for this NetworkInterface. |
| Modifier and Type | Method and Description |
|---|---|
boolean |
NetRecordingRequestHandler.notifyDelete(InetAddress address,
ContentEntry recording)
Notifies this NetRecordingRequestHandler that a device on the home
network has requested that metadata associated with a recording be
deleted.
|
boolean |
NetRecordingRequestHandler.notifyDeleteService(InetAddress address,
ContentEntry recording)
Notifies this NetRecordingRequestHandler that a device on the home
network has requested that content associated with a recorded service be
deleted.
|
boolean |
NetRecordingRequestHandler.notifyDisable(InetAddress address,
ContentEntry recording)
Notifies this NetRecordingRequestHandler that a device on the home
network has requested that a recording be disabled.
|
boolean |
NetRecordingRequestHandler.notifyPrioritization(InetAddress address,
NetRecordingEntry[] recordings)
Notifies this NetRecordingRequestHandler that a device on the home
network has requested that a group of recordings be re-prioritized.
|
boolean |
NetRecordingRequestHandler.notifyPrioritization(InetAddress address,
RecordingContentItem[] recordings)
Notifies this NetRecordingRequestHandler that a device on the home
network has requested that a group of individual recordings be
re-prioritized.
|
boolean |
NetRecordingRequestHandler.notifyReschedule(InetAddress address,
ContentEntry recording,
NetRecordingEntry spec)
Notifies this NetRecordingRequestHandler that a device on the home
network has requested that a recording be rescheduled.
|
boolean |
NetRecordingRequestHandler.notifySchedule(InetAddress address,
NetRecordingEntry spec)
Notifies this NetRecordingRequestHandler that a device on the home
network has requested that a recording be scheduled.
|
| Modifier and Type | Method and Description |
|---|---|
InetAddress |
NetResourceUsage.getInetAddress()
Returns the network address of the device from which the request was
originated for this usage.
|
| Modifier and Type | Method and Description |
|---|---|
boolean |
NetAuthorizationHandler2.notifyAction(String actionName,
InetAddress inetAddress,
int activityID,
String[] request,
NetworkInterface networkInterface)
Notifies the authorization handler that an action it
registered interest in has been received.
|
boolean |
NetAuthorizationHandler.notifyAction(String actionName,
InetAddress inetAddress,
String macAddress,
int activityID)
Notifies the authorization handler that an action it
registered interest in has been received.
|
boolean |
NetAuthorizationHandler.notifyActivityStart(InetAddress inetAddress,
String macAddress,
URL url,
int activityID)
Notifies the registered authorization handler that an
activity to access cable services has been started.
|
boolean |
NetAuthorizationHandler2.notifyActivityStart(InetAddress inetAddress,
URL url,
int activityID,
ContentEntry entry,
String[] request,
NetworkInterface networkInterface)
Notifies the registered authorization handler that an
activity to access cable services has been started.
|
boolean |
NetSecurityManager.queryTransaction(String actionName,
InetAddress inetAddress,
String macAddress,
URL url,
int activityID)
Queries the implementation to determine if it has sent a transaction
matching the parameters.
|
| Modifier and Type | Method and Description |
|---|---|
URL |
HttpRequestResolutionHandler.resolveHttpRequest(InetAddress inetAddress,
URL url,
String[] request,
NetworkInterface networkInterface)
Resolves the incoming HTTP request to a URL
that identifies a content binary
|
| Modifier and Type | Method and Description |
|---|---|
InetAddress[] |
UPnPControlPoint.getInetAddresses()
Gets the
InetAddresses that this
UPnPControlPoint is associated with. |
InetAddress[] |
UPnPControlPoint.setInetAddresses(InetAddress[] addresses)
Sets the InetAddresses that the
UPnPControlPoint is associated with. |
| Modifier and Type | Method and Description |
|---|---|
InetAddress[] |
UPnPControlPoint.setInetAddresses(InetAddress[] addresses)
Sets the InetAddresses that the
UPnPControlPoint is associated with. |
| Modifier and Type | Method and Description |
|---|---|
InetAddress |
UPnPAdvertisedDevice.getInetAddress()
Returns the IP address from which this device was advertised.
|
| Modifier and Type | Method and Description |
|---|---|
InetAddress[] |
UPnPManagedDevice.getInetAddresses()
Gets the
InetAddresses that this
UPnPManagedDevice is associated with. |
InetAddress[] |
UPnPManagedDevice.setInetAddresses(InetAddress[] addresses)
Sets the InetAddresses that this
UPnPManagedDevice
is associated with. |
| Modifier and Type | Method and Description |
|---|---|
InetAddress[] |
UPnPManagedDevice.setInetAddresses(InetAddress[] addresses)
Sets the InetAddresses that this
UPnPManagedDevice
is associated with. |
Copyright © 2013 CableLabs. All rights reserved.