| Package | Description |
|---|---|
| java.net |
Provides the classes for implementing networking applications.
|
| Modifier and Type | Method and Description |
|---|---|
static NetworkInterface |
NetworkInterface.getByInetAddress(InetAddress addr)
Convenience method to search for a network interface that
has the specified Internet Protocol (IP) address bound to
it.
|
static NetworkInterface |
NetworkInterface.getByName(String name)
Searches for the network interface with the specified name.
|
NetworkInterface |
MulticastSocket.getNetworkInterface()
Get the multicast network interface set.
|
| Modifier and Type | Method and Description |
|---|---|
void |
MulticastSocket.joinGroup(SocketAddress mcastaddr,
NetworkInterface netIf)
Joins the specified multicast group at the specified interface.
|
protected abstract void |
DatagramSocketImpl.joinGroup(SocketAddress mcastaddr,
NetworkInterface netIf)
Join the multicast group.
|
void |
MulticastSocket.leaveGroup(SocketAddress mcastaddr,
NetworkInterface netIf)
Leave a multicast group on a specified local interface.
|
protected abstract void |
DatagramSocketImpl.leaveGroup(SocketAddress mcastaddr,
NetworkInterface netIf)
Leave the multicast group.
|
void |
MulticastSocket.setNetworkInterface(NetworkInterface netIf)
Specify the network interface for outgoing multicast datagrams
sent on this socket.
|
Copyright © 2013 CableLabs. All rights reserved.