| Package | Description |
|---|---|
| java.net |
Provides the classes for implementing networking applications.
|
| javax.net |
Provides classes for networking applications.
|
| javax.net.ssl |
Provides classes for the secure socket package.
|
| org.dvb.net.rc |
Provides session management for bi-directional IP connections
which are session based from the point of view of an application.
|
| Modifier and Type | Method and Description |
|---|---|
Socket |
ServerSocket.accept()
Listens for a connection to be made to this socket and accepts
it.
|
| Modifier and Type | Method and Description |
|---|---|
protected void |
ServerSocket.implAccept(Socket s)
Subclasses of ServerSocket use this method to override accept()
to return their own subclass of socket.
|
| Modifier and Type | Method and Description |
|---|---|
Socket |
SocketFactory.createSocket()
Creates an unconnected socket.
|
abstract Socket |
SocketFactory.createSocket(InetAddress host,
int port)
Creates a socket and connects it to the specified port number
at the specified address.
|
abstract Socket |
SocketFactory.createSocket(InetAddress address,
int port,
InetAddress localAddress,
int localPort)
Creates a socket and connect it to the specified remote address
on the specified remote port.
|
abstract Socket |
SocketFactory.createSocket(String host,
int port)
Creates a socket and connects it to the specified remote host
at the specified remote port.
|
abstract Socket |
SocketFactory.createSocket(String host,
int port,
InetAddress localHost,
int localPort)
Creates a socket and connects it to the specified remote host
on the specified remote port.
|
| Modifier and Type | Class and Description |
|---|---|
class |
SSLSocket
This class extends
Sockets and provides secure
socket using protocols such as the "Secure
Sockets Layer" (SSL) or IETF "Transport Layer Security" (TLS) protocols. |
| Modifier and Type | Method and Description |
|---|---|
abstract Socket |
SSLSocketFactory.createSocket(Socket s,
String host,
int port,
boolean autoClose)
Returns a socket layered over an existing socket connected to the named
host, at the given port.
|
| Modifier and Type | Method and Description |
|---|---|
String |
X509KeyManager.chooseClientAlias(String[] keyType,
Principal[] issuers,
Socket socket)
Choose an alias to authenticate the client side of a secure
socket given the public key type and the list of
certificate issuer authorities recognized by the peer (if any).
|
String |
X509KeyManager.chooseServerAlias(String keyType,
Principal[] issuers,
Socket socket)
Choose an alias to authenticate the server side of a secure
socket given the public key type and the list of
certificate issuer authorities recognized by the peer (if any).
|
abstract Socket |
SSLSocketFactory.createSocket(Socket s,
String host,
int port,
boolean autoClose)
Returns a socket layered over an existing socket connected to the named
host, at the given port.
|
| Modifier and Type | Method and Description |
|---|---|
RCInterface |
RCInterfaceManager.getInterface(Socket s)
Return the interface which is used for a particular socket.
|
Copyright © 2013 CableLabs. All rights reserved.