| Package | Description |
|---|---|
| java.io |
Provides for system input and output through data streams,
serialization and the file system.
|
| java.net |
Provides the classes for implementing networking applications.
|
| Modifier and Type | Method and Description |
|---|---|
URI |
File.toURI()
Constructs a file: URI that represents this abstract pathname.
|
| Constructor and Description |
|---|
File(URI uri)
Creates a new File instance by converting the given
file: URI into an abstract pathname.
|
| Modifier and Type | Method and Description |
|---|---|
static URI |
URI.create(String str)
Creates a URI by parsing the given string.
|
URI |
URI.normalize()
Normalizes this URI's path.
|
URI |
URI.parseServerAuthority()
Attempts to parse this URI's authority component, if defined, into
user-information, host, and port components.
|
URI |
URI.relativize(URI uri)
Relativizes the given URI against this URI.
|
URI |
URI.resolve(String str)
Constructs a new URI by parsing the given string and then resolving it
against this URI.
|
URI |
URI.resolve(URI uri)
Resolves the given URI against this URI.
|
| Modifier and Type | Method and Description |
|---|---|
URI |
URI.relativize(URI uri)
Relativizes the given URI against this URI.
|
URI |
URI.resolve(URI uri)
Resolves the given URI against this URI.
|
Copyright © 2012 CableLabs. All Rights Reserved.