| Package | Description |
|---|---|
| java.awt |
Contains all of the classes for creating user
interfaces and for painting graphics and images.
|
| java.io |
Provides for system input and output through data streams,
serialization and the file system.
|
| java.lang |
Provides classes that are fundamental to the design of the Java
programming language.
|
| java.net |
Provides the classes for implementing networking applications.
|
| java.security |
Provides the classes and interfaces for the security framework.
|
| javax.media |
Provides media players, means of controlling playback and being notified of playback state changes.
|
| javax.media.protocol |
Provides several means of streaming data for playback, as well as controlling that streaming.
|
| javax.net.ssl |
Provides classes for the secure socket package.
|
| org.apache.log4j | |
| org.apache.log4j.spi | |
| org.apache.log4j.xml | |
| org.dvb.dsmcc |
Provides extended access to files carried in the broadcast
stream.
|
| org.dvb.lang |
Provides those core platform related features not found
in the java.lang package.
|
| org.dvb.ui |
Provides extended graphics functionality.
|
| org.havi.ui |
Provides user interfaces to HAVI components.
|
| org.ocap.hn.security |
Provides access to home network security capabilities.
|
| org.ocap.hn.service |
A service which is hosted or provided by another device on the home network.
|
| org.ocap.net |
The org.ocap.net package provides locators for accessing various types of items in the transport stream.
|
| Modifier and Type | Method and Description |
|---|---|
abstract Image |
Toolkit.createImage(URL url)
Returns an image which gets pixel data from the specified URL.
|
abstract Image |
Toolkit.getImage(URL url)
Returns an image which gets pixel data from the specified URL.
|
| Modifier and Type | Method and Description |
|---|---|
URL |
File.toURL()
Converts this abstract pathname into a
file: URL. |
| Modifier and Type | Method and Description |
|---|---|
protected URL |
ClassLoader.findResource(String name)
Finds the resource with the given name.
|
URL |
ClassLoader.getResource(String name)
Finds the resource with the given name.
|
URL |
Class.getResource(String name)
Finds a resource with a given name.
|
static URL |
ClassLoader.getSystemResource(String name)
Find a resource of the specified name from the search path used to load
classes.
|
| Modifier and Type | Method and Description |
|---|---|
protected Package |
ClassLoader.definePackage(String name,
String specTitle,
String specVersion,
String specVendor,
String implTitle,
String implVersion,
String implVendor,
URL sealBase)
Defines a package by name in this ClassLoader.
|
boolean |
Package.isSealed(URL url)
Returns true if this package is sealed with respect to the specified
code source url.
|
| Modifier and Type | Field and Description |
|---|---|
protected URL |
URLConnection.url
The URL represents the remote object on the World Wide Web to
which this connection is opened.
|
| Modifier and Type | Method and Description |
|---|---|
URL |
URLClassLoader.findResource(String name)
Finds the resource with the specified name on the URL search path.
|
URL |
JarURLConnection.getJarFileURL()
Returns the URL for the Jar file for this connection.
|
URL |
URLConnection.getURL()
Returns the value of this
URLConnection's URL
field. |
URL[] |
URLClassLoader.getURLs()
Returns the search path of URLs for loading classes and resources.
|
URL |
URI.toURL()
Constructs a URL from this URI.
|
| Modifier and Type | Method and Description |
|---|---|
protected void |
URLClassLoader.addURL(URL url)
Appends the specified URL to the list of URLs to search for
classes and resources.
|
protected Package |
URLClassLoader.definePackage(String name,
Manifest man,
URL url)
Defines a new package by name in this ClassLoader.
|
protected boolean |
URLStreamHandler.equals(URL u1,
URL u2)
Provides the default equals calculation.
|
protected InetAddress |
URLStreamHandler.getHostAddress(URL u)
Get the IP address of our host.
|
protected int |
URLStreamHandler.hashCode(URL u)
Provides the default hash calculation.
|
protected boolean |
URLStreamHandler.hostsEqual(URL u1,
URL u2)
Compares the host components of two URLs.
|
static URLClassLoader |
URLClassLoader.newInstance(URL[] urls)
Creates a new instance of URLClassLoader for the specified
URLs and default parent class loader.
|
static URLClassLoader |
URLClassLoader.newInstance(URL[] urls,
ClassLoader parent)
Creates a new instance of URLClassLoader for the specified
URLs and parent class loader.
|
protected abstract URLConnection |
URLStreamHandler.openConnection(URL u)
Opens a connection to the object referenced by the
URL argument. |
protected void |
URLStreamHandler.parseURL(URL u,
String spec,
int start,
int limit)
Parses the string representation of a
URL into a
URL object. |
boolean |
URL.sameFile(URL other)
Compares two URLs, excluding the fragment component.
|
protected boolean |
URLStreamHandler.sameFile(URL u1,
URL u2)
Compare two urls to see whether they refer to the same file,
i.e., having the same protocol, host, port, and path.
|
protected void |
URLStreamHandler.setURL(URL u,
String protocol,
String host,
int port,
String authority,
String userInfo,
String path,
String query,
String ref)
Sets the fields of the
URL argument to the indicated values. |
protected String |
URLStreamHandler.toExternalForm(URL u)
Converts a
URL of a specific protocol to a
String. |
| Constructor and Description |
|---|
HttpURLConnection(URL u)
Constructor for the HttpURLConnection.
|
JarURLConnection(URL url)
Creates the new JarURLConnection to the specified URL.
|
URL(URL context,
String spec)
Creates a URL by parsing the given spec within a specified context.
|
URL(URL context,
String spec,
URLStreamHandler handler)
Creates a URL by parsing the given spec with the specified handler
within a specified context.
|
URLClassLoader(URL[] urls)
Constructs a new URLClassLoader for the specified URLs using the
default delegation parent
ClassLoader. |
URLClassLoader(URL[] urls,
ClassLoader parent)
Constructs a new URLClassLoader for the given URLs.
|
URLClassLoader(URL[] urls,
ClassLoader parent,
URLStreamHandlerFactory factory)
Constructs a new URLClassLoader for the specified URLs, parent
class loader, and URLStreamHandlerFactory.
|
URLConnection(URL url)
Constructs a URL connection to the specified URL.
|
| Modifier and Type | Method and Description |
|---|---|
URL |
CodeSource.getLocation()
Returns the location associated with this CodeSource.
|
| Constructor and Description |
|---|
CodeSource(URL url,
Certificate[] certs)
Constructs a CodeSource and associates it with the specified
location and set of certificates.
|
| Modifier and Type | Method and Description |
|---|---|
URL |
MediaLocator.getURL()
Get the
URL associated with this MediaLocator. |
| Modifier and Type | Method and Description |
|---|---|
static DataSource |
Manager.createDataSource(URL sourceURL)
Create a
DataSource for the specified media. |
static Player |
Manager.createPlayer(URL sourceURL)
Create a
Player for the specified media. |
| Constructor and Description |
|---|
MediaLocator(URL url) |
| Constructor and Description |
|---|
URLDataSource(URL url)
Construct a
URLDataSource
directly from a URL. |
| Constructor and Description |
|---|
HttpsURLConnection(URL url)
Creates an
HttpsURLConnection using the
URL specified. |
| Modifier and Type | Method and Description |
|---|---|
static void |
PropertyConfigurator.configure(URL configURL)
Read configuration options from url
configURL. |
void |
PropertyConfigurator.doConfigure(URL configURL,
LoggerRepository hierarchy)
Read configuration options from url
configURL. |
| Modifier and Type | Method and Description |
|---|---|
void |
Configurator.doConfigure(URL url,
LoggerRepository repository)
Interpret a resource pointed by a URL and set up log4j accordingly.
|
| Modifier and Type | Method and Description |
|---|---|
static void |
DOMConfigurator.configure(URL url)
A static version of
DOMConfigurator.doConfigure(URL, LoggerRepository). |
void |
DOMConfigurator.doConfigure(URL url,
LoggerRepository repository) |
| Modifier and Type | Method and Description |
|---|---|
URL |
DSMCCObject.getURL()
Returns a URL identifying this carousel object.
|
static URL |
ServiceDomain.getURL(Locator l)
Obtain a java.net.URL corresponding to a 'dvb:' locator.
|
| Modifier and Type | Method and Description |
|---|---|
static DVBClassLoader |
DVBClassLoader.newInstance(URL[] urls)
Creates a new instance of DVBClassLoader for the specified URLs.
|
static DVBClassLoader |
DVBClassLoader.newInstance(URL[] urls,
ClassLoader parent)
Creates a new instance of DVBClassLoader for the specified URLs.
|
| Constructor and Description |
|---|
DVBClassLoader(URL[] urls)
Constructs a new DVBClassLoader for the given URLs.
|
DVBClassLoader(URL[] urls,
ClassLoader parent)
Constructs a new DVBClassLoader for the given URLs.
|
| Constructor and Description |
|---|
FontFactory(URL u)
Constructs a FontFactory for the font file found at the given location.
|
| Modifier and Type | Method and Description |
|---|---|
void |
HSound.load(URL contents)
Loads data synchronously into an
HSound object from an audio sample indicated by a URL. |
| Constructor and Description |
|---|
HBackgroundImage(URL contents)
Create an HBackgroundImage
object.
|
| Modifier and Type | Method and Description |
|---|---|
boolean |
NetAuthorizationHandler.notifyActivityStart(InetAddress inetAddress,
String macAddress,
URL url,
int activityID)
Notifies the registered authorization handler that an
activity to access cable services has been started.
|
boolean |
NetAuthorizationHandler2.notifyActivityStart(InetAddress inetAddress,
URL url,
int activityID,
ContentEntry entry,
String[] request,
NetworkInterface networkInterface)
Notifies the registered authorization handler that an
activity to access cable services has been started.
|
boolean |
NetSecurityManager.queryTransaction(String actionName,
InetAddress inetAddress,
String macAddress,
URL url,
int activityID)
Queries the implementation to determine if it has sent a transaction
matching the parameters.
|
| Modifier and Type | Method and Description |
|---|---|
URL |
HttpRequestResolutionHandler.resolveHttpRequest(InetAddress inetAddress,
URL url,
String[] request,
NetworkInterface networkInterface)
Resolves the incoming HTTP request to a URL
that identifies a content binary
|
| Modifier and Type | Method and Description |
|---|---|
URL |
HttpRequestResolutionHandler.resolveHttpRequest(InetAddress inetAddress,
URL url,
String[] request,
NetworkInterface networkInterface)
Resolves the incoming HTTP request to a URL
that identifies a content binary
|
| Constructor and Description |
|---|
URLLocator(URL url)
Construct an
URLLocator encapsulating the given URL. |
Copyright © 2013 CableLabs. All rights reserved.