| Package | Description |
|---|---|
| java.net |
Provides the classes for implementing networking applications.
|
| javax.media.protocol |
Provides several means of streaming data for playback, as well as controlling that streaming.
|
| javax.net.ssl |
Provides classes for the secure socket package.
|
| org.dvb.net.rc |
Provides session management for bi-directional IP connections
which are session based from the point of view of an application.
|
| Modifier and Type | Class and Description |
|---|---|
class |
HttpURLConnection
A URLConnection with support for HTTP-specific features.
|
class |
JarURLConnection
A URL Connection to a Java ARchive (JAR) file or an entry in a JAR
file.
|
| Modifier and Type | Field and Description |
|---|---|
protected URLConnection |
JarURLConnection.jarFileURLConnection
The connection to the JAR file URL, if the connection has been
initiated.
|
| Modifier and Type | Method and Description |
|---|---|
URLConnection |
URL.openConnection()
Returns a
URLConnection object that represents a
connection to the remote object referred to by the URL. |
protected abstract URLConnection |
URLStreamHandler.openConnection(URL u)
Opens a connection to the object referenced by the
URL argument. |
| Modifier and Type | Method and Description |
|---|---|
abstract Object |
ContentHandler.getContent(URLConnection urlc)
Given a URL connect stream positioned at the beginning of the
representation of an object, this method reads that stream and
creates an object from it.
|
Object |
ContentHandler.getContent(URLConnection urlc,
Class[] classes)
Given a URL connect stream positioned at the beginning of the
representation of an object, this method reads that stream and
creates an object that matches one of the types specified.
|
| Modifier and Type | Field and Description |
|---|---|
protected URLConnection |
URLDataSource.conn |
| Modifier and Type | Class and Description |
|---|---|
class |
HttpsURLConnection
HttpsURLConnection extends HttpURLConnection
with support for https-specific features. |
| Modifier and Type | Method and Description |
|---|---|
RCInterface |
RCInterfaceManager.getInterface(URLConnection u)
Return the interface which is used for a particular URLConnection
|
Copyright © 2013 CableLabs. All rights reserved.