Package java.net

Provides the classes for implementing networking applications.

See: Description

Package java.net Description

Provides the classes for implementing networking applications. Using the socket classes, you can communicate with any server on the Internet or implement your own Internet server. A number of classes are provided to make it convenient to use Universal Resource Locators (URLs) to retrieve data on the Internet.
Since:
JDK1.0

Copyright © 2013 CableLabs. All rights reserved.