| Package | Description |
|---|---|
| java.awt |
Contains all of the classes for creating user
interfaces and for painting graphics and images.
|
| java.io |
Provides for system input and output through data streams,
serialization and the file system.
|
| java.lang |
Provides classes that are fundamental to the design of the Java
programming language.
|
| java.net |
Provides the classes for implementing networking applications.
|
| java.security |
Provides the classes and interfaces for the security framework.
|
| javax.media |
Provides media players, means of controlling playback and being notified of playback state changes.
|
| javax.media.protocol |
Provides several means of streaming data for playback, as well as controlling that streaming.
|
| javax.net |
Provides classes for networking applications.
|
| javax.net.ssl |
Provides classes for the secure socket package.
|
| javax.tv.net |
Provides access to IP datagrams transmitted in the broadcast stream.
|
| org.apache.log4j | |
| org.apache.log4j.spi | |
| org.apache.log4j.xml | |
| org.dvb.dsmcc |
Provides extended access to files carried in the broadcast
stream.
|
| org.dvb.lang |
Provides those core platform related features not found
in the java.lang package.
|
| org.dvb.net |
Provides general networking features not found elsewhere.
|
| org.dvb.net.rc |
Provides session management for bi-directional IP connections
which are session based from the point of view of an application.
|
| org.dvb.ui |
Provides extended graphics functionality.
|
| org.havi.ui |
Provides user interfaces to HAVI components.
|
| org.ocap.hn |
Provides representation of the main components of HN, such as servers, actions, action responses, and change listeners.
|
| org.ocap.hn.recording |
Provides control and listing of recorded content.
|
| org.ocap.hn.resource | |
| org.ocap.hn.security |
Provides access to home network security capabilities.
|
| org.ocap.hn.service |
A service which is hosted or provided by another device on the home network.
|
| org.ocap.hn.upnp.client |
Provides UPnP client functionality, permitting access to devices and
services on a home network.
|
| org.ocap.hn.upnp.common |
Provides UPnP APIs common to client- and server-side use.
|
| org.ocap.hn.upnp.server |
Provides UPnP server functionality, permitting management of devices and services in the local Host device.
|
| org.ocap.net |
The org.ocap.net package provides locators for accessing various types of items in the transport stream.
|
| Class and Description |
|---|
| URL
Class
URL represents a Uniform Resource
Locator, a pointer to a "resource" on the World
Wide Web. |
| Class and Description |
|---|
| MalformedURLException
Thrown to indicate that a malformed URL has occurred.
|
| URI
Represents a Uniform Resource Identifier (URI) reference.
|
| URL
Class
URL represents a Uniform Resource
Locator, a pointer to a "resource" on the World
Wide Web. |
| Class and Description |
|---|
| InetAddress
This class represents an Internet Protocol (IP) address.
|
| URL
Class
URL represents a Uniform Resource
Locator, a pointer to a "resource" on the World
Wide Web. |
| Class and Description |
|---|
| Authenticator
The class Authenticator represents an object that knows how to obtain
authentication for a network connection.
|
| ContentHandler
The abstract class
ContentHandler is the superclass
of all classes that read an Object from a
URLConnection. |
| ContentHandlerFactory
This interface defines a factory for content handlers.
|
| DatagramPacket
This class represents a datagram packet.
|
| DatagramSocket
This class represents a socket for sending and receiving datagram packets.
|
| DatagramSocketImpl
Abstract datagram and multicast socket implementation base class.
|
| DatagramSocketImplFactory
This interface defines a factory for datagram socket implementations.
|
| FileNameMap
A simple interface which provides a mechanism to map
between a file name and a MIME type string.
|
| InetAddress
This class represents an Internet Protocol (IP) address.
|
| MalformedURLException
Thrown to indicate that a malformed URL has occurred.
|
| NetworkInterface
This class represents a Network Interface made up of a name,
and a list of IP addresses assigned to this interface.
|
| PasswordAuthentication
The class PasswordAuthentication is a data holder that is used by
Authenticator.
|
| ProtocolException
Thrown to indicate that there is an error in the underlying
protocol, such as a TCP error.
|
| Socket
This class implements client sockets (also called just
"sockets").
|
| SocketAddress
This class represents a Socket Address with no protocol attachment.
|
| SocketException
Thrown to indicate that there is an error in the underlying
protocol, such as a TCP error.
|
| SocketImpl
The abstract class
SocketImpl is a common superclass
of all classes that actually implement sockets. |
| SocketImplFactory
This interface defines a factory for socket implementations.
|
| SocketOptions
Interface of methods to get/set socket options.
|
| UnknownHostException
Thrown to indicate that the IP address of a host could not be determined.
|
| URI
Represents a Uniform Resource Identifier (URI) reference.
|
| URISyntaxException
Checked exception thrown to indicate that a string could not be parsed as a
URI reference.
|
| URL
Class
URL represents a Uniform Resource
Locator, a pointer to a "resource" on the World
Wide Web. |
| URLClassLoader
This class loader is used to load classes and resources from a search
path of URLs referring to both JAR files and directories.
|
| URLConnection
The abstract class
URLConnection is the superclass
of all classes that represent a communications link between the
application and a URL. |
| URLStreamHandler
The abstract class
URLStreamHandler is the common
superclass for all stream protocol handlers. |
| URLStreamHandlerFactory
This interface defines a factory for
URL stream
protocol handlers. |
| Class and Description |
|---|
| URL
Class
URL represents a Uniform Resource
Locator, a pointer to a "resource" on the World
Wide Web. |
| Class and Description |
|---|
| MalformedURLException
Thrown to indicate that a malformed URL has occurred.
|
| URL
Class
URL represents a Uniform Resource
Locator, a pointer to a "resource" on the World
Wide Web. |
| Class and Description |
|---|
| URL
Class
URL represents a Uniform Resource
Locator, a pointer to a "resource" on the World
Wide Web. |
| URLConnection
The abstract class
URLConnection is the superclass
of all classes that represent a communications link between the
application and a URL. |
| Class and Description |
|---|
| InetAddress
This class represents an Internet Protocol (IP) address.
|
| ServerSocket
This class implements server sockets.
|
| Socket
This class implements client sockets (also called just
"sockets").
|
| UnknownHostException
Thrown to indicate that the IP address of a host could not be determined.
|
| Class and Description |
|---|
| HttpURLConnection
A URLConnection with support for HTTP-specific features.
|
| InetAddress
This class represents an Internet Protocol (IP) address.
|
| ServerSocket
This class implements server sockets.
|
| Socket
This class implements client sockets (also called just
"sockets").
|
| UnknownHostException
Thrown to indicate that the IP address of a host could not be determined.
|
| URL
Class
URL represents a Uniform Resource
Locator, a pointer to a "resource" on the World
Wide Web. |
| URLConnection
The abstract class
URLConnection is the superclass
of all classes that represent a communications link between the
application and a URL. |
| Class and Description |
|---|
| InetAddress
This class represents an Internet Protocol (IP) address.
|
| Class and Description |
|---|
| URL
Class
URL represents a Uniform Resource
Locator, a pointer to a "resource" on the World
Wide Web. |
| Class and Description |
|---|
| URL
Class
URL represents a Uniform Resource
Locator, a pointer to a "resource" on the World
Wide Web. |
| Class and Description |
|---|
| URL
Class
URL represents a Uniform Resource
Locator, a pointer to a "resource" on the World
Wide Web. |
| Class and Description |
|---|
| URL
Class
URL represents a Uniform Resource
Locator, a pointer to a "resource" on the World
Wide Web. |
| Class and Description |
|---|
| URL
Class
URL represents a Uniform Resource
Locator, a pointer to a "resource" on the World
Wide Web. |
| Class and Description |
|---|
| DatagramSocket
This class represents a socket for sending and receiving datagram packets.
|
| SocketException
Thrown to indicate that there is an error in the underlying
protocol, such as a TCP error.
|
| Class and Description |
|---|
| InetAddress
This class represents an Internet Protocol (IP) address.
|
| Socket
This class implements client sockets (also called just
"sockets").
|
| URLConnection
The abstract class
URLConnection is the superclass
of all classes that represent a communications link between the
application and a URL. |
| Class and Description |
|---|
| URL
Class
URL represents a Uniform Resource
Locator, a pointer to a "resource" on the World
Wide Web. |
| Class and Description |
|---|
| URL
Class
URL represents a Uniform Resource
Locator, a pointer to a "resource" on the World
Wide Web. |
| Class and Description |
|---|
| InetAddress
This class represents an Internet Protocol (IP) address.
|
| Class and Description |
|---|
| InetAddress
This class represents an Internet Protocol (IP) address.
|
| Class and Description |
|---|
| InetAddress
This class represents an Internet Protocol (IP) address.
|
| Class and Description |
|---|
| InetAddress
This class represents an Internet Protocol (IP) address.
|
| URL
Class
URL represents a Uniform Resource
Locator, a pointer to a "resource" on the World
Wide Web. |
| Class and Description |
|---|
| InetAddress
This class represents an Internet Protocol (IP) address.
|
| URL
Class
URL represents a Uniform Resource
Locator, a pointer to a "resource" on the World
Wide Web. |
| Class and Description |
|---|
| InetAddress
This class represents an Internet Protocol (IP) address.
|
| Class and Description |
|---|
| InetAddress
This class represents an Internet Protocol (IP) address.
|
| InetSocketAddress
This class implements an IP Socket Address (IP address + port number)
It can also be a pair (hostname + port number), in which case an attempt
will be made to resolve the hostname.
|
| Class and Description |
|---|
| InetAddress
This class represents an Internet Protocol (IP) address.
|
| Class and Description |
|---|
| URL
Class
URL represents a Uniform Resource
Locator, a pointer to a "resource" on the World
Wide Web. |
Copyright © 2013 CableLabs. All rights reserved.