| Package | Description |
|---|---|
| java.rmi.registry |
Provides APIs related to the RMI registry.
|
| javax.microedition.xlet.ixc |
Provides facilities for inter-Xlet communication (IXC).
|
| Modifier and Type | Method and Description |
|---|---|
void |
Registry.bind(String name,
Remote obj)
Binds a remote reference to the specified
name in
this registry. |
String[] |
Registry.list()
Returns an array of the names bound in this registry.
|
Remote |
Registry.lookup(String name)
Returns the remote reference bound to the specified
name in this registry. |
void |
Registry.rebind(String name,
Remote obj)
Replaces the binding for the specified
name in
this registry with the supplied remote reference. |
void |
Registry.unbind(String name)
Removes the binding for the specified
name in
this registry. |
| Modifier and Type | Method and Description |
|---|---|
abstract void |
IxcRegistry.rebind(String name,
Remote obj)
Rebinds the specified name to a new remote object.
|
abstract void |
IxcRegistry.unbind(String name)
Destroys the binding for the specified name that is associated
with a remote object.
|
Copyright © 2012 CableLabs. All Rights Reserved.