| Package | Description |
|---|---|
| java.rmi.registry |
Provides APIs related to the RMI registry.
|
| javax.microedition.xlet.ixc |
Provides facilities for inter-Xlet communication (IXC).
|
| org.dvb.io.ixc |
Provides support for inter-application communication.
|
| Modifier and Type | Method and Description |
|---|---|
Remote |
Registry.lookup(String name)
Returns the remote reference bound to the specified
name in this registry. |
void |
Registry.unbind(String name)
Removes the binding for the specified
name in
this registry. |
| Modifier and Type | Method and Description |
|---|---|
abstract Remote |
IxcRegistry.lookup(String name)
Returns a reference, a stub, for the remote object associated
with the specified
name. |
abstract void |
IxcRegistry.unbind(String name)
Destroys the binding for the specified name that is associated
with a remote object.
|
| Modifier and Type | Method and Description |
|---|---|
static Remote |
IxcRegistry.lookup(XletContext xc,
String path)
Returns a remote object previously exported by an Xlet that
has not been destroyed.
|
static void |
IxcRegistry.unbind(XletContext xc,
String name)
Unbind the name.
|
Copyright © 2013 CableLabs. All rights reserved.