| Package | Description |
|---|---|
| java.rmi.registry |
Provides APIs related to the RMI registry.
|
| javax.microedition.xlet.ixc |
Provides facilities for inter-Xlet communication (IXC).
|
| org.dvb.io.ixc |
Provides support for inter-application communication.
|
| Modifier and Type | Interface and Description |
|---|---|
interface |
Registry
Registry is a remote interface to a simple remote
object registry that provides methods for storing and retrieving
remote object references bound with arbitrary string names. |
| Modifier and Type | Method and Description |
|---|---|
Remote |
Registry.lookup(String name)
Returns the remote reference bound to the specified
name in this registry. |
| Modifier and Type | Method and Description |
|---|---|
void |
Registry.bind(String name,
Remote obj)
Binds a remote reference to the specified
name in
this registry. |
void |
Registry.rebind(String name,
Remote obj)
Replaces the binding for the specified
name in
this registry with the supplied remote reference. |
| Modifier and Type | Class and Description |
|---|---|
class |
IxcRegistry
IxcRegistry is the bootstrap mechanism for obtaining
references to remote objects residing in other Xlets executing on
the same machine, but in separate classloaders. |
| Modifier and Type | Method and Description |
|---|---|
abstract Remote |
IxcRegistry.lookup(String name)
Returns a reference, a stub, for the remote object associated
with the specified
name. |
| Modifier and Type | Method and Description |
|---|---|
abstract void |
IxcRegistry.bind(String name,
Remote obj)
Binds the specified
name to a remote object. |
abstract void |
IxcRegistry.rebind(String name,
Remote obj)
Rebinds the specified name to a new remote object.
|
| Modifier and Type | Method and Description |
|---|---|
static Remote |
IxcRegistry.lookup(XletContext xc,
String path)
Returns a remote object previously exported by an Xlet that
has not been destroyed.
|
| Modifier and Type | Method and Description |
|---|---|
static void |
IxcRegistry.bind(XletContext xc,
String name,
Remote obj)
Exports an object under a given name in the namespace of
an Xlet.
|
static void |
IxcRegistry.rebind(XletContext xc,
String name,
Remote obj)
Rebind the name to a new object in the context of an Xlet;
replaces any existing binding.
|
Copyright © 2012 CableLabs. All Rights Reserved.