| Package | Description |
|---|---|
| java.rmi |
Provides the RMI package.
|
| java.rmi.registry |
Provides APIs related to the RMI registry.
|
| javax.microedition.xlet.ixc |
Provides facilities for inter-Xlet communication (IXC).
|
| org.dvb.io.ixc |
Provides support for inter-application communication.
|
| Modifier and Type | Class and Description |
|---|---|
class |
AccessException
An
AccessException is thrown to
indicate that the caller does not have permission to perform the action
requested by the method call. |
class |
UnexpectedException
An
UnexpectedException is thrown if the client of a
remote method call receives, as a result of the call, a checked
exception that is not among the checked exception types declared in the
throws clause of the method in the remote interface. |
| Modifier and Type | Method and Description |
|---|---|
void |
Registry.bind(String name,
Remote obj)
Binds a remote reference to the specified
name in
this registry. |
String[] |
Registry.list()
Returns an array of the names bound in this registry.
|
Remote |
Registry.lookup(String name)
Returns the remote reference bound to the specified
name in this registry. |
void |
Registry.rebind(String name,
Remote obj)
Replaces the binding for the specified
name in
this registry with the supplied remote reference. |
void |
Registry.unbind(String name)
Removes the binding for the specified
name in
this registry. |
| Modifier and Type | Class and Description |
|---|---|
class |
StubException
StubException is thrown whenever stub class generation fails
for inter-Xlet communication.
|
| Modifier and Type | Method and Description |
|---|---|
static Remote |
IxcRegistry.lookup(XletContext xc,
String path)
Returns a remote object previously exported by an Xlet that
has not been destroyed.
|
Copyright © 2013 CableLabs. All rights reserved.