| Interface | Description |
|---|---|
| Remote |
The
Remote interface serves to identify interfaces whose
methods may be invoked from a remote client. |
| Exception | Description |
|---|---|
| AccessException |
An
AccessException is thrown to
indicate that the caller does not have permission to perform the action
requested by the method call. |
| AlreadyBoundException |
An
AlreadyBoundException is thrown if an attempt
is made to bind an object in the registry to a name that already
has an associated binding. |
| NotBoundException |
A
NotBoundException is thrown if an attempt
is made to lookup or unbind in the registry a name that has
no associated binding. |
| RemoteException |
A
RemoteException is the common superclass for a number of
communication-related exceptions that may occur during the execution of a
remote method call. |
| UnexpectedException |
An
UnexpectedException is thrown if the client of a
remote method call receives, as a result of the call, a checked
exception that is not among the checked exception types declared in the
throws clause of the method in the remote interface. |
Copyright © 2012 CableLabs. All Rights Reserved.