| Package | Description |
|---|---|
| java.rmi |
Provides the RMI package.
|
| java.rmi.registry |
Provides APIs related to the RMI registry.
|
| javax.microedition.xlet.ixc |
Provides facilities for inter-Xlet communication (IXC).
|
| org.dvb.io.ixc |
Provides support for inter-application communication.
|
| Class and Description |
|---|
| RemoteException
A
RemoteException is the common superclass for a number of
communication-related exceptions that may occur during the execution of a
remote method call. |
| Class and Description |
|---|
| AccessException
An
AccessException is thrown to
indicate that the caller does not have permission to perform the action
requested by the method call. |
| AlreadyBoundException
An
AlreadyBoundException is thrown if an attempt
is made to bind an object in the registry to a name that already
has an associated binding. |
| NotBoundException
A
NotBoundException is thrown if an attempt
is made to lookup or unbind in the registry a name that has
no associated binding. |
| Remote
The
Remote interface serves to identify interfaces whose
methods may be invoked from a remote client. |
| RemoteException
A
RemoteException is the common superclass for a number of
communication-related exceptions that may occur during the execution of a
remote method call. |
| Class and Description |
|---|
| AccessException
An
AccessException is thrown to
indicate that the caller does not have permission to perform the action
requested by the method call. |
| AlreadyBoundException
An
AlreadyBoundException is thrown if an attempt
is made to bind an object in the registry to a name that already
has an associated binding. |
| NotBoundException
A
NotBoundException is thrown if an attempt
is made to lookup or unbind in the registry a name that has
no associated binding. |
| Remote
The
Remote interface serves to identify interfaces whose
methods may be invoked from a remote client. |
| RemoteException
A
RemoteException is the common superclass for a number of
communication-related exceptions that may occur during the execution of a
remote method call. |
| Class and Description |
|---|
| RemoteException
A
RemoteException is the common superclass for a number of
communication-related exceptions that may occur during the execution of a
remote method call. |
Copyright © 2012 CableLabs. All Rights Reserved.