public abstract class Provider extends Properties
Each provider has a name and a version number, and is configured in each runtime it is installed in.
See The Provider Class in the "Java Cryptography Architecture API Specification & Reference" for information about how a particular type of provider, the cryptographic service provider, works and is installed. However, please note that a provider can be used to implement any security service in Java that uses a pluggable architecture with a choice of implementations that fit underneath.
defaults| Modifier | Constructor and Description |
|---|---|
protected |
Provider(String name,
double version,
String info)
Constructs a provider with the specified name, version number,
and information.
|
| Modifier and Type | Method and Description |
|---|---|
void |
clear()
Clears this provider so that it no longer contains the properties
used to look up facilities implemented by the provider.
|
Set |
entrySet()
Returns an unmodifiable Set view of the property entries contained
in this Provider.
|
String |
getInfo()
Returns a human-readable description of the provider and its
services.
|
String |
getName()
Returns the name of this provider.
|
double |
getVersion()
Returns the version number for this provider.
|
Set |
keySet()
Returns an unmodifiable Set view of the property keys contained in
this provider.
|
void |
load(InputStream inStream)
Reads a property list (key and element pairs) from the input stream.
|
Object |
put(Object key,
Object value)
Sets the
key property to have the specified
value. |
void |
putAll(Map t)
Copies all of the mappings from the specified Map to this provider.
|
Object |
remove(Object key)
Removes the
key property (and its corresponding
value). |
String |
toString()
Returns a string with the name and the version number
of this provider.
|
Collection |
values()
Returns an unmodifiable Collection view of the property values
contained in this provider.
|
getProperty, getProperty, list, list, propertyNames, save, setProperty, storepublic String getName()
public double getVersion()
public String getInfo()
public String toString()
public void clear()
First, if there is a security manager, its checkSecurityAccess
method is called with the string "clearProviderProperties."+name
(where name is the provider name) to see if it's ok to clear this provider.
If the default implementation of checkSecurityAccess
is used (that is, that method is not overriden), then this results in
a call to the security manager's checkPermission method with a
SecurityPermission("clearProviderProperties."+name)
permission.
clear in interface Mapclear in class HashtableSecurityException - if a security manager exists and its SecurityManager.checkSecurityAccess(java.lang.String) method denies
access to clear this providerpublic void load(InputStream inStream) throws IOException
load in class PropertiesinStream - the input stream.IOException - if an error occurred when reading from the
input stream.Properties.load(java.io.InputStream)public void putAll(Map t)
public Set entrySet()
public Set keySet()
public Collection values()
public Object put(Object key, Object value)
key property to have the specified
value.
First, if there is a security manager, its checkSecurityAccess
method is called with the string "putProviderProperty."+name,
where name is the provider name,
to see if it's ok to set this provider's property values.
If the default implementation of checkSecurityAccess
is used (that is, that method is not overriden), then this results in
a call to the security manager's checkPermission method with a
SecurityPermission("putProviderProperty."+name)
permission.
put in interface Mapput in class Hashtablekey - the property key.value - the property value.key), or null if it did not have one.SecurityException - if a security manager exists and its SecurityManager.checkSecurityAccess(java.lang.String) method denies
access to set property values.Object.equals(Object),
Hashtable.get(Object)public Object remove(Object key)
key property (and its corresponding
value).
First, if there is a security manager, its checkSecurityAccess
method is called with the string ""removeProviderProperty."+name,
where name is the provider name,
to see if it's ok to remove this provider's properties.
If the default implementation of checkSecurityAccess
is used (that is, that method is not overriden), then this results in
a call to the security manager's checkPermission method with a
SecurityPermission("removeProviderProperty."+name)
permission.
remove in interface Mapremove in class Hashtablekey - the key for the property to be removed.SecurityException - if a security manager exists and its SecurityManager.checkSecurityAccess(java.lang.String) method denies
access to remove this provider's properties.Copyright © 2013 CableLabs. All rights reserved.