public abstract class SecureRandomSpi extends Object implements Serializable
SecureRandom class.
All the abstract methods in this class must be implemented by each
service provider who wishes to supply the implementation
of a cryptographically strong pseudo-random number generator.SecureRandom,
Serialized Form| Constructor and Description |
|---|
SecureRandomSpi() |
| Modifier and Type | Method and Description |
|---|---|
protected abstract byte[] |
engineGenerateSeed(int numBytes)
Returns the given number of seed bytes.
|
protected abstract void |
engineNextBytes(byte[] bytes)
Generates a user-specified number of random bytes.
|
protected abstract void |
engineSetSeed(byte[] seed)
Reseeds this random object.
|
protected abstract void engineSetSeed(byte[] seed)
seed - the seed.protected abstract void engineNextBytes(byte[] bytes)
bytes - the array to be filled in with random bytes.protected abstract byte[] engineGenerateSeed(int numBytes)
numBytes - the number of seed bytes to generate.Copyright © 2013 CableLabs. All rights reserved.