| Package | Description |
|---|---|
| java.net |
Provides the classes for implementing networking applications.
|
| java.security |
Provides the classes and interfaces for the security framework.
|
| java.security.cert |
Provides classes and interfaces for parsing and managing
certificates, certificate revocation lists (CRLs), and
certification paths.
|
| java.util.jar |
Provides classes for reading and writing the JAR (Java ARchive) file
format, which is based on the standard ZIP file format with an
optional manifest file.
|
| javax.net.ssl |
Provides classes for the secure socket package.
|
| org.ocap.application |
|
| Modifier and Type | Method and Description |
|---|---|
Certificate[] |
JarURLConnection.getCertificates()
Return the Certificate object for this connection if the URL
for it points to a JAR file entry, null otherwise.
|
| Modifier and Type | Method and Description |
|---|---|
abstract Certificate |
KeyStoreSpi.engineGetCertificate(String alias)
Returns the certificate associated with the given alias.
|
abstract Certificate[] |
KeyStoreSpi.engineGetCertificateChain(String alias)
Returns the certificate chain associated with the given alias.
|
Certificate |
KeyStore.getCertificate(String alias)
Returns the certificate associated with the given alias.
|
Certificate[] |
KeyStore.getCertificateChain(String alias)
Returns the certificate chain associated with the given alias.
|
Certificate[] |
CodeSource.getCertificates()
Returns the certificates associated with this CodeSource.
|
| Modifier and Type | Method and Description |
|---|---|
abstract String |
KeyStoreSpi.engineGetCertificateAlias(Certificate cert)
Returns the (alias) name of the first keystore entry whose certificate
matches the given certificate.
|
abstract void |
KeyStoreSpi.engineSetCertificateEntry(String alias,
Certificate cert)
Assigns the given certificate to the given alias.
|
abstract void |
KeyStoreSpi.engineSetKeyEntry(String alias,
byte[] key,
Certificate[] chain)
Assigns the given key (that has already been protected) to the given
alias.
|
abstract void |
KeyStoreSpi.engineSetKeyEntry(String alias,
Key key,
char[] password,
Certificate[] chain)
Assigns the given key to the given alias, protecting it with the given
password.
|
String |
KeyStore.getCertificateAlias(Certificate cert)
Returns the (alias) name of the first keystore entry whose certificate
matches the given certificate.
|
void |
Signature.initVerify(Certificate certificate)
Initializes this object for verification, using the public key from
the given certificate.
|
void |
KeyStore.setCertificateEntry(String alias,
Certificate cert)
Assigns the given certificate to the given alias.
|
void |
KeyStore.setKeyEntry(String alias,
byte[] key,
Certificate[] chain)
Assigns the given key (that has already been protected) to the given
alias.
|
void |
KeyStore.setKeyEntry(String alias,
Key key,
char[] password,
Certificate[] chain)
Assigns the given key to the given alias, protecting it with the given
password.
|
| Constructor and Description |
|---|
CodeSource(URL url,
Certificate[] certs)
Constructs a CodeSource and associates it with the specified
location and set of certificates.
|
UnresolvedPermission(String type,
String name,
String actions,
Certificate[] certs)
Creates a new UnresolvedPermission containing the permission
information needed later to actually create a Permission of the
specified class, when the permission is resolved.
|
| Modifier and Type | Class and Description |
|---|---|
class |
X509Certificate
Abstract class for X.509 certificates.
|
| Modifier and Type | Method and Description |
|---|---|
abstract Certificate |
CertificateFactorySpi.engineGenerateCertificate(InputStream inStream)
Generates a certificate object and initializes it with
the data read from the input stream
inStream. |
Certificate |
CertificateFactory.generateCertificate(InputStream inStream)
Generates a certificate object and initializes it with
the data read from the input stream
inStream. |
| Modifier and Type | Method and Description |
|---|---|
abstract boolean |
CRL.isRevoked(Certificate cert)
Checks whether the given certificate is on this CRL.
|
| Modifier and Type | Method and Description |
|---|---|
Certificate[] |
JarEntry.getCertificates()
Returns the
Certificate objects for this entry, or
null if none. |
| Modifier and Type | Method and Description |
|---|---|
Certificate[] |
SSLSession.getLocalCertificates()
Returns the certificate(s) that were sent to the peer during
handshaking.
|
abstract Certificate[] |
HttpsURLConnection.getLocalCertificates()
Returns the certificate(s) that were sent to the server during
handshaking.
|
Certificate[] |
HandshakeCompletedEvent.getLocalCertificates()
Returns the certificate(s) that were sent to the peer during
handshaking.
|
Certificate[] |
SSLSession.getPeerCertificates()
Returns the identity of the peer which was established as part
of defining the session.
|
Certificate[] |
HandshakeCompletedEvent.getPeerCertificates()
Returns the identity of the peer which was established as part
of defining the session.
|
abstract Certificate[] |
HttpsURLConnection.getServerCertificates()
Returns the server's certificate chain which was established
as part of defining the session.
|
| Modifier and Type | Method and Description |
|---|---|
abstract Certificate[][] |
PermissionInformation.getCertificates()
Returns the set of valid certificates that were used to sign the
application identified by the AppID returned by the getAppID() method.
|
| Modifier and Type | Method and Description |
|---|---|
abstract boolean |
PermissionInformation.isPrivilegedCertificate(Certificate cert)
Verifies that an end-entity certificate used to validate and application
or file is a member of the list of privileged certificates in the privileged
certificate descriptor.
|
Copyright © 2012. All Rights Reserved.