See: Description
| Interface | Description |
|---|---|
| X509Extension |
Interface for an X.509 extension.
|
| Class | Description |
|---|---|
| Certificate |
Abstract class for managing a variety of identity certificates.
|
| Certificate.CertificateRep |
Alternate Certificate class for serialization.
|
| CertificateFactory |
This class defines the functionality of a certificate factory, which is
used to generate certificate, certification path (
CertPath)
and certificate revocation list (CRL) objects from their encodings. |
| CertificateFactorySpi |
This class defines the Service Provider Interface (SPI)
for the
CertificateFactory class. |
| CertPath |
An immutable sequence of certificates (a certification path).
|
| CertPath.CertPathRep |
Alternate
CertPath class for serialization. |
| CRL |
This class is an abstraction of certificate revocation lists (CRLs) that
have different formats but important common uses.
|
| X509Certificate |
Abstract class for X.509 certificates.
|
| X509CRL |
Abstract class for an X.509 Certificate Revocation List (CRL).
|
| X509CRLEntry |
Abstract class for a revoked certificate in a CRL (Certificate
Revocation List).
|
| Exception | Description |
|---|---|
| CertificateEncodingException |
Certificate Encoding Exception.
|
| CertificateException |
This exception indicates one of a variety of certificate problems.
|
| CertificateExpiredException |
Certificate Expired Exception.
|
| CertificateNotYetValidException |
Certificate is not yet valid exception.
|
| CertificateParsingException |
Certificate Parsing Exception.
|
| CRLException |
CRL (Certificate Revocation List) Exception.
|
Copyright © 2013 CableLabs. All rights reserved.