| Package | Description |
|---|---|
| java.net |
Provides the classes for implementing networking applications.
|
| java.security |
Provides the classes and interfaces for the security framework.
|
| java.security.cert |
Provides classes and interfaces for parsing and managing
certificates, certificate revocation lists (CRLs), and
certification paths.
|
| java.util.jar |
Provides classes for reading and writing the JAR (Java ARchive) file
format, which is based on the standard ZIP file format with an
optional manifest file.
|
| javax.net.ssl |
Provides classes for the secure socket package.
|
| org.dvb.dsmcc |
Provides extended access to files carried in the broadcast
stream.
|
| org.ocap.application |
|
| Class and Description |
|---|
| Certificate
Abstract class for managing a variety of identity certificates.
|
| Class and Description |
|---|
| Certificate
Abstract class for managing a variety of identity certificates.
|
| CertificateException
This exception indicates one of a variety of certificate problems.
|
| Class and Description |
|---|
| Certificate
Abstract class for managing a variety of identity certificates.
|
| CertificateEncodingException
Certificate Encoding Exception.
|
| CertificateException
This exception indicates one of a variety of certificate problems.
|
| CertificateExpiredException
Certificate Expired Exception.
|
| CertificateFactory
This class defines the functionality of a certificate factory, which is
used to generate certificate, certification path (
CertPath)
and certificate revocation list (CRL) objects from their encodings. |
| CertificateFactorySpi
This class defines the Service Provider Interface (SPI)
for the
CertificateFactory class. |
| CertificateNotYetValidException
Certificate is not yet valid exception.
|
| CertificateParsingException
Certificate Parsing Exception.
|
| CertPath
An immutable sequence of certificates (a certification path).
|
| CRL
This class is an abstraction of certificate revocation lists (CRLs) that
have different formats but important common uses.
|
| CRLException
CRL (Certificate Revocation List) Exception.
|
| X509CRLEntry
Abstract class for a revoked certificate in a CRL (Certificate
Revocation List).
|
| X509Extension
Interface for an X.509 extension.
|
| Class and Description |
|---|
| Certificate
Abstract class for managing a variety of identity certificates.
|
| Class and Description |
|---|
| Certificate
Abstract class for managing a variety of identity certificates.
|
| CertificateException
This exception indicates one of a variety of certificate problems.
|
| X509Certificate
Abstract class for X.509 certificates.
|
| Class and Description |
|---|
| X509Certificate
Abstract class for X.509 certificates.
|
| Class and Description |
|---|
| Certificate
Abstract class for managing a variety of identity certificates.
|
Copyright © 2013 CableLabs. All rights reserved.