| Package | Description |
|---|---|
| java.security |
Provides the classes and interfaces for the security framework.
|
| Modifier and Type | Method and Description |
|---|---|
static void |
AccessController.checkPermission(Permission perm)
Determines whether the access request indicated by the
specified permission should be allowed or denied, based on
the security policy currently in effect.
|
void |
AccessControlContext.checkPermission(Permission perm)
Determines whether the access request indicated by the
specified permission should be allowed or denied, based on
the security policy currently in effect, and the context in
this object.
|
Copyright © 2013 CableLabs. All rights reserved.