| Package | Description |
|---|---|
| java.security |
Provides the classes and interfaces for the security framework.
|
| Modifier and Type | Method and Description |
|---|---|
static AlgorithmParameterGenerator |
AlgorithmParameterGenerator.getInstance(String algorithm)
Generates an AlgorithmParameterGenerator object that implements the
specified digest algorithm.
|
static AlgorithmParameterGenerator |
AlgorithmParameterGenerator.getInstance(String algorithm,
Provider provider)
Generates an AlgorithmParameterGenerator object for the requested
algorithm, as supplied from the specified provider,
if such a parameter generator is available from the provider.
|
static AlgorithmParameterGenerator |
AlgorithmParameterGenerator.getInstance(String algorithm,
String provider)
Generates an AlgorithmParameterGenerator object for the requested
algorithm, as supplied from the specified provider,
if such a parameter generator is available from the provider.
|
Copyright © 2013 CableLabs. All rights reserved.