| Package | Description |
|---|---|
| java.security |
Provides the classes and interfaces for the security framework.
|
| Modifier and Type | Method and Description |
|---|---|
protected abstract AlgorithmParameters |
AlgorithmParameterGeneratorSpi.engineGenerateParameters()
Generates the parameters.
|
protected AlgorithmParameters |
SignatureSpi.engineGetParameters()
This method is overridden by providers to return the
parameters used with this signature engine, or null
if this signature engine does not use any parameters.
|
AlgorithmParameters |
AlgorithmParameterGenerator.generateParameters()
Generates the parameters.
|
static AlgorithmParameters |
AlgorithmParameters.getInstance(String algorithm)
Generates a parameter object for the specified algorithm.
|
static AlgorithmParameters |
AlgorithmParameters.getInstance(String algorithm,
Provider provider)
Generates a parameter object for the specified algorithm, as supplied
by the specified provider, if such an algorithm is available from the
provider.
|
static AlgorithmParameters |
AlgorithmParameters.getInstance(String algorithm,
String provider)
Generates a parameter object for the specified algorithm, as supplied
by the specified provider, if such an algorithm is available from the
provider.
|
AlgorithmParameters |
Signature.getParameters()
Returns the parameters used with this signature object.
|
Copyright © 2013 CableLabs. All rights reserved.