| Package | Description |
|---|---|
| java.net |
Provides the classes for implementing networking applications.
|
| java.security |
Provides the classes and interfaces for the security framework.
|
| Modifier and Type | Method and Description |
|---|---|
protected PermissionCollection |
URLClassLoader.getPermissions(CodeSource codesource)
Returns the permissions for the given codesource object.
|
| Modifier and Type | Method and Description |
|---|---|
CodeSource |
ProtectionDomain.getCodeSource()
Returns the CodeSource of this domain.
|
| Modifier and Type | Method and Description |
|---|---|
protected Class |
SecureClassLoader.defineClass(String name,
byte[] b,
int off,
int len,
CodeSource cs)
Converts an array of bytes into an instance of class Class,
with an optional CodeSource.
|
protected PermissionCollection |
SecureClassLoader.getPermissions(CodeSource codesource)
Returns the permissions for the given CodeSource object.
|
abstract PermissionCollection |
Policy.getPermissions(CodeSource codesource)
Evaluates the global policy and returns a
PermissionCollection object specifying the set of
permissions allowed for code from the specified
code source.
|
boolean |
CodeSource.implies(CodeSource codesource)
Returns true if this CodeSource object "implies" the specified CodeSource.
|
| Constructor and Description |
|---|
ProtectionDomain(CodeSource codesource,
PermissionCollection permissions)
Creates a new ProtectionDomain with the given CodeSource and
Permissions.
|
ProtectionDomain(CodeSource codesource,
PermissionCollection permissions,
ClassLoader classloader,
Principal[] principals)
Creates a new ProtectionDomain qualified by the given CodeSource,
Permissions, ClassLoader and array of Principals.
|
Copyright © 2013 CableLabs. All rights reserved.