| Package | Description |
|---|---|
| java.security |
Provides the classes and interfaces for the security framework.
|
| java.security.cert |
Provides classes and interfaces for parsing and managing
certificates, certificate revocation lists (CRLs), and
certification paths.
|
| java.security.spec |
Provides classes and interfaces for key specifications and algorithm
parameter specifications.
|
| Modifier and Type | Class and Description |
|---|---|
class |
DigestException
This is the generic Message Digest exception.
|
class |
InvalidAlgorithmParameterException
This is the exception for invalid or inappropriate algorithm parameters.
|
class |
InvalidKeyException
This is the exception for invalid Keys (invalid encoding, wrong
length, uninitialized, etc).
|
class |
KeyException
This is the basic key exception.
|
class |
KeyManagementException
This is the general key management exception for all operations
dealing with key management.
|
class |
KeyStoreException
This is the generic KeyStore exception.
|
class |
NoSuchAlgorithmException
This exception is thrown when a particular cryptographic algorithm is
requested but is not available in the environment.
|
class |
NoSuchProviderException
This exception is thrown when a particular security provider is
requested but is not available in the environment.
|
class |
SignatureException
This is the generic Signature exception.
|
class |
UnrecoverableKeyException
This exception is thrown if a key in the keystore cannot be recovered.
|
| Modifier and Type | Class and Description |
|---|---|
class |
CertificateEncodingException
Certificate Encoding Exception.
|
class |
CertificateException
This exception indicates one of a variety of certificate problems.
|
class |
CertificateExpiredException
Certificate Expired Exception.
|
class |
CertificateNotYetValidException
Certificate is not yet valid exception.
|
class |
CertificateParsingException
Certificate Parsing Exception.
|
class |
CRLException
CRL (Certificate Revocation List) Exception.
|
| Modifier and Type | Class and Description |
|---|---|
class |
InvalidKeySpecException
This is the exception for invalid key specifications.
|
class |
InvalidParameterSpecException
This is the exception for invalid parameter specifications.
|
Copyright © 2013 CableLabs. All rights reserved.