| Package | Description |
|---|---|
| java.security |
Provides the classes and interfaces for the security framework.
|
| javax.net.ssl |
Provides classes for the secure socket package.
|
| Modifier and Type | Method and Description |
|---|---|
protected abstract void |
AlgorithmParameterGeneratorSpi.engineInit(AlgorithmParameterSpec genParamSpec,
SecureRandom random)
Initializes this parameter generator with a set of
algorithm-specific parameter generation values.
|
protected void |
SignatureSpi.engineSetParameter(AlgorithmParameterSpec params)
This method is overridden by providers to initialize
this signature engine with the specified parameter set.
|
void |
AlgorithmParameterGenerator.init(AlgorithmParameterSpec genParamSpec)
Initializes this parameter generator with a set of algorithm-specific
parameter generation values.
|
void |
AlgorithmParameterGenerator.init(AlgorithmParameterSpec genParamSpec,
SecureRandom random)
Initializes this parameter generator with a set of algorithm-specific
parameter generation values.
|
void |
KeyPairGenerator.initialize(AlgorithmParameterSpec params)
Initializes the key pair generator using the specified parameter
set and the
SecureRandom
implementation of the highest-priority installed provider as the source
of randomness. |
void |
KeyPairGeneratorSpi.initialize(AlgorithmParameterSpec params,
SecureRandom random)
Initializes the key pair generator using the specified parameter
set and user-provided source of randomness.
|
void |
KeyPairGenerator.initialize(AlgorithmParameterSpec params,
SecureRandom random)
Initializes the key pair generator with the given parameter
set and source of randomness.
|
void |
Signature.setParameter(AlgorithmParameterSpec params)
Initializes this signature engine with the specified parameter set.
|
| Modifier and Type | Method and Description |
|---|---|
protected abstract void |
TrustManagerFactorySpi.engineInit(ManagerFactoryParameters spec)
Initializes this factory with a source of provider-specific
key material.
|
protected abstract void |
KeyManagerFactorySpi.engineInit(ManagerFactoryParameters spec)
Initializes this factory with a source of key material.
|
void |
TrustManagerFactory.init(ManagerFactoryParameters spec)
Initializes this factory with a source of provider-specific
trust material.
|
void |
KeyManagerFactory.init(ManagerFactoryParameters spec)
Initializes this factory with a source of provider-specific
key material.
|
Copyright © 2013 CableLabs. All rights reserved.