| Package | Description |
|---|---|
| java.security |
Provides the classes and interfaces for the security framework.
|
| java.security.cert |
Provides classes and interfaces for parsing and managing
certificates, certificate revocation lists (CRLs), and
certification paths.
|
| javax.security.cert |
Provides classes for public key certificates.
|
| Modifier and Type | Method and Description |
|---|---|
protected abstract void |
SignatureSpi.engineInitSign(PrivateKey privateKey)
Initializes this signature object with the specified
private key for signing operations.
|
protected void |
SignatureSpi.engineInitSign(PrivateKey privateKey,
SecureRandom random)
Initializes this signature object with the specified
private key and source of randomness for signing operations.
|
protected abstract void |
SignatureSpi.engineInitVerify(PublicKey publicKey)
Initializes this signature object with the specified
public key for verification operations.
|
protected abstract Key |
KeyFactorySpi.engineTranslateKey(Key key)
Translates a key object, whose provider may be unknown or
potentially untrusted, into a corresponding key object of this key
factory.
|
void |
Signature.initSign(PrivateKey privateKey)
Initialize this object for signing.
|
void |
Signature.initSign(PrivateKey privateKey,
SecureRandom random)
Initialize this object for signing.
|
void |
Signature.initVerify(Certificate certificate)
Initializes this object for verification, using the public key from
the given certificate.
|
void |
Signature.initVerify(PublicKey publicKey)
Initializes this object for verification.
|
Key |
KeyFactory.translateKey(Key key)
Translates a key object, whose provider may be unknown or potentially
untrusted, into a corresponding key object of this key factory.
|
boolean |
SignedObject.verify(PublicKey verificationKey,
Signature verificationEngine)
Verifies that the signature in this SignedObject is the valid
signature for the object stored inside, with the given
verification key, using the designated verification engine.
|
| Constructor and Description |
|---|
SignedObject(Serializable object,
PrivateKey signingKey,
Signature signingEngine)
Constructs a SignedObject from any Serializable object.
|
| Modifier and Type | Method and Description |
|---|---|
abstract void |
X509CRL.verify(PublicKey key)
Verifies that this CRL was signed using the
private key that corresponds to the given public key.
|
abstract void |
Certificate.verify(PublicKey key)
Verifies that this certificate was signed using the
private key that corresponds to the specified public key.
|
abstract void |
X509CRL.verify(PublicKey key,
String sigProvider)
Verifies that this CRL was signed using the
private key that corresponds to the given public key.
|
abstract void |
Certificate.verify(PublicKey key,
String sigProvider)
Verifies that this certificate was signed using the
private key that corresponds to the specified public key.
|
| Modifier and Type | Method and Description |
|---|---|
abstract void |
Certificate.verify(PublicKey key)
Verifies that this certificate was signed using the
private key that corresponds to the specified public key.
|
abstract void |
Certificate.verify(PublicKey key,
String sigProvider)
Verifies that this certificate was signed using the
private key that corresponds to the specified public key.
|
Copyright © 2013 CableLabs. All rights reserved.