| Package | Description |
|---|---|
| java.security |
Provides the classes and interfaces for the security framework.
|
| java.security.interfaces |
Provides interfaces for generating RSA (Rivest, Shamir and
Adleman AsymmetricCipher algorithm)
keys as defined in the RSA Laboratory Technical Note
PKCS#1, and DSA (Digital Signature
Algorithm) keys as defined in NIST's FIPS-186.
|
| Modifier and Type | Method and Description |
|---|---|
void |
Signer.setKeyPair(KeyPair pair)
Deprecated.
Sets the key pair (public key and private key) for this signer.
|
| Modifier and Type | Method and Description |
|---|---|
void |
DSAKeyPairGenerator.initialize(DSAParams params,
SecureRandom random)
Initializes the key pair generator using p, q and g, the DSA
family parameters.
|
void |
DSAKeyPairGenerator.initialize(int modlen,
boolean genParams,
SecureRandom random)
Initializes the key pair generator for a given modulus length,
without parameters.
|
Copyright © 2013 CableLabs. All rights reserved.