| Package | Description |
|---|---|
| java.security |
Provides the classes and interfaces for the security framework.
|
| java.security.interfaces |
Provides interfaces for generating RSA (Rivest, Shamir and
Adleman AsymmetricCipher algorithm)
keys as defined in the RSA Laboratory Technical Note
PKCS#1, and DSA (Digital Signature
Algorithm) keys as defined in NIST's FIPS-186.
|
| Modifier and Type | Interface and Description |
|---|---|
interface |
PrivateKey
A private key.
|
interface |
PublicKey
A public key.
|
| Modifier and Type | Method and Description |
|---|---|
abstract Key |
KeyStoreSpi.engineGetKey(String alias,
char[] password)
Returns the key associated with the given alias, using the given
password to recover it.
|
protected abstract Key |
KeyFactorySpi.engineTranslateKey(Key key)
Translates a key object, whose provider may be unknown or
potentially untrusted, into a corresponding key object of this key
factory.
|
Key |
KeyStore.getKey(String alias,
char[] password)
Returns the key associated with the given alias, using the given
password to recover it.
|
Key |
KeyFactory.translateKey(Key key)
Translates a key object, whose provider may be unknown or potentially
untrusted, into a corresponding key object of this key factory.
|
| Modifier and Type | Method and Description |
|---|---|
protected abstract KeySpec |
KeyFactorySpi.engineGetKeySpec(Key key,
Class keySpec)
Returns a specification (key material) of the given key
object.
|
abstract void |
KeyStoreSpi.engineSetKeyEntry(String alias,
Key key,
char[] password,
Certificate[] chain)
Assigns the given key to the given alias, protecting it with the given
password.
|
protected abstract Key |
KeyFactorySpi.engineTranslateKey(Key key)
Translates a key object, whose provider may be unknown or
potentially untrusted, into a corresponding key object of this key
factory.
|
KeySpec |
KeyFactory.getKeySpec(Key key,
Class keySpec)
Returns a specification (key material) of the given key object.
|
void |
KeyStore.setKeyEntry(String alias,
Key key,
char[] password,
Certificate[] chain)
Assigns the given key to the given alias, protecting it with the given
password.
|
Key |
KeyFactory.translateKey(Key key)
Translates a key object, whose provider may be unknown or potentially
untrusted, into a corresponding key object of this key factory.
|
| Modifier and Type | Interface and Description |
|---|---|
interface |
DSAPrivateKey
The standard interface to a DSA private key.
|
interface |
DSAPublicKey
The interface to a DSA public key.
|
interface |
RSAPrivateCrtKey
The interface to an RSA private key, as defined in the PKCS#1 standard,
using the Chinese Remainder Theorem (CRT) information values.
|
interface |
RSAPrivateKey
The interface to an RSA private key.
|
interface |
RSAPublicKey
The interface to an RSA public key.
|
Copyright © 2013 CableLabs. All rights reserved.