| Package | Description |
|---|---|
| java.security |
Provides the classes and interfaces for the security framework.
|
| Modifier and Type | Class and Description |
|---|---|
class |
InvalidKeyException
This is the exception for invalid Keys (invalid encoding, wrong
length, uninitialized, etc).
|
class |
KeyManagementException
This is the general key management exception for all operations
dealing with key management.
|
| Modifier and Type | Method and Description |
|---|---|
void |
Certificate.decode(InputStream stream)
Deprecated.
Decodes a certificate from an input stream.
|
void |
Certificate.encode(OutputStream stream)
Deprecated.
Encodes the certificate to an output stream in a format that can
be decoded by the
decode method. |
void |
Signer.setKeyPair(KeyPair pair)
Deprecated.
Sets the key pair (public key and private key) for this signer.
|
Copyright © 2013 CableLabs. All rights reserved.