| Package | Description |
|---|---|
| java.security |
Provides the classes and interfaces for the security framework.
|
| Modifier and Type | Method and Description |
|---|---|
static KeyPairGenerator |
KeyPairGenerator.getInstance(String algorithm)
Generates a KeyPairGenerator object that implements the specified digest
algorithm.
|
static KeyPairGenerator |
KeyPairGenerator.getInstance(String algorithm,
Provider provider)
Generates a KeyPairGenerator object implementing the specified
algorithm, as supplied from the specified provider,
if such an algorithm is available from the provider.
|
static KeyPairGenerator |
KeyPairGenerator.getInstance(String algorithm,
String provider)
Generates a KeyPairGenerator object implementing the specified
algorithm, as supplied from the specified provider,
if such an algorithm is available from the provider.
|
Copyright © 2012 CableLabs. All Rights Reserved.