| Package | Description |
|---|---|
| java.security |
Provides the classes and interfaces for the security framework.
|
| javax.net.ssl |
Provides classes for the secure socket package.
|
| Modifier and Type | Method and Description |
|---|---|
static KeyStore |
KeyStore.getInstance(String type)
Generates a keystore object of the given type.
|
static KeyStore |
KeyStore.getInstance(String type,
Provider provider)
Generates a keystore object for the specified keystore
type from the specified provider.
|
static KeyStore |
KeyStore.getInstance(String type,
String provider)
Generates a keystore object for the specified keystore
type from the specified provider.
|
| Modifier and Type | Method and Description |
|---|---|
protected abstract void |
TrustManagerFactorySpi.engineInit(KeyStore ks)
Initializes this factory with a source of certificate
authorities and related trust material.
|
protected abstract void |
KeyManagerFactorySpi.engineInit(KeyStore ks,
char[] password)
Initializes this factory with a source of key material.
|
void |
TrustManagerFactory.init(KeyStore ks)
Initializes this factory with a source of certificate
authorities and related trust material.
|
void |
KeyManagerFactory.init(KeyStore ks,
char[] password)
Initializes this factory with a source of key material.
|
Copyright © 2013 CableLabs. All rights reserved.