| Package | Description |
|---|---|
| java.security |
Provides the classes and interfaces for the security framework.
|
| javax.net.ssl |
Provides classes for the secure socket package.
|
| Modifier and Type | Method and Description |
|---|---|
Enumeration |
KeyStore.aliases()
Lists all the alias names of this keystore.
|
boolean |
KeyStore.containsAlias(String alias)
Checks if the given alias exists in this keystore.
|
void |
KeyStore.deleteEntry(String alias)
Deletes the entry identified by the given alias from this keystore.
|
abstract void |
KeyStoreSpi.engineDeleteEntry(String alias)
Deletes the entry identified by the given alias from this keystore.
|
abstract void |
KeyStoreSpi.engineSetCertificateEntry(String alias,
Certificate cert)
Assigns the given certificate to the given alias.
|
abstract void |
KeyStoreSpi.engineSetKeyEntry(String alias,
byte[] key,
Certificate[] chain)
Assigns the given key (that has already been protected) to the given
alias.
|
abstract void |
KeyStoreSpi.engineSetKeyEntry(String alias,
Key key,
char[] password,
Certificate[] chain)
Assigns the given key to the given alias, protecting it with the given
password.
|
Certificate |
KeyStore.getCertificate(String alias)
Returns the certificate associated with the given alias.
|
String |
KeyStore.getCertificateAlias(Certificate cert)
Returns the (alias) name of the first keystore entry whose certificate
matches the given certificate.
|
Certificate[] |
KeyStore.getCertificateChain(String alias)
Returns the certificate chain associated with the given alias.
|
Date |
KeyStore.getCreationDate(String alias)
Returns the creation date of the entry identified by the given alias.
|
static KeyStore |
KeyStore.getInstance(String type)
Generates a keystore object of the given type.
|
static KeyStore |
KeyStore.getInstance(String type,
Provider provider)
Generates a keystore object for the specified keystore
type from the specified provider.
|
static KeyStore |
KeyStore.getInstance(String type,
String provider)
Generates a keystore object for the specified keystore
type from the specified provider.
|
Key |
KeyStore.getKey(String alias,
char[] password)
Returns the key associated with the given alias, using the given
password to recover it.
|
boolean |
KeyStore.isCertificateEntry(String alias)
Returns true if the entry identified by the given alias is a
trusted certificate entry, and false otherwise.
|
boolean |
KeyStore.isKeyEntry(String alias)
Returns true if the entry identified by the given alias is a
key entry, and false otherwise.
|
void |
KeyStore.setCertificateEntry(String alias,
Certificate cert)
Assigns the given certificate to the given alias.
|
void |
KeyStore.setKeyEntry(String alias,
byte[] key,
Certificate[] chain)
Assigns the given key (that has already been protected) to the given
alias.
|
void |
KeyStore.setKeyEntry(String alias,
Key key,
char[] password,
Certificate[] chain)
Assigns the given key to the given alias, protecting it with the given
password.
|
int |
KeyStore.size()
Retrieves the number of entries in this keystore.
|
void |
KeyStore.store(OutputStream stream,
char[] password)
Stores this keystore to the given output stream, and protects its
integrity with the given password.
|
| Modifier and Type | Method and Description |
|---|---|
protected abstract void |
TrustManagerFactorySpi.engineInit(KeyStore ks)
Initializes this factory with a source of certificate
authorities and related trust material.
|
protected abstract void |
KeyManagerFactorySpi.engineInit(KeyStore ks,
char[] password)
Initializes this factory with a source of key material.
|
void |
TrustManagerFactory.init(KeyStore ks)
Initializes this factory with a source of certificate
authorities and related trust material.
|
void |
KeyManagerFactory.init(KeyStore ks,
char[] password)
Initializes this factory with a source of key material.
|
Copyright © 2013 CableLabs. All rights reserved.