| Package | Description |
|---|---|
| java.security |
Provides the classes and interfaces for the security framework.
|
| Constructor and Description |
|---|
KeyStore(KeyStoreSpi keyStoreSpi,
Provider provider,
String type)
Creates a KeyStore object of the given type, and encapsulates the given
provider implementation (SPI object) in it.
|
Copyright © 2013 CableLabs. All rights reserved.