| Package | Description |
|---|---|
| java.security |
Provides the classes and interfaces for the security framework.
|
| java.security.cert |
Provides classes and interfaces for parsing and managing
certificates, certificate revocation lists (CRLs), and
certification paths.
|
| javax.net.ssl |
Provides classes for the secure socket package.
|
| javax.security.cert |
Provides classes for public key certificates.
|
| Modifier and Type | Method and Description |
|---|---|
abstract Key |
KeyStoreSpi.engineGetKey(String alias,
char[] password)
Returns the key associated with the given alias, using the given
password to recover it.
|
abstract void |
KeyStoreSpi.engineLoad(InputStream stream,
char[] password)
Loads the keystore from the given input stream.
|
abstract void |
KeyStoreSpi.engineStore(OutputStream stream,
char[] password)
Stores this keystore to the given output stream, and protects its
integrity with the given password.
|
static Signature |
Signature.getInstance(String algorithm)
Generates a Signature object that implements the specified digest
algorithm.
|
static SecureRandom |
SecureRandom.getInstance(String algorithm)
Generates a SecureRandom object that implements the specified
Pseudo Random Number Generator (PRNG) algorithm.
|
static MessageDigest |
MessageDigest.getInstance(String algorithm)
Generates a MessageDigest object that implements the specified digest
algorithm.
|
static KeyPairGenerator |
KeyPairGenerator.getInstance(String algorithm)
Generates a KeyPairGenerator object that implements the specified digest
algorithm.
|
static KeyFactory |
KeyFactory.getInstance(String algorithm)
Generates a KeyFactory object that implements the specified
algorithm.
|
static AlgorithmParameters |
AlgorithmParameters.getInstance(String algorithm)
Generates a parameter object for the specified algorithm.
|
static AlgorithmParameterGenerator |
AlgorithmParameterGenerator.getInstance(String algorithm)
Generates an AlgorithmParameterGenerator object that implements the
specified digest algorithm.
|
static Signature |
Signature.getInstance(String algorithm,
Provider provider)
Generates a Signature object implementing the specified
algorithm, as supplied from the specified provider, if such an
algorithm is available from the provider.
|
static SecureRandom |
SecureRandom.getInstance(String algorithm,
Provider provider)
Generates a SecureRandom object for the specified PRNG
algorithm, as supplied from the specified provider, if such a
PRNG implementation is available from the provider.
|
static MessageDigest |
MessageDigest.getInstance(String algorithm,
Provider provider)
Generates a MessageDigest object implementing the specified
algorithm, as supplied from the specified provider, if such an
algorithm is available from the provider.
|
static KeyPairGenerator |
KeyPairGenerator.getInstance(String algorithm,
Provider provider)
Generates a KeyPairGenerator object implementing the specified
algorithm, as supplied from the specified provider,
if such an algorithm is available from the provider.
|
static KeyFactory |
KeyFactory.getInstance(String algorithm,
Provider provider)
Generates a KeyFactory object for the specified algorithm from the
specified provider.
|
static AlgorithmParameters |
AlgorithmParameters.getInstance(String algorithm,
Provider provider)
Generates a parameter object for the specified algorithm, as supplied
by the specified provider, if such an algorithm is available from the
provider.
|
static AlgorithmParameterGenerator |
AlgorithmParameterGenerator.getInstance(String algorithm,
Provider provider)
Generates an AlgorithmParameterGenerator object for the requested
algorithm, as supplied from the specified provider,
if such a parameter generator is available from the provider.
|
static Signature |
Signature.getInstance(String algorithm,
String provider)
Generates a Signature object implementing the specified
algorithm, as supplied from the specified provider, if such an
algorithm is available from the provider.
|
static SecureRandom |
SecureRandom.getInstance(String algorithm,
String provider)
Generates a SecureRandom object for the specified PRNG
algorithm, as supplied from the specified provider, if such a
PRNG implementation is available from the provider.
|
static MessageDigest |
MessageDigest.getInstance(String algorithm,
String provider)
Generates a MessageDigest object implementing the specified
algorithm, as supplied from the specified provider, if such an
algorithm is available from the provider.
|
static KeyPairGenerator |
KeyPairGenerator.getInstance(String algorithm,
String provider)
Generates a KeyPairGenerator object implementing the specified
algorithm, as supplied from the specified provider,
if such an algorithm is available from the provider.
|
static KeyFactory |
KeyFactory.getInstance(String algorithm,
String provider)
Generates a KeyFactory object for the specified algorithm from the
specified provider.
|
static AlgorithmParameters |
AlgorithmParameters.getInstance(String algorithm,
String provider)
Generates a parameter object for the specified algorithm, as supplied
by the specified provider, if such an algorithm is available from the
provider.
|
static AlgorithmParameterGenerator |
AlgorithmParameterGenerator.getInstance(String algorithm,
String provider)
Generates an AlgorithmParameterGenerator object for the requested
algorithm, as supplied from the specified provider,
if such a parameter generator is available from the provider.
|
Key |
KeyStore.getKey(String alias,
char[] password)
Returns the key associated with the given alias, using the given
password to recover it.
|
void |
KeyStore.load(InputStream stream,
char[] password)
Loads this KeyStore from the given input stream.
|
void |
KeyStore.store(OutputStream stream,
char[] password)
Stores this keystore to the given output stream, and protects its
integrity with the given password.
|
| Modifier and Type | Method and Description |
|---|---|
abstract void |
X509CRL.verify(PublicKey key)
Verifies that this CRL was signed using the
private key that corresponds to the given public key.
|
abstract void |
Certificate.verify(PublicKey key)
Verifies that this certificate was signed using the
private key that corresponds to the specified public key.
|
abstract void |
X509CRL.verify(PublicKey key,
String sigProvider)
Verifies that this CRL was signed using the
private key that corresponds to the given public key.
|
abstract void |
Certificate.verify(PublicKey key,
String sigProvider)
Verifies that this certificate was signed using the
private key that corresponds to the specified public key.
|
| Modifier and Type | Method and Description |
|---|---|
protected abstract void |
KeyManagerFactorySpi.engineInit(KeyStore ks,
char[] password)
Initializes this factory with a source of key material.
|
static TrustManagerFactory |
TrustManagerFactory.getInstance(String algorithm)
Generates a
TrustManagerFactory object that implements the
specified trust management algorithm. |
static SSLContext |
SSLContext.getInstance(String protocol)
Generates a
SSLContext object that implements the
specified secure socket protocol. |
static KeyManagerFactory |
KeyManagerFactory.getInstance(String algorithm)
Generates a
KeyManagerFactory object that implements the
specified key management algorithm. |
static TrustManagerFactory |
TrustManagerFactory.getInstance(String algorithm,
Provider provider)
Generates a
TrustManagerFactory object for the specified
trust management algorithm from the specified provider. |
static SSLContext |
SSLContext.getInstance(String protocol,
Provider provider)
Generates a
SSLContext object that implements the
specified secure socket protocol from the specified provider. |
static KeyManagerFactory |
KeyManagerFactory.getInstance(String algorithm,
Provider provider)
Generates a
KeyManagerFactory object for the specified
key management algorithm from the specified provider. |
static TrustManagerFactory |
TrustManagerFactory.getInstance(String algorithm,
String provider)
Generates a
TrustManagerFactory object for the specified
trust management algorithm from the specified provider. |
static SSLContext |
SSLContext.getInstance(String protocol,
String provider)
Generates a
SSLContext object that implements the
specified secure socket protocol from the specified provider. |
static KeyManagerFactory |
KeyManagerFactory.getInstance(String algorithm,
String provider)
Generates a
KeyManagerFactory object for the specified
key management algorithm from the specified provider. |
void |
KeyManagerFactory.init(KeyStore ks,
char[] password)
Initializes this factory with a source of key material.
|
| Modifier and Type | Method and Description |
|---|---|
abstract void |
Certificate.verify(PublicKey key)
Verifies that this certificate was signed using the
private key that corresponds to the specified public key.
|
abstract void |
Certificate.verify(PublicKey key,
String sigProvider)
Verifies that this certificate was signed using the
private key that corresponds to the specified public key.
|
Copyright © 2013 CableLabs. All rights reserved.