| Package | Description |
|---|---|
| java.security |
Provides the classes and interfaces for the security framework.
|
| java.security.cert |
Provides classes and interfaces for parsing and managing
certificates, certificate revocation lists (CRLs), and
certification paths.
|
| javax.net.ssl |
Provides classes for the secure socket package.
|
| javax.security.cert |
Provides classes for public key certificates.
|
| Modifier and Type | Method and Description |
|---|---|
static Signature |
Signature.getInstance(String algorithm,
String provider)
Generates a Signature object implementing the specified
algorithm, as supplied from the specified provider, if such an
algorithm is available from the provider.
|
static SecureRandom |
SecureRandom.getInstance(String algorithm,
String provider)
Generates a SecureRandom object for the specified PRNG
algorithm, as supplied from the specified provider, if such a
PRNG implementation is available from the provider.
|
static MessageDigest |
MessageDigest.getInstance(String algorithm,
String provider)
Generates a MessageDigest object implementing the specified
algorithm, as supplied from the specified provider, if such an
algorithm is available from the provider.
|
static KeyStore |
KeyStore.getInstance(String type,
String provider)
Generates a keystore object for the specified keystore
type from the specified provider.
|
static KeyPairGenerator |
KeyPairGenerator.getInstance(String algorithm,
String provider)
Generates a KeyPairGenerator object implementing the specified
algorithm, as supplied from the specified provider,
if such an algorithm is available from the provider.
|
static KeyFactory |
KeyFactory.getInstance(String algorithm,
String provider)
Generates a KeyFactory object for the specified algorithm from the
specified provider.
|
static AlgorithmParameters |
AlgorithmParameters.getInstance(String algorithm,
String provider)
Generates a parameter object for the specified algorithm, as supplied
by the specified provider, if such an algorithm is available from the
provider.
|
static AlgorithmParameterGenerator |
AlgorithmParameterGenerator.getInstance(String algorithm,
String provider)
Generates an AlgorithmParameterGenerator object for the requested
algorithm, as supplied from the specified provider,
if such a parameter generator is available from the provider.
|
| Modifier and Type | Method and Description |
|---|---|
static CertificateFactory |
CertificateFactory.getInstance(String type,
String provider)
Generates a certificate factory object for the specified
certificate type from the specified provider.
|
abstract void |
X509CRL.verify(PublicKey key)
Verifies that this CRL was signed using the
private key that corresponds to the given public key.
|
abstract void |
Certificate.verify(PublicKey key)
Verifies that this certificate was signed using the
private key that corresponds to the specified public key.
|
abstract void |
X509CRL.verify(PublicKey key,
String sigProvider)
Verifies that this CRL was signed using the
private key that corresponds to the given public key.
|
abstract void |
Certificate.verify(PublicKey key,
String sigProvider)
Verifies that this certificate was signed using the
private key that corresponds to the specified public key.
|
| Modifier and Type | Method and Description |
|---|---|
static TrustManagerFactory |
TrustManagerFactory.getInstance(String algorithm,
String provider)
Generates a
TrustManagerFactory object for the specified
trust management algorithm from the specified provider. |
static SSLContext |
SSLContext.getInstance(String protocol,
String provider)
Generates a
SSLContext object that implements the
specified secure socket protocol from the specified provider. |
static KeyManagerFactory |
KeyManagerFactory.getInstance(String algorithm,
String provider)
Generates a
KeyManagerFactory object for the specified
key management algorithm from the specified provider. |
| Modifier and Type | Method and Description |
|---|---|
abstract void |
Certificate.verify(PublicKey key)
Verifies that this certificate was signed using the
private key that corresponds to the specified public key.
|
abstract void |
Certificate.verify(PublicKey key,
String sigProvider)
Verifies that this certificate was signed using the
private key that corresponds to the specified public key.
|
Copyright © 2012 CableLabs. All Rights Reserved.