| Package | Description |
|---|---|
| java.awt |
Contains all of the classes for creating user
interfaces and for painting graphics and images.
|
| java.io |
Provides for system input and output through data streams,
serialization and the file system.
|
| java.lang |
Provides classes that are fundamental to the design of the Java
programming language.
|
| java.lang.reflect |
Provides classes and interfaces for obtaining reflective
information about classes and objects.
|
| java.net |
Provides the classes for implementing networking applications.
|
| java.security |
Provides the classes and interfaces for the security framework.
|
| java.util |
Contains the collections framework, legacy collection classes, event model,
date and time facilities, internationalization, and miscellaneous utility
classes (a string tokenizer, a random-number generator, and a bit array).
|
| javax.microedition.xlet.ixc |
Provides facilities for inter-Xlet communication (IXC).
|
| javax.net.ssl |
Provides classes for the secure socket package.
|
| javax.tv.media |
Provides controls and events for the management of real-time media
in a television environment.
|
| javax.tv.service |
Provides mechanisms for accessing the service information (SI) database
and APIs representing the SI elements it contains.
|
| javax.tv.service.selection |
Provides a mechanism to select a Service for
presentation.
|
| org.dvb.application |
Provides access to lists of applications which are available
in this context and the ability to launch those applications.
|
| org.dvb.media |
Provides DVB specific extensions to the Java Media Framework.
|
| org.dvb.net.rc |
Provides session management for bi-directional IP connections
which are session based from the point of view of an application.
|
| org.dvb.net.tuning |
Provides extensions to the tuning API from DAVIC.
|
| org.dvb.spi |
This package defines a central registry for all DVB Service Provider Interface
(SPI) providers.
|
| org.dvb.user |
Provides access to settings and preferences configured by the end-user.
|
| org.ocap.application |
|
| org.ocap.hn |
Provides representation of the main components of HN, such as servers, actions, action responses, and change listeners.
|
| org.ocap.service |
The org.ocap.service package represents various aspects of a service.
|
| org.ocap.shared.dvr |
The shared DVR API for scheduling and managing recording requests.
|
| org.ocap.system |
This API is used to access
system modules. |
| Modifier and Type | Class and Description |
|---|---|
class |
AWTPermission
This class is for AWT permissions.
|
| Modifier and Type | Class and Description |
|---|---|
class |
FilePermission
This class represents access to a file or directory.
|
class |
SerializablePermission
This class is for Serializable permissions.
|
| Modifier and Type | Method and Description |
|---|---|
boolean |
FilePermission.implies(Permission p)
Checks if this FilePermission object "implies" the specified permission.
|
| Modifier and Type | Class and Description |
|---|---|
class |
RuntimePermission
This class is for runtime permissions.
|
| Modifier and Type | Method and Description |
|---|---|
void |
SecurityManager.checkPermission(Permission perm)
Throws a
SecurityException if the requested
access, specified by the given permission, is not permitted based
on the security policy currently in effect. |
void |
SecurityManager.checkPermission(Permission perm,
Object context)
Throws a
SecurityException if the
specified security context is denied access to the resource
specified by the given permission. |
| Modifier and Type | Class and Description |
|---|---|
class |
ReflectPermission
The Permission class for reflective operations.
|
| Modifier and Type | Class and Description |
|---|---|
class |
NetPermission
This class is for various network permissions.
|
class |
SocketPermission
This class represents access to a network via sockets.
|
| Modifier and Type | Method and Description |
|---|---|
Permission |
URLConnection.getPermission()
Returns a permission object representing the permission
necessary to make the connection represented by this
object.
|
Permission |
HttpURLConnection.getPermission() |
| Modifier and Type | Method and Description |
|---|---|
boolean |
SocketPermission.implies(Permission p)
Checks if this socket permission object "implies" the
specified permission.
|
| Modifier and Type | Class and Description |
|---|---|
class |
AllPermission
The AllPermission is a permission that implies all other permissions.
|
class |
BasicPermission
The BasicPermission class extends the Permission class, and
can be used as the base class for permissions that want to
follow the same naming convention as BasicPermission.
|
class |
SecurityPermission
This class is for security permissions.
|
class |
UnresolvedPermission
The UnresolvedPermission class is used to hold Permissions that
were "unresolved" when the Policy was initialized.
|
| Modifier and Type | Method and Description |
|---|---|
Permission |
AccessControlException.getPermission()
Gets the Permission object associated with this exeception, or
null if there was no corresponding Permission object.
|
| Modifier and Type | Method and Description |
|---|---|
void |
Permissions.add(Permission permission)
Adds a permission object to the PermissionCollection for the class the
permission belongs to.
|
abstract void |
PermissionCollection.add(Permission permission)
Adds a permission object to the current collection of permission objects.
|
static void |
AccessController.checkPermission(Permission perm)
Determines whether the access request indicated by the
specified permission should be allowed or denied, based on
the security policy currently in effect.
|
void |
AccessControlContext.checkPermission(Permission perm)
Determines whether the access request indicated by the
specified permission should be allowed or denied, based on
the security policy currently in effect, and the context in
this object.
|
boolean |
UnresolvedPermission.implies(Permission p)
This method always returns false for unresolved permissions.
|
boolean |
ProtectionDomain.implies(Permission permission)
Check and see if this ProtectionDomain implies the permissions
expressed in the Permission object.
|
boolean |
Permissions.implies(Permission permission)
Checks to see if this object's PermissionCollection for permissions of
the specified permission's type implies the permissions
expressed in the permission object.
|
abstract boolean |
PermissionCollection.implies(Permission permission)
Checks to see if the specified permission is implied by
the collection of Permission objects held in this PermissionCollection.
|
abstract boolean |
Permission.implies(Permission permission)
Checks if the specified permission's actions are "implied by"
this object's actions.
|
boolean |
BasicPermission.implies(Permission p)
Checks if the specified permission is "implied" by
this object.
|
boolean |
AllPermission.implies(Permission p)
Checks if the specified permission is "implied" by
this object.
|
boolean |
Policy.implies(ProtectionDomain domain,
Permission permission)
Evaluates the global policy for the permissions granted to
the ProtectionDomain and tests whether the permission is
granted.
|
| Constructor and Description |
|---|
AccessControlException(String s,
Permission p)
Constructs an
AccessControlException with the
specified, detailed message, and the requested permission that caused
the exception. |
| Modifier and Type | Class and Description |
|---|---|
class |
PropertyPermission
This class is for property permissions.
|
| Modifier and Type | Method and Description |
|---|---|
boolean |
PropertyPermission.implies(Permission p)
Checks if this PropertyPermission object "implies" the specified
permission.
|
| Modifier and Type | Class and Description |
|---|---|
class |
IxcPermission
This class represents access to the inter-xlet communication registry.
|
| Modifier and Type | Method and Description |
|---|---|
boolean |
IxcPermission.implies(Permission p)
Checks if this IxcPermission "implies" the specified permission.
|
| Modifier and Type | Class and Description |
|---|---|
class |
SSLPermission
This class is for various network permissions.
|
| Modifier and Type | Class and Description |
|---|---|
class |
MediaSelectPermission
This class represents permission to select, via a
MediaSelectControl, the content that a JMF Player
presents. |
| Modifier and Type | Method and Description |
|---|---|
boolean |
MediaSelectPermission.implies(Permission p)
Checks if this
MediaSelectPermission "implies" the
specified Permission. |
| Modifier and Type | Class and Description |
|---|---|
class |
ReadPermission
This class represents permission to read the data referenced by a given
Locator. |
| Modifier and Type | Method and Description |
|---|---|
boolean |
ReadPermission.implies(Permission p)
Checks if this ReadPermission object "implies" the specified
permission.
|
| Modifier and Type | Class and Description |
|---|---|
class |
SelectPermission
SelectPermission represents permission to perform a
select() operation on a ServiceContext. |
class |
ServiceContextPermission
ServiceContextPermission represents permission to
control a ServiceContext. |
| Modifier and Type | Method and Description |
|---|---|
boolean |
ServiceContextPermission.implies(Permission p)
Checks if the specified permission is "implied" by this object.
|
boolean |
SelectPermission.implies(Permission p)
Checks if this SelectPermission object "implies" the specified
permission.
|
| Modifier and Type | Class and Description |
|---|---|
class |
AppsControlPermission
This class represents a Permission to control the lifecycle
of another application.
|
| Modifier and Type | Method and Description |
|---|---|
boolean |
AppsControlPermission.implies(Permission permission)
Checks if this AppsControlPermission object "implies" the specified permission.
|
| Modifier and Type | Class and Description |
|---|---|
class |
DripFeedPermission
This class represents a permission to access the drip feed mode.
|
| Modifier and Type | Method and Description |
|---|---|
boolean |
DripFeedPermission.implies(Permission p)
Checks if the specified permission is "implied" by this object.
|
| Modifier and Type | Class and Description |
|---|---|
class |
RCPermission
This class is for return channel set-up permissions.
|
| Modifier and Type | Method and Description |
|---|---|
boolean |
RCPermission.implies(Permission p)
Checks if this RCPermission "implies" the specified Permission.
|
| Modifier and Type | Class and Description |
|---|---|
class |
TunerPermission
This class is for tuner permissions.
|
| Modifier and Type | Method and Description |
|---|---|
boolean |
TunerPermission.implies(Permission p)
Checks if the specified permission is "implied" by this object.
|
| Modifier and Type | Class and Description |
|---|---|
class |
ProviderPermission
This class is for applications which wish to be able to install
providers.
|
| Modifier and Type | Class and Description |
|---|---|
class |
UserPreferencePermission
This class is for user preference and setting permissions.
|
| Modifier and Type | Class and Description |
|---|---|
class |
OcapIxcPermission
This class represents access to the inter-xlet communication registry.
|
| Modifier and Type | Method and Description |
|---|---|
boolean |
OcapIxcPermission.implies(Permission p)
Checks if this OcapIxcPermission "implies" the specified permission.
|
| Modifier and Type | Class and Description |
|---|---|
class |
HomeNetPermission
The HomeNetPermission class represents permission to execute privileged
home networking operations only signed applications MAY be granted.
|
| Modifier and Type | Class and Description |
|---|---|
class |
ServiceTypePermission
ServiceTypePermission represents application permission to
select a specific service type using a ServiceContext accessible by the
application. |
| Modifier and Type | Method and Description |
|---|---|
boolean |
ServiceTypePermission.implies(Permission p)
Checks if the specified permission is "implied" by this object.
|
| Modifier and Type | Class and Description |
|---|---|
class |
RecordingPermission
Controls access to recording features by an application.
|
| Modifier and Type | Class and Description |
|---|---|
class |
MonitorAppPermission
The MonitorAppPermission class represents permission to execute privileged
operations only Monitor Application should be granted.
|
class |
RegisteredApiUserPermission
The RegisteredApiUserPermission class represents permission for an
application to use a specific registered API.
|
Copyright © 2012 CableLabs. All Rights Reserved.