| Package | Description |
|---|---|
| java.io |
Provides for system input and output through data streams,
serialization and the file system.
|
| java.net |
Provides the classes for implementing networking applications.
|
| java.security |
Provides the classes and interfaces for the security framework.
|
| java.util |
Contains the collections framework, legacy collection classes, event model,
date and time facilities, internationalization, and miscellaneous utility
classes (a string tokenizer, a random-number generator, and a bit array).
|
| javax.microedition.xlet.ixc |
Provides facilities for inter-Xlet communication (IXC).
|
| org.ocap.application |
|
| Modifier and Type | Method and Description |
|---|---|
PermissionCollection |
FilePermission.newPermissionCollection()
Returns a new PermissionCollection object for storing FilePermission
objects.
|
| Modifier and Type | Method and Description |
|---|---|
protected PermissionCollection |
URLClassLoader.getPermissions(CodeSource codesource)
Returns the permissions for the given codesource object.
|
PermissionCollection |
SocketPermission.newPermissionCollection()
Returns a new PermissionCollection object for storing SocketPermission
objects.
|
| Modifier and Type | Class and Description |
|---|---|
class |
Permissions
This class represents a heterogeneous collection of Permissions.
|
| Modifier and Type | Method and Description |
|---|---|
PermissionCollection |
ProtectionDomain.getPermissions()
Returns the static permissions granted to this domain.
|
protected PermissionCollection |
SecureClassLoader.getPermissions(CodeSource codesource)
Returns the permissions for the given CodeSource object.
|
abstract PermissionCollection |
Policy.getPermissions(CodeSource codesource)
Evaluates the global policy and returns a
PermissionCollection object specifying the set of
permissions allowed for code from the specified
code source.
|
PermissionCollection |
Policy.getPermissions(ProtectionDomain domain)
Evaluates the global policy and returns a
PermissionCollection object specifying the set of
permissions allowed given the characteristics of the
protection domain.
|
PermissionCollection |
UnresolvedPermission.newPermissionCollection()
Returns a new PermissionCollection object for storing
UnresolvedPermission objects.
|
PermissionCollection |
Permission.newPermissionCollection()
Returns an empty PermissionCollection for a given Permission object, or null if
one is not defined.
|
PermissionCollection |
BasicPermission.newPermissionCollection()
Returns a new PermissionCollection object for storing BasicPermission
objects.
|
PermissionCollection |
AllPermission.newPermissionCollection()
Returns a new PermissionCollection object for storing AllPermission
objects.
|
| Constructor and Description |
|---|
ProtectionDomain(CodeSource codesource,
PermissionCollection permissions)
Creates a new ProtectionDomain with the given CodeSource and
Permissions.
|
ProtectionDomain(CodeSource codesource,
PermissionCollection permissions,
ClassLoader classloader,
Principal[] principals)
Creates a new ProtectionDomain qualified by the given CodeSource,
Permissions, ClassLoader and array of Principals.
|
| Modifier and Type | Method and Description |
|---|---|
PermissionCollection |
PropertyPermission.newPermissionCollection()
Returns a new PermissionCollection object for storing
PropertyPermission objects.
|
| Modifier and Type | Method and Description |
|---|---|
PermissionCollection |
IxcPermission.newPermissionCollection()
Returns a new PermissionCollection object for storing
IxcPermission objects.
|
| Modifier and Type | Method and Description |
|---|---|
PermissionCollection |
SecurityPolicyHandler.getAppPermissions(PermissionInformation permissionInfo)
This callback method is used to modify the set of Permissions
that is granted to an application to be launched.
|
abstract PermissionCollection |
PermissionInformation.getRequestedPermissions()
This method returns the requested set of Permissions for the
application specified by the AppID that is returned by the
PermissionInformation.getAppID() method. |
static PermissionCollection |
PermissionInformation.getUnsignedAppPermissions()
This method returns the set of Permissions that are requested by
all unsigned applications.
|
PermissionCollection |
OcapIxcPermission.newPermissionCollection()
Returns a new PermissionCollection object for storing OcapIxcPermission objects.
|
Copyright © 2013 CableLabs. All rights reserved.