| Package | Description |
|---|---|
| java.security |
Provides the classes and interfaces for the security framework.
|
| java.security.acl |
The classes and interfaces in this package have been
superseded by classes in the java.security package.
|
| java.security.cert |
Provides classes and interfaces for parsing and managing
certificates, certificate revocation lists (CRLs), and
certification paths.
|
| javax.net.ssl |
Provides classes for the secure socket package.
|
| javax.security.auth.x500 |
This package contains the classes that should be used to store
X500 Principal and X500 Private Crendentials in a
Subject.
|
| javax.security.cert |
Provides classes for public key certificates.
|
| Modifier and Type | Class and Description |
|---|---|
class |
Identity
Deprecated.
This class is no longer used. Its functionality has been
replaced by
java.security.KeyStore, the
java.security.cert package, and
java.security.Principal. |
class |
IdentityScope
Deprecated.
This class is no longer used. Its functionality has been
replaced by
java.security.KeyStore, the
java.security.cert package, and
java.security.Principal. |
class |
Signer
Deprecated.
This class is no longer used. Its functionality has been
replaced by
java.security.KeyStore, the
java.security.cert package, and
java.security.Principal. |
| Modifier and Type | Method and Description |
|---|---|
Principal |
Certificate.getGuarantor()
Deprecated.
Returns the guarantor of the certificate, that is, the principal
guaranteeing that the public key associated with this certificate
is that of the principal associated with this certificate.
|
Principal |
Certificate.getPrincipal()
Deprecated.
Returns the principal of the principal-key pair being guaranteed by
the guarantor.
|
Principal[] |
ProtectionDomain.getPrincipals()
Returns an array of principals for this domain.
|
| Modifier and Type | Method and Description |
|---|---|
Identity |
IdentityScope.getIdentity(Principal principal)
Deprecated.
Retrieves the identity whose name is the same as that of the
specified principal.
|
| Constructor and Description |
|---|
ProtectionDomain(CodeSource codesource,
PermissionCollection permissions,
ClassLoader classloader,
Principal[] principals)
Creates a new ProtectionDomain qualified by the given CodeSource,
Permissions, ClassLoader and array of Principals.
|
| Modifier and Type | Interface and Description |
|---|---|
interface |
Group
This interface is used to represent a group of principals.
|
| Modifier and Type | Method and Description |
|---|---|
Principal |
AclEntry.getPrincipal()
Returns the principal for which permissions are granted or denied by
this ACL entry.
|
| Modifier and Type | Method and Description |
|---|---|
boolean |
Acl.addEntry(Principal caller,
AclEntry entry)
Adds an ACL entry to this ACL.
|
boolean |
Group.addMember(Principal user)
Adds the specified member to the group.
|
boolean |
Owner.addOwner(Principal caller,
Principal owner)
Adds an owner.
|
boolean |
Acl.checkPermission(Principal principal,
Permission permission)
Checks whether or not the specified principal has the specified
permission.
|
boolean |
Owner.deleteOwner(Principal caller,
Principal owner)
Deletes an owner.
|
Enumeration |
Acl.getPermissions(Principal user)
Returns an enumeration for the set of allowed permissions for the
specified principal (representing an entity such as an individual or
a group).
|
boolean |
Group.isMember(Principal member)
Returns true if the passed principal is a member of the group.
|
boolean |
Owner.isOwner(Principal owner)
Returns true if the given principal is an owner of the ACL.
|
boolean |
Acl.removeEntry(Principal caller,
AclEntry entry)
Removes an ACL entry from this ACL.
|
boolean |
Group.removeMember(Principal user)
Removes the specified member from the group.
|
void |
Acl.setName(Principal caller,
String name)
Sets the name of this ACL.
|
boolean |
AclEntry.setPrincipal(Principal user)
Specifies the principal for which permissions are granted or denied
by this ACL entry.
|
| Modifier and Type | Method and Description |
|---|---|
abstract Principal |
X509Certificate.getIssuerDN()
Gets the
issuer (issuer distinguished name) value from
the certificate. |
abstract Principal |
X509CRL.getIssuerDN()
Gets the
issuer (issuer distinguished name) value from
the CRL. |
abstract Principal |
X509Certificate.getSubjectDN()
Gets the
subject (subject distinguished name) value
from the certificate. |
| Modifier and Type | Method and Description |
|---|---|
String |
X509KeyManager.chooseClientAlias(String[] keyType,
Principal[] issuers,
Socket socket)
Choose an alias to authenticate the client side of a secure
socket given the public key type and the list of
certificate issuer authorities recognized by the peer (if any).
|
String |
X509KeyManager.chooseServerAlias(String keyType,
Principal[] issuers,
Socket socket)
Choose an alias to authenticate the server side of a secure
socket given the public key type and the list of
certificate issuer authorities recognized by the peer (if any).
|
String[] |
X509KeyManager.getClientAliases(String keyType,
Principal[] issuers)
Get the matching aliases for authenticating the client side of a secure
socket given the public key type and the list of
certificate issuer authorities recognized by the peer (if any).
|
String[] |
X509KeyManager.getServerAliases(String keyType,
Principal[] issuers)
Get the matching aliases for authenticating the server side of a secure
socket given the public key type and the list of
certificate issuer authorities recognized by the peer (if any).
|
| Modifier and Type | Class and Description |
|---|---|
class |
X500Principal
This class represents an X.500
Principal. |
| Modifier and Type | Method and Description |
|---|---|
abstract Principal |
X509Certificate.getIssuerDN()
Gets the
issuer (issuer distinguished name) value from
the certificate. |
abstract Principal |
X509Certificate.getSubjectDN()
Gets the
subject (subject distinguished name) value
from the certificate. |
Copyright © 2012 CableLabs. All Rights Reserved.