| Package | Description |
|---|---|
| java.security |
Provides the classes and interfaces for the security framework.
|
| java.security.interfaces |
Provides interfaces for generating RSA (Rivest, Shamir and
Adleman AsymmetricCipher algorithm)
keys as defined in the RSA Laboratory Technical Note
PKCS#1, and DSA (Digital Signature
Algorithm) keys as defined in NIST's FIPS-186.
|
| javax.net.ssl |
Provides classes for the secure socket package.
|
| Modifier and Type | Method and Description |
|---|---|
protected abstract PrivateKey |
KeyFactorySpi.engineGeneratePrivate(KeySpec keySpec)
Generates a private key object from the provided key
specification (key material).
|
PrivateKey |
KeyFactory.generatePrivate(KeySpec keySpec)
Generates a private key object from the provided key specification
(key material).
|
PrivateKey |
KeyPair.getPrivate()
Returns a reference to the private key component of this key pair.
|
PrivateKey |
Signer.getPrivateKey()
Deprecated.
Returns this signer's private key.
|
| Modifier and Type | Method and Description |
|---|---|
protected abstract void |
SignatureSpi.engineInitSign(PrivateKey privateKey)
Initializes this signature object with the specified
private key for signing operations.
|
protected void |
SignatureSpi.engineInitSign(PrivateKey privateKey,
SecureRandom random)
Initializes this signature object with the specified
private key and source of randomness for signing operations.
|
void |
Signature.initSign(PrivateKey privateKey)
Initialize this object for signing.
|
void |
Signature.initSign(PrivateKey privateKey,
SecureRandom random)
Initialize this object for signing.
|
| Constructor and Description |
|---|
KeyPair(PublicKey publicKey,
PrivateKey privateKey)
Constructs a key pair from the given public key and private key.
|
SignedObject(Serializable object,
PrivateKey signingKey,
Signature signingEngine)
Constructs a SignedObject from any Serializable object.
|
| Modifier and Type | Interface and Description |
|---|---|
interface |
DSAPrivateKey
The standard interface to a DSA private key.
|
interface |
RSAPrivateCrtKey
The interface to an RSA private key, as defined in the PKCS#1 standard,
using the Chinese Remainder Theorem (CRT) information values.
|
interface |
RSAPrivateKey
The interface to an RSA private key.
|
| Modifier and Type | Method and Description |
|---|---|
PrivateKey |
X509KeyManager.getPrivateKey(String alias)
Returns the key associated with the given alias.
|
Copyright © 2013 CableLabs. All rights reserved.