| Package | Description |
|---|---|
| java.lang |
Provides classes that are fundamental to the design of the Java
programming language.
|
| java.security |
Provides the classes and interfaces for the security framework.
|
| Modifier and Type | Method and Description |
|---|---|
ProtectionDomain |
Class.getProtectionDomain()
Returns the
ProtectionDomain of this class. |
| Modifier and Type | Method and Description |
|---|---|
protected Class |
ClassLoader.defineClass(String name,
byte[] b,
int off,
int len,
ProtectionDomain protectionDomain)
Converts an array of bytes into an instance of class Class,
with an optional ProtectionDomain.
|
| Modifier and Type | Method and Description |
|---|---|
ProtectionDomain[] |
DomainCombiner.combine(ProtectionDomain[] currentDomains,
ProtectionDomain[] assignedDomains)
Modify or update the provided ProtectionDomains.
|
| Modifier and Type | Method and Description |
|---|---|
ProtectionDomain[] |
DomainCombiner.combine(ProtectionDomain[] currentDomains,
ProtectionDomain[] assignedDomains)
Modify or update the provided ProtectionDomains.
|
ProtectionDomain[] |
DomainCombiner.combine(ProtectionDomain[] currentDomains,
ProtectionDomain[] assignedDomains)
Modify or update the provided ProtectionDomains.
|
PermissionCollection |
Policy.getPermissions(ProtectionDomain domain)
Evaluates the global policy and returns a
PermissionCollection object specifying the set of
permissions allowed given the characteristics of the
protection domain.
|
boolean |
Policy.implies(ProtectionDomain domain,
Permission permission)
Evaluates the global policy for the permissions granted to
the ProtectionDomain and tests whether the permission is
granted.
|
| Constructor and Description |
|---|
AccessControlContext(ProtectionDomain[] context)
Create an AccessControlContext with the given set of ProtectionDomains.
|
Copyright © 2013 CableLabs. All rights reserved.