| Package | Description |
|---|---|
| java.security |
Provides the classes and interfaces for the security framework.
|
| java.security.cert |
Provides classes and interfaces for parsing and managing
certificates, certificate revocation lists (CRLs), and
certification paths.
|
| javax.net.ssl |
Provides classes for the secure socket package.
|
| Modifier and Type | Method and Description |
|---|---|
Provider |
Signature.getProvider()
Returns the provider of this signature object.
|
Provider |
SecureRandom.getProvider()
Returns the provider of this SecureRandom object.
|
Provider |
MessageDigest.getProvider()
Returns the provider of this message digest object.
|
Provider |
KeyStore.getProvider()
Returns the provider of this keystore.
|
Provider |
KeyPairGenerator.getProvider()
Returns the provider of this key pair generator object.
|
Provider |
KeyFactory.getProvider()
Returns the provider of this key factory object.
|
Provider |
AlgorithmParameters.getProvider()
Returns the provider of this parameter object.
|
Provider |
AlgorithmParameterGenerator.getProvider()
Returns the provider of this algorithm parameter generator object.
|
static Provider |
Security.getProvider(String name)
Returns the provider installed with the specified name, if
any.
|
static Provider[] |
Security.getProviders()
Returns an array containing all the installed providers.
|
static Provider[] |
Security.getProviders(Map filter)
Returns an array containing all installed providers that satisfy the specified
selection criteria, or null if no such providers have been installed.
|
static Provider[] |
Security.getProviders(String filter)
Returns an array containing all installed providers that satisfy the
specified selection criterion, or null if no such providers have been
installed.
|
| Modifier and Type | Method and Description |
|---|---|
static int |
Security.addProvider(Provider provider)
Adds a provider to the next position available.
|
static Signature |
Signature.getInstance(String algorithm,
Provider provider)
Generates a Signature object implementing the specified
algorithm, as supplied from the specified provider, if such an
algorithm is available from the provider.
|
static SecureRandom |
SecureRandom.getInstance(String algorithm,
Provider provider)
Generates a SecureRandom object for the specified PRNG
algorithm, as supplied from the specified provider, if such a
PRNG implementation is available from the provider.
|
static MessageDigest |
MessageDigest.getInstance(String algorithm,
Provider provider)
Generates a MessageDigest object implementing the specified
algorithm, as supplied from the specified provider, if such an
algorithm is available from the provider.
|
static KeyStore |
KeyStore.getInstance(String type,
Provider provider)
Generates a keystore object for the specified keystore
type from the specified provider.
|
static KeyPairGenerator |
KeyPairGenerator.getInstance(String algorithm,
Provider provider)
Generates a KeyPairGenerator object implementing the specified
algorithm, as supplied from the specified provider,
if such an algorithm is available from the provider.
|
static KeyFactory |
KeyFactory.getInstance(String algorithm,
Provider provider)
Generates a KeyFactory object for the specified algorithm from the
specified provider.
|
static AlgorithmParameters |
AlgorithmParameters.getInstance(String algorithm,
Provider provider)
Generates a parameter object for the specified algorithm, as supplied
by the specified provider, if such an algorithm is available from the
provider.
|
static AlgorithmParameterGenerator |
AlgorithmParameterGenerator.getInstance(String algorithm,
Provider provider)
Generates an AlgorithmParameterGenerator object for the requested
algorithm, as supplied from the specified provider,
if such a parameter generator is available from the provider.
|
static int |
Security.insertProviderAt(Provider provider,
int position)
Adds a new provider, at a specified position.
|
| Constructor and Description |
|---|
AlgorithmParameterGenerator(AlgorithmParameterGeneratorSpi paramGenSpi,
Provider provider,
String algorithm)
Creates an AlgorithmParameterGenerator object.
|
AlgorithmParameters(AlgorithmParametersSpi paramSpi,
Provider provider,
String algorithm)
Creates an AlgorithmParameters object.
|
KeyFactory(KeyFactorySpi keyFacSpi,
Provider provider,
String algorithm)
Creates a KeyFactory object.
|
KeyStore(KeyStoreSpi keyStoreSpi,
Provider provider,
String type)
Creates a KeyStore object of the given type, and encapsulates the given
provider implementation (SPI object) in it.
|
SecureRandom(SecureRandomSpi secureRandomSpi,
Provider provider)
Creates a SecureRandom object.
|
| Modifier and Type | Method and Description |
|---|---|
Provider |
CertificateFactory.getProvider()
Returns the provider of this certificate factory.
|
| Modifier and Type | Method and Description |
|---|---|
static CertificateFactory |
CertificateFactory.getInstance(String type,
Provider provider)
Generates a certificate factory object for the specified
certificate type from the specified provider.
|
| Constructor and Description |
|---|
CertificateFactory(CertificateFactorySpi certFacSpi,
Provider provider,
String type)
Creates a CertificateFactory object of the given type, and encapsulates
the given provider implementation (SPI object) in it.
|
| Modifier and Type | Method and Description |
|---|---|
Provider |
TrustManagerFactory.getProvider()
Returns the provider of this
TrustManagerFactory object. |
Provider |
SSLContext.getProvider()
Returns the provider of this
SSLContext object. |
Provider |
KeyManagerFactory.getProvider()
Returns the provider of this
KeyManagerFactory object. |
| Modifier and Type | Method and Description |
|---|---|
static TrustManagerFactory |
TrustManagerFactory.getInstance(String algorithm,
Provider provider)
Generates a
TrustManagerFactory object for the specified
trust management algorithm from the specified provider. |
static SSLContext |
SSLContext.getInstance(String protocol,
Provider provider)
Generates a
SSLContext object that implements the
specified secure socket protocol from the specified provider. |
static KeyManagerFactory |
KeyManagerFactory.getInstance(String algorithm,
Provider provider)
Generates a
KeyManagerFactory object for the specified
key management algorithm from the specified provider. |
| Constructor and Description |
|---|
KeyManagerFactory(KeyManagerFactorySpi factorySpi,
Provider provider,
String algorithm)
Creates a KeyManagerFactory object.
|
SSLContext(SSLContextSpi contextSpi,
Provider provider,
String protocol)
Creates an SSLContext object.
|
TrustManagerFactory(TrustManagerFactorySpi factorySpi,
Provider provider,
String algorithm)
Creates a TrustManagerFactory object.
|
Copyright © 2013 CableLabs. All rights reserved.