| Package | Description |
|---|---|
| java.security |
Provides the classes and interfaces for the security framework.
|
| java.security.cert |
Provides classes and interfaces for parsing and managing
certificates, certificate revocation lists (CRLs), and
certification paths.
|
| java.security.interfaces |
Provides interfaces for generating RSA (Rivest, Shamir and
Adleman AsymmetricCipher algorithm)
keys as defined in the RSA Laboratory Technical Note
PKCS#1, and DSA (Digital Signature
Algorithm) keys as defined in NIST's FIPS-186.
|
| javax.security.cert |
Provides classes for public key certificates.
|
| Modifier and Type | Method and Description |
|---|---|
protected abstract PublicKey |
KeyFactorySpi.engineGeneratePublic(KeySpec keySpec)
Generates a public key object from the provided key
specification (key material).
|
PublicKey |
KeyFactory.generatePublic(KeySpec keySpec)
Generates a public key object from the provided key specification
(key material).
|
PublicKey |
KeyPair.getPublic()
Returns a reference to the public key component of this key pair.
|
PublicKey |
Identity.getPublicKey()
Deprecated.
Returns this identity's public key.
|
PublicKey |
Certificate.getPublicKey()
Deprecated.
Returns the key of the principal-key pair being guaranteed by
the guarantor.
|
| Modifier and Type | Method and Description |
|---|---|
protected abstract void |
SignatureSpi.engineInitVerify(PublicKey publicKey)
Initializes this signature object with the specified
public key for verification operations.
|
abstract Identity |
IdentityScope.getIdentity(PublicKey key)
Deprecated.
Retrieves the identity with the specified public key.
|
void |
Signature.initVerify(PublicKey publicKey)
Initializes this object for verification.
|
void |
Identity.setPublicKey(PublicKey key)
Deprecated.
Sets this identity's public key.
|
boolean |
SignedObject.verify(PublicKey verificationKey,
Signature verificationEngine)
Verifies that the signature in this SignedObject is the valid
signature for the object stored inside, with the given
verification key, using the designated verification engine.
|
| Constructor and Description |
|---|
KeyPair(PublicKey publicKey,
PrivateKey privateKey)
Constructs a key pair from the given public key and private key.
|
| Modifier and Type | Method and Description |
|---|---|
abstract PublicKey |
Certificate.getPublicKey()
Gets the public key from this certificate.
|
| Modifier and Type | Method and Description |
|---|---|
abstract void |
X509CRL.verify(PublicKey key)
Verifies that this CRL was signed using the
private key that corresponds to the given public key.
|
abstract void |
Certificate.verify(PublicKey key)
Verifies that this certificate was signed using the
private key that corresponds to the specified public key.
|
abstract void |
X509CRL.verify(PublicKey key,
String sigProvider)
Verifies that this CRL was signed using the
private key that corresponds to the given public key.
|
abstract void |
Certificate.verify(PublicKey key,
String sigProvider)
Verifies that this certificate was signed using the
private key that corresponds to the specified public key.
|
| Modifier and Type | Interface and Description |
|---|---|
interface |
DSAPublicKey
The interface to a DSA public key.
|
interface |
RSAPublicKey
The interface to an RSA public key.
|
| Modifier and Type | Method and Description |
|---|---|
abstract PublicKey |
Certificate.getPublicKey()
Gets the public key from this certificate.
|
| Modifier and Type | Method and Description |
|---|---|
abstract void |
Certificate.verify(PublicKey key)
Verifies that this certificate was signed using the
private key that corresponds to the specified public key.
|
abstract void |
Certificate.verify(PublicKey key,
String sigProvider)
Verifies that this certificate was signed using the
private key that corresponds to the specified public key.
|
Copyright © 2013 CableLabs. All rights reserved.