| Package | Description |
|---|---|
| java.security |
Provides the classes and interfaces for the security framework.
|
| java.security.interfaces |
Provides interfaces for generating RSA (Rivest, Shamir and
Adleman AsymmetricCipher algorithm)
keys as defined in the RSA Laboratory Technical Note
PKCS#1, and DSA (Digital Signature
Algorithm) keys as defined in NIST's FIPS-186.
|
| javax.net.ssl |
Provides classes for the secure socket package.
|
| Modifier and Type | Field and Description |
|---|---|
protected SecureRandom |
SignatureSpi.appRandom
Application-specified source of randomness.
|
| Modifier and Type | Method and Description |
|---|---|
static SecureRandom |
SecureRandom.getInstance(String algorithm)
Generates a SecureRandom object that implements the specified
Pseudo Random Number Generator (PRNG) algorithm.
|
static SecureRandom |
SecureRandom.getInstance(String algorithm,
Provider provider)
Generates a SecureRandom object for the specified PRNG
algorithm, as supplied from the specified provider, if such a
PRNG implementation is available from the provider.
|
static SecureRandom |
SecureRandom.getInstance(String algorithm,
String provider)
Generates a SecureRandom object for the specified PRNG
algorithm, as supplied from the specified provider, if such a
PRNG implementation is available from the provider.
|
| Modifier and Type | Method and Description |
|---|---|
protected abstract void |
AlgorithmParameterGeneratorSpi.engineInit(AlgorithmParameterSpec genParamSpec,
SecureRandom random)
Initializes this parameter generator with a set of
algorithm-specific parameter generation values.
|
protected abstract void |
AlgorithmParameterGeneratorSpi.engineInit(int size,
SecureRandom random)
Initializes this parameter generator for a certain size
and source of randomness.
|
protected void |
SignatureSpi.engineInitSign(PrivateKey privateKey,
SecureRandom random)
Initializes this signature object with the specified
private key and source of randomness for signing operations.
|
void |
AlgorithmParameterGenerator.init(AlgorithmParameterSpec genParamSpec,
SecureRandom random)
Initializes this parameter generator with a set of algorithm-specific
parameter generation values.
|
void |
AlgorithmParameterGenerator.init(int size,
SecureRandom random)
Initializes this parameter generator for a certain size and source
of randomness.
|
void |
KeyPairGeneratorSpi.initialize(AlgorithmParameterSpec params,
SecureRandom random)
Initializes the key pair generator using the specified parameter
set and user-provided source of randomness.
|
void |
KeyPairGenerator.initialize(AlgorithmParameterSpec params,
SecureRandom random)
Initializes the key pair generator with the given parameter
set and source of randomness.
|
abstract void |
KeyPairGeneratorSpi.initialize(int keysize,
SecureRandom random)
Initializes the key pair generator for a certain keysize, using
the default parameter set.
|
void |
KeyPairGenerator.initialize(int keysize,
SecureRandom random)
Initializes the key pair generator for a certain keysize with
the given source of randomness (and a default parameter set).
|
void |
Signature.initSign(PrivateKey privateKey,
SecureRandom random)
Initialize this object for signing.
|
| Modifier and Type | Method and Description |
|---|---|
void |
DSAKeyPairGenerator.initialize(DSAParams params,
SecureRandom random)
Initializes the key pair generator using p, q and g, the DSA
family parameters.
|
void |
DSAKeyPairGenerator.initialize(int modlen,
boolean genParams,
SecureRandom random)
Initializes the key pair generator for a given modulus length,
without parameters.
|
| Modifier and Type | Method and Description |
|---|---|
protected abstract void |
SSLContextSpi.engineInit(KeyManager[] km,
TrustManager[] tm,
SecureRandom sr)
Initializes this context.
|
void |
SSLContext.init(KeyManager[] km,
TrustManager[] tm,
SecureRandom random)
Initializes this context.
|
Copyright © 2013 CableLabs. All rights reserved.