| Package | Description |
|---|---|
| java.security.interfaces |
Provides interfaces for generating RSA (Rivest, Shamir and
Adleman AsymmetricCipher algorithm)
keys as defined in the RSA Laboratory Technical Note
PKCS#1, and DSA (Digital Signature
Algorithm) keys as defined in NIST's FIPS-186.
|
| java.security.spec |
Provides classes and interfaces for key specifications and algorithm
parameter specifications.
|
| Modifier and Type | Method and Description |
|---|---|
DSAParams |
DSAKey.getParams()
Returns the DSA-specific key parameters.
|
| Modifier and Type | Method and Description |
|---|---|
void |
DSAKeyPairGenerator.initialize(DSAParams params,
SecureRandom random)
Initializes the key pair generator using p, q and g, the DSA
family parameters.
|
| Modifier and Type | Class and Description |
|---|---|
class |
DSAParameterSpec
This class specifies the set of parameters used with the DSA algorithm.
|
Copyright © 2012. All Rights Reserved.