| Package | Description |
|---|---|
| java.awt |
Contains all of the classes for creating user
interfaces and for painting graphics and images.
|
| java.io |
Provides for system input and output through data streams,
serialization and the file system.
|
| java.lang |
Provides classes that are fundamental to the design of the Java
programming language.
|
| java.lang.reflect |
Provides classes and interfaces for obtaining reflective
information about classes and objects.
|
| java.net |
Provides the classes for implementing networking applications.
|
| java.security |
Provides the classes and interfaces for the security framework.
|
| java.security.acl |
The classes and interfaces in this package have been
superseded by classes in the java.security package.
|
| java.security.cert |
Provides classes and interfaces for parsing and managing
certificates, certificate revocation lists (CRLs), and
certification paths.
|
| java.security.interfaces |
Provides interfaces for generating RSA (Rivest, Shamir and
Adleman AsymmetricCipher algorithm)
keys as defined in the RSA Laboratory Technical Note
PKCS#1, and DSA (Digital Signature
Algorithm) keys as defined in NIST's FIPS-186.
|
| java.security.spec |
Provides classes and interfaces for key specifications and algorithm
parameter specifications.
|
| java.util |
Contains the collections framework, legacy collection classes, event model,
date and time facilities, internationalization, and miscellaneous utility
classes (a string tokenizer, a random-number generator, and a bit array).
|
| javax.microedition.xlet.ixc |
Provides facilities for inter-Xlet communication (IXC).
|
| javax.net.ssl |
Provides classes for the secure socket package.
|
| javax.security.auth.x500 |
This package contains the classes that should be used to store
X500 Principal and X500 Private Crendentials in a
Subject.
|
| javax.tv.media |
Provides controls and events for the management of real-time media
in a television environment.
|
| javax.tv.service |
Provides mechanisms for accessing the service information (SI) database
and APIs representing the SI elements it contains.
|
| javax.tv.service.selection |
Provides a mechanism to select a Service for
presentation.
|
| org.dvb.application |
Provides access to lists of applications which are available
in this context and the ability to launch those applications.
|
| org.dvb.lang |
Provides those core platform related features not found
in the java.lang package.
|
| org.dvb.media |
Provides DVB specific extensions to the Java Media Framework.
|
| org.dvb.net.rc |
Provides session management for bi-directional IP connections
which are session based from the point of view of an application.
|
| org.dvb.net.tuning |
Provides extensions to the tuning API from DAVIC.
|
| org.dvb.spi |
This package defines a central registry for all DVB Service Provider Interface
(SPI) providers.
|
| org.dvb.user |
Provides access to settings and preferences configured by the end-user.
|
| org.ocap.application |
|
| org.ocap.hn |
Provides representation of the main components of HN, such as servers, actions, action responses, and change listeners.
|
| org.ocap.service |
The org.ocap.service package represents various aspects of a service.
|
| org.ocap.shared.dvr |
The shared DVR API for scheduling and managing recording requests.
|
| org.ocap.system |
This API is used to access
system modules. |
| Class and Description |
|---|
| BasicPermission
The BasicPermission class extends the Permission class, and
can be used as the base class for permissions that want to
follow the same naming convention as BasicPermission.
|
| Guard
This interface represents a guard, which is an object that is used
to protect access to another object.
|
| Permission
Abstract class for representing access to a system resource.
|
| Class and Description |
|---|
| BasicPermission
The BasicPermission class extends the Permission class, and
can be used as the base class for permissions that want to
follow the same naming convention as BasicPermission.
|
| Guard
This interface represents a guard, which is an object that is used
to protect access to another object.
|
| Permission
Abstract class for representing access to a system resource.
|
| PermissionCollection
Abstract class representing a collection of Permission objects.
|
| Class and Description |
|---|
| BasicPermission
The BasicPermission class extends the Permission class, and
can be used as the base class for permissions that want to
follow the same naming convention as BasicPermission.
|
| Guard
This interface represents a guard, which is an object that is used
to protect access to another object.
|
| Permission
Abstract class for representing access to a system resource.
|
| ProtectionDomain
This ProtectionDomain class encapsulates the characteristics of a domain,
which encloses a set of classes whose instances are granted a set
of permissions when being executed on behalf of a given set of Principals.
|
| Class and Description |
|---|
| BasicPermission
The BasicPermission class extends the Permission class, and
can be used as the base class for permissions that want to
follow the same naming convention as BasicPermission.
|
| Guard
This interface represents a guard, which is an object that is used
to protect access to another object.
|
| Permission
Abstract class for representing access to a system resource.
|
| Class and Description |
|---|
| BasicPermission
The BasicPermission class extends the Permission class, and
can be used as the base class for permissions that want to
follow the same naming convention as BasicPermission.
|
| CodeSource
This class extends the concept of a codebase to
encapsulate not only the location (URL) but also the certificate(s)
that were used to verify signed code originating from that
location.
|
| Guard
This interface represents a guard, which is an object that is used
to protect access to another object.
|
| Permission
Abstract class for representing access to a system resource.
|
| PermissionCollection
Abstract class representing a collection of Permission objects.
|
| SecureClassLoader
This class extends ClassLoader with additional support for defining
classes with an associated code source and permissions which are
retrieved by the system policy by default.
|
| Class and Description |
|---|
| AccessControlContext
An AccessControlContext is used to make system resource access decisions
based on the context it encapsulates.
|
| AccessControlException
This exception is thrown by the AccessController to indicate
that a requested access (to a critical system resource such as the
file system or the network) is denied.
|
| AlgorithmParameterGenerator
The
AlgorithmParameterGenerator class is used to generate a
set of
parameters to be used with a certain algorithm. |
| AlgorithmParameterGeneratorSpi
This class defines the Service Provider Interface (SPI)
for the
AlgorithmParameterGenerator class, which
is used to generate a set of parameters to be used with a certain algorithm. |
| AlgorithmParameters
This class is used as an opaque representation of cryptographic parameters.
|
| AlgorithmParametersSpi
This class defines the Service Provider Interface (SPI)
for the
AlgorithmParameters class, which is used to manage
algorithm parameters. |
| BasicPermission
The BasicPermission class extends the Permission class, and
can be used as the base class for permissions that want to
follow the same naming convention as BasicPermission.
|
| Certificate
Deprecated.
A new certificate handling package is created in the Java 2 platform.
This Certificate interface is entirely deprecated and
is here to allow for a smooth transition to the new
package.
|
| CodeSource
This class extends the concept of a codebase to
encapsulate not only the location (URL) but also the certificate(s)
that were used to verify signed code originating from that
location.
|
| DigestException
This is the generic Message Digest exception.
|
| DomainCombiner
A
DomainCombiner provides a means to dynamically
update the ProtectionDomains associated with the current
AccessControlContext. |
| GeneralSecurityException
The
GeneralSecurityException class is a generic
security exception class that provides type safety for all the
security-related exception classes that extend from it. |
| Guard
This interface represents a guard, which is an object that is used
to protect access to another object.
|
| Identity
Deprecated.
This class is no longer used. Its functionality has been
replaced by
java.security.KeyStore, the
java.security.cert package, and
java.security.Principal. |
| IdentityScope
Deprecated.
This class is no longer used. Its functionality has been
replaced by
java.security.KeyStore, the
java.security.cert package, and
java.security.Principal. |
| InvalidAlgorithmParameterException
This is the exception for invalid or inappropriate algorithm parameters.
|
| InvalidKeyException
This is the exception for invalid Keys (invalid encoding, wrong
length, uninitialized, etc).
|
| InvalidParameterException
This exception, designed for use by the JCA/JCE engine classes,
is thrown when an invalid parameter is passed
to a method.
|
| Key
The Key interface is the top-level interface for all keys.
|
| KeyException
This is the basic key exception.
|
| KeyFactory
Key factories are used to convert keys (opaque
cryptographic keys of type
Key) into key specifications
(transparent representations of the underlying key material), and vice
versa. |
| KeyFactorySpi
This class defines the Service Provider Interface (SPI)
for the
KeyFactory class. |
| KeyManagementException
This is the general key management exception for all operations
dealing with key management.
|
| KeyPair
This class is a simple holder for a key pair (a public key and a
private key).
|
| KeyPairGenerator
The KeyPairGenerator class is used to generate pairs of
public and private keys.
|
| KeyPairGeneratorSpi
This class defines the Service Provider Interface (SPI)
for the
KeyPairGenerator class, which is used to generate
pairs of public and private keys. |
| KeyStore
This class represents an in-memory collection of keys and certificates.
|
| KeyStoreException
This is the generic KeyStore exception.
|
| KeyStoreSpi
This class defines the Service Provider Interface (SPI)
for the
KeyStore class. |
| MessageDigest
This MessageDigest class provides applications the functionality of a
message digest algorithm, such as MD5 or SHA.
|
| MessageDigestSpi
This class defines the Service Provider Interface (SPI)
for the
MessageDigest class, which provides the functionality
of a message digest algorithm, such as MD5 or SHA. |
| NoSuchAlgorithmException
This exception is thrown when a particular cryptographic algorithm is
requested but is not available in the environment.
|
| NoSuchProviderException
This exception is thrown when a particular security provider is
requested but is not available in the environment.
|
| Permission
Abstract class for representing access to a system resource.
|
| PermissionCollection
Abstract class representing a collection of Permission objects.
|
| Policy
This is an abstract class for representing the system security
policy for a Java application environment (specifying
which permissions are available for code from various sources).
|
| Principal
This interface represents the abstract notion of a principal, which
can be used to represent any entity, such as an individual, a
corporation, and a login id.
|
| PrivateKey
A private key.
|
| PrivilegedAction
A computation to be performed with privileges enabled.
|
| PrivilegedActionException
This exception is thrown by
doPrivileged(PrivilegedExceptionAction) and
doPrivileged(PrivilegedExceptionAction,
AccessControlContext context) to indicate
that the action being performed threw a checked exception. |
| PrivilegedExceptionAction
A computation to be performed with privileges enabled, that throws one or
more checked exceptions.
|
| ProtectionDomain
This ProtectionDomain class encapsulates the characteristics of a domain,
which encloses a set of classes whose instances are granted a set
of permissions when being executed on behalf of a given set of Principals.
|
| Provider
This class represents a "provider" for the
Java Security API, where a provider implements some or all parts of
Java Security.
|
| PublicKey
A public key.
|
| SecureRandom
This class provides a cryptographically strong pseudo-random number
generator (PRNG).
|
| SecureRandomSpi
This class defines the Service Provider Interface (SPI)
for the
SecureRandom class. |
| Signature
This Signature class is used to provide applications the functionality
of a digital signature algorithm.
|
| SignatureException
This is the generic Signature exception.
|
| SignatureSpi
This class defines the Service Provider Interface (SPI)
for the
Signature class, which is used to provide the
functionality of a digital signature algorithm. |
| UnrecoverableKeyException
This exception is thrown if a key in the keystore cannot be recovered.
|
| Class and Description |
|---|
| Principal
This interface represents the abstract notion of a principal, which
can be used to represent any entity, such as an individual, a
corporation, and a login id.
|
| Class and Description |
|---|
| GeneralSecurityException
The
GeneralSecurityException class is a generic
security exception class that provides type safety for all the
security-related exception classes that extend from it. |
| InvalidKeyException
This is the exception for invalid Keys (invalid encoding, wrong
length, uninitialized, etc).
|
| NoSuchAlgorithmException
This exception is thrown when a particular cryptographic algorithm is
requested but is not available in the environment.
|
| NoSuchProviderException
This exception is thrown when a particular security provider is
requested but is not available in the environment.
|
| Principal
This interface represents the abstract notion of a principal, which
can be used to represent any entity, such as an individual, a
corporation, and a login id.
|
| Provider
This class represents a "provider" for the
Java Security API, where a provider implements some or all parts of
Java Security.
|
| PublicKey
A public key.
|
| SignatureException
This is the generic Signature exception.
|
| Class and Description |
|---|
| InvalidParameterException
This exception, designed for use by the JCA/JCE engine classes,
is thrown when an invalid parameter is passed
to a method.
|
| Key
The Key interface is the top-level interface for all keys.
|
| PrivateKey
A private key.
|
| PublicKey
A public key.
|
| SecureRandom
This class provides a cryptographically strong pseudo-random number
generator (PRNG).
|
| Class and Description |
|---|
| GeneralSecurityException
The
GeneralSecurityException class is a generic
security exception class that provides type safety for all the
security-related exception classes that extend from it. |
| Class and Description |
|---|
| BasicPermission
The BasicPermission class extends the Permission class, and
can be used as the base class for permissions that want to
follow the same naming convention as BasicPermission.
|
| Guard
This interface represents a guard, which is an object that is used
to protect access to another object.
|
| Permission
Abstract class for representing access to a system resource.
|
| PermissionCollection
Abstract class representing a collection of Permission objects.
|
| Class and Description |
|---|
| Guard
This interface represents a guard, which is an object that is used
to protect access to another object.
|
| Permission
Abstract class for representing access to a system resource.
|
| PermissionCollection
Abstract class representing a collection of Permission objects.
|
| Class and Description |
|---|
| BasicPermission
The BasicPermission class extends the Permission class, and
can be used as the base class for permissions that want to
follow the same naming convention as BasicPermission.
|
| Guard
This interface represents a guard, which is an object that is used
to protect access to another object.
|
| InvalidAlgorithmParameterException
This is the exception for invalid or inappropriate algorithm parameters.
|
| KeyManagementException
This is the general key management exception for all operations
dealing with key management.
|
| KeyStore
This class represents an in-memory collection of keys and certificates.
|
| KeyStoreException
This is the generic KeyStore exception.
|
| NoSuchAlgorithmException
This exception is thrown when a particular cryptographic algorithm is
requested but is not available in the environment.
|
| NoSuchProviderException
This exception is thrown when a particular security provider is
requested but is not available in the environment.
|
| Permission
Abstract class for representing access to a system resource.
|
| Principal
This interface represents the abstract notion of a principal, which
can be used to represent any entity, such as an individual, a
corporation, and a login id.
|
| PrivateKey
A private key.
|
| Provider
This class represents a "provider" for the
Java Security API, where a provider implements some or all parts of
Java Security.
|
| SecureRandom
This class provides a cryptographically strong pseudo-random number
generator (PRNG).
|
| UnrecoverableKeyException
This exception is thrown if a key in the keystore cannot be recovered.
|
| Class and Description |
|---|
| Principal
This interface represents the abstract notion of a principal, which
can be used to represent any entity, such as an individual, a
corporation, and a login id.
|
| Class and Description |
|---|
| Guard
This interface represents a guard, which is an object that is used
to protect access to another object.
|
| Permission
Abstract class for representing access to a system resource.
|
| Class and Description |
|---|
| Guard
This interface represents a guard, which is an object that is used
to protect access to another object.
|
| Permission
Abstract class for representing access to a system resource.
|
| Class and Description |
|---|
| BasicPermission
The BasicPermission class extends the Permission class, and
can be used as the base class for permissions that want to
follow the same naming convention as BasicPermission.
|
| Guard
This interface represents a guard, which is an object that is used
to protect access to another object.
|
| Permission
Abstract class for representing access to a system resource.
|
| Class and Description |
|---|
| BasicPermission
The BasicPermission class extends the Permission class, and
can be used as the base class for permissions that want to
follow the same naming convention as BasicPermission.
|
| Guard
This interface represents a guard, which is an object that is used
to protect access to another object.
|
| Permission
Abstract class for representing access to a system resource.
|
| Class and Description |
|---|
| SecureClassLoader
This class extends ClassLoader with additional support for defining
classes with an associated code source and permissions which are
retrieved by the system policy by default.
|
| Class and Description |
|---|
| BasicPermission
The BasicPermission class extends the Permission class, and
can be used as the base class for permissions that want to
follow the same naming convention as BasicPermission.
|
| Guard
This interface represents a guard, which is an object that is used
to protect access to another object.
|
| Permission
Abstract class for representing access to a system resource.
|
| Class and Description |
|---|
| BasicPermission
The BasicPermission class extends the Permission class, and
can be used as the base class for permissions that want to
follow the same naming convention as BasicPermission.
|
| Guard
This interface represents a guard, which is an object that is used
to protect access to another object.
|
| Permission
Abstract class for representing access to a system resource.
|
| Class and Description |
|---|
| BasicPermission
The BasicPermission class extends the Permission class, and
can be used as the base class for permissions that want to
follow the same naming convention as BasicPermission.
|
| Guard
This interface represents a guard, which is an object that is used
to protect access to another object.
|
| Permission
Abstract class for representing access to a system resource.
|
| Class and Description |
|---|
| BasicPermission
The BasicPermission class extends the Permission class, and
can be used as the base class for permissions that want to
follow the same naming convention as BasicPermission.
|
| Guard
This interface represents a guard, which is an object that is used
to protect access to another object.
|
| Permission
Abstract class for representing access to a system resource.
|
| Class and Description |
|---|
| BasicPermission
The BasicPermission class extends the Permission class, and
can be used as the base class for permissions that want to
follow the same naming convention as BasicPermission.
|
| Guard
This interface represents a guard, which is an object that is used
to protect access to another object.
|
| Permission
Abstract class for representing access to a system resource.
|
| Class and Description |
|---|
| BasicPermission
The BasicPermission class extends the Permission class, and
can be used as the base class for permissions that want to
follow the same naming convention as BasicPermission.
|
| Guard
This interface represents a guard, which is an object that is used
to protect access to another object.
|
| Permission
Abstract class for representing access to a system resource.
|
| PermissionCollection
Abstract class representing a collection of Permission objects.
|
| Class and Description |
|---|
| BasicPermission
The BasicPermission class extends the Permission class, and
can be used as the base class for permissions that want to
follow the same naming convention as BasicPermission.
|
| Guard
This interface represents a guard, which is an object that is used
to protect access to another object.
|
| Permission
Abstract class for representing access to a system resource.
|
| Class and Description |
|---|
| BasicPermission
The BasicPermission class extends the Permission class, and
can be used as the base class for permissions that want to
follow the same naming convention as BasicPermission.
|
| Guard
This interface represents a guard, which is an object that is used
to protect access to another object.
|
| Permission
Abstract class for representing access to a system resource.
|
| Class and Description |
|---|
| BasicPermission
The BasicPermission class extends the Permission class, and
can be used as the base class for permissions that want to
follow the same naming convention as BasicPermission.
|
| Guard
This interface represents a guard, which is an object that is used
to protect access to another object.
|
| Permission
Abstract class for representing access to a system resource.
|
| Class and Description |
|---|
| BasicPermission
The BasicPermission class extends the Permission class, and
can be used as the base class for permissions that want to
follow the same naming convention as BasicPermission.
|
| Guard
This interface represents a guard, which is an object that is used
to protect access to another object.
|
| Permission
Abstract class for representing access to a system resource.
|
Copyright © 2013 CableLabs. All rights reserved.