| Package | Description |
|---|---|
| java.security |
Provides the classes and interfaces for the security framework.
|
| java.security.spec |
Provides classes and interfaces for key specifications and algorithm
parameter specifications.
|
| Modifier and Type | Method and Description |
|---|---|
protected abstract AlgorithmParameterSpec |
AlgorithmParametersSpi.engineGetParameterSpec(Class paramSpec)
Returns a (transparent) specification of this parameters
object.
|
AlgorithmParameterSpec |
AlgorithmParameters.getParameterSpec(Class paramSpec)
Returns a (transparent) specification of this parameter object.
|
| Modifier and Type | Method and Description |
|---|---|
protected abstract void |
AlgorithmParametersSpi.engineInit(AlgorithmParameterSpec paramSpec)
Initializes this parameters object using the parameters
specified in
paramSpec. |
protected abstract void |
AlgorithmParameterGeneratorSpi.engineInit(AlgorithmParameterSpec genParamSpec,
SecureRandom random)
Initializes this parameter generator with a set of
algorithm-specific parameter generation values.
|
protected void |
SignatureSpi.engineSetParameter(AlgorithmParameterSpec params)
This method is overridden by providers to initialize
this signature engine with the specified parameter set.
|
void |
AlgorithmParameters.init(AlgorithmParameterSpec paramSpec)
Initializes this parameter object using the parameters
specified in
paramSpec. |
void |
AlgorithmParameterGenerator.init(AlgorithmParameterSpec genParamSpec)
Initializes this parameter generator with a set of algorithm-specific
parameter generation values.
|
void |
AlgorithmParameterGenerator.init(AlgorithmParameterSpec genParamSpec,
SecureRandom random)
Initializes this parameter generator with a set of algorithm-specific
parameter generation values.
|
void |
KeyPairGenerator.initialize(AlgorithmParameterSpec params)
Initializes the key pair generator using the specified parameter
set and the
SecureRandom
implementation of the highest-priority installed provider as the source
of randomness. |
void |
KeyPairGeneratorSpi.initialize(AlgorithmParameterSpec params,
SecureRandom random)
Initializes the key pair generator using the specified parameter
set and user-provided source of randomness.
|
void |
KeyPairGenerator.initialize(AlgorithmParameterSpec params,
SecureRandom random)
Initializes the key pair generator with the given parameter
set and source of randomness.
|
void |
Signature.setParameter(AlgorithmParameterSpec params)
Initializes this signature engine with the specified parameter set.
|
| Modifier and Type | Class and Description |
|---|---|
class |
DSAParameterSpec
This class specifies the set of parameters used with the DSA algorithm.
|
class |
PSSParameterSpec
This class specifies a parameter spec for RSA PSS encoding scheme,
as defined in the PKCS#1 v2.1.
|
class |
RSAKeyGenParameterSpec
This class specifies the set of parameters used to generate an RSA
key pair.
|
Copyright © 2013 CableLabs. All rights reserved.