| Package | Description |
|---|---|
| java.security |
Provides the classes and interfaces for the security framework.
|
| Modifier and Type | Method and Description |
|---|---|
protected abstract PrivateKey |
KeyFactorySpi.engineGeneratePrivate(KeySpec keySpec)
Generates a private key object from the provided key
specification (key material).
|
protected abstract PublicKey |
KeyFactorySpi.engineGeneratePublic(KeySpec keySpec)
Generates a public key object from the provided key
specification (key material).
|
protected abstract KeySpec |
KeyFactorySpi.engineGetKeySpec(Key key,
Class keySpec)
Returns a specification (key material) of the given key
object.
|
PrivateKey |
KeyFactory.generatePrivate(KeySpec keySpec)
Generates a private key object from the provided key specification
(key material).
|
PublicKey |
KeyFactory.generatePublic(KeySpec keySpec)
Generates a public key object from the provided key specification
(key material).
|
KeySpec |
KeyFactory.getKeySpec(Key key,
Class keySpec)
Returns a specification (key material) of the given key object.
|
Copyright © 2013 CableLabs. All rights reserved.