| Package | Description |
|---|---|
| java.security |
Provides the classes and interfaces for the security framework.
|
| java.security.spec |
Provides classes and interfaces for key specifications and algorithm
parameter specifications.
|
| Modifier and Type | Method and Description |
|---|---|
protected abstract KeySpec |
KeyFactorySpi.engineGetKeySpec(Key key,
Class keySpec)
Returns a specification (key material) of the given key
object.
|
KeySpec |
KeyFactory.getKeySpec(Key key,
Class keySpec)
Returns a specification (key material) of the given key object.
|
| Modifier and Type | Method and Description |
|---|---|
protected abstract PrivateKey |
KeyFactorySpi.engineGeneratePrivate(KeySpec keySpec)
Generates a private key object from the provided key
specification (key material).
|
protected abstract PublicKey |
KeyFactorySpi.engineGeneratePublic(KeySpec keySpec)
Generates a public key object from the provided key
specification (key material).
|
PrivateKey |
KeyFactory.generatePrivate(KeySpec keySpec)
Generates a private key object from the provided key specification
(key material).
|
PublicKey |
KeyFactory.generatePublic(KeySpec keySpec)
Generates a public key object from the provided key specification
(key material).
|
| Modifier and Type | Class and Description |
|---|---|
class |
DSAPrivateKeySpec
This class specifies a DSA private key with its associated parameters.
|
class |
DSAPublicKeySpec
This class specifies a DSA public key with its associated parameters.
|
class |
EncodedKeySpec
This class represents a public or private key in encoded format.
|
class |
PKCS8EncodedKeySpec
This class represents the ASN.1 encoding of a private key,
encoded according to the ASN.1 type
PrivateKeyInfo. |
class |
RSAPrivateCrtKeySpec
This class specifies an RSA private key, as defined in the PKCS#1
standard, using the Chinese Remainder Theorem (CRT) information values for
efficiency.
|
class |
RSAPrivateKeySpec
This class specifies an RSA private key.
|
class |
RSAPublicKeySpec
This class specifies an RSA public key.
|
class |
X509EncodedKeySpec
This class represents the ASN.1 encoding of a public key,
encoded according to the ASN.1 type
SubjectPublicKeyInfo. |
Copyright © 2013 CableLabs. All rights reserved.