See: Description
| Interface | Description |
|---|---|
| AlgorithmParameterSpec |
A (transparent) specification of cryptographic parameters.
|
| KeySpec |
A (transparent) specification of the key material
that constitutes a cryptographic key.
|
| Class | Description |
|---|---|
| DSAParameterSpec |
This class specifies the set of parameters used with the DSA algorithm.
|
| DSAPrivateKeySpec |
This class specifies a DSA private key with its associated parameters.
|
| DSAPublicKeySpec |
This class specifies a DSA public key with its associated parameters.
|
| EncodedKeySpec |
This class represents a public or private key in encoded format.
|
| PKCS8EncodedKeySpec |
This class represents the ASN.1 encoding of a private key,
encoded according to the ASN.1 type
PrivateKeyInfo. |
| PSSParameterSpec |
This class specifies a parameter spec for RSA PSS encoding scheme,
as defined in the PKCS#1 v2.1.
|
| RSAKeyGenParameterSpec |
This class specifies the set of parameters used to generate an RSA
key pair.
|
| RSAPrivateCrtKeySpec |
This class specifies an RSA private key, as defined in the PKCS#1
standard, using the Chinese Remainder Theorem (CRT) information values for
efficiency.
|
| RSAPrivateKeySpec |
This class specifies an RSA private key.
|
| RSAPublicKeySpec |
This class specifies an RSA public key.
|
| X509EncodedKeySpec |
This class represents the ASN.1 encoding of a public key,
encoded according to the ASN.1 type
SubjectPublicKeyInfo. |
| Exception | Description |
|---|---|
| InvalidKeySpecException |
This is the exception for invalid key specifications.
|
| InvalidParameterSpecException |
This is the exception for invalid parameter specifications.
|
A key specification is a transparent representation of the key material that constitutes a key. A key may be specified in an algorithm-specific way, or in an algorithm-independent encoding format (such as ASN.1). This package contains key specifications for DSA public and private keys, RSA public and private keys, PKCS #8 private keys in DER-encoded format, and X.509 public and private keys in DER-encoded format.
An algorithm parameter specification is a transparent representation of the sets of parameters used with an algorithm. This package contains an algorithm parameter specification for parameters used with the DSA algorithm.
Copyright © 2013 CableLabs. All rights reserved.