| Package | Description |
|---|---|
| java.security |
Provides the classes and interfaces for the security framework.
|
| java.security.spec |
Provides classes and interfaces for key specifications and algorithm
parameter specifications.
|
| Class and Description |
|---|
| AlgorithmParameterSpec
A (transparent) specification of cryptographic parameters.
|
| InvalidKeySpecException
This is the exception for invalid key specifications.
|
| InvalidParameterSpecException
This is the exception for invalid parameter specifications.
|
| KeySpec
A (transparent) specification of the key material
that constitutes a cryptographic key.
|
| Class and Description |
|---|
| AlgorithmParameterSpec
A (transparent) specification of cryptographic parameters.
|
| EncodedKeySpec
This class represents a public or private key in encoded format.
|
| KeySpec
A (transparent) specification of the key material
that constitutes a cryptographic key.
|
| RSAPrivateKeySpec
This class specifies an RSA private key.
|
Copyright © 2013 CableLabs. All rights reserved.