| Package | Description |
|---|---|
| java.awt |
Contains all of the classes for creating user
interfaces and for painting graphics and images.
|
| java.awt.event |
Provides interfaces and classes for dealing with different
types of events fired by AWT components.
|
| java.awt.im |
Provides classes and interfaces for the input method framework.
|
| java.text |
Provides classes and interfaces for handling text, dates, numbers, and messages
in a manner independent of natural languages.
|
| Modifier and Type | Method and Description |
|---|---|
abstract void |
Graphics.drawString(AttributedCharacterIterator iterator,
int x,
int y)
Draws the text given by the specified iterator, using this
graphics context's current color.
|
| Modifier and Type | Method and Description |
|---|---|
AttributedCharacterIterator |
InputMethodEvent.getText()
Gets the combined committed and composed text.
|
| Constructor and Description |
|---|
InputMethodEvent(Component source,
int id,
AttributedCharacterIterator text,
int committedCharacterCount,
TextHitInfo caret,
TextHitInfo visiblePosition)
Constructs an
InputMethodEvent with the specified
source component, type, text, caret, and visiblePosition. |
InputMethodEvent(Component source,
int id,
long when,
AttributedCharacterIterator text,
int committedCharacterCount,
TextHitInfo caret,
TextHitInfo visiblePosition)
Constructs an
InputMethodEvent with the specified
source component, type, time, text, caret, and visiblePosition. |
| Modifier and Type | Method and Description |
|---|---|
AttributedCharacterIterator |
InputMethodRequests.cancelLatestCommittedText(AttributedCharacterIterator.Attribute[] attributes)
Gets the latest committed text from the text editing component and
removes it from the component's text body.
|
AttributedCharacterIterator |
InputMethodRequests.getCommittedText(int beginIndex,
int endIndex,
AttributedCharacterIterator.Attribute[] attributes)
Gets an iterator providing access to the entire text and attributes
contained in the text editing component except for uncommitted
text.
|
AttributedCharacterIterator |
InputMethodRequests.getSelectedText(AttributedCharacterIterator.Attribute[] attributes)
Gets the currently selected text from the text editing component.
|
| Modifier and Type | Method and Description |
|---|---|
AttributedCharacterIterator |
SimpleDateFormat.formatToCharacterIterator(Object obj)
Formats an Object producing an
AttributedCharacterIterator. |
AttributedCharacterIterator |
MessageFormat.formatToCharacterIterator(Object arguments)
Formats an array of objects and inserts them into the
MessageFormat's pattern, producing an
AttributedCharacterIterator. |
AttributedCharacterIterator |
Format.formatToCharacterIterator(Object obj)
Formats an Object producing an
AttributedCharacterIterator. |
AttributedCharacterIterator |
DecimalFormat.formatToCharacterIterator(Object obj)
Formats an Object producing an
AttributedCharacterIterator. |
AttributedCharacterIterator |
AttributedString.getIterator()
Creates an AttributedCharacterIterator instance that provides access to the entire contents of
this string.
|
AttributedCharacterIterator |
AttributedString.getIterator(AttributedCharacterIterator.Attribute[] attributes)
Creates an AttributedCharacterIterator instance that provides access to
selected contents of this string.
|
AttributedCharacterIterator |
AttributedString.getIterator(AttributedCharacterIterator.Attribute[] attributes,
int beginIndex,
int endIndex)
Creates an AttributedCharacterIterator instance that provides access to
selected contents of this string.
|
| Constructor and Description |
|---|
AttributedString(AttributedCharacterIterator text)
Constructs an AttributedString instance with the given attributed
text represented by AttributedCharacterIterator.
|
AttributedString(AttributedCharacterIterator text,
int beginIndex,
int endIndex)
Constructs an AttributedString instance with the subrange of
the given attributed text represented by
AttributedCharacterIterator.
|
AttributedString(AttributedCharacterIterator text,
int beginIndex,
int endIndex,
AttributedCharacterIterator.Attribute[] attributes)
Constructs an AttributedString instance with the subrange of
the given attributed text represented by
AttributedCharacterIterator.
|
Copyright © 2013 CableLabs. All rights reserved.