| Package | Description |
|---|---|
| java.awt |
Contains all of the classes for creating user
interfaces and for painting graphics and images.
|
| java.awt.font |
Provides classes and interface relating to fonts.
|
| java.awt.im |
Provides classes and interfaces for the input method framework.
|
| java.text |
Provides classes and interfaces for handling text, dates, numbers, and messages
in a manner independent of natural languages.
|
| Modifier and Type | Method and Description |
|---|---|
AttributedCharacterIterator.Attribute[] |
Font.getAvailableAttributes()
Returns the keys of all the attributes supported by this
Font. |
| Modifier and Type | Class and Description |
|---|---|
class |
TextAttribute
The
TextAttribute class defines attribute keys and
attribute values used for text rendering. |
| Modifier and Type | Method and Description |
|---|---|
AttributedCharacterIterator |
InputMethodRequests.cancelLatestCommittedText(AttributedCharacterIterator.Attribute[] attributes)
Gets the latest committed text from the text editing component and
removes it from the component's text body.
|
AttributedCharacterIterator |
InputMethodRequests.getCommittedText(int beginIndex,
int endIndex,
AttributedCharacterIterator.Attribute[] attributes)
Gets an iterator providing access to the entire text and attributes
contained in the text editing component except for uncommitted
text.
|
AttributedCharacterIterator |
InputMethodRequests.getSelectedText(AttributedCharacterIterator.Attribute[] attributes)
Gets the currently selected text from the text editing component.
|
| Modifier and Type | Class and Description |
|---|---|
static class |
DateFormat.Field
Defines constants that are used as attribute keys in the
AttributedCharacterIterator returned
from DateFormat.formatToCharacterIterator and as
field identifiers in FieldPosition. |
static class |
Format.Field
Defines constants that are used as attribute keys in the
AttributedCharacterIterator returned
from Format.formatToCharacterIterator and as
field identifiers in FieldPosition. |
static class |
MessageFormat.Field
Defines constants that are used as attribute keys in the
AttributedCharacterIterator returned
from MessageFormat.formatToCharacterIterator. |
static class |
NumberFormat.Field
Defines constants that are used as attribute keys in the
AttributedCharacterIterator returned
from NumberFormat.formatToCharacterIterator and as
field identifiers in FieldPosition. |
| Modifier and Type | Field and Description |
|---|---|
static AttributedCharacterIterator.Attribute |
AttributedCharacterIterator.Attribute.INPUT_METHOD_SEGMENT
Attribute key for input method segments.
|
static AttributedCharacterIterator.Attribute |
AttributedCharacterIterator.Attribute.LANGUAGE
Attribute key for the language of some text.
|
static AttributedCharacterIterator.Attribute |
AttributedCharacterIterator.Attribute.READING
Attribute key for the reading of some text.
|
| Modifier and Type | Method and Description |
|---|---|
void |
AttributedString.addAttribute(AttributedCharacterIterator.Attribute attribute,
Object value)
Adds an attribute to the entire string.
|
void |
AttributedString.addAttribute(AttributedCharacterIterator.Attribute attribute,
Object value,
int beginIndex,
int endIndex)
Adds an attribute to a subrange of the string.
|
Object |
AttributedCharacterIterator.getAttribute(AttributedCharacterIterator.Attribute attribute)
Returns the value of the named attribute for the current character.
|
AttributedCharacterIterator |
AttributedString.getIterator(AttributedCharacterIterator.Attribute[] attributes)
Creates an AttributedCharacterIterator instance that provides access to
selected contents of this string.
|
AttributedCharacterIterator |
AttributedString.getIterator(AttributedCharacterIterator.Attribute[] attributes,
int beginIndex,
int endIndex)
Creates an AttributedCharacterIterator instance that provides access to
selected contents of this string.
|
int |
AttributedCharacterIterator.getRunLimit(AttributedCharacterIterator.Attribute attribute)
Returns the index of the first character following the run
with respect to the given attribute containing the current character.
|
int |
AttributedCharacterIterator.getRunStart(AttributedCharacterIterator.Attribute attribute)
Returns the index of the first character of the run
with respect to the given attribute containing the current character.
|
| Constructor and Description |
|---|
AttributedString(AttributedCharacterIterator text,
int beginIndex,
int endIndex,
AttributedCharacterIterator.Attribute[] attributes)
Constructs an AttributedString instance with the subrange of
the given attributed text represented by
AttributedCharacterIterator.
|
Copyright © 2013 CableLabs. All rights reserved.