| Package | Description |
|---|---|
| java.text |
Provides classes and interfaces for handling text, dates, numbers, and messages
in a manner independent of natural languages.
|
| Modifier and Type | Method and Description |
|---|---|
DateFormatSymbols |
SimpleDateFormat.getDateFormatSymbols()
Gets a copy of the date and time format symbols of this date format.
|
| Modifier and Type | Method and Description |
|---|---|
void |
SimpleDateFormat.setDateFormatSymbols(DateFormatSymbols newFormatSymbols)
Sets the date and time format symbols of this date format.
|
| Constructor and Description |
|---|
SimpleDateFormat(String pattern,
DateFormatSymbols formatSymbols)
Constructs a
SimpleDateFormat using the given pattern and
date format symbols. |
Copyright © 2013 CableLabs. All rights reserved.