| Package | Description |
|---|---|
| java.text |
Provides classes and interfaces for handling text, dates, numbers, and messages
in a manner independent of natural languages.
|
| Modifier and Type | Method and Description |
|---|---|
DecimalFormatSymbols |
DecimalFormat.getDecimalFormatSymbols()
Returns the decimal format symbols, which is generally not changed
by the programmer or user.
|
| Modifier and Type | Method and Description |
|---|---|
void |
DecimalFormat.setDecimalFormatSymbols(DecimalFormatSymbols newSymbols)
Sets the decimal format symbols, which is generally not changed
by the programmer or user.
|
| Constructor and Description |
|---|
DecimalFormat(String pattern,
DecimalFormatSymbols symbols)
Creates a DecimalFormat using the given pattern and symbols.
|
Copyright © 2013 CableLabs. All rights reserved.