| Package | Description |
|---|---|
| java.text |
Provides classes and interfaces for handling text, dates, numbers, and messages
in a manner independent of natural languages.
|
| Modifier and Type | Method and Description |
|---|---|
Number |
NumberFormat.parse(String source)
Parses text from the beginning of the given string to produce a number.
|
Object[] |
MessageFormat.parse(String source)
Parses text from the beginning of the given string to produce an object
array.
|
Date |
DateFormat.parse(String source)
Parses text from the beginning of the given string to produce a date.
|
Object |
Format.parseObject(String source)
Parses text from the beginning of the given string to produce an object.
|
| Constructor and Description |
|---|
RuleBasedCollator(String rules)
RuleBasedCollator constructor.
|
Copyright © 2013 CableLabs. All rights reserved.