| Package | Description |
|---|---|
| java.awt |
Contains all of the classes for creating user
interfaces and for painting graphics and images.
|
| java.awt.event |
Provides interfaces and classes for dealing with different
types of events fired by AWT components.
|
| java.awt.font |
Provides classes and interface relating to fonts.
|
| java.awt.im |
Provides classes and interfaces for the input method framework.
|
| java.text |
Provides classes and interfaces for handling text, dates, numbers, and messages
in a manner independent of natural languages.
|
| Class and Description |
|---|
| AttributedCharacterIterator
An AttributedCharacterIterator allows iteration through both text and
related attribute information.
|
| AttributedCharacterIterator.Attribute
Defines attribute keys that are used to identify text attributes.
|
| Class and Description |
|---|
| AttributedCharacterIterator
An AttributedCharacterIterator allows iteration through both text and
related attribute information.
|
| Class and Description |
|---|
| AttributedCharacterIterator.Attribute
Defines attribute keys that are used to identify text attributes.
|
| Class and Description |
|---|
| AttributedCharacterIterator
An AttributedCharacterIterator allows iteration through both text and
related attribute information.
|
| AttributedCharacterIterator.Attribute
Defines attribute keys that are used to identify text attributes.
|
| Class and Description |
|---|
| AttributedCharacterIterator
An AttributedCharacterIterator allows iteration through both text and
related attribute information.
|
| AttributedCharacterIterator.Attribute
Defines attribute keys that are used to identify text attributes.
|
| BreakIterator
The
BreakIterator class implements methods for finding
the location of boundaries in text. |
| CharacterIterator
This interface defines a protocol for bidirectional iteration over text.
|
| CollationElementIterator
The
CollationElementIterator class is used as an iterator
to walk through each character of an international string. |
| CollationKey
A
CollationKey represents a String under the
rules of a specific Collator object. |
| Collator
The
Collator class performs locale-sensitive
String comparison. |
| DateFormat
DateFormat is an abstract class for date/time formatting subclasses which
formats and parses dates or time in a language-independent manner.
|
| DateFormat.Field
Defines constants that are used as attribute keys in the
AttributedCharacterIterator returned
from DateFormat.formatToCharacterIterator and as
field identifiers in FieldPosition. |
DateFormatSymbols
DateFormatSymbols is a public class for encapsulating
localizable date-time formatting data, such as the names of the
months, the names of the days of the week, and the time zone data. |
| DecimalFormatSymbols
This class represents the set of symbols (such as the decimal separator,
the grouping separator, and so on) needed by
DecimalFormat
to format numbers. |
FieldPosition
FieldPosition is a simple class used by Format
and its subclasses to identify fields in formatted output. |
Format
Format is an abstract base class for formatting locale-sensitive
information such as dates, messages, and numbers. |
| Format.Field
Defines constants that are used as attribute keys in the
AttributedCharacterIterator returned
from Format.formatToCharacterIterator and as
field identifiers in FieldPosition. |
| MessageFormat.Field
Defines constants that are used as attribute keys in the
AttributedCharacterIterator returned
from MessageFormat.formatToCharacterIterator. |
NumberFormat
NumberFormat is the abstract base class for all number
formats. |
| NumberFormat.Field
Defines constants that are used as attribute keys in the
AttributedCharacterIterator returned
from NumberFormat.formatToCharacterIterator and as
field identifiers in FieldPosition. |
| ParseException
Signals that an error has been reached unexpectedly
while parsing.
|
ParsePosition
ParsePosition is a simple class used by Format
and its subclasses to keep track of the current position during parsing. |
Copyright © 2013 CableLabs. All rights reserved.