public class HashSet extends AbstractSet implements Set, Cloneable, Serializable
This class offers constant time performance for the basic operations (add, remove, contains and size), assuming the hash function disperses the elements properly among the buckets. Iterating over this set requires time proportional to the sum of the HashSet instance's size (the number of elements) plus the "capacity" of the backing HashMap instance (the number of buckets). Thus, it's very important not to set the initial capacity too high (or the load factor too low) if iteration performance is important.
Note that this implementation is not synchronized. If multiple threads access a set concurrently, and at least one of the threads modifies the set, it must be synchronized externally. This is typically accomplished by synchronizing on some object that naturally encapsulates the set. If no such object exists, the set should be "wrapped" using the Collections.synchronizedSet method. This is best done at creation time, to prevent accidental unsynchronized access to the HashSet instance:
Set s = Collections.synchronizedSet(new HashSet(...));
The iterators returned by this class's iterator method are fail-fast: if the set is modified at any time after the iterator is created, in any way except through the iterator's own remove method, the Iterator throws a ConcurrentModificationException. Thus, in the face of concurrent modification, the iterator fails quickly and cleanly, rather than risking arbitrary, non-deterministic behavior at an undetermined time in the future.
Note that the fail-fast behavior of an iterator cannot be guaranteed as it is, generally speaking, impossible to make any hard guarantees in the presence of unsynchronized concurrent modification. Fail-fast iterators throw ConcurrentModificationException on a best-effort basis. Therefore, it would be wrong to write a program that depended on this exception for its correctness: the fail-fast behavior of iterators should be used only to detect bugs.
This class is a member of the Java Collections Framework.
Collection,
Set,
TreeSet,
Collections.synchronizedSet(Set),
HashMap,
Serialized Form| Constructor and Description |
|---|
HashSet()
Constructs a new, empty set; the backing HashMap instance has
default initial capacity (16) and load factor (0.75).
|
HashSet(Collection c)
Constructs a new set containing the elements in the specified
collection.
|
HashSet(int initialCapacity)
Constructs a new, empty set; the backing HashMap instance has
the specified initial capacity and default load factor, which is
0.75.
|
HashSet(int initialCapacity,
float loadFactor)
Constructs a new, empty set; the backing HashMap instance has
the specified initial capacity and the specified load factor.
|
| Modifier and Type | Method and Description |
|---|---|
boolean |
add(Object o)
Adds the specified element to this set if it is not already
present.
|
void |
clear()
Removes all of the elements from this set.
|
Object |
clone()
Returns a shallow copy of this HashSet instance: the elements
themselves are not cloned.
|
boolean |
contains(Object o)
Returns true if this set contains the specified element.
|
boolean |
isEmpty()
Returns true if this set contains no elements.
|
Iterator |
iterator()
Returns an iterator over the elements in this set.
|
boolean |
remove(Object o)
Removes the specified element from this set if it is present.
|
int |
size()
Returns the number of elements in this set (its cardinality).
|
equals, hashCode, removeAlladdAll, containsAll, retainAll, toArray, toArray, toStringpublic HashSet()
public HashSet(Collection c)
c - the collection whose elements are to be placed into this set.NullPointerException - if the specified collection is null.public HashSet(int initialCapacity,
float loadFactor)
initialCapacity - the initial capacity of the hash map.loadFactor - the load factor of the hash map.IllegalArgumentException - if the initial capacity is less
than zero, or if the load factor is nonpositive.public HashSet(int initialCapacity)
initialCapacity - the initial capacity of the hash table.IllegalArgumentException - if the initial capacity is less
than zero.public Iterator iterator()
iterator in interface Collectioniterator in interface Setiterator in class AbstractCollectionConcurrentModificationExceptionpublic int size()
size in interface Collectionsize in interface Setsize in class AbstractCollectionpublic boolean isEmpty()
isEmpty in interface CollectionisEmpty in interface SetisEmpty in class AbstractCollectionpublic boolean contains(Object o)
contains in interface Collectioncontains in interface Setcontains in class AbstractCollectiono - element whose presence in this set is to be tested.public boolean add(Object o)
add in interface Collectionadd in interface Setadd in class AbstractCollectiono - element to be added to this set.public boolean remove(Object o)
remove in interface Collectionremove in interface Setremove in class AbstractCollectiono - object to be removed from this set, if present.public void clear()
clear in interface Collectionclear in interface Setclear in class AbstractCollectionCopyright © 2013 CableLabs. All rights reserved.