public static interface Map.Entry
Map.entrySet()| Modifier and Type | Method and Description |
|---|---|
boolean |
equals(Object o)
Compares the specified object with this entry for equality.
|
Object |
getKey()
Returns the key corresponding to this entry.
|
Object |
getValue()
Returns the value corresponding to this entry.
|
int |
hashCode()
Returns the hash code value for this map entry.
|
Object |
setValue(Object value)
Replaces the value corresponding to this entry with the specified
value (optional operation).
|
Object getKey()
Object getValue()
Object setValue(Object value)
value - new value to be stored in this entry.UnsupportedOperationException - if the put operation
is not supported by the backing map.ClassCastException - if the class of the specified value
prevents it from being stored in the backing map.IllegalArgumentException - if some aspect of this value
prevents it from being stored in the backing map.NullPointerException - the backing map does not permit
null values, and the specified value is
null.boolean equals(Object o)
(e1.getKey()==null ?
e2.getKey()==null : e1.getKey().equals(e2.getKey())) &&
(e1.getValue()==null ?
e2.getValue()==null : e1.getValue().equals(e2.getValue()))
This ensures that the equals method works properly across
different implementations of the Map.Entry interface.equals in class Objecto - object to be compared for equality with this map entry.Object.hashCode(),
Hashtableint hashCode()
(e.getKey()==null ? 0 : e.getKey().hashCode()) ^
(e.getValue()==null ? 0 : e.getValue().hashCode())
This ensures that e1.equals(e2) implies that
e1.hashCode()==e2.hashCode() for any two Entries
e1 and e2, as required by the general
contract of Object.hashCode.hashCode in class ObjectObject.hashCode(),
Object.equals(Object),
equals(Object)Copyright © 2013 CableLabs. All rights reserved.