public class Stack extends Vector
Stack class represents a last-in-first-out
(LIFO) stack of objects. It extends class Vector with five
operations that allow a vector to be treated as a stack. The usual
push and pop operations are provided, as well as a
method to peek at the top item on the stack, a method to test
for whether the stack is empty, and a method to search
the stack for an item and discover how far it is from the top.
When a stack is first created, it contains no items.
capacityIncrement, elementCount, elementDatamodCount| Constructor and Description |
|---|
Stack()
Creates an empty Stack.
|
| Modifier and Type | Method and Description |
|---|---|
boolean |
empty()
Tests if this stack is empty.
|
Object |
peek()
Looks at the object at the top of this stack without removing it
from the stack.
|
Object |
pop()
Removes the object at the top of this stack and returns that
object as the value of this function.
|
Object |
push(Object item)
Pushes an item onto the top of this stack.
|
int |
search(Object o)
Returns the 1-based position where an object is on this stack.
|
add, add, addAll, addAll, addElement, capacity, clear, clone, contains, containsAll, copyInto, elementAt, elements, ensureCapacity, equals, firstElement, get, hashCode, indexOf, indexOf, insertElementAt, isEmpty, lastElement, lastIndexOf, lastIndexOf, remove, remove, removeAll, removeAllElements, removeElement, removeElementAt, removeRange, retainAll, set, setElementAt, setSize, size, subList, toArray, toArray, toString, trimToSizeiterator, listIterator, listIteratorfinalize, getClass, notify, notifyAll, wait, wait, waititerator, listIterator, listIteratorpublic Object push(Object item)
addElement(item)
item - the item to be pushed onto this stack.item argument.Vector.addElement(java.lang.Object)public Object pop()
EmptyStackException - if this stack is empty.public Object peek()
EmptyStackException - if this stack is empty.public boolean empty()
true if and only if this stack contains
no items; false otherwise.public int search(Object o)
o - the desired object.-1
indicates that the object is not on the stack.Copyright © 2013 CableLabs. All rights reserved.