| Package | Description |
|---|---|
| java.util |
Contains the collections framework, legacy collection classes, event model,
date and time facilities, internationalization, and miscellaneous utility
classes (a string tokenizer, a random-number generator, and a bit array).
|
| Modifier and Type | Class and Description |
|---|---|
class |
HashMap
Hash table based implementation of the Map interface.
|
class |
IdentityHashMap
This class implements the Map interface with a hash table, using
reference-equality in place of object-equality when comparing keys (and
values).
|
class |
LinkedHashMap
Hash table and linked list implementation of the Map interface,
with predictable iteration order.
|
class |
TreeMap
Red-Black tree based implementation of the SortedMap interface.
|
class |
WeakHashMap
A hashtable-based Map implementation with weak keys.
|
Copyright © 2012 CableLabs. All Rights Reserved.