| Package | Description |
|---|---|
| java.util |
Contains the collections framework, legacy collection classes, event model,
date and time facilities, internationalization, and miscellaneous utility
classes (a string tokenizer, a random-number generator, and a bit array).
|
| Modifier and Type | Class and Description |
|---|---|
class |
HashSet
This class implements the Set interface, backed by a hash table
(actually a HashMap instance).
|
class |
LinkedHashSet
Hash table and linked list implementation of the Set interface,
with predictable iteration order.
|
class |
TreeSet
This class implements the Set interface, backed by a
TreeMap instance.
|
Copyright © 2013 CableLabs. All rights reserved.