| Package | Description |
|---|---|
| java.util |
Contains the collections framework, legacy collection classes, event model,
date and time facilities, internationalization, and miscellaneous utility
classes (a string tokenizer, a random-number generator, and a bit array).
|
| org.dvb.application |
Provides access to lists of applications which are available
in this context and the ability to launch those applications.
|
| Modifier and Type | Method and Description |
|---|---|
BitSet |
BitSet.get(int fromIndex,
int toIndex)
Returns a new BitSet composed of bits from this BitSet
from fromIndex(inclusive) to toIndex(exclusive).
|
| Modifier and Type | Method and Description |
|---|---|
void |
BitSet.and(BitSet set)
Performs a logical AND of this target bit set with the
argument bit set.
|
void |
BitSet.andNot(BitSet set)
Clears all of the bits in this
BitSet whose corresponding
bit is set in the specified BitSet. |
boolean |
BitSet.intersects(BitSet set)
Returns true if the specified
BitSet has any bits set to
true that are also set to true in this
BitSet. |
void |
BitSet.or(BitSet set)
Performs a logical OR of this bit set with the bit set
argument.
|
void |
BitSet.xor(BitSet set)
Performs a logical XOR of this bit set with the bit set
argument.
|
| Modifier and Type | Method and Description |
|---|---|
BitSet |
AppIcon.getIconFlags()
This method returns the flags identifying which icons are provided for the application.
|
Copyright © 2013 CableLabs. All rights reserved.