| Package | Description |
|---|---|
| java.text |
Provides classes and interfaces for handling text, dates, numbers, and messages
in a manner independent of natural languages.
|
| java.util |
Contains the collections framework, legacy collection classes, event model,
date and time facilities, internationalization, and miscellaneous utility
classes (a string tokenizer, a random-number generator, and a bit array).
|
| Modifier and Type | Field and Description |
|---|---|
protected Calendar |
DateFormat.calendar
The calendar that
DateFormat uses to produce the time field
values needed to implement date and time formatting. |
| Modifier and Type | Method and Description |
|---|---|
Calendar |
DateFormat.getCalendar()
Gets the calendar associated with this date/time formatter.
|
| Modifier and Type | Method and Description |
|---|---|
void |
DateFormat.setCalendar(Calendar newCalendar)
Set the calendar to be used by this date format.
|
| Modifier and Type | Class and Description |
|---|---|
class |
GregorianCalendar
GregorianCalendar is a concrete subclass of
Calendar
and provides the standard calendar used by most of the world. |
| Modifier and Type | Method and Description |
|---|---|
static Calendar |
Calendar.getInstance()
Gets a calendar using the default time zone and locale.
|
static Calendar |
Calendar.getInstance(Locale aLocale)
Gets a calendar using the default time zone and specified locale.
|
static Calendar |
Calendar.getInstance(TimeZone zone)
Gets a calendar using the specified time zone and default locale.
|
static Calendar |
Calendar.getInstance(TimeZone zone,
Locale aLocale)
Gets a calendar with the specified time zone and locale.
|
Copyright © 2012 CableLabs. All Rights Reserved.