| Package | Description |
|---|---|
| java.security |
Provides the classes and interfaces for the security framework.
|
| java.security.cert |
Provides classes and interfaces for parsing and managing
certificates, certificate revocation lists (CRLs), and
certification paths.
|
| java.util |
Contains the collections framework, legacy collection classes, event model,
date and time facilities, internationalization, and miscellaneous utility
classes (a string tokenizer, a random-number generator, and a bit array).
|
| java.util.jar |
Provides classes for reading and writing the JAR (Java ARchive) file
format, which is based on the standard ZIP file format with an
optional manifest file.
|
| Modifier and Type | Method and Description |
|---|---|
Collection |
Provider.values()
Returns an unmodifiable Collection view of the property values
contained in this provider.
|
| Modifier and Type | Method and Description |
|---|---|
abstract Collection |
CertificateFactorySpi.engineGenerateCertificates(InputStream inStream)
Returns a (possibly empty) collection view of the certificates read
from the given input stream
inStream. |
abstract Collection |
CertificateFactorySpi.engineGenerateCRLs(InputStream inStream)
Returns a (possibly empty) collection view of the CRLs read
from the given input stream
inStream. |
Collection |
CertificateFactory.generateCertificates(InputStream inStream)
Returns a (possibly empty) collection view of the certificates read
from the given input stream
inStream. |
Collection |
CertificateFactory.generateCRLs(InputStream inStream)
Returns a (possibly empty) collection view of the CRLs read
from the given input stream
inStream. |
Collection |
X509Certificate.getIssuerAlternativeNames()
Gets an immutable collection of issuer alternative names from the
IssuerAltName extension, (OID = 2.5.29.18). |
Collection |
X509Certificate.getSubjectAlternativeNames()
Gets an immutable collection of subject alternative names from the
SubjectAltName extension, (OID = 2.5.29.17). |
| Modifier and Type | Interface and Description |
|---|---|
interface |
List
An ordered collection (also known as a sequence).
|
interface |
Set
A collection that contains no duplicate elements.
|
interface |
SortedSet
A set that further guarantees that its iterator will traverse the set in
ascending element order, sorted according to the natural ordering of
its elements (see Comparable), or by a Comparator provided at sorted set
creation time.
|
| Modifier and Type | Class and Description |
|---|---|
class |
AbstractCollection
This class provides a skeletal implementation of the Collection
interface, to minimize the effort required to implement this interface.
|
class |
AbstractList
This class provides a skeletal implementation of the List
interface to minimize the effort required to implement this interface
backed by a "random access" data store (such as an array).
|
class |
AbstractSequentialList
This class provides a skeletal implementation of the List
interface to minimize the effort required to implement this interface
backed by a "sequential access" data store (such as a linked list).
|
class |
AbstractSet
This class provides a skeletal implementation of the Set
interface to minimize the effort required to implement this
interface.
|
class |
ArrayList
Resizable-array implementation of the List interface.
|
class |
HashSet
This class implements the Set interface, backed by a hash table
(actually a HashMap instance).
|
class |
LinkedHashSet
Hash table and linked list implementation of the Set interface,
with predictable iteration order.
|
class |
LinkedList
Linked list implementation of the List interface.
|
class |
Stack
The
Stack class represents a last-in-first-out
(LIFO) stack of objects. |
class |
TreeSet
This class implements the Set interface, backed by a
TreeMap instance.
|
class |
Vector
The
Vector class implements a growable array of
objects. |
| Modifier and Type | Method and Description |
|---|---|
static Collection |
Collections.synchronizedCollection(Collection c)
Returns a synchronized (thread-safe) collection backed by the specified
collection.
|
static Collection |
Collections.unmodifiableCollection(Collection c)
Returns an unmodifiable view of the specified collection.
|
Collection |
WeakHashMap.values()
Returns a collection view of the values contained in this map.
|
Collection |
TreeMap.values()
Returns a collection view of the values contained in this map.
|
Collection |
Map.values()
Returns a collection view of the values contained in this map.
|
Collection |
IdentityHashMap.values()
Returns a collection view of the values contained in this map.
|
Collection |
Hashtable.values()
Returns a Collection view of the values contained in this Hashtable.
|
Collection |
HashMap.values()
Returns a collection view of the values contained in this map.
|
Collection |
AbstractMap.values()
Returns a collection view of the values contained in this map.
|
| Modifier and Type | Method and Description |
|---|---|
boolean |
Vector.addAll(Collection c)
Appends all of the elements in the specified Collection to the end of
this Vector, in the order that they are returned by the specified
Collection's Iterator.
|
boolean |
TreeSet.addAll(Collection c)
Adds all of the elements in the specified collection to this set.
|
boolean |
Set.addAll(Collection c)
Adds all of the elements in the specified collection to this set if
they're not already present (optional operation).
|
boolean |
List.addAll(Collection c)
Appends all of the elements in the specified collection to the end of
this list, in the order that they are returned by the specified
collection's iterator (optional operation).
|
boolean |
LinkedList.addAll(Collection c)
Appends all of the elements in the specified collection to the end of
this list, in the order that they are returned by the specified
collection's iterator.
|
boolean |
Collection.addAll(Collection c)
Adds all of the elements in the specified collection to this collection
(optional operation).
|
boolean |
ArrayList.addAll(Collection c)
Appends all of the elements in the specified Collection to the end of
this list, in the order that they are returned by the
specified Collection's Iterator.
|
boolean |
AbstractCollection.addAll(Collection c)
Adds all of the elements in the specified collection to this collection
(optional operation).
|
boolean |
Vector.addAll(int index,
Collection c)
Inserts all of the elements in in the specified Collection into this
Vector at the specified position.
|
boolean |
List.addAll(int index,
Collection c)
Inserts all of the elements in the specified collection into this
list at the specified position (optional operation).
|
boolean |
LinkedList.addAll(int index,
Collection c)
Inserts all of the elements in the specified collection into this
list, starting at the specified position.
|
boolean |
ArrayList.addAll(int index,
Collection c)
Inserts all of the elements in the specified Collection into this
list, starting at the specified position.
|
boolean |
AbstractSequentialList.addAll(int index,
Collection c)
Inserts all of the elements in in the specified collection into this
list at the specified position.
|
boolean |
AbstractList.addAll(int index,
Collection c)
Inserts all of the elements in the specified collection into this list
at the specified position (optional operation).
|
boolean |
Vector.containsAll(Collection c)
Returns true if this Vector contains all of the elements in the
specified Collection.
|
boolean |
Set.containsAll(Collection c)
Returns true if this set contains all of the elements of the
specified collection.
|
boolean |
List.containsAll(Collection c)
Returns true if this list contains all of the elements of the
specified collection.
|
boolean |
Collection.containsAll(Collection c)
Returns true if this collection contains all of the elements
in the specified collection.
|
boolean |
AbstractCollection.containsAll(Collection c)
Returns true if this collection contains all of the elements
in the specified collection.
|
static Enumeration |
Collections.enumeration(Collection c)
Returns an enumeration over the specified collection.
|
static Object |
Collections.max(Collection coll)
Returns the maximum element of the given collection, according to the
natural ordering of its elements.
|
static Object |
Collections.max(Collection coll,
Comparator comp)
Returns the maximum element of the given collection, according to the
order induced by the specified comparator.
|
static Object |
Collections.min(Collection coll)
Returns the minimum element of the given collection, according to the
natural ordering of its elements.
|
static Object |
Collections.min(Collection coll,
Comparator comp)
Returns the minimum element of the given collection, according to the
order induced by the specified comparator.
|
boolean |
Vector.removeAll(Collection c)
Removes from this Vector all of its elements that are contained in the
specified Collection.
|
boolean |
Set.removeAll(Collection c)
Removes from this set all of its elements that are contained in the
specified collection (optional operation).
|
boolean |
List.removeAll(Collection c)
Removes from this list all the elements that are contained in the
specified collection (optional operation).
|
boolean |
Collection.removeAll(Collection c)
Removes all this collection's elements that are also contained in the
specified collection (optional operation).
|
boolean |
AbstractSet.removeAll(Collection c)
Removes from this set all of its elements that are contained in
the specified collection (optional operation).
|
boolean |
AbstractCollection.removeAll(Collection c)
Removes from this collection all of its elements that are contained in
the specified collection (optional operation).
|
boolean |
Vector.retainAll(Collection c)
Retains only the elements in this Vector that are contained in the
specified Collection.
|
boolean |
Set.retainAll(Collection c)
Retains only the elements in this set that are contained in the
specified collection (optional operation).
|
boolean |
List.retainAll(Collection c)
Retains only the elements in this list that are contained in the
specified collection (optional operation).
|
boolean |
Collection.retainAll(Collection c)
Retains only the elements in this collection that are contained in the
specified collection (optional operation).
|
boolean |
AbstractCollection.retainAll(Collection c)
Retains only the elements in this collection that are contained in the
specified collection (optional operation).
|
static Collection |
Collections.synchronizedCollection(Collection c)
Returns a synchronized (thread-safe) collection backed by the specified
collection.
|
static Collection |
Collections.unmodifiableCollection(Collection c)
Returns an unmodifiable view of the specified collection.
|
| Constructor and Description |
|---|
ArrayList(Collection c)
Constructs a list containing the elements of the specified
collection, in the order they are returned by the collection's
iterator.
|
HashSet(Collection c)
Constructs a new set containing the elements in the specified
collection.
|
LinkedHashSet(Collection c)
Constructs a new linked hash set with the same elements as the
specified collection.
|
LinkedList(Collection c)
Constructs a list containing the elements of the specified
collection, in the order they are returned by the collection's
iterator.
|
TreeSet(Collection c)
Constructs a new set containing the elements in the specified
collection, sorted according to the elements' natural order.
|
Vector(Collection c)
Constructs a vector containing the elements of the specified
collection, in the order they are returned by the collection's
iterator.
|
| Modifier and Type | Method and Description |
|---|---|
Collection |
Attributes.values()
Returns a Collection view of the attribute values contained in this Map.
|
Copyright © 2013 CableLabs. All rights reserved.