| Package | Description |
|---|---|
| java.lang |
Provides classes that are fundamental to the design of the Java
programming language.
|
| java.text |
Provides classes and interfaces for handling text, dates, numbers, and messages
in a manner independent of natural languages.
|
| java.util |
Contains the collections framework, legacy collection classes, event model,
date and time facilities, internationalization, and miscellaneous utility
classes (a string tokenizer, a random-number generator, and a bit array).
|
| Modifier and Type | Field and Description |
|---|---|
static Comparator |
String.CASE_INSENSITIVE_ORDER
A Comparator that orders
String objects as by
compareToIgnoreCase. |
| Modifier and Type | Class and Description |
|---|---|
class |
Collator
The
Collator class performs locale-sensitive
String comparison. |
class |
RuleBasedCollator
The
RuleBasedCollator class is a concrete subclass of
Collator that provides a simple, data-driven, table
collator. |
| Modifier and Type | Method and Description |
|---|---|
Comparator |
TreeSet.comparator()
Returns the comparator used to order this sorted set, or null
if this tree set uses its elements natural ordering.
|
Comparator |
TreeMap.comparator()
Returns the comparator used to order this map, or null if this
map uses its keys' natural order.
|
Comparator |
SortedSet.comparator()
Returns the comparator associated with this sorted set, or
null if it uses its elements' natural ordering.
|
Comparator |
SortedMap.comparator()
Returns the comparator associated with this sorted map, or
null if it uses its keys' natural ordering.
|
static Comparator |
Collections.reverseOrder()
Returns a comparator that imposes the reverse of the natural
ordering on a collection of objects that implement the
Comparable interface.
|
| Modifier and Type | Method and Description |
|---|---|
static int |
Collections.binarySearch(List list,
Object key,
Comparator c)
Searches the specified list for the specified object using the binary
search algorithm.
|
static int |
Arrays.binarySearch(Object[] a,
Object key,
Comparator c)
Searches the specified array for the specified object using the binary
search algorithm.
|
static Object |
Collections.max(Collection coll,
Comparator comp)
Returns the maximum element of the given collection, according to the
order induced by the specified comparator.
|
static Object |
Collections.min(Collection coll,
Comparator comp)
Returns the minimum element of the given collection, according to the
order induced by the specified comparator.
|
static void |
Collections.sort(List list,
Comparator c)
Sorts the specified list according to the order induced by the
specified comparator.
|
static void |
Arrays.sort(Object[] a,
Comparator c)
Sorts the specified array of objects according to the order induced by
the specified comparator.
|
static void |
Arrays.sort(Object[] a,
int fromIndex,
int toIndex,
Comparator c)
Sorts the specified range of the specified array of objects according
to the order induced by the specified comparator.
|
| Constructor and Description |
|---|
TreeMap(Comparator c)
Constructs a new, empty map, sorted according to the given comparator.
|
TreeSet(Comparator c)
Constructs a new, empty set, sorted according to the specified
comparator.
|
Copyright © 2013 CableLabs. All rights reserved.