| Package | Description |
|---|---|
| java.security |
Provides the classes and interfaces for the security framework.
|
| java.security.cert |
Provides classes and interfaces for parsing and managing
certificates, certificate revocation lists (CRLs), and
certification paths.
|
| java.text |
Provides classes and interfaces for handling text, dates, numbers, and messages
in a manner independent of natural languages.
|
| java.util |
Contains the collections framework, legacy collection classes, event model,
date and time facilities, internationalization, and miscellaneous utility
classes (a string tokenizer, a random-number generator, and a bit array).
|
| javax.security.cert |
Provides classes for public key certificates.
|
| javax.tv.service |
Provides mechanisms for accessing the service information (SI) database
and APIs representing the SI elements it contains.
|
| javax.tv.service.guide |
Provides APIs to support electronic program guides (EPGs), including program
schedules, program events and program ratings.
|
| org.dvb.application |
Provides access to lists of applications which are available
in this context and the ability to launch those applications.
|
| org.dvb.io.persistent |
Provides extensions to the java.io package for access to files
held in persistent storage.
|
| org.ocap.application |
|
| org.ocap.dvr.event |
Provides ability to receive DVR events.
|
| org.ocap.hn.content |
Provides representation of the content and content containers, and means of identifying content type.
|
| org.ocap.shared.dvr |
The shared DVR API for scheduling and managing recording requests.
|
| Modifier and Type | Method and Description |
|---|---|
abstract Date |
KeyStoreSpi.engineGetCreationDate(String alias)
Returns the creation date of the entry identified by the given alias.
|
Date |
KeyStore.getCreationDate(String alias)
Returns the creation date of the entry identified by the given alias.
|
| Modifier and Type | Method and Description |
|---|---|
abstract Date |
X509CRL.getNextUpdate()
Gets the
nextUpdate date from the CRL. |
abstract Date |
X509Certificate.getNotAfter()
Gets the
notAfter date from the validity period of
the certificate. |
abstract Date |
X509Certificate.getNotBefore()
Gets the
notBefore date from the validity period of
the certificate. |
abstract Date |
X509CRLEntry.getRevocationDate()
Gets the revocation date from this X509CRLEntry,
the revocationDate.
|
abstract Date |
X509CRL.getThisUpdate()
Gets the
thisUpdate date from the CRL. |
| Modifier and Type | Method and Description |
|---|---|
abstract void |
X509Certificate.checkValidity(Date date)
Checks that the given date is within the certificate's
validity period.
|
| Modifier and Type | Method and Description |
|---|---|
Date |
SimpleDateFormat.get2DigitYearStart()
Returns the beginning date of the 100-year period 2-digit years are interpreted
as being within.
|
Date |
DateFormat.parse(String source)
Parses text from the beginning of the given string to produce a date.
|
Date |
SimpleDateFormat.parse(String text,
ParsePosition pos)
Parses text from a string to produce a
Date. |
abstract Date |
DateFormat.parse(String source,
ParsePosition pos)
Parse a date/time string according to the given parse position.
|
| Modifier and Type | Method and Description |
|---|---|
String |
DateFormat.format(Date date)
Formats a Date into a date/time string.
|
StringBuffer |
SimpleDateFormat.format(Date date,
StringBuffer toAppendTo,
FieldPosition pos)
Formats the given
Date into a date/time string and appends
the result to the given StringBuffer. |
abstract StringBuffer |
DateFormat.format(Date date,
StringBuffer toAppendTo,
FieldPosition fieldPosition)
Formats a Date into a date/time string.
|
void |
SimpleDateFormat.set2DigitYearStart(Date startDate)
Sets the 100-year period 2-digit years will be interpreted as being in
to begin on the date the user specifies.
|
| Modifier and Type | Method and Description |
|---|---|
Date |
GregorianCalendar.getGregorianChange()
Gets the Gregorian Calendar change date.
|
Date |
Calendar.getTime()
Gets this Calendar's current time.
|
| Modifier and Type | Method and Description |
|---|---|
boolean |
Date.after(Date when)
Tests if this date is after the specified date.
|
boolean |
Date.before(Date when)
Tests if this date is before the specified date.
|
int |
Date.compareTo(Date anotherDate)
Compares two Dates for ordering.
|
abstract boolean |
TimeZone.inDaylightTime(Date date)
Queries if the given date is in daylight savings time in
this time zone.
|
boolean |
SimpleTimeZone.inDaylightTime(Date date)
Queries if the given date is in daylight saving time.
|
void |
Timer.schedule(TimerTask task,
Date time)
Schedules the specified task for execution at the specified time.
|
void |
Timer.schedule(TimerTask task,
Date firstTime,
long period)
Schedules the specified task for repeated fixed-delay execution,
beginning at the specified time.
|
void |
Timer.scheduleAtFixedRate(TimerTask task,
Date firstTime,
long period)
Schedules the specified task for repeated fixed-rate execution,
beginning at the specified time.
|
void |
GregorianCalendar.setGregorianChange(Date date)
Sets the GregorianCalendar change date.
|
void |
Calendar.setTime(Date date)
Sets this Calendar's current time with the given Date.
|
| Modifier and Type | Method and Description |
|---|---|
abstract Date |
X509Certificate.getNotAfter()
Gets the
notAfter date from the validity period of
the certificate. |
abstract Date |
X509Certificate.getNotBefore()
Gets the
notBefore date from the validity period of
the certificate. |
| Modifier and Type | Method and Description |
|---|---|
abstract void |
X509Certificate.checkValidity(Date date)
Checks that the specified date is within the certificate's
validity period.
|
| Modifier and Type | Method and Description |
|---|---|
Date |
SIRetrievable.getUpdateTime()
Returns the time when this object was last updated from data in
the broadcast.
|
| Modifier and Type | Method and Description |
|---|---|
Date |
ProgramEvent.getEndTime()
Returns the end time of this program event.
|
Date |
ProgramEvent.getStartTime()
Returns the start time of this program event.
|
| Modifier and Type | Method and Description |
|---|---|
SIRequest |
ProgramSchedule.retrieveFutureProgramEvent(Date time,
SIRequestor requestor)
Retrieves the program event for the specified time.
|
SIRequest |
ProgramSchedule.retrieveFutureProgramEvents(Date begin,
Date end,
SIRequestor requestor)
Retrieves all known program events on this service for the
specified time interval.
|
| Modifier and Type | Method and Description |
|---|---|
void |
DVBHTMLProxy.startTrigger(Date starttime)
Sends the application a start trigger at the specified time.
|
void |
DVBHTMLProxy.trigger(Date time,
Object triggerPayload)
Sends the application a trigger with the given payload at the specified time.
|
| Modifier and Type | Method and Description |
|---|---|
Date |
FileAttributes.getExpirationDate()
Returns the expiration date.
|
| Modifier and Type | Method and Description |
|---|---|
void |
FileAttributes.setExpirationDate(Date d)
Sets the expiration date.
|
| Modifier and Type | Method and Description |
|---|---|
Date |
AppPattern.getExpirationTime()
Returns the time for this AppPattern to expire or
null if it never expires. |
| Modifier and Type | Method and Description |
|---|---|
void |
AppManagerProxy.registerAddressingProperties(Properties properties,
boolean persist,
Date expirationDate)
Registers addressing properties used for comparison when an
addressing_descriptor from an AIT or XAIT is evaluated.
|
| Constructor and Description |
|---|
AppPattern(String idPattern,
int action,
int priority,
Date expirationTime,
Object info)
Constructs a new AppPattern with an expiration time and MSO
private information.
|
| Modifier and Type | Method and Description |
|---|---|
void |
LightweightTriggerSession.registerEvent(Date date,
String name,
int id,
byte[] data)
Registers a synchronized event to the stream event list for this session.
|
| Modifier and Type | Method and Description |
|---|---|
Date |
ContentResource.getCreationDate()
Gets the creation date of the content or NULL if not known.
|
Date |
ContentEntry.getCreationDate()
Gets the creation date of the content associated with this ContentEntry.
|
Date |
ContentContainer.getCreationDate()
Returns the creation date of this ContentContainer.
|
| Modifier and Type | Method and Description |
|---|---|
Date |
DeletionDetails.getDeletionTime()
Gets the date and time when the recorded service was deleted.
|
Date |
RecordedService.getRecordingStartTime()
Gets the time when the recording was initiated.
|
Date |
ServiceRecordingSpec.getStartTime()
Returns the start time passed as an argument to the constructor.
|
Date |
ServiceContextRecordingSpec.getStartTime()
Returns the start time passed as an argument to the constructor.
|
Date |
LocatorRecordingSpec.getStartTime()
Returns the start time passed as an argument to the constructor.
|
| Constructor and Description |
|---|
DeletionDetails(int reason,
Date date)
Constructs a DeletionDetails
|
LocatorRecordingSpec(Locator[] source,
Date startTime,
long duration,
RecordingProperties properties)
Constructor
|
ServiceContextRecordingSpec(ServiceContext serviceContext,
Date startTime,
long duration,
RecordingProperties properties)
Constructor
|
ServiceRecordingSpec(Service source,
Date startTime,
long duration,
RecordingProperties properties)
Constructor.
|
Copyright © 2013 CableLabs. All rights reserved.