| Package | Description |
|---|---|
| java.security |
Provides the classes and interfaces for the security framework.
|
| java.util |
Contains the collections framework, legacy collection classes, event model,
date and time facilities, internationalization, and miscellaneous utility
classes (a string tokenizer, a random-number generator, and a bit array).
|
| Modifier and Type | Class and Description |
|---|---|
class |
Provider
This class represents a "provider" for the
Java Security API, where a provider implements some or all parts of
Java Security.
|
| Modifier and Type | Class and Description |
|---|---|
class |
Hashtable
This class implements a hashtable, which maps keys to values.
|
class |
Properties
The
Properties class represents a persistent set of
properties. |
Copyright © 2013 CableLabs. All rights reserved.