| Package | Description |
|---|---|
| java.io |
Provides for system input and output through data streams,
serialization and the file system.
|
| java.lang |
Provides classes that are fundamental to the design of the Java
programming language.
|
| java.net |
Provides the classes for implementing networking applications.
|
| java.security |
Provides the classes and interfaces for the security framework.
|
| java.security.acl |
The classes and interfaces in this package have been
superseded by classes in the java.security package.
|
| java.util |
Contains the collections framework, legacy collection classes, event model,
date and time facilities, internationalization, and miscellaneous utility
classes (a string tokenizer, a random-number generator, and a bit array).
|
| java.util.jar |
Provides classes for reading and writing the JAR (Java ARchive) file
format, which is based on the standard ZIP file format with an
optional manifest file.
|
| java.util.zip |
Provides classes for reading and writing the standard ZIP and GZIP
file formats.
|
| javax.net.ssl |
Provides classes for the secure socket package.
|
| org.apache.log4j | |
| org.apache.log4j.spi | |
| org.dvb.application |
Provides access to lists of applications which are available
in this context and the ability to launch those applications.
|
| org.ocap.application |
|
| org.ocap.hardware |
The org.ocap.hardware package provides representations of several aspects of the hardware.
|
| org.ocap.hardware.device |
Provides extension classes and interfaces related to accessing and controlling
certain device parameters that are normally controlled by a
device manufacturer specific application.
|
| org.ocap.hn |
Provides representation of the main components of HN, such as servers, actions, action responses, and change listeners.
|
| org.ocap.hn.content |
Provides representation of the content and content containers, and means of identifying content type.
|
| org.ocap.hn.content.navigation |
Provides ways to search for content and filter results.
|
| org.ocap.media |
The org.ocap.media package is a collection of classes and interfaces for controlling access to various kinds of media components
|
| org.ocap.service |
The org.ocap.service package represents various aspects of a service.
|
| Constructor and Description |
|---|
SequenceInputStream(Enumeration e)
Initializes a newly created
SequenceInputStream
by remembering the argument, which must
be an Enumeration that produces
objects whose run-time type is InputStream. |
| Modifier and Type | Method and Description |
|---|---|
protected Enumeration |
ClassLoader.findResources(String name)
Returns an enumeration of
URL objects
representing all the resources with the given name. |
Enumeration |
ClassLoader.getResources(String name)
Finds all the resources with the given name.
|
static Enumeration |
ClassLoader.getSystemResources(String name)
Finds all resources of the specified name from the search path used to
load classes.
|
| Modifier and Type | Method and Description |
|---|---|
Enumeration |
URLClassLoader.findResources(String name)
Returns an Enumeration of URLs representing all of the resources
on the URL search path having the specified name.
|
Enumeration |
NetworkInterface.getInetAddresses()
Convenience method to return an Enumeration with all or a
subset of the InetAddresses bound to this network interface.
|
static Enumeration |
NetworkInterface.getNetworkInterfaces()
Returns all the interfaces on this machine.
|
| Modifier and Type | Method and Description |
|---|---|
Enumeration |
KeyStore.aliases()
Lists all the alias names of this keystore.
|
Enumeration |
Permissions.elements()
Returns an enumeration of all the Permission objects in all the
PermissionCollections in this Permissions object.
|
abstract Enumeration |
PermissionCollection.elements()
Returns an enumeration of all the Permission objects in the collection.
|
abstract Enumeration |
KeyStoreSpi.engineAliases()
Lists all the alias names of this keystore.
|
abstract Enumeration |
IdentityScope.identities()
Deprecated.
Returns an enumeration of all identities in this identity scope.
|
| Modifier and Type | Method and Description |
|---|---|
Enumeration |
Acl.entries()
Returns an enumeration of the entries in this ACL.
|
Enumeration |
Acl.getPermissions(Principal user)
Returns an enumeration for the set of allowed permissions for the
specified principal (representing an entity such as an individual or
a group).
|
Enumeration |
Group.members()
Returns an enumeration of the members in the group.
|
Enumeration |
AclEntry.permissions()
Returns an enumeration of the permissions in this ACL entry.
|
| Modifier and Type | Class and Description |
|---|---|
class |
StringTokenizer
The string tokenizer class allows an application to break a
string into tokens.
|
| Modifier and Type | Method and Description |
|---|---|
Enumeration |
Vector.elements()
Returns an enumeration of the components of this vector.
|
Enumeration |
Hashtable.elements()
Returns an enumeration of the values in this hashtable.
|
abstract Enumeration |
Dictionary.elements()
Returns an enumeration of the values in this dictionary.
|
static Enumeration |
Collections.enumeration(Collection c)
Returns an enumeration over the specified collection.
|
abstract Enumeration |
ResourceBundle.getKeys()
Returns an enumeration of the keys.
|
Enumeration |
PropertyResourceBundle.getKeys()
Implementation of ResourceBundle.getKeys.
|
Enumeration |
ListResourceBundle.getKeys()
Implementation of ResourceBundle.getKeys.
|
Enumeration |
Hashtable.keys()
Returns an enumeration of the keys in this hashtable.
|
abstract Enumeration |
Dictionary.keys()
Returns an enumeration of the keys in this dictionary.
|
Enumeration |
Properties.propertyNames()
Returns an enumeration of all the keys in this property list,
including distinct keys in the default property list if a key
of the same name has not already been found from the main
properties list.
|
| Modifier and Type | Method and Description |
|---|---|
static ArrayList |
Collections.list(Enumeration e)
Returns an array list containing the elements returned by the
specified enumeration in the order they are returned by the
enumeration.
|
| Modifier and Type | Method and Description |
|---|---|
Enumeration |
JarFile.entries()
Returns an enumeration of the ZIP file entries.
|
| Modifier and Type | Method and Description |
|---|---|
Enumeration |
ZipFile.entries()
Returns an enumeration of the ZIP file entries.
|
| Modifier and Type | Method and Description |
|---|---|
Enumeration |
SSLSessionContext.getIds()
Returns an Enumeration of all session id's grouped under this
SSLSessionContext. |
| Modifier and Type | Method and Description |
|---|---|
Enumeration |
Category.getAllAppenders()
Get the appenders contained in this category as an
Enumeration. |
Enumeration |
AsyncAppender.getAllAppenders()
Get iterator over attached appenders.
|
Enumeration |
Hierarchy.getCurrentCategories()
Deprecated.
Please use
Hierarchy.getCurrentLoggers() instead. |
static Enumeration |
Category.getCurrentCategories()
Deprecated.
Please use
LogManager.getCurrentLoggers() instead. |
static Enumeration |
LogManager.getCurrentLoggers() |
Enumeration |
Hierarchy.getCurrentLoggers()
Returns all the currently defined categories in this hierarchy as
an
Enumeration. |
| Modifier and Type | Method and Description |
|---|---|
Enumeration |
AppenderAttachable.getAllAppenders()
Get all previously added appenders as an Enumeration.
|
Enumeration |
LoggerRepository.getCurrentCategories()
Deprecated.
|
Enumeration |
LoggerRepository.getCurrentLoggers() |
| Modifier and Type | Method and Description |
|---|---|
Enumeration |
AppsDatabase.getAppAttributes(AppsDatabaseFilter filter)
Returns an enumeration of AppAttributes of the applications available.
|
Enumeration |
AppsDatabase.getAppIDs(AppsDatabaseFilter filter)
Returns an enumeration of the application IDs available.
|
| Modifier and Type | Method and Description |
|---|---|
Enumeration |
AppFilter.getAppPatterns()
Returns the AppPatterns in this AppFilter.
|
| Modifier and Type | Method and Description |
|---|---|
Enumeration |
Host.getVideoOutputPorts()
This method returns a java.util.Enumeration of
VideoOutputPort instances representing all video output ports
physically present on the device.
|
| Modifier and Type | Method and Description |
|---|---|
Enumeration |
HostSettings.getAudioOutputs()
Get the set of individually controllable audio outputs for this host.
|
Enumeration |
AudioOutputPort.getConnectedVideoOutputPorts()
Get the set of
VideoOutputPorts whose audio is controlled by
this AudioOutputPort instance. |
Enumeration |
DynamicVideoOutputConfiguration.getInputResolutions()
Get the set of input video resolutions for which a mapping to output configuration
is specified.
|
| Modifier and Type | Method and Description |
|---|---|
Enumeration |
Device.getCapabilities()
Returns capabilities of this device in
Enumeration. |
Enumeration |
NetList.getElements()
Returns all elements in this NetList in
Enumeration. |
Enumeration |
NetModule.getKeys()
Returns the property keys supported by this NetModule.
|
Enumeration |
Device.getKeys()
Returns all property keys supported by this device in
Enumeration. |
| Modifier and Type | Method and Description |
|---|---|
Enumeration |
ContentContainer.getEntries()
Gets an Enumeration over all entries in this ContentContainer, from local
cache only; does not cause network activity.
|
abstract Enumeration |
MetadataNode.getMetadata()
Gets an
Enumeration of all top-level metadata in this
MetadataNode. |
| Modifier and Type | Interface and Description |
|---|---|
interface |
ContentList
This interface represents a list of filtered ContentEntry objects.
|
| Modifier and Type | Method and Description |
|---|---|
Enumeration |
MediaAccessAuthorization.getDeniedElementaryStreams()
Returns the list of service components whose presentation has not been authorized
by the
. |
| Modifier and Type | Method and Description |
|---|---|
Enumeration |
AbstractService.getAppAttributes()
Returns a java.util.Enumeration of references to
org.ocap.application.OcapAppAttributes instances.
|
Enumeration |
AbstractService.getAppIDs()
Returns a java.util.Enumeration of references to
org.dvb.application.AppID instances.
|
Copyright © 2013 CableLabs. All rights reserved.