| Package | Description |
|---|---|
| java.awt |
Contains all of the classes for creating user
interfaces and for painting graphics and images.
|
| java.awt.event |
Provides interfaces and classes for dealing with different
types of events fired by AWT components.
|
| java.beans |
Contains classes for run-time Java Beans support.
|
| javax.media |
Provides media players, means of controlling playback and being notified of playback state changes.
|
| javax.net.ssl |
Provides classes for the secure socket package.
|
| javax.tv.media |
Provides controls and events for the management of real-time media
in a television environment.
|
| javax.tv.service |
Provides mechanisms for accessing the service information (SI) database
and APIs representing the SI elements it contains.
|
| javax.tv.service.guide |
Provides APIs to support electronic program guides (EPGs), including program
schedules, program events and program ratings.
|
| javax.tv.service.navigation |
Provides APIs to navigate through services and hierarchical service information.
|
| javax.tv.service.selection |
Provides a mechanism to select a Service for
presentation.
|
| javax.tv.service.transport |
Provides additional information about the transport mechanisms that
deliver the content the SI data describes.
|
| javax.tv.util |
Provides APIs for creating and managing timer events.
|
| org.davic.media |
Provides various extensions to the Java Media Framework for
the control of TV oriented audio / video content.
|
| org.davic.mpeg.sections |
Provides access to MPEG-2 section filtering.
|
| org.davic.net.tuning |
Provides access to tuning - MPEG multiplex selection.
|
| org.davic.resources |
Provides a framework for scarce resource management.
|
| org.dvb.application |
Provides access to lists of applications which are available
in this context and the ability to launch those applications.
|
| org.dvb.dsmcc |
Provides extended access to files carried in the broadcast
stream.
|
| org.dvb.event |
Provides access to user input events before they
are processed through the event mechanism of the java.awt package.
|
| org.dvb.media |
Provides DVB specific extensions to the Java Media Framework.
|
| org.dvb.net.rc |
Provides session management for bi-directional IP connections
which are session based from the point of view of an application.
|
| org.dvb.user |
Provides access to settings and preferences configured by the end-user.
|
| org.havi.ui.event |
Provides ability to receive HAVI UI events.
|
| org.ocap.dvr |
OCAP Specific extensions to the shared DVR API.
|
| org.ocap.environment |
Represents an environment that provides the context in which applications run.
|
| org.ocap.hn |
Provides representation of the main components of HN, such as servers, actions, action responses, and change listeners.
|
| org.ocap.media |
The org.ocap.media package is a collection of classes and interfaces for controlling access to various kinds of media components
|
| org.ocap.service |
The org.ocap.service package represents various aspects of a service.
|
| org.ocap.shared.dvr |
The shared DVR API for scheduling and managing recording requests.
|
| org.ocap.shared.media |
Extensions to JMF to support DVR playback.
|
| org.ocap.storage |
The org.ocap.storage package represents storage devices.
|
| org.ocap.system |
This API is used to access
system modules. |
| org.ocap.ui.event |
Extensions to HAVi User Interface Event classes, including OCAP
specific remote control events and multiscreen management events.
|
| Modifier and Type | Class and Description |
|---|---|
class |
AWTEvent
The root event class for all AWT events.
|
| Modifier and Type | Class and Description |
|---|---|
class |
ActionEvent
A semantic event which indicates that a component-defined action occured.
|
class |
AdjustmentEvent
The adjustment event emitted by Adjustable objects.
|
class |
ComponentEvent
A low-level event which indicates that a component moved, changed
size, or changed visibility (also, the root class for the other
component-level events).
|
class |
ContainerEvent
A low-level event which indicates that a container's contents
changed because a component was added or removed.
|
class |
FocusEvent
A low-level event which indicates that a Component has gained or lost the
input focus.
|
class |
InputEvent
The root event class for all component-level input events.
|
class |
InputMethodEvent
Input method events contain information about text that is being
composed using an input method.
|
class |
InvocationEvent
An event which executes the
run() method on a Runnable
when dispatched by the AWT event dispatcher thread. |
class |
ItemEvent
A semantic event which indicates that an item was selected or deselected.
|
class |
KeyEvent
An event which indicates that a keystroke occurred in a component.
|
class |
MouseEvent
An event which indicates that a mouse action occurred in a component.
|
class |
MouseWheelEvent
An event which indicates that the mouse wheel was rotated in a component.
|
class |
PaintEvent
The component-level paint event.
|
class |
TextEvent
A semantic event which indicates that an object's text changed.
|
class |
WindowEvent
A low-level event that indicates that a window has changed its status.
|
| Modifier and Type | Class and Description |
|---|---|
class |
PropertyChangeEvent
A "PropertyChange" event gets delivered whenever a bean changes a "bound"
or "constrained" property.
|
| Modifier and Type | Class and Description |
|---|---|
class |
CachingControlEvent
This event is generated by a
Controller that supports
the CachingControl interface. |
class |
ConnectionErrorEvent
A
ConnectionErrorEvent is posted when an error occurs within a DataSource
when obtaining data or communicating with a server. |
class |
ControllerClosedEvent
A
ControllerClosedEvent describes an event that is
generated when an a Controller is closed. |
class |
ControllerErrorEvent
A
ControllerErrorEvent describes an event that is
generated when an error condition occurs that will cause
a Controller to cease functioning. |
class |
ControllerEvent
ControllerEvent is the base class for events generated by
a Controller. |
class |
DataStarvedEvent
DataStarvedEvent indicates that a Controller has
lost data or has stopped receiving data altogether. |
class |
DeallocateEvent
A
DeallocateEvent is posted as an acknowledgement of the
invocation of the deallocate method. |
class |
DurationUpdateEvent
DurationUpdateEvent is posted by a Controller when its
duration changes. |
class |
EndOfMediaEvent
An
EndOfMediaEvent indicates that the Controller
has reached the end of its media and is stopping. |
class |
GainChangeEvent
A
GainChangeEvent is posted by a
GainControl when its state has been updated. |
class |
InternalErrorEvent
An
InternalErrorEvent indicates that a Controller failed
for implementation-specific reasons. |
class |
MediaTimeSetEvent
A
MediaTimeSetEvent is posted by a Controller when its
media-time has been set with the setMediaTime method. |
class |
PrefetchCompleteEvent
A
PrefetchCompleteEvent is posted when a Controller finishes
Prefetching. |
class |
RateChangeEvent
A
RateChangeEvent is a ControllerEvent that is posted when
a Controller's rate changes. |
class |
RealizeCompleteEvent
A
RealizeCompleteEvent is posted when a Controller finishes
Realizing. |
class |
ResourceUnavailableEvent
A
ResourceUnavailableEvent indicates that a Controller was
unable to allocate a resource that it requires for operation. |
class |
RestartingEvent
A
RestartingEvent indicates that a Controller has moved from
the Started state back to the Prefetching state
(a Stopped state) and intends to return to the
Started state when Prefetching is complete. |
class |
StartEvent
StartEvent is a TransitionEvent that indicates that
a Controller has entered the Started state. |
class |
StopAtTimeEvent
A
StopAtTimeEvent indicates that the Controller has stopped because it reached
its stop time. |
class |
StopByRequestEvent
A
StopByRequestEvent indicates that the Controller has stopped in response to a stop call. |
class |
StopEvent
StopEvent is a ControllerEvent that indicates that a Controller
has stopped. |
class |
StopTimeChangeEvent
A
StopTimeChangeEvent is generated by a Controller when its stop time
has changed. |
class |
TransitionEvent
TransitionEvent is a ControllerEvent that indicates
that a Controller has changed state. |
| Modifier and Type | Class and Description |
|---|---|
class |
HandshakeCompletedEvent
This event indicates that an SSL handshake completed on a given
SSL connection.
|
class |
SSLSessionBindingEvent
This event is propagated to a SSLSessionBindingListener.
|
| Modifier and Type | Class and Description |
|---|---|
class |
MediaSelectCARefusedEvent
MediaSelectCARefusedEvent is generated when a
media select operation fails due to lack of CA authorization. |
class |
MediaSelectEvent
MediaSelectEvent is the base class of events sent to
MediaSelectListener instances. |
class |
MediaSelectFailedEvent
MediaSelectFailedEvent notifies a
MediaSelectListener that a selection operation failed. |
class |
MediaSelectSucceededEvent
A
MediaSelectSucceededEvent notifies a
MediaSelectListener that a selection operation
succeeded. |
| Modifier and Type | Class and Description |
|---|---|
class |
SIChangeEvent
SIChangeEvent objects are sent to
SIChangeListener instances to signal detected changes
in the SI database. |
| Modifier and Type | Class and Description |
|---|---|
class |
ProgramScheduleEvent
A
ProgramScheduleEvent notifies an
ProgramScheduleListener of changes to program events
detected in a ProgramSchedule. |
| Modifier and Type | Class and Description |
|---|---|
class |
ServiceComponentChangeEvent
A
ServiceComponentChangeEvent notifies an
ServiceComponentChangeListener of changes to a
ServiceComponent detected in a
ServiceDetails. |
class |
ServiceDetailsSIChangeEvent
A
ServiceDetailsSIChangeEvent notifies an
SIChangeListener of changes to a
ServiceDetails. |
| Modifier and Type | Class and Description |
|---|---|
class |
AlternativeContentEvent
AlternativeContentEvent is generated to indicate that
"alternative" content is being presented during the presentation of
a service. |
class |
NormalContentEvent
NormalContentEvent is generated to indicate that the
normal content of a service is being presented. |
class |
PresentationTerminatedEvent
PresentationTerminatedEvent is generated when the
presentation of a service terminates. |
class |
SelectionFailedEvent
SelectionFailedEvent is generated when a service
selection operation fails. |
class |
ServiceContextDestroyedEvent
ServiceContextDestroyedEvent is generated when a
ServiceContext is destroyed via its
destroy() method. |
class |
ServiceContextEvent
The parent class for service context events.
|
| Modifier and Type | Class and Description |
|---|---|
class |
BouquetChangeEvent
A
BouquetChangeEvent notifies an
BouquetChangeListener of changes detected in a
BouquetCollection. |
class |
NetworkChangeEvent
A
NetworkChangeEvent notifies an
NetworkChangeListener of changes detected in a
NetworkCollection. |
class |
ServiceDetailsChangeEvent
A
ServiceDetailsChangeEvent notifies an
ServiceDetailsChangeListener of changes detected to a
ServiceDetails on a Transport. |
class |
TransportSIChangeEvent
An
TransportSIChangeEvent notifies an
SIChangeListener of changes detected to the SI on a
Transport. |
class |
TransportStreamChangeEvent
A
TransportStreamChangeEvent notifies an
TransportStreamChangeListener of changes detected in a
TransportStreamCollection. |
| Modifier and Type | Class and Description |
|---|---|
class |
TVTimerWentOffEvent
An event indicating that a timer specification has gone off.
|
| Modifier and Type | Class and Description |
|---|---|
class |
MediaPresentedEvent
Generated as soon as possible after new content is actually being presented to the user,
regardless of whether a state change has taken place in the player or not.
|
class |
MediaTimePositionChangedEvent
This event is generated whenever the media position is changed (when the invocation of the
setMediaPosition resulted in a change in the media position).
|
class |
ResourceReturnedEvent
Generated if a Player which was stopped due to having its resources withdrawn has had those
resources returned to it.
|
class |
ResourceWithdrawnEvent
Generated if a Player has some or all of the resources used withdrawn for some reason.
|
| Modifier and Type | Class and Description |
|---|---|
class |
EndOfFilteringEvent
This class is used to report the end of a filtering operation started by RingSectionFilter or
TableSectionFilter.
|
class |
FilterResourcesAvailableEvent
This event signals that enough section filter resources for the corresponding
section filter group were available at the time this event was generated.
|
class |
ForcedDisconnectedEvent
This class is used to report when a TransportStream which was available becomes no longer available or
if the section filter resources are removed from a connected SectionFilterGroup.
|
class |
IncompleteFilteringEvent
This class is used to report the end of a filtering operation started by TableSectionFilter.
|
class |
SectionAvailableEvent
This class is used to report a complete section being filtered.
|
class |
SectionFilterEvent
This class is the base class for Events in the section filter API.
|
class |
TimeOutEvent
This event is generated if section filter operations time out within the period specified by the
setTimeOut() method.
|
class |
VersionChangeDetectedEvent
This class is used by TableSectionFilter to report that a section has been encountered which has a different
version_number from earlier sections.
|
| Modifier and Type | Class and Description |
|---|---|
class |
NetworkInterfaceEvent
Base class for events related to network interfaces.
|
class |
NetworkInterfaceReleasedEvent
This event informs that the NetworkInterface returned by
the getNetworkInterface method has been released
by an application or other entity in the system.
|
class |
NetworkInterfaceReservedEvent
This event informs that a particular network interface has been reserved
by an application or other entity in the system.
|
class |
NetworkInterfaceTuningEvent
This event signals that a particular NetworkInterface has started
to tune to another transport stream.
|
class |
NetworkInterfaceTuningOverEvent
This event signals that a particular NetworkInterface has completed
its tuning action.
|
| Modifier and Type | Class and Description |
|---|---|
class |
ResourceStatusEvent
This class is the parent class for events reporting changes in the status
of resources.
|
| Modifier and Type | Class and Description |
|---|---|
class |
AppsDatabaseEvent
The
AppsDatabaseEvent class indicates either an entry
in the application database has changed, or so many changes have occurred. |
class |
AppStateChangeEvent
The
AppStateChangeEvent class indicates a state transition of
the application. |
| Modifier and Type | Class and Description |
|---|---|
class |
AsynchronousLoadingEvent
This class described an Object event which is used to notify the loading
of a DSMCC object.
|
class |
InsufficientResourcesEvent
This event is generated if there are insufficient resources available
to load a DSMCCObject.
|
class |
InvalidFormatEvent
This event is generated if the format of the data received is inconsistent.
|
class |
InvalidPathnameEvent
The pathname does not exist or the ServiceDomain has been detached.
|
class |
LoadingAbortedEvent
This event will be sent to the AsynchronousEventListener when an
asynchronous loading operation is aborted.
|
class |
MPEGDeliveryErrorEvent
An MPEGDeliveryErrorEvent indicates that an error (for instance, a time out or accessing the data would
require tuning) has occurred while loading data
from an MPEG Stream.
|
class |
NotEntitledEvent
This event is sent when an attempt to asynchronously load an object
has failed because the elementary stream carrying the object is scrambled
and the user is not entitled to access the content of the object.
|
class |
NPTDiscontinuityEvent
Sent when an MHP terminal detects a permanent discontinuity in NPT
as defined in the main body of the present document.
|
class |
NPTPresentEvent
Sent to listeners on a DSMCCStream object when NPT newly appears for that DSMCC stream
when it was not previously present.
|
class |
NPTRateChangeEvent
Sent only when the rate of an NPT time-base changes value.
|
class |
NPTRemovedEvent
Sent to listeners on a DSMCCStream object when NPT which was present for that DSMCC
stream is removed.
|
class |
NPTStatusEvent
Sent when an MHP terminal detects a change of status in the NPT of a stream.
|
class |
ObjectChangeEvent
This class describes an object change event that is used to monitor
the arrival of a new version of a
DSMCCObject. |
class |
ServerDeliveryErrorEvent
The local machine can not communicate with the server.
|
class |
ServiceXFRErrorEvent
The object requested is available in an alternate ServiceDomain.
|
class |
StreamEvent
This class describes a Stream event which is used to synchronize
an application with an MPEG Stream.
|
class |
SuccessEvent
This event indicates that the asynchronous loading was
successful.
|
| Modifier and Type | Class and Description |
|---|---|
class |
UserEvent
Represents a user event.
|
class |
UserEventAvailableEvent
This event is sent to the resource status event listeners when user input
events which had been exclusively reserved by an application are no longer
exclusively reserved.
|
class |
UserEventUnavailableEvent
This event is sent to the resource status event listeners when user input
events are exclusively reserved by an application.
|
| Modifier and Type | Class and Description |
|---|---|
class |
ActiveFormatDescriptionChangedEvent
Event signalling that the transmitted active format definition has changed
|
class |
AspectRatioChangedEvent
Event signalling that the aspect ratio of the transmitted video
has changed
|
class |
CAStopEvent
This event is generated whenever access to a service is withdrawn by the
CA system, e.g.
|
class |
DFCChangedEvent
Event signalling that the decoder format conversion being used
has changed
|
class |
NoComponentSelectedEvent
This event is generated whenever presentation of a stream stops because there
are no selected components to present.
|
class |
PresentationChangedEvent
This event is generated whenever the content being presented by a player changes for reasons outside the control of the application.
|
class |
ServiceRemovedEvent
This event is generated whenever access to a service stops because the
service concerned has been removed from the network.
|
class |
StopByResourceLossEvent
This event is generated whenever presentation of a stream stops because
the player has lost so many resources that it cannot continue.
|
class |
SubtitleAvailableEvent
Report that subtitles are available to be presented having been unavailable.
|
class |
SubtitleNotAvailableEvent
Inform an application that a subtitle stream has vanished from the network.
|
class |
SubtitleNotSelectedEvent
Report that subtitles are not now selected.
|
class |
SubtitleSelectedEvent
Report that subtitles are now selected.
|
class |
VideoFormatEvent
The base class for all other events relating to changes in video format
|
| Modifier and Type | Method and Description |
|---|---|
void |
SubtitleListener.subtitleStatusChanged(EventObject event)
Report a subtitle event has happened.
|
| Modifier and Type | Class and Description |
|---|---|
class |
ConnectionEstablishedEvent
ConnectionEstablishedEvent - An event generated after a connection is established
for a
ConnectionRCInterface. |
class |
ConnectionFailedEvent
ConnectionFailedEvent - An event generated after an attempt to setup a connection for a
ConnectionRCInterface fails. |
class |
ConnectionRCEvent
ConnectionRCEvent - the base class for events related to connection
oriented return channels.
|
class |
ConnectionTerminatedEvent
ConnectionTerminatedEvent - An event generated after a connected
ConnectionRCInterface is disconnected. |
class |
RCInterfaceReleasedEvent
This event informs an application that a
RCInterface
has been released by an application or other entity in the system. |
class |
RCInterfaceReservedEvent
This event informs an application that a
RCInterface
has been reserved by an application or other entity in the system. |
| Modifier and Type | Class and Description |
|---|---|
class |
UserPreferenceChangeEvent
This class defines the event sent to appropriate listeners when a user
preference has been changed.
|
| Modifier and Type | Class and Description |
|---|---|
class |
HActionEvent
An
HActionEvent event is used to
interact with a component implementing the HActionInputPreferred interface
as follows: |
class |
HAdjustmentEvent
An
HAdjustmentEvent event is used to
interact with a component implementing the HAdjustmentValue interface as follows: |
class |
HBackgroundImageEvent
This event informs an application that a loading operation for an
HBackgroundImage has
finished. |
class |
HFocusEvent
An
HFocusEvent event is used to
interact with a component implementing the HNavigationInputPreferred
interface as follows: |
class |
HItemEvent
An
HItemEvent event is used to
interact with a component implementing the HSelectionInputPreferred
interface as follows: |
class |
HKeyEvent
An
HKeyEvent event is used to
interact with a component implementing the HKeyboardInputPreferred interface
as follows: |
class |
HRcEvent
The remote control event class.
|
class |
HScreenConfigurationEvent
This event is sent to all registered
HScreenConfigurationListeners when an HScreenDevice modifies its
configuration. |
class |
HScreenDeviceReleasedEvent
This event informs an application that a device for this
HScreen has been released by an application
or other entity in the system. |
class |
HScreenDeviceReservedEvent
This event informs that a device on this
HScreen has been reserved by an application or other entity in the
system. |
class |
HScreenLocationModifiedEvent
This event is generated by the system when a component is moved
on-screen, rather than within a container.
|
class |
HTextEvent
An
HTextEvent event is used to
interact with a component implementing the HKeyboardInputPreferred
interface as follows: |
| Modifier and Type | Class and Description |
|---|---|
class |
RecordingAlertEvent
Event notifying that a scheduled recording is about to occur.
|
class |
TimeShiftEvent
The parent class for TimeShiftBuffer events.
|
| Modifier and Type | Class and Description |
|---|---|
class |
EnvironmentEvent
The
EnvironmentEvent class is used to notify
applications of events relating to environments. |
class |
EnvironmentStateChangedEvent
The
EnvironmentStateChangedEvent class indicates
the completion of a state transition of an environment. |
| Modifier and Type | Class and Description |
|---|---|
class |
ContentServerEvent
Event which will be sent to registered ContentServerListeners when
ContentEntrys have been added, changed or removed.
|
class |
DeviceEvent
Represents a Device Event.
|
class |
NetActionEvent
This class represents an event generated in response to an action.
|
class |
NetModuleEvent
Entity for NetModule Event.
|
| Modifier and Type | Class and Description |
|---|---|
class |
AlternativeMediaPresentationEvent
AlternativeMediaPresentationEvent is a JMF event generated
to indicate that an "alternative" content is presented during the media
presentation of a service. |
class |
ClosedCaptioningEvent
This class is an event to notify a change of a closed-captioning state.
|
class |
FilterResourceAvailableEvent
This event notifies an application that a VBIFilterGroup released
VBIFilters, i.e., another application may have an opportunity to reserve
new VBIFilters.
|
class |
MediaPresentationEvent
MediaPresentationEvent is a JMF event used as the parent
class of events indicating dynamic changes to the presentation of
media components. |
class |
NormalMediaPresentationEvent
NormalMediaPresentationEvent is a JMF event generated when the
normal media components of a service are presented. |
class |
S3DSignalingChangedEvent
This class represents an event that will be reported to an application with an
org.ocap.media.VideoFormatControl. |
| Modifier and Type | Class and Description |
|---|---|
class |
AlternativeContentErrorEvent
AlternativeContentErrorEvent is generated to indicate that
"alternative" content is being presented due to an error that
prevents the presentation of normal content as part of selection
of a service and during presentation of that selected service. |
class |
S3DAlternativeContentErrorEvent
S3DAlternativeContentErrorEvent is generated to indicate that
"alternative" content may be presenting due to a detected incompatibility
between the selected 3D content and the display device. |
| Modifier and Type | Class and Description |
|---|---|
class |
RecordingChangedEvent
Event used to notify listeners of changes in the list of recording requests maintained
by the RecordingManager.
|
class |
RecordingTerminatedEvent
An Event Notifying that recording has terminated for the
ServiceContext. |
| Modifier and Type | Class and Description |
|---|---|
class |
BeginningOfContentEvent
BeginningOfContentEvent is a RateChangeEvent that is posted when the rate change is
due to a rewind hitting the beginning of the media, or due to the time-shift
buffer reaching maximum depth.
|
class |
EndOfContentEvent
EndOfContentEvent is a RateChangeEvent that is posted when the rate change is
due to a forward playback hitting the end of the stored context, or a forward
playback catching up with the live recording point.
|
class |
EnteringLiveModeEvent
EnteringLiveModeEvent is a ControllerEvent that is posted when the
the controller has started playing back a live broadcast stream.
|
class |
LeavingLiveModeEvent
This event shall be generated during timeshift playback when the playback point
departs from the head of the buffer (where the content is the same as the
currently received content).
|
| Modifier and Type | Class and Description |
|---|---|
class |
StorageManagerEvent
Event sent to a
StorageManagerListener registered with the StorageManager that a StorageProxy was added, removed or changed
state. |
| Modifier and Type | Class and Description |
|---|---|
class |
EASEvent
This class represents an EAS event.
|
| Modifier and Type | Class and Description |
|---|---|
class |
OCRcEvent
The OCAP remote control event class.
|
Copyright © 2013 CableLabs. All rights reserved.