| Package | Description |
|---|---|
| java.awt |
Contains all of the classes for creating user
interfaces and for painting graphics and images.
|
| java.awt.image |
Provides classes for creating and modifying images.
|
| java.security |
Provides the classes and interfaces for the security framework.
|
| java.util |
Contains the collections framework, legacy collection classes, event model,
date and time facilities, internationalization, and miscellaneous utility
classes (a string tokenizer, a random-number generator, and a bit array).
|
| org.ocap.hardware.device |
Provides extension classes and interfaces related to accessing and controlling
certain device parameters that are normally controlled by a
device manufacturer specific application.
|
| org.ocap.hardware.frontpanel |
Represents various aspects of front panel displays .
|
| Modifier and Type | Field and Description |
|---|---|
protected Hashtable |
GridBagLayout.comptable
This hashtable maintains the association between
a component and its gridbag constraints.
|
| Modifier and Type | Method and Description |
|---|---|
void |
ReplicateScaleFilter.setProperties(Hashtable props)
Passes along the properties from the source object after adding a
property indicating the scale applied.
|
void |
PixelGrabber.setProperties(Hashtable props)
The setProperties method is part of the ImageConsumer API which
this class must implement to retrieve the pixels.
|
void |
ImageFilter.setProperties(Hashtable props)
Passes the properties from the source object along after adding a
property indicating the stream of filters it has been run through.
|
void |
ImageConsumer.setProperties(Hashtable props)
Sets the extensible list of properties associated with this image.
|
void |
CropImageFilter.setProperties(Hashtable props)
Passes along the properties from the source object after adding a
property indicating the cropped region.
|
| Constructor and Description |
|---|
MemoryImageSource(int w,
int h,
ColorModel cm,
byte[] pix,
int off,
int scan,
Hashtable props)
Constructs an ImageProducer object which uses an array of bytes
to produce data for an Image object.
|
MemoryImageSource(int w,
int h,
ColorModel cm,
int[] pix,
int off,
int scan,
Hashtable props)
Constructs an ImageProducer object which uses an array of integers
to produce data for an Image object.
|
MemoryImageSource(int w,
int h,
int[] pix,
int off,
int scan,
Hashtable props)
Constructs an ImageProducer object which uses an array of integers
in the default RGB ColorModel to produce data for an Image object.
|
| Modifier and Type | Class and Description |
|---|---|
class |
Provider
This class represents a "provider" for the
Java Security API, where a provider implements some or all parts of
Java Security.
|
| Modifier and Type | Class and Description |
|---|---|
class |
Properties
The
Properties class represents a persistent set of
properties. |
| Modifier and Type | Method and Description |
|---|---|
Hashtable |
VideoOutputSettings.getDisplayAttributes()
Get the set of attributes describing the display currently connected to
this
VideoOutputPort. |
| Modifier and Type | Method and Description |
|---|---|
Hashtable |
IndicatorDisplay.getIndicators()
Gets the set of reserved indicators.
|
Copyright © 2012 CableLabs. All Rights Reserved.