| Package | Description |
|---|---|
| java.security.cert |
Provides classes and interfaces for parsing and managing
certificates, certificate revocation lists (CRLs), and
certification paths.
|
| java.util |
Contains the collections framework, legacy collection classes, event model,
date and time facilities, internationalization, and miscellaneous utility
classes (a string tokenizer, a random-number generator, and a bit array).
|
| Modifier and Type | Method and Description |
|---|---|
Iterator |
CertificateFactorySpi.engineGetCertPathEncodings()
Returns an iteration of the
CertPath encodings supported
by this certificate factory, with the default encoding first. |
Iterator |
CertificateFactory.getCertPathEncodings()
Returns an iteration of the
CertPath encodings supported
by this certificate factory, with the default encoding first. |
abstract Iterator |
CertPath.getEncodings()
Returns an iteration of the encodings supported by this certification
path, with the default encoding first.
|
| Modifier and Type | Interface and Description |
|---|---|
interface |
ListIterator
An iterator for lists that allows the programmer
to traverse the list in either direction, modify
the list during iteration, and obtain the iterator's
current position in the list.
|
| Modifier and Type | Method and Description |
|---|---|
Iterator |
TreeSet.iterator()
Returns an iterator over the elements in this set.
|
Iterator |
Set.iterator()
Returns an iterator over the elements in this set.
|
Iterator |
List.iterator()
Returns an iterator over the elements in this list in proper sequence.
|
Iterator |
HashSet.iterator()
Returns an iterator over the elements in this set.
|
Iterator |
Collection.iterator()
Returns an iterator over the elements in this collection.
|
Iterator |
AbstractSequentialList.iterator()
Returns an iterator over the elements in this list (in proper
sequence).
|
Iterator |
AbstractList.iterator()
Returns an iterator over the elements in this list in proper
sequence.
|
abstract Iterator |
AbstractCollection.iterator()
Returns an iterator over the elements contained in this collection.
|
Copyright © 2013 CableLabs. All rights reserved.