| Package | Description |
|---|---|
| java.security.cert |
Provides classes and interfaces for parsing and managing
certificates, certificate revocation lists (CRLs), and
certification paths.
|
| java.util |
Contains the collections framework, legacy collection classes, event model,
date and time facilities, internationalization, and miscellaneous utility
classes (a string tokenizer, a random-number generator, and a bit array).
|
| Modifier and Type | Method and Description |
|---|---|
abstract List |
CertPath.getCertificates()
Returns the list of certificates in this certification path.
|
List |
X509Certificate.getExtendedKeyUsage()
Gets an unmodifiable list of Strings representing the OBJECT
IDENTIFIERs of the
ExtKeyUsageSyntax field of the
extended key usage extension, (OID = 2.5.29.37). |
| Modifier and Type | Method and Description |
|---|---|
CertPath |
CertificateFactorySpi.engineGenerateCertPath(List certificates)
Generates a
CertPath object and initializes it with
a List of Certificates. |
CertPath |
CertificateFactory.generateCertPath(List certificates)
Generates a
CertPath object and initializes it with
a List of Certificates. |
| Modifier and Type | Class and Description |
|---|---|
class |
AbstractList
This class provides a skeletal implementation of the List
interface to minimize the effort required to implement this interface
backed by a "random access" data store (such as an array).
|
class |
AbstractSequentialList
This class provides a skeletal implementation of the List
interface to minimize the effort required to implement this interface
backed by a "sequential access" data store (such as a linked list).
|
class |
ArrayList
Resizable-array implementation of the List interface.
|
class |
LinkedList
Linked list implementation of the List interface.
|
class |
Stack
The
Stack class represents a last-in-first-out
(LIFO) stack of objects. |
class |
Vector
The
Vector class implements a growable array of
objects. |
| Modifier and Type | Field and Description |
|---|---|
static List |
Collections.EMPTY_LIST
The empty list (immutable).
|
| Modifier and Type | Method and Description |
|---|---|
static List |
Arrays.asList(Object[] a)
Returns a fixed-size list backed by the specified array.
|
static List |
Collections.nCopies(int n,
Object o)
Returns an immutable list consisting of n copies of the
specified object.
|
static List |
Collections.singletonList(Object o)
Returns an immutable list containing only the specified object.
|
List |
Vector.subList(int fromIndex,
int toIndex)
Returns a view of the portion of this List between fromIndex,
inclusive, and toIndex, exclusive.
|
List |
List.subList(int fromIndex,
int toIndex)
Returns a view of the portion of this list between the specified
fromIndex, inclusive, and toIndex, exclusive.
|
List |
AbstractList.subList(int fromIndex,
int toIndex)
Returns a view of the portion of this list between fromIndex,
inclusive, and toIndex, exclusive.
|
static List |
Collections.synchronizedList(List list)
Returns a synchronized (thread-safe) list backed by the specified
list.
|
static List |
Collections.unmodifiableList(List list)
Returns an unmodifiable view of the specified list.
|
| Modifier and Type | Method and Description |
|---|---|
static int |
Collections.binarySearch(List list,
Object key)
Searches the specified list for the specified object using the binary
search algorithm.
|
static int |
Collections.binarySearch(List list,
Object key,
Comparator c)
Searches the specified list for the specified object using the binary
search algorithm.
|
static void |
Collections.copy(List dest,
List src)
Copies all of the elements from one list into another.
|
static void |
Collections.fill(List list,
Object obj)
Replaces all of the elements of the specified list with the specified
element.
|
static int |
Collections.indexOfSubList(List source,
List target)
Returns the starting position of the first occurrence of the specified
target list within the specified source list, or -1 if there is no
such occurrence.
|
static int |
Collections.lastIndexOfSubList(List source,
List target)
Returns the starting position of the last occurrence of the specified
target list within the specified source list, or -1 if there is no such
occurrence.
|
static boolean |
Collections.replaceAll(List list,
Object oldVal,
Object newVal)
Replaces all occurrences of one specified value in a list with another.
|
static void |
Collections.reverse(List list)
Reverses the order of the elements in the specified list.
|
static void |
Collections.rotate(List list,
int distance)
Rotates the elements in the specified list by the specified distance.
|
static void |
Collections.shuffle(List list)
Randomly permutes the specified list using a default source of
randomness.
|
static void |
Collections.shuffle(List list,
Random rnd)
Randomly permute the specified list using the specified source of
randomness.
|
static void |
Collections.sort(List list)
Sorts the specified list into ascending order, according to the
natural ordering of its elements.
|
static void |
Collections.sort(List list,
Comparator c)
Sorts the specified list according to the order induced by the
specified comparator.
|
static void |
Collections.swap(List list,
int i,
int j)
Swaps the elements at the specified positions in the specified list.
|
static List |
Collections.synchronizedList(List list)
Returns a synchronized (thread-safe) list backed by the specified
list.
|
static List |
Collections.unmodifiableList(List list)
Returns an unmodifiable view of the specified list.
|
Copyright © 2013 CableLabs. All rights reserved.