| Package | Description |
|---|---|
| java.util |
Contains the collections framework, legacy collection classes, event model,
date and time facilities, internationalization, and miscellaneous utility
classes (a string tokenizer, a random-number generator, and a bit array).
|
| Modifier and Type | Method and Description |
|---|---|
ListIterator |
List.listIterator()
Returns a list iterator of the elements in this list (in proper
sequence).
|
ListIterator |
AbstractList.listIterator()
Returns an iterator of the elements in this list (in proper sequence).
|
ListIterator |
List.listIterator(int index)
Returns a list iterator of the elements in this list (in proper
sequence), starting at the specified position in this list.
|
ListIterator |
LinkedList.listIterator(int index)
Returns a list-iterator of the elements in this list (in proper
sequence), starting at the specified position in the list.
|
abstract ListIterator |
AbstractSequentialList.listIterator(int index)
Returns a list iterator over the elements in this list (in proper
sequence).
|
ListIterator |
AbstractList.listIterator(int index)
Returns a list iterator of the elements in this list (in proper
sequence), starting at the specified position in the list.
|
Copyright © 2013 CableLabs. All rights reserved.