| Package | Description |
|---|---|
| java.awt |
Contains all of the classes for creating user
interfaces and for painting graphics and images.
|
| java.awt.im |
Provides classes and interfaces for the input method framework.
|
| java.lang |
Provides classes that are fundamental to the design of the Java
programming language.
|
| java.text |
Provides classes and interfaces for handling text, dates, numbers, and messages
in a manner independent of natural languages.
|
| java.util |
Contains the collections framework, legacy collection classes, event model,
date and time facilities, internationalization, and miscellaneous utility
classes (a string tokenizer, a random-number generator, and a bit array).
|
| Modifier and Type | Method and Description |
|---|---|
Locale |
Window.getLocale()
Gets the
Locale object that is associated
with this window, if the locale has been set. |
Locale |
Component.getLocale()
Gets the locale of this component.
|
| Modifier and Type | Method and Description |
|---|---|
abstract String[] |
GraphicsEnvironment.getAvailableFontFamilyNames(Locale l)
Returns an array containing the localized names of all font families
available in this
GraphicsEnvironment. |
void |
Component.setLocale(Locale l)
Sets the locale of this component.
|
| Modifier and Type | Method and Description |
|---|---|
Locale |
InputContext.getLocale()
Returns the current locale of the current input method or keyboard
layout.
|
| Modifier and Type | Method and Description |
|---|---|
boolean |
InputContext.selectInputMethod(Locale locale)
Attempts to select an input method or keyboard layout that
supports the given locale, and returns a value indicating whether such
an input method or keyboard layout has been successfully selected.
|
| Modifier and Type | Method and Description |
|---|---|
String |
String.toLowerCase(Locale locale)
Converts all of the characters in this
String to lower
case using the rules of the given Locale. |
String |
String.toUpperCase(Locale locale)
Converts all of the characters in this
String to upper
case using the rules of the given Locale. |
| Modifier and Type | Method and Description |
|---|---|
static Locale[] |
NumberFormat.getAvailableLocales()
Get the set of Locales for which NumberFormats are installed
|
static Locale[] |
DateFormat.getAvailableLocales()
Gets the set of locales for which DateFormats are installed.
|
static Locale[] |
Collator.getAvailableLocales()
Get the set of Locales for which Collators are installed.
|
static Locale[] |
BreakIterator.getAvailableLocales()
Get the set of Locales for which BreakIterators are installed
|
Locale |
MessageFormat.getLocale()
Gets the locale that's used when creating or comparing subformats.
|
| Modifier and Type | Method and Description |
|---|---|
static BreakIterator |
BreakIterator.getCharacterInstance(Locale where)
Create BreakIterator for character-breaks using specified locale
Returns an instance of a BreakIterator implementing character breaks.
|
static NumberFormat |
NumberFormat.getCurrencyInstance(Locale inLocale)
Returns a currency format for the specified locale.
|
static DateFormat |
DateFormat.getDateInstance(int style,
Locale aLocale)
Gets the date formatter with the given formatting style
for the given locale.
|
static DateFormat |
DateFormat.getDateTimeInstance(int dateStyle,
int timeStyle,
Locale aLocale)
Gets the date/time formatter with the given formatting styles
for the given locale.
|
static NumberFormat |
NumberFormat.getInstance(Locale inLocale)
Returns the default number format for the specified locale.
|
static Collator |
Collator.getInstance(Locale desiredLocale)
Gets the Collator for the desired locale.
|
static NumberFormat |
NumberFormat.getIntegerInstance(Locale inLocale)
Returns an integer number format for the specified locale.
|
static BreakIterator |
BreakIterator.getLineInstance(Locale where)
Create BreakIterator for line-breaks using specified locale.
|
static NumberFormat |
NumberFormat.getNumberInstance(Locale inLocale)
Returns a general-purpose number format for the specified locale.
|
static NumberFormat |
NumberFormat.getPercentInstance(Locale inLocale)
Returns a percentage format for the specified locale.
|
static BreakIterator |
BreakIterator.getSentenceInstance(Locale where)
Create BreakIterator for sentence-breaks using specified locale
Returns an instance of a BreakIterator implementing sentence breaks.
|
static DateFormat |
DateFormat.getTimeInstance(int style,
Locale aLocale)
Gets the time formatter with the given formatting style
for the given locale.
|
static BreakIterator |
BreakIterator.getWordInstance(Locale where)
Create BreakIterator for word-breaks using specified locale.
|
void |
MessageFormat.setLocale(Locale locale)
Sets the locale to be used when creating or comparing subformats.
|
| Constructor and Description |
|---|
DateFormatSymbols(Locale locale)
Construct a DateFormatSymbols object by loading format data from
resources for the given locale.
|
DecimalFormatSymbols(Locale locale)
Create a DecimalFormatSymbols object for the given locale.
|
MessageFormat(String pattern,
Locale locale)
Constructs a MessageFormat for the specified locale and
pattern.
|
SimpleDateFormat(String pattern,
Locale locale)
Constructs a
SimpleDateFormat using the given pattern and
the default date format symbols for the given locale. |
| Modifier and Type | Field and Description |
|---|---|
static Locale |
Locale.CANADA
Useful constant for country.
|
static Locale |
Locale.CANADA_FRENCH
Useful constant for country.
|
static Locale |
Locale.CHINA
Useful constant for country.
|
static Locale |
Locale.CHINESE
Useful constant for language.
|
static Locale |
Locale.ENGLISH
Useful constant for language.
|
static Locale |
Locale.FRANCE
Useful constant for country.
|
static Locale |
Locale.FRENCH
Useful constant for language.
|
static Locale |
Locale.GERMAN
Useful constant for language.
|
static Locale |
Locale.GERMANY
Useful constant for country.
|
static Locale |
Locale.ITALIAN
Useful constant for language.
|
static Locale |
Locale.ITALY
Useful constant for country.
|
static Locale |
Locale.JAPAN
Useful constant for country.
|
static Locale |
Locale.JAPANESE
Useful constant for language.
|
static Locale |
Locale.KOREA
Useful constant for country.
|
static Locale |
Locale.KOREAN
Useful constant for language.
|
static Locale |
Locale.PRC
Useful constant for country.
|
static Locale |
Locale.SIMPLIFIED_CHINESE
Useful constant for language.
|
static Locale |
Locale.TAIWAN
Useful constant for country.
|
static Locale |
Locale.TRADITIONAL_CHINESE
Useful constant for language.
|
static Locale |
Locale.UK
Useful constant for country.
|
static Locale |
Locale.US
Useful constant for country.
|
| Modifier and Type | Method and Description |
|---|---|
static Locale[] |
Locale.getAvailableLocales()
Returns a list of all installed locales.
|
static Locale[] |
Calendar.getAvailableLocales()
Gets the list of locales for which Calendars are installed.
|
static Locale |
Locale.getDefault()
Gets the current value of the default locale for this instance
of the Java Virtual Machine.
|
Locale |
ResourceBundle.getLocale()
Returns the locale of this resource bundle.
|
| Modifier and Type | Method and Description |
|---|---|
static ResourceBundle |
ResourceBundle.getBundle(String baseName,
Locale locale)
Gets a resource bundle using the specified base name and locale,
and the caller's class loader.
|
static ResourceBundle |
ResourceBundle.getBundle(String baseName,
Locale locale,
ClassLoader loader)
Gets a resource bundle using the specified base name, locale, and class loader.
|
String |
Locale.getDisplayCountry(Locale inLocale)
Returns a name for the locale's country that is appropriate for display to the
user.
|
String |
Locale.getDisplayLanguage(Locale inLocale)
Returns a name for the locale's language that is appropriate for display to the
user.
|
String |
TimeZone.getDisplayName(boolean daylight,
int style,
Locale locale)
Returns a name of this time zone suitable for presentation to the user
in the specified locale.
|
String |
TimeZone.getDisplayName(Locale locale)
Returns a name of this time zone suitable for presentation to the user
in the specified locale.
|
String |
Locale.getDisplayName(Locale inLocale)
Returns a name for the locale that is appropriate for display to the
user.
|
String |
Locale.getDisplayVariant(Locale inLocale)
Returns a name for the locale's variant code that is appropriate for display to the
user.
|
static Currency |
Currency.getInstance(Locale locale)
Returns the
Currency instance for the country of the
given locale. |
static Calendar |
Calendar.getInstance(Locale aLocale)
Gets a calendar using the default time zone and specified locale.
|
static Calendar |
Calendar.getInstance(TimeZone zone,
Locale aLocale)
Gets a calendar with the specified time zone and locale.
|
String |
Currency.getSymbol(Locale locale)
Gets the symbol of this currency for the specified locale.
|
static void |
Locale.setDefault(Locale newLocale)
Sets the default locale for this instance of the Java Virtual Machine.
|
| Constructor and Description |
|---|
Calendar(TimeZone zone,
Locale aLocale)
Constructs a calendar with the specified time zone and locale.
|
GregorianCalendar(Locale aLocale)
Constructs a GregorianCalendar based on the current time
in the default time zone with the given locale.
|
GregorianCalendar(TimeZone zone,
Locale aLocale)
Constructs a GregorianCalendar based on the current time
in the given time zone with the given locale.
|
Copyright © 2013 CableLabs. All rights reserved.