| Package | Description |
|---|---|
| java.awt |
Contains all of the classes for creating user
interfaces and for painting graphics and images.
|
| java.net |
Provides the classes for implementing networking applications.
|
| java.security |
Provides the classes and interfaces for the security framework.
|
| java.text |
Provides classes and interfaces for handling text, dates, numbers, and messages
in a manner independent of natural languages.
|
| java.util |
Contains the collections framework, legacy collection classes, event model,
date and time facilities, internationalization, and miscellaneous utility
classes (a string tokenizer, a random-number generator, and a bit array).
|
| java.util.jar |
Provides classes for reading and writing the JAR (Java ARchive) file
format, which is based on the standard ZIP file format with an
optional manifest file.
|
| org.apache.log4j.spi |
| Modifier and Type | Method and Description |
|---|---|
Map |
Font.getAttributes()
Returns a map of font attributes available in this
Font. |
| Modifier and Type | Method and Description |
|---|---|
static Font |
Font.getFont(Map attributes)
Returns a
Font appropriate to this attribute set. |
| Constructor and Description |
|---|
Font(Map attributes)
Creates a new
Font with the specified attributes. |
| Modifier and Type | Method and Description |
|---|---|
Map |
URLConnection.getHeaderFields()
Returns an unmodifiable Map of the header fields.
|
Map |
URLConnection.getRequestProperties()
Returns an unmodifiable Map of general request
properties for this connection.
|
| Modifier and Type | Class and Description |
|---|---|
class |
Provider
This class represents a "provider" for the
Java Security API, where a provider implements some or all parts of
Java Security.
|
| Modifier and Type | Method and Description |
|---|---|
static Provider[] |
Security.getProviders(Map filter)
Returns an array containing all installed providers that satisfy the specified
selection criteria, or null if no such providers have been installed.
|
void |
Provider.putAll(Map t)
Copies all of the mappings from the specified Map to this provider.
|
| Modifier and Type | Method and Description |
|---|---|
Map |
AttributedCharacterIterator.getAttributes()
Returns a map with the attributes defined on the current
character.
|
| Modifier and Type | Method and Description |
|---|---|
void |
AttributedString.addAttributes(Map attributes,
int beginIndex,
int endIndex)
Adds a set of attributes to a subrange of the string.
|
| Constructor and Description |
|---|
AttributedString(String text,
Map attributes)
Constructs an AttributedString instance with the given text and attributes.
|
| Modifier and Type | Interface and Description |
|---|---|
interface |
SortedMap
A map that further guarantees that it will be in ascending key order,
sorted according to the natural ordering of its keys (see the
Comparable interface), or by a comparator provided at sorted map
creation time.
|
| Modifier and Type | Class and Description |
|---|---|
class |
AbstractMap
This class provides a skeletal implementation of the Map
interface, to minimize the effort required to implement this interface.
|
class |
HashMap
Hash table based implementation of the Map interface.
|
class |
Hashtable
This class implements a hashtable, which maps keys to values.
|
class |
IdentityHashMap
This class implements the Map interface with a hash table, using
reference-equality in place of object-equality when comparing keys (and
values).
|
class |
LinkedHashMap
Hash table and linked list implementation of the Map interface,
with predictable iteration order.
|
class |
Properties
The
Properties class represents a persistent set of
properties. |
class |
TreeMap
Red-Black tree based implementation of the SortedMap interface.
|
class |
WeakHashMap
A hashtable-based Map implementation with weak keys.
|
| Modifier and Type | Field and Description |
|---|---|
static Map |
Collections.EMPTY_MAP
The empty map (immutable).
|
| Modifier and Type | Method and Description |
|---|---|
static Map |
Collections.singletonMap(Object key,
Object value)
Returns an immutable map, mapping only the specified key to the
specified value.
|
static Map |
Collections.synchronizedMap(Map m)
Returns a synchronized (thread-safe) map backed by the specified
map.
|
static Map |
Collections.unmodifiableMap(Map m)
Returns an unmodifiable view of the specified map.
|
| Modifier and Type | Method and Description |
|---|---|
void |
WeakHashMap.putAll(Map m)
Copies all of the mappings from the specified map to this map These
mappings will replace any mappings that this map had for any of the
keys currently in the specified map.
|
void |
TreeMap.putAll(Map map)
Copies all of the mappings from the specified map to this map.
|
void |
Map.putAll(Map t)
Copies all of the mappings from the specified map to this map
(optional operation).
|
void |
IdentityHashMap.putAll(Map t)
Copies all of the mappings from the specified map to this map
These mappings will replace any mappings that
this map had for any of the keys currently in the specified map.
|
void |
Hashtable.putAll(Map t)
Copies all of the mappings from the specified Map to this Hashtable
These mappings will replace any mappings that this Hashtable had for any
of the keys currently in the specified Map.
|
void |
HashMap.putAll(Map m)
Copies all of the mappings from the specified map to this map
These mappings will replace any mappings that
this map had for any of the keys currently in the specified map.
|
void |
AbstractMap.putAll(Map t)
Copies all of the mappings from the specified map to this map
(optional operation).
|
static Map |
Collections.synchronizedMap(Map m)
Returns a synchronized (thread-safe) map backed by the specified
map.
|
static Map |
Collections.unmodifiableMap(Map m)
Returns an unmodifiable view of the specified map.
|
| Constructor and Description |
|---|
HashMap(Map m)
Constructs a new HashMap with the same mappings as the
specified Map.
|
Hashtable(Map t)
Constructs a new hashtable with the same mappings as the given
Map.
|
IdentityHashMap(Map m)
Constructs a new identity hash map containing the keys-value mappings
in the specified map.
|
LinkedHashMap(Map m)
Constructs an insertion-ordered LinkedHashMap instance with
the same mappings as the specified map.
|
TreeMap(Map m)
Constructs a new map containing the same mappings as the given map,
sorted according to the keys' natural order.
|
WeakHashMap(Map t)
Constructs a new WeakHashMap with the same mappings as the
specified Map.
|
| Modifier and Type | Class and Description |
|---|---|
class |
Attributes
The Attributes class maps Manifest attribute names to associated string
values.
|
| Modifier and Type | Field and Description |
|---|---|
protected Map |
Attributes.map
The attribute name-value mappings.
|
| Modifier and Type | Method and Description |
|---|---|
Map |
Manifest.getEntries()
Returns a Map of the entries contained in this Manifest.
|
| Modifier and Type | Method and Description |
|---|---|
void |
Attributes.putAll(Map attr)
Copies all of the attribute name-value mappings from the specified
Attributes to this Map.
|
| Modifier and Type | Method and Description |
|---|---|
Map |
LoggingEvent.getProperties()
Returns the set of properties
for the event.
|
| Constructor and Description |
|---|
LoggingEvent(String fqnOfCategoryClass,
Category logger,
long timeStamp,
Level level,
Object message,
String threadName,
ThrowableInformation throwable,
String ndc,
LocationInfo info,
Map properties)
Create new instance.
|
Copyright © 2013 CableLabs. All rights reserved.