| Package | Description |
|---|---|
| java.lang |
Provides classes that are fundamental to the design of the Java
programming language.
|
| java.security |
Provides the classes and interfaces for the security framework.
|
| java.util |
Contains the collections framework, legacy collection classes, event model,
date and time facilities, internationalization, and miscellaneous utility
classes (a string tokenizer, a random-number generator, and a bit array).
|
| org.apache.log4j | |
| org.apache.log4j.config | |
| org.apache.log4j.xml | |
| org.ocap.application |
|
| org.ocap.hn |
Provides representation of the main components of HN, such as servers, actions, action responses, and change listeners.
|
| Modifier and Type | Method and Description |
|---|---|
static Properties |
System.getProperties()
Determines the current system properties.
|
| Modifier and Type | Method and Description |
|---|---|
static void |
System.setProperties(Properties props)
Sets the system properties to the
Properties
argument. |
| Modifier and Type | Class and Description |
|---|---|
class |
Provider
This class represents a "provider" for the
Java Security API, where a provider implements some or all parts of
Java Security.
|
| Modifier and Type | Field and Description |
|---|---|
protected Properties |
Properties.defaults
A property list that contains default values for any keys not
found in this property list.
|
| Constructor and Description |
|---|
Properties(Properties defaults)
Creates an empty property list with the specified defaults.
|
| Modifier and Type | Method and Description |
|---|---|
static void |
PropertyConfigurator.configure(Properties properties)
Read configuration options from
properties. |
void |
PropertyConfigurator.doConfigure(Properties properties,
LoggerRepository hierarchy)
Read configuration options from
properties. |
| Modifier and Type | Method and Description |
|---|---|
static void |
PropertySetter.setProperties(Object obj,
Properties properties,
String prefix)
Set the properties of an object passed as a parameter in one
go.
|
void |
PropertySetter.setProperties(Properties properties,
String prefix) |
| Modifier and Type | Method and Description |
|---|---|
static Object |
DOMConfigurator.parseElement(Element element,
Properties props,
Class expectedClass)
Creates an object and processes any nested param elements
but does not call activateOptions.
|
static void |
DOMConfigurator.setParameter(Element elem,
PropertySetter propSetter,
Properties props)
Sets a parameter based from configuration file content.
|
static String |
DOMConfigurator.subst(String value,
Properties props)
Substitutes property value for any references in expression.
|
| Modifier and Type | Method and Description |
|---|---|
Properties |
AppManagerProxy.getAddressingProperties()
Gets the addressing properties previously registered by the
registerAddressingProperties method. |
Properties |
AppManagerProxy.getSecurityAddressableAttributes()
Gets the security system Host addressable attributes queried by the
implementation.
|
| Modifier and Type | Method and Description |
|---|---|
void |
AppManagerProxy.registerAddressingProperties(Properties properties,
boolean persist,
Date expirationDate)
Registers addressing properties used for comparison when an
addressing_descriptor from an AIT or XAIT is evaluated.
|
| Constructor and Description |
|---|
PropertyFilter(Properties prop)
Constructs a PropertyFilter object.
|
Copyright © 2012 CableLabs. All Rights Reserved.