| Package | Description |
|---|---|
| java.math |
Provides classes for performing arbitrary-precision integer arithmetic
(BigInteger) and arbitrary-precision decimal arithmetic (BigDecimal).
|
| java.security |
Provides the classes and interfaces for the security framework.
|
| java.util |
Contains the collections framework, legacy collection classes, event model,
date and time facilities, internationalization, and miscellaneous utility
classes (a string tokenizer, a random-number generator, and a bit array).
|
| Constructor and Description |
|---|
BigInteger(int bitLength,
int certainty,
Random rnd)
Constructs a randomly generated positive BigInteger that is probably
prime, with the specified bitLength.
|
BigInteger(int numBits,
Random rnd)
Constructs a randomly generated BigInteger, uniformly distributed over
the range 0 to (2numBits - 1), inclusive.
|
| Modifier and Type | Class and Description |
|---|---|
class |
SecureRandom
This class provides a cryptographically strong pseudo-random number
generator (PRNG).
|
| Modifier and Type | Method and Description |
|---|---|
static void |
Collections.shuffle(List list,
Random rnd)
Randomly permute the specified list using the specified source of
randomness.
|
Copyright © 2013 CableLabs. All rights reserved.