| Package | Description |
|---|---|
| java.util |
Contains the collections framework, legacy collection classes, event model,
date and time facilities, internationalization, and miscellaneous utility
classes (a string tokenizer, a random-number generator, and a bit array).
|
| org.apache.log4j |
| Modifier and Type | Class and Description |
|---|---|
class |
ListResourceBundle
ListResourceBundle is an abstract subclass of
ResourceBundle that manages resources for a locale
in a convenient and easy to use list. |
class |
PropertyResourceBundle
PropertyResourceBundle is a concrete subclass of
ResourceBundle that manages resources for a locale
using a set of static strings from a property file. |
| Modifier and Type | Field and Description |
|---|---|
protected ResourceBundle |
ResourceBundle.parent
The parent bundle of this bundle.
|
| Modifier and Type | Method and Description |
|---|---|
static ResourceBundle |
ResourceBundle.getBundle(String baseName)
Gets a resource bundle using the specified base name, the default locale,
and the caller's class loader.
|
static ResourceBundle |
ResourceBundle.getBundle(String baseName,
Locale locale)
Gets a resource bundle using the specified base name and locale,
and the caller's class loader.
|
static ResourceBundle |
ResourceBundle.getBundle(String baseName,
Locale locale,
ClassLoader loader)
Gets a resource bundle using the specified base name, locale, and class loader.
|
| Modifier and Type | Method and Description |
|---|---|
protected void |
ResourceBundle.setParent(ResourceBundle parent)
Sets the parent bundle of this bundle.
|
| Modifier and Type | Field and Description |
|---|---|
protected ResourceBundle |
Category.resourceBundle |
| Modifier and Type | Method and Description |
|---|---|
ResourceBundle |
Category.getResourceBundle()
Return the inherited
ResourceBundle for this
category. |
| Modifier and Type | Method and Description |
|---|---|
void |
Category.setResourceBundle(ResourceBundle bundle)
Set the resource bundle to be used with localized logging
methods
#l7dlog(Priority,String,Throwable) and #l7dlog(Priority,String,Object[],Throwable). |
Copyright © 2013 CableLabs. All rights reserved.