| Package | Description |
|---|---|
| java.awt |
Contains all of the classes for creating user
interfaces and for painting graphics and images.
|
| java.security |
Provides the classes and interfaces for the security framework.
|
| java.security.cert |
Provides classes and interfaces for parsing and managing
certificates, certificate revocation lists (CRLs), and
certification paths.
|
| java.text |
Provides classes and interfaces for handling text, dates, numbers, and messages
in a manner independent of natural languages.
|
| java.util |
Contains the collections framework, legacy collection classes, event model,
date and time facilities, internationalization, and miscellaneous utility
classes (a string tokenizer, a random-number generator, and a bit array).
|
| java.util.jar |
Provides classes for reading and writing the JAR (Java ARchive) file
format, which is based on the standard ZIP file format with an
optional manifest file.
|
| org.apache.log4j.spi |
| Modifier and Type | Method and Description |
|---|---|
Set |
KeyboardFocusManager.getDefaultFocusTraversalKeys(int id)
Returns a Set of default focus traversal keys for a given traversal
operation.
|
Set |
Window.getFocusTraversalKeys(int id)
Gets a focus traversal key for this Window.
|
Set |
Container.getFocusTraversalKeys(int id)
Returns the Set of focus traversal keys for a given traversal operation
for this Container.
|
Set |
Component.getFocusTraversalKeys(int id)
Returns the Set of focus traversal keys for a given traversal operation
for this Component.
|
| Modifier and Type | Method and Description |
|---|---|
void |
KeyboardFocusManager.setDefaultFocusTraversalKeys(int id,
Set keystrokes)
Sets the default focus traversal keys for a given traversal operation.
|
void |
Container.setFocusTraversalKeys(int id,
Set keystrokes)
Sets the focus traversal keys for a given traversal operation for this
Container.
|
void |
Component.setFocusTraversalKeys(int id,
Set keystrokes)
Sets the focus traversal keys for a given traversal operation for this
Component.
|
| Modifier and Type | Method and Description |
|---|---|
Set |
Provider.entrySet()
Returns an unmodifiable Set view of the property entries contained
in this Provider.
|
static Set |
Security.getAlgorithms(String serviceName)
Returns a Set of Strings containing the names of all available
algorithms or types for the specified Java cryptographic service
(e.g., Signature, MessageDigest, Cipher, Mac, KeyStore).
|
Set |
Provider.keySet()
Returns an unmodifiable Set view of the property keys contained in
this provider.
|
| Modifier and Type | Method and Description |
|---|---|
Set |
X509Extension.getCriticalExtensionOIDs()
Gets a Set of the OID strings for the extension(s) marked
CRITICAL in the certificate/CRL managed by the object
implementing this interface.
|
Set |
X509Extension.getNonCriticalExtensionOIDs()
Gets a Set of the OID strings for the extension(s) marked
NON-CRITICAL in the certificate/CRL managed by the object
implementing this interface.
|
abstract Set |
X509CRL.getRevokedCertificates()
Gets all the entries from this CRL.
|
| Modifier and Type | Method and Description |
|---|---|
Set |
AttributedCharacterIterator.getAllAttributeKeys()
Returns the keys of all attributes defined on the
iterator's text range.
|
| Modifier and Type | Method and Description |
|---|---|
int |
AttributedCharacterIterator.getRunLimit(Set attributes)
Returns the index of the first character following the run
with respect to the given attributes containing the current character.
|
int |
AttributedCharacterIterator.getRunStart(Set attributes)
Returns the index of the first character of the run
with respect to the given attributes containing the current character.
|
| Modifier and Type | Interface and Description |
|---|---|
interface |
SortedSet
A set that further guarantees that its iterator will traverse the set in
ascending element order, sorted according to the natural ordering of
its elements (see Comparable), or by a Comparator provided at sorted set
creation time.
|
| Modifier and Type | Class and Description |
|---|---|
class |
AbstractSet
This class provides a skeletal implementation of the Set
interface to minimize the effort required to implement this
interface.
|
class |
HashSet
This class implements the Set interface, backed by a hash table
(actually a HashMap instance).
|
class |
LinkedHashSet
Hash table and linked list implementation of the Set interface,
with predictable iteration order.
|
class |
TreeSet
This class implements the Set interface, backed by a
TreeMap instance.
|
| Modifier and Type | Field and Description |
|---|---|
static Set |
Collections.EMPTY_SET
The empty set (immutable).
|
| Modifier and Type | Method and Description |
|---|---|
Set |
WeakHashMap.entrySet()
Returns a collection view of the mappings contained in this map.
|
Set |
TreeMap.entrySet()
Returns a set view of the mappings contained in this map.
|
Set |
Map.entrySet()
Returns a set view of the mappings contained in this map.
|
Set |
IdentityHashMap.entrySet()
Returns a set view of the mappings contained in this map.
|
Set |
Hashtable.entrySet()
Returns a Set view of the entries contained in this Hashtable.
|
Set |
HashMap.entrySet()
Returns a collection view of the mappings contained in this map.
|
abstract Set |
AbstractMap.entrySet()
Returns a set view of the mappings contained in this map.
|
Set |
WeakHashMap.keySet()
Returns a set view of the keys contained in this map.
|
Set |
TreeMap.keySet()
Returns a Set view of the keys contained in this map.
|
Set |
Map.keySet()
Returns a set view of the keys contained in this map.
|
Set |
IdentityHashMap.keySet()
Returns an identity-based set view of the keys contained in this map.
|
Set |
Hashtable.keySet()
Returns a Set view of the keys contained in this Hashtable.
|
Set |
HashMap.keySet()
Returns a set view of the keys contained in this map.
|
Set |
AbstractMap.keySet()
Returns a Set view of the keys contained in this map.
|
static Set |
Collections.singleton(Object o)
Returns an immutable set containing only the specified object.
|
static Set |
Collections.synchronizedSet(Set s)
Returns a synchronized (thread-safe) set backed by the specified
set.
|
static Set |
Collections.unmodifiableSet(Set s)
Returns an unmodifiable view of the specified set.
|
| Modifier and Type | Method and Description |
|---|---|
static Set |
Collections.synchronizedSet(Set s)
Returns a synchronized (thread-safe) set backed by the specified
set.
|
static Set |
Collections.unmodifiableSet(Set s)
Returns an unmodifiable view of the specified set.
|
| Modifier and Type | Method and Description |
|---|---|
Set |
Attributes.entrySet()
Returns a Collection view of the attribute name-value mappings
contained in this Map.
|
Set |
Attributes.keySet()
Returns a Set view of the attribute names (keys) contained in this Map.
|
| Modifier and Type | Method and Description |
|---|---|
Set |
LoggingEvent.getPropertyKeySet()
Returns the set of the key values in the properties
for the event.
|
Copyright © 2013 CableLabs. All rights reserved.