| Package | Description |
|---|---|
| java.util |
Contains the collections framework, legacy collection classes, event model,
date and time facilities, internationalization, and miscellaneous utility
classes (a string tokenizer, a random-number generator, and a bit array).
|
| Modifier and Type | Class and Description |
|---|---|
class |
TreeMap
Red-Black tree based implementation of the SortedMap interface.
|
| Modifier and Type | Method and Description |
|---|---|
SortedMap |
TreeMap.headMap(Object toKey)
Returns a view of the portion of this map whose keys are strictly less
than toKey.
|
SortedMap |
SortedMap.headMap(Object toKey)
Returns a view of the portion of this sorted map whose keys are
strictly less than toKey.
|
SortedMap |
TreeMap.subMap(Object fromKey,
Object toKey)
Returns a view of the portion of this map whose keys range from
fromKey, inclusive, to toKey, exclusive.
|
SortedMap |
SortedMap.subMap(Object fromKey,
Object toKey)
Returns a view of the portion of this sorted map whose keys range from
fromKey, inclusive, to toKey, exclusive.
|
static SortedMap |
Collections.synchronizedSortedMap(SortedMap m)
Returns a synchronized (thread-safe) sorted map backed by the specified
sorted map.
|
SortedMap |
TreeMap.tailMap(Object fromKey)
Returns a view of the portion of this map whose keys are greater than
or equal to fromKey.
|
SortedMap |
SortedMap.tailMap(Object fromKey)
Returns a view of the portion of this sorted map whose keys are greater
than or equal to fromKey.
|
static SortedMap |
Collections.unmodifiableSortedMap(SortedMap m)
Returns an unmodifiable view of the specified sorted map.
|
| Modifier and Type | Method and Description |
|---|---|
static SortedMap |
Collections.synchronizedSortedMap(SortedMap m)
Returns a synchronized (thread-safe) sorted map backed by the specified
sorted map.
|
static SortedMap |
Collections.unmodifiableSortedMap(SortedMap m)
Returns an unmodifiable view of the specified sorted map.
|
| Constructor and Description |
|---|
TreeMap(SortedMap m)
Constructs a new map containing the same mappings as the given
SortedMap, sorted according to the same ordering.
|
Copyright © 2013 CableLabs. All rights reserved.