| Package | Description |
|---|---|
| java.util |
Contains the collections framework, legacy collection classes, event model,
date and time facilities, internationalization, and miscellaneous utility
classes (a string tokenizer, a random-number generator, and a bit array).
|
| Modifier and Type | Class and Description |
|---|---|
class |
TreeSet
This class implements the Set interface, backed by a
TreeMap instance.
|
| Modifier and Type | Method and Description |
|---|---|
SortedSet |
TreeSet.headSet(Object toElement)
Returns a view of the portion of this set whose elements are strictly
less than toElement.
|
SortedSet |
SortedSet.headSet(Object toElement)
Returns a view of the portion of this sorted set whose elements are
strictly less than toElement.
|
SortedSet |
TreeSet.subSet(Object fromElement,
Object toElement)
Returns a view of the portion of this set whose elements range from
fromElement, inclusive, to toElement, exclusive.
|
SortedSet |
SortedSet.subSet(Object fromElement,
Object toElement)
Returns a view of the portion of this sorted set whose elements range
from fromElement, inclusive, to toElement, exclusive.
|
static SortedSet |
Collections.synchronizedSortedSet(SortedSet s)
Returns a synchronized (thread-safe) sorted set backed by the specified
sorted set.
|
SortedSet |
TreeSet.tailSet(Object fromElement)
Returns a view of the portion of this set whose elements are
greater than or equal to fromElement.
|
SortedSet |
SortedSet.tailSet(Object fromElement)
Returns a view of the portion of this sorted set whose elements are
greater than or equal to fromElement.
|
static SortedSet |
Collections.unmodifiableSortedSet(SortedSet s)
Returns an unmodifiable view of the specified sorted set.
|
| Modifier and Type | Method and Description |
|---|---|
static SortedSet |
Collections.synchronizedSortedSet(SortedSet s)
Returns a synchronized (thread-safe) sorted set backed by the specified
sorted set.
|
static SortedSet |
Collections.unmodifiableSortedSet(SortedSet s)
Returns an unmodifiable view of the specified sorted set.
|
| Constructor and Description |
|---|
TreeSet(SortedSet s)
Constructs a new set containing the same elements as the specified
sorted set, sorted according to the same ordering.
|
Copyright © 2012 CableLabs. All Rights Reserved.