| Package | Description |
|---|---|
| java.util |
Contains the collections framework, legacy collection classes, event model,
date and time facilities, internationalization, and miscellaneous utility
classes (a string tokenizer, a random-number generator, and a bit array).
|
| javax.media |
Provides media players, means of controlling playback and being notified of playback state changes.
|
| Modifier and Type | Class and Description |
|---|---|
class |
Stack
The
Stack class represents a last-in-first-out
(LIFO) stack of objects. |
| Modifier and Type | Method and Description |
|---|---|
static Vector |
PackageManager.getContentPrefixList()
Get the current value of the content package-prefix list.
|
static Vector |
Manager.getDataSourceList(String protocolName)
Build a list of
DataSource class names from the
protocol prefix-list and a protocol name. |
static Vector |
Manager.getHandlerClassList(String contentName)
Build a list of
Handler/CODE> classes from the
content-prefix-list and a content name. |
static Vector |
PackageManager.getProtocolPrefixList()
Get the current value of the protocol package-prefix list.
|
| Modifier and Type | Method and Description |
|---|---|
static void |
PackageManager.setContentPrefixList(Vector list)
Set the current value of the content package-prefix list.
|
static void |
PackageManager.setProtocolPrefixList(Vector list)
Set the protocol package-prefix list.
|
Copyright © 2013 CableLabs. All rights reserved.