public class Attributes extends Object implements Map, Cloneable
Manifest| Modifier and Type | Class and Description |
|---|---|
static class |
Attributes.Name
The Attributes.Name class represents an attribute name stored in
this Map.
|
| Modifier and Type | Field and Description |
|---|---|
protected Map |
map
The attribute name-value mappings.
|
| Constructor and Description |
|---|
Attributes()
Constructs a new, empty Attributes object with default size.
|
Attributes(Attributes attr)
Constructs a new Attributes object with the same attribute name-value
mappings as in the specified Attributes.
|
Attributes(int size)
Constructs a new, empty Attributes object with the specified
initial size.
|
| Modifier and Type | Method and Description |
|---|---|
void |
clear()
Removes all attributes from this Map.
|
Object |
clone()
Returns a copy of the Attributes, implemented as follows:
|
boolean |
containsKey(Object name)
Returns true if this Map contains the specified attribute name (key).
|
boolean |
containsValue(Object value)
Returns true if this Map maps one or more attribute names (keys)
to the specified value.
|
Set |
entrySet()
Returns a Collection view of the attribute name-value mappings
contained in this Map.
|
boolean |
equals(Object o)
Compares the specified Attributes object with this Map for equality.
|
Object |
get(Object name)
Returns the value of the specified attribute name, or null if the
attribute name was not found.
|
String |
getValue(Attributes.Name name)
Returns the value of the specified Attributes.Name, or null if the
attribute was not found.
|
String |
getValue(String name)
Returns the value of the specified attribute name, specified as
a string, or null if the attribute was not found.
|
int |
hashCode()
Returns the hash code value for this Map.
|
boolean |
isEmpty()
Returns true if this Map contains no attributes.
|
Set |
keySet()
Returns a Set view of the attribute names (keys) contained in this Map.
|
Object |
put(Object name,
Object value)
Associates the specified value with the specified attribute name
(key) in this Map.
|
void |
putAll(Map attr)
Copies all of the attribute name-value mappings from the specified
Attributes to this Map.
|
String |
putValue(String name,
String value)
Associates the specified value with the specified attribute name,
specified as a String.
|
Object |
remove(Object name)
Removes the attribute with the specified name (key) from this Map.
|
int |
size()
Returns the number of attributes in this Map.
|
Collection |
values()
Returns a Collection view of the attribute values contained in this Map.
|
protected Map map
public Attributes()
public Attributes(int size)
size - the initial number of attributespublic Attributes(Attributes attr)
attr - the specified Attributespublic Object get(Object name)
get in interface Mapname - the attribute nameMap.containsKey(Object)public String getValue(String name)
This method is defined as:
return (String)get(new Attributes.Name((String)name));
name - the attribute name as a stringIllegalArgumentException - if the attribute name is invalidpublic String getValue(Attributes.Name name)
This method is defined as:
return (String)get(name);
name - the Attributes.Name objectpublic Object put(Object name, Object value)
put in interface Mapname - the attribute namevalue - the attribute valueClassCastException - if the name is not a Attributes.Name
or the value is not a Stringpublic String putValue(String name, String value)
This method is defined as:
return (String)put(new Attributes.Name(name), value);
name - the attribute name as a stringvalue - the attribute valueIllegalArgumentException - if the attribute name is invalidpublic Object remove(Object name)
public boolean containsValue(Object value)
containsValue in interface Mapvalue - the attribute valuepublic boolean containsKey(Object name)
containsKey in interface Mapname - the attribute namepublic void putAll(Map attr)
putAll in interface Mapattr - the Attributes to be stored in this mapClassCastException - if attr is not an Attributespublic void clear()
public int size()
public boolean isEmpty()
public Set keySet()
public Collection values()
public Set entrySet()
public boolean equals(Object o)
public int hashCode()
public Object clone()
public Object clone() { return new Attributes(this); }
Since the attribute names and values are themselves immutable,
the Attributes returned can be safely modified without affecting
the original.Copyright © 2013 CableLabs. All rights reserved.