public class Manifest extends Object implements Cloneable
Attributes| Constructor and Description |
|---|
Manifest()
Constructs a new, empty Manifest.
|
Manifest(InputStream is)
Constructs a new Manifest from the specified input stream.
|
Manifest(Manifest man)
Constructs a new Manifest that is a copy of the specified Manifest.
|
| Modifier and Type | Method and Description |
|---|---|
void |
clear()
Clears the main Attributes as well as the entries in this Manifest.
|
Object |
clone()
Returns a shallow copy of this Manifest.
|
boolean |
equals(Object o)
Returns true if the specified Object is also a Manifest and has
the same main Attributes and entries.
|
Attributes |
getAttributes(String name)
Returns the Attributes for the specified entry name.
|
Map |
getEntries()
Returns a Map of the entries contained in this Manifest.
|
Attributes |
getMainAttributes()
Returns the main Attributes for the Manifest.
|
int |
hashCode()
Returns the hash code for this Manifest.
|
void |
read(InputStream is)
Reads the Manifest from the specified InputStream.
|
void |
write(OutputStream out)
Writes the Manifest to the specified OutputStream.
|
public Manifest()
public Manifest(InputStream is) throws IOException
is - the input stream containing manifest dataIOException - if an I/O error has occuredpublic Manifest(Manifest man)
man - the Manifest to copypublic Attributes getMainAttributes()
public Map getEntries()
public Attributes getAttributes(String name)
return (Attributes)getEntries().get(name)
name - entry namepublic void clear()
public void write(OutputStream out) throws IOException
out - the output streamIOException - if an I/O error has occurredgetMainAttributes()public void read(InputStream is) throws IOException
is - the input streamIOException - if an I/O error has occurredpublic boolean equals(Object o)
equals in class Objecto - the object to be comparedObject.hashCode(),
Hashtablepublic int hashCode()
hashCode in class ObjectObject.equals(java.lang.Object),
HashtableCopyright © 2012. All Rights Reserved.