See: Description
| Class | Description |
|---|---|
| Attributes |
The Attributes class maps Manifest attribute names to associated string
values.
|
| Attributes.Name |
The Attributes.Name class represents an attribute name stored in
this Map.
|
| JarEntry |
This class is used to represent a JAR file entry.
|
| JarFile |
The
JarFile class is used to read the contents of a JAR file
from any file that can be opened with java.io.RandomAccessFile. |
| JarInputStream |
The
JarInputStream class is used to read the contents of
a JAR file from any input stream. |
| JarOutputStream |
The
JarOutputStream class is used to write the contents
of a JAR file to any output stream. |
| Manifest |
The Manifest class is used to maintain Manifest entry names and their
associated Attributes.
|
| Exception | Description |
|---|---|
| JarException |
Signals that an error of some sort has occurred while reading from
or writing to a JAR file.
|
java.util.zip package is based on the following specifications:
Copyright © 2012. All Rights Reserved.