| Package | Description |
|---|---|
| java.net |
Provides the classes for implementing networking applications.
|
| java.util.jar |
Provides classes for reading and writing the JAR (Java ARchive) file
format, which is based on the standard ZIP file format with an
optional manifest file.
|
| Class and Description |
|---|
| Attributes
The Attributes class maps Manifest attribute names to associated string
values.
|
| JarEntry
This class is used to represent a JAR file entry.
|
| JarFile
The
JarFile class is used to read the contents of a JAR file
from any file that can be opened with java.io.RandomAccessFile. |
| Manifest
The Manifest class is used to maintain Manifest entry names and their
associated Attributes.
|
| Class and Description |
|---|
| Attributes
The Attributes class maps Manifest attribute names to associated string
values.
|
| Attributes.Name
The Attributes.Name class represents an attribute name stored in
this Map.
|
| JarEntry
This class is used to represent a JAR file entry.
|
| Manifest
The Manifest class is used to maintain Manifest entry names and their
associated Attributes.
|
Copyright © 2012. All Rights Reserved.