See: Description
| Interface | Description |
|---|---|
| Collection |
The root interface in the collection hierarchy.
|
| Comparator |
A comparison function, which imposes a total ordering on some
collection of objects.
|
| Enumeration |
An object that implements the Enumeration interface generates a
series of elements, one at a time.
|
| EventListener |
A tagging interface that all event listener interfaces must extend.
|
| Iterator |
An iterator over a collection.
|
| List |
An ordered collection (also known as a sequence).
|
| ListIterator |
An iterator for lists that allows the programmer
to traverse the list in either direction, modify
the list during iteration, and obtain the iterator's
current position in the list.
|
| Map |
An object that maps keys to values.
|
| Map.Entry |
A map entry (key-value pair).
|
| Observer |
A class can implement the
Observer interface when it
wants to be informed of changes in observable objects. |
| RandomAccess |
Marker interface used by List implementations to indicate that
they support fast (generally constant time) random access.
|
| Set |
A collection that contains no duplicate elements.
|
| SortedMap |
A map that further guarantees that it will be in ascending key order,
sorted according to the natural ordering of its keys (see the
Comparable interface), or by a comparator provided at sorted map
creation time.
|
| SortedSet |
A set that further guarantees that its iterator will traverse the set in
ascending element order, sorted according to the natural ordering of
its elements (see Comparable), or by a Comparator provided at sorted set
creation time.
|
| Class | Description |
|---|---|
| AbstractCollection |
This class provides a skeletal implementation of the Collection
interface, to minimize the effort required to implement this interface.
|
| AbstractList |
This class provides a skeletal implementation of the List
interface to minimize the effort required to implement this interface
backed by a "random access" data store (such as an array).
|
| AbstractMap |
This class provides a skeletal implementation of the Map
interface, to minimize the effort required to implement this interface.
|
| AbstractSequentialList |
This class provides a skeletal implementation of the List
interface to minimize the effort required to implement this interface
backed by a "sequential access" data store (such as a linked list).
|
| AbstractSet |
This class provides a skeletal implementation of the Set
interface to minimize the effort required to implement this
interface.
|
| ArrayList |
Resizable-array implementation of the List interface.
|
| Arrays |
This class contains various methods for manipulating arrays (such as
sorting and searching).
|
| BitSet |
This class implements a vector of bits that grows as needed.
|
| Calendar |
Calendar is an abstract base class for converting between
a Date object and a set of integer fields such as
YEAR, MONTH, DAY, HOUR,
and so on. |
| Collections |
This class consists exclusively of static methods that operate on or return
collections.
|
| Currency |
Represents a currency.
|
| Date |
The class
Date represents a specific instant
in time, with millisecond precision. |
| Dictionary |
The
Dictionary class is the abstract parent of any
class, such as Hashtable, which maps keys to values. |
| EventListenerProxy |
An abstract wrapper class for an EventListener class which associates a set
of additional parameters with the listener.
|
| EventObject |
The root class from which all event state objects shall be derived.
|
| GregorianCalendar |
GregorianCalendar is a concrete subclass of
Calendar
and provides the standard calendar used by most of the world. |
| HashMap |
Hash table based implementation of the Map interface.
|
| HashSet |
This class implements the Set interface, backed by a hash table
(actually a HashMap instance).
|
| Hashtable |
This class implements a hashtable, which maps keys to values.
|
| IdentityHashMap |
This class implements the Map interface with a hash table, using
reference-equality in place of object-equality when comparing keys (and
values).
|
| LinkedHashMap |
Hash table and linked list implementation of the Map interface,
with predictable iteration order.
|
| LinkedHashSet |
Hash table and linked list implementation of the Set interface,
with predictable iteration order.
|
| LinkedList |
Linked list implementation of the List interface.
|
| ListResourceBundle |
ListResourceBundle is an abstract subclass of
ResourceBundle that manages resources for a locale
in a convenient and easy to use list. |
| Locale |
A
Locale object represents a specific geographical, political,
or cultural region. |
| Observable |
This class represents an observable object, or "data"
in the model-view paradigm.
|
| Properties |
The
Properties class represents a persistent set of
properties. |
| PropertyPermission |
This class is for property permissions.
|
| PropertyResourceBundle |
PropertyResourceBundle is a concrete subclass of
ResourceBundle that manages resources for a locale
using a set of static strings from a property file. |
| Random |
An instance of this class is used to generate a stream of
pseudorandom numbers.
|
| ResourceBundle |
Resource bundles contain locale-specific objects.
|
| SimpleTimeZone |
SimpleTimeZone is a concrete subclass of TimeZone
that represents a time zone for use with a Gregorian calendar. |
| Stack |
The
Stack class represents a last-in-first-out
(LIFO) stack of objects. |
| StringTokenizer |
The string tokenizer class allows an application to break a
string into tokens.
|
| Timer |
A facility for threads to schedule tasks for future execution in a
background thread.
|
| TimerTask |
A task that can be scheduled for one-time or repeated execution by a Timer.
|
| TimeZone |
TimeZone represents a time zone offset, and also figures out daylight
savings. |
| TreeMap |
Red-Black tree based implementation of the SortedMap interface.
|
| TreeSet |
This class implements the Set interface, backed by a
TreeMap instance.
|
| Vector |
The
Vector class implements a growable array of
objects. |
| WeakHashMap |
A hashtable-based Map implementation with weak keys.
|
| Exception | Description |
|---|---|
| ConcurrentModificationException |
This exception may be thrown by methods that have detected concurrent
modification of an object when such modification is not permissible.
|
| EmptyStackException |
Thrown by methods in the
Stack class to indicate
that the stack is empty. |
| MissingResourceException |
Signals that a resource is missing.
|
| NoSuchElementException |
Thrown by the
nextElement method of an
Enumeration to indicate that there are no more
elements in the enumeration. |
| TooManyListenersException |
The
TooManyListenersException Exception is used as part of
the Java Event model to annotate and implement a unicast special case of
a multicast Event Source. |
Copyright © 2013 CableLabs. All rights reserved.