| Package | Description |
|---|---|
| java.util.zip |
Provides classes for reading and writing the standard ZIP and GZIP
file formats.
|
| Modifier and Type | Field and Description |
|---|---|
protected Deflater |
DeflaterOutputStream.def
Compressor for this stream.
|
| Constructor and Description |
|---|
DeflaterOutputStream(OutputStream out,
Deflater def)
Creates a new output stream with the specified compressor and
a default buffer size.
|
DeflaterOutputStream(OutputStream out,
Deflater def,
int size)
Creates a new output stream with the specified compressor and
buffer size.
|
Copyright © 2013 CableLabs. All rights reserved.