| Package | Description |
|---|---|
| java.util.jar |
Provides classes for reading and writing the JAR (Java ARchive) file
format, which is based on the standard ZIP file format with an
optional manifest file.
|
| Modifier and Type | Class and Description |
|---|---|
class |
JarFile
The
JarFile class is used to read the contents of a JAR file
from any file that can be opened with java.io.RandomAccessFile. |
Copyright © 2013 CableLabs. All rights reserved.