public abstract class ServerSocketFactory extends Object
Like socket factories, server Socket factory instances have methods used to create sockets. There is also an environment specific default server socket factory; frameworks will often use their own customized factory.
SocketFactory| Modifier | Constructor and Description |
|---|---|
protected |
ServerSocketFactory()
Creates a server socket factory.
|
| Modifier and Type | Method and Description |
|---|---|
ServerSocket |
createServerSocket()
Returns an unbound server socket.
|
abstract ServerSocket |
createServerSocket(int port)
Returns a server socket bound to the specified port.
|
abstract ServerSocket |
createServerSocket(int port,
int backlog)
Returns a server socket bound to the specified port, and uses the
specified connection backlog.
|
abstract ServerSocket |
createServerSocket(int port,
int backlog,
InetAddress ifAddress)
Returns a server socket bound to the specified port,
with a specified listen backlog and local IP.
|
static ServerSocketFactory |
getDefault()
Returns a copy of the environment's default socket factory.
|
protected ServerSocketFactory()
public static ServerSocketFactory getDefault()
ServerSocketFactorypublic ServerSocket createServerSocket() throws IOException
IOException - if the socket cannot be createdServerSocket.bind(java.net.SocketAddress),
ServerSocket.bind(java.net.SocketAddress, int),
ServerSocket.ServerSocket()public abstract ServerSocket createServerSocket(int port) throws IOException
port - the port to listen toServerSocketIOException - for networking errorsServerSocket.ServerSocket(int)public abstract ServerSocket createServerSocket(int port, int backlog) throws IOException
port - the port to listen tobacklog - how many connections are queuedServerSocketIOException - for networking errorsServerSocket.ServerSocket(int, int)public abstract ServerSocket createServerSocket(int port, int backlog, InetAddress ifAddress) throws IOException
ServerSocket that will only accept
connect requests to one
of its addresses. The socket is configured
with the socket options (such as accept timeout) given to this factory.port - the port to listen tobacklog - how many connections are queuedifAddress - the network interface address to useServerSocketIOException - for networking errorsServerSocket.ServerSocket(int, int, java.net.InetAddress)Copyright © 2013 CableLabs. All rights reserved.