| Package | Description |
|---|---|
| org.dvb.application |
Provides access to lists of applications which are available
in this context and the ability to launch those applications.
|
| Modifier and Type | Method and Description |
|---|---|
void |
AppsDatabaseEventListener.entryAdded(AppsDatabaseEvent evt)
The AppsDataBase has had an application entry added.
|
void |
AppsDatabaseEventListener.entryChanged(AppsDatabaseEvent evt)
The AppsDataBase has had an application entry changed.
|
void |
AppsDatabaseEventListener.entryRemoved(AppsDatabaseEvent evt)
The AppsDataBase has had an application entry removed.
|
void |
AppsDatabaseEventListener.newDatabase(AppsDatabaseEvent evt)
The AppsDataBase has radically changed.
|
Copyright © 2012. All Rights Reserved.