public final class GeneralPreference extends Preference
UserPreferenceManager.read method. The
standardized preferences are "User Language", "Parental Rating",
"User Name", "User Address", "User @", "Country Code", "Default Font Size".
When constructed, objects of this class are empty and have no values
defined. Values may be added using the add methods inherited from the
Preference class or by calling UserPreferenceManager.read.
The encodings of these standardized preferences are as follows.
javax.tv.service.guide.ContentRatingAdvisory.getDisplayText;
The standardized preference names in the present document shall only use such letters where the upper and lower case characters are recognized by the "EN.UK" locale.
| Constructor and Description |
|---|
GeneralPreference(String name)
Constructs a GeneralPreference object.
|
add, add, add, getFavourites, getMostFavourite, getName, getPosition, hasValue, remove, removeAll, setMostFavourite, toStringpublic GeneralPreference(String name) throws IllegalArgumentException
name - the general preference name.IllegalArgumentException - if the preference's name is not
supported.Copyright © 2012. All Rights Reserved.