public class AppPattern extends Object
AppFilter. An
AppPattern has the following attributes:
AppFilterHandler may use it for making a decision.
idPattern specifies an AppID group with a String: a
pair of ranges for Organization IDs and Application IDs. The syntax
is:
"oid1[-oid2][:aid1[-aid2]]"
oid1 and oid2 specify a range of
Organization IDs inclusive. Each of them must be a 32-bit value.
aid1 and aid2 specify a range of
Application IDs inclusive. Each of them must be a 16-bit value.
oid2 and aid2 must be greater than
oid1 and aid1, respectively.
oid2 is omitted, only oid1 is in
the range.
aid2 is omitted, only aid1 is in
the range.
aid1 and aid2 are omitted,
all Application IDs are in the range.
See AppFilter for the examples.
AppFilter,
AppFilterHandler| Modifier and Type | Field and Description |
|---|---|
static int |
ALLOW
When
AppFilter.accept finds a matching
AppPattern with this action, it returns
true. |
static int |
ASK
When
AppFilter.accept finds a matching
AppPattern with this action, it asks
AppFilterHandler.accept for the decision. |
static int |
DENY
When
AppFilter.accept finds a matching
AppPattern with this action, it returns
false. |
| Constructor and Description |
|---|
AppPattern(String idPattern,
int action,
int priority)
Constructs a new AppPattern with no expiration.
|
AppPattern(String idPattern,
int action,
int priority,
Date expirationTime,
Object info)
Constructs a new AppPattern with an expiration time and MSO
private information.
|
| Modifier and Type | Method and Description |
|---|---|
boolean |
equals(Object that)
Indicates whether some other object is "equal to" this one.
|
int |
getAction()
Returns the action associated with this AppPattern.
|
String |
getAppIDPattern()
Returns the pattern string that specifies a group of AppIDs.
|
Date |
getExpirationTime()
Returns the time for this AppPattern to expire or
null if it never expires. |
int |
getPriority()
Returns the search order priority of this AppPattern.
|
Object |
getPrivateInfo()
Returns MSO-private information of this AppPattern.
|
int |
hashCode()
Returns a hash code value for the object.
|
public static final int ALLOW
AppFilter.accept finds a matching
AppPattern with this action, it returns
true.public static final int DENY
AppFilter.accept finds a matching
AppPattern with this action, it returns
false.public static final int ASK
AppFilter.accept finds a matching
AppPattern with this action, it asks
AppFilterHandler.accept for the decision.public AppPattern(String idPattern, int action, int priority)
idPattern - a String to specify an AppID group.action - an action.priority - a search order priority.IllegalArgumentException - idPattern has a bad
format, action or priority is out of
range.public AppPattern(String idPattern, int action, int priority, Date expirationTime, Object info)
idPattern - a String to specify an AppID group.action - an action.priority - a search order priority.expirationTime - time for this AppPattern to expire. null
it never expires.info - MSO specific information. Can be null.IllegalArgumentException - idPattern has a bad
format, action or priority is out of
range.public String getAppIDPattern()
public int getAction()
public int getPriority()
public Date getExpirationTime()
null if it never expires.null.public Object getPrivateInfo()
public boolean equals(Object that)
This method does not factor in expirationTime or
info attributes, but does compare
idPattern, action, and
priority attributes.
equals in class Objectthat - the reference object with which to compare.true if this object is the same as the obj
argument; false otherwise.Object.hashCode(),
Hashtablepublic int hashCode()
Objectjava.util.Hashtable.
The general contract of hashCode is:
hashCode method on each of
the two objects must produce the same integer result.
Object.equals(java.lang.Object)
method, then calling the hashCode method on each of the
two objects must produce distinct integer results. However, the
programmer should be aware that producing distinct integer results
for unequal objects may improve the performance of hashtables.
As much as is reasonably practical, the hashCode method defined by class Object does return distinct integers for distinct objects. (This is typically implemented by converting the internal address of the object into an integer, but this implementation technique is not required by the JavaTM programming language.)
hashCode in class ObjectObject.equals(java.lang.Object),
HashtableCopyright © 2012. All Rights Reserved.