| Interface | Description |
|---|---|
| ContentHandlerFactory |
This interface defines a factory for content handlers.
|
| DatagramSocketImplFactory |
This interface defines a factory for datagram socket implementations.
|
| FileNameMap |
A simple interface which provides a mechanism to map
between a file name and a MIME type string.
|
| SocketImplFactory |
This interface defines a factory for socket implementations.
|
| SocketOptions |
Interface of methods to get/set socket options.
|
| URLStreamHandlerFactory |
This interface defines a factory for
URL stream
protocol handlers. |
| Class | Description |
|---|---|
| Authenticator |
The class Authenticator represents an object that knows how to obtain
authentication for a network connection.
|
| ContentHandler |
The abstract class
ContentHandler is the superclass
of all classes that read an Object from a
URLConnection. |
| DatagramPacket |
This class represents a datagram packet.
|
| DatagramSocket |
This class represents a socket for sending and receiving datagram packets.
|
| DatagramSocketImpl |
Abstract datagram and multicast socket implementation base class.
|
| HttpURLConnection |
A URLConnection with support for HTTP-specific features.
|
| Inet4Address |
This class represents an Internet Protocol version 4 (IPv4) address.
|
| Inet6Address |
This class represents an Internet Protocol version 6 (IPv6) address.
|
| InetAddress |
This class represents an Internet Protocol (IP) address.
|
| InetSocketAddress |
This class implements an IP Socket Address (IP address + port number)
It can also be a pair (hostname + port number), in which case an attempt
will be made to resolve the hostname.
|
| JarURLConnection |
A URL Connection to a Java ARchive (JAR) file or an entry in a JAR
file.
|
| MulticastSocket |
The multicast datagram socket class is useful for sending
and receiving IP multicast packets.
|
| NetPermission |
This class is for various network permissions.
|
| NetworkInterface |
This class represents a Network Interface made up of a name,
and a list of IP addresses assigned to this interface.
|
| PasswordAuthentication |
The class PasswordAuthentication is a data holder that is used by
Authenticator.
|
| ServerSocket |
This class implements server sockets.
|
| Socket |
This class implements client sockets (also called just
"sockets").
|
| SocketAddress |
This class represents a Socket Address with no protocol attachment.
|
| SocketImpl |
The abstract class
SocketImpl is a common superclass
of all classes that actually implement sockets. |
| SocketPermission |
This class represents access to a network via sockets.
|
| URI |
Represents a Uniform Resource Identifier (URI) reference.
|
| URL |
Class
URL represents a Uniform Resource
Locator, a pointer to a "resource" on the World
Wide Web. |
| URLClassLoader |
This class loader is used to load classes and resources from a search
path of URLs referring to both JAR files and directories.
|
| URLConnection |
The abstract class
URLConnection is the superclass
of all classes that represent a communications link between the
application and a URL. |
| URLDecoder |
Utility class for HTML form decoding.
|
| URLEncoder |
Utility class for HTML form encoding.
|
| URLStreamHandler |
The abstract class
URLStreamHandler is the common
superclass for all stream protocol handlers. |
| Exception | Description |
|---|---|
| BindException |
Signals that an error occurred while attempting to bind a
socket to a local address and port.
|
| ConnectException |
Signals that an error occurred while attempting to connect a
socket to a remote address and port.
|
| MalformedURLException |
Thrown to indicate that a malformed URL has occurred.
|
| NoRouteToHostException |
Signals that an error occurred while attempting to connect a
socket to a remote address and port.
|
| PortUnreachableException |
Signals that an ICMP Port Unreachable message has been
received on a connected datagram.
|
| ProtocolException |
Thrown to indicate that there is an error in the underlying
protocol, such as a TCP error.
|
| SocketException |
Thrown to indicate that there is an error in the underlying
protocol, such as a TCP error.
|
| SocketTimeoutException |
Signals that a timeout has occurred on a socket read or accept.
|
| UnknownHostException |
Thrown to indicate that the IP address of a host could not be determined.
|
| UnknownServiceException |
Thrown to indicate that an unknown service exception has
occurred.
|
| URISyntaxException |
Checked exception thrown to indicate that a string could not be parsed as a
URI reference.
|
Copyright © 2013 CableLabs. All rights reserved.