| Package | Description |
|---|---|
| java.lang |
Provides classes that are fundamental to the design of the Java
programming language.
|
| java.security |
Provides the classes and interfaces for the security framework.
|
| java.util |
Contains the collections framework, legacy collection classes, event model,
date and time facilities, internationalization, and miscellaneous utility
classes (a string tokenizer, a random-number generator, and a bit array).
|
| org.ocap.application |
|
| Modifier and Type | Method and Description |
|---|---|
static Properties |
System.getProperties()
Determines the current system properties.
|
| Modifier and Type | Method and Description |
|---|---|
static void |
System.setProperties(Properties props)
Sets the system properties to the
Properties
argument. |
| Modifier and Type | Class and Description |
|---|---|
class |
Provider
This class represents a "provider" for the
Java Security API, where a provider implements some or all parts of
Java Security.
|
| Modifier and Type | Field and Description |
|---|---|
protected Properties |
Properties.defaults
A property list that contains default values for any keys not
found in this property list.
|
| Constructor and Description |
|---|
Properties(Properties defaults)
Creates an empty property list with the specified defaults.
|
| Modifier and Type | Method and Description |
|---|---|
Properties |
AppManagerProxy.getAddressingProperties()
Gets the addressing properties previously registered by the
registerAddressingProperties method. |
Properties |
AppManagerProxy.getSecurityAddressableAttributes()
Gets the security system Host addressable attributes queried by the
implementation.
|
| Modifier and Type | Method and Description |
|---|---|
void |
AppManagerProxy.registerAddressingProperties(Properties properties,
boolean persist,
Date expirationDate)
Registers addressing properties used for comparison when an
addressing_descriptor from an AIT or XAIT is evaluated.
|
Copyright © 2012. All Rights Reserved.